@@ -1,10 +1,9 @@
-// -*- c-basic-offset: 4 -*-
 
 /*
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,7 +23,6 @@
 
 #include <set>
 #include "Segment.h"
-#include "Selection.h"
 
 namespace Rosegarden
 {
@@ -104,19 +102,11 @@ public:
     Segment *newSegment(const Segment *copyFrom);
 
     /**
-     * Add one or more new segments to the clipboard, containing
-     * copies of the events in copyFrom found between from and to.  If
-     * expandRepeats is true, include any events found in the
-     * repeating trail of the segment within this time.  (The
-     * clipboard retains ownership of the new segment(s).)
-     *
-     * This may insert more than one new segment, if it is required to
-     * insert a repeating section of an audio segment.  For this
-     * reason it does not return the inserted segment (even though in
-     * most situations it will only insert one).
+     * Add a new segment to the clipboard, containing copies of
+     * the events in copyFrom found between from and to.
+     * (The clipboard retains ownership of the new segment.)
      */
-    void newSegment(const Segment *copyFrom, timeT from, timeT to,
-		    bool expandRepeats);
+    Segment *newSegment(const Segment *copyFrom, timeT from, timeT to);
 
     /**
      * Add a new segment to the clipboard, containing copied of
@@ -124,78 +114,14 @@ public:
      */
     Segment *newSegment(const EventSelection *copyFrom);
 
-    /**
-     * Add a time signature selection to this clipboard, replacing any
-     * that already exists.
-     */
-    void setTimeSignatureSelection(const TimeSignatureSelection &);
-
-    bool hasTimeSignatureSelection() const { return m_haveTimeSigSelection; }
-
-    /**
-     * Remove any time signature selection from the clipboard.
-     */
-    void clearTimeSignatureSelection();
-
-    /**
-     * Retrieve any time signature selection found in the clipboard.
-     */
-    const TimeSignatureSelection &getTimeSignatureSelection() const;
-
-    /**
-     * Add a tempo selection to this clipboard, replacing any
-     * that already exists.
-     */
-    void setTempoSelection(const TempoSelection &);
-
-    bool hasTempoSelection() const { return m_haveTempoSelection; }
-
-    /**
-     * Remove any tempo selection from the clipboard.
-     */
-    void clearTempoSelection();
-
-    /**
-     * Retrieve any tempo selection found in the clipboard.
-     */
-    const TempoSelection &getTempoSelection() const;
-
     /**
      * Clear the current clipboard and re-fill it by copying from c.
      */
     void copyFrom(const Clipboard *c);
 
-    /**
-     * Get the earliest start time for anything in this clipboard,
-     * or the start of the nominal range if there is one.
-     */
-    timeT getBaseTime() const;
-
-    /**
-     * Set nominal start and end times for the range in the clipboard,
-     * if it is intended to cover a particular time range regardless
-     * of whether the data in it covers the full range or not.
-     */
-    void setNominalRange(timeT start, timeT end);
-
-    void clearNominalRange() { setNominalRange(0, 0); }
-
-    bool hasNominalRange() const { return m_nominalStart != m_nominalEnd; }
-    
-    void getNominalRange(timeT &start, timeT &end);
-
 private:
     segmentcontainer m_segments;
     bool m_partial;
-
-    TimeSignatureSelection m_timeSigSelection;
-    bool m_haveTimeSigSelection;
-
-    TempoSelection m_tempoSelection;
-    bool m_haveTempoSelection;
-
-    timeT m_nominalStart;
-    timeT m_nominalEnd;
 };
 
 }
