@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -33,19 +33,11 @@
 #include "Configuration.h"
 #include "XmlExportable.h"
 #include "ColourMap.h"
-#include "TriggerSegment.h"
 
 #include "Marker.h"
 
 namespace Rosegarden 
 {
-// We store tempo in quarter-notes per minute * 10^5 (hundred
-// thousandths of a quarter-note per minute).  This means the maximum
-// tempo in a 32-bit integer is about 21400 qpm.  We use a signed int
-// for compatibility with the Event integer type -- but note that we
-// use 0 (rather than -1) to indicate "tempo not set", by convention
-// (though see usage of target tempo in e.g. addTempoAtTime).
-typedef int tempoT;
 
 class Quantizer;
 class BasicQuantizer;
@@ -74,19 +66,10 @@ public:
 
     typedef std::map<TrackId, Track*> trackcontainer;
     typedef trackcontainer::iterator trackiterator;
-    typedef trackcontainer::const_iterator trackconstiterator;
 
     typedef std::vector<Marker*> markercontainer;
-    typedef markercontainer::iterator markeriterator;
-    typedef markercontainer::const_iterator markerconstiterator;
-
-    typedef std::set<TriggerSegmentRec *, TriggerSegmentCmp> triggersegmentcontainer;
-    typedef triggersegmentcontainer::iterator triggersegmentcontaineriterator;
-    typedef triggersegmentcontainer::const_iterator triggersegmentcontainerconstiterator;
-
-    typedef std::set<TrackId> recordtrackcontainer;
-    typedef recordtrackcontainer::iterator recordtrackiterator;
-    typedef recordtrackcontainer::const_iterator recordtrackconstiterator;
+    typedef std::vector<Marker*>::iterator markeriterator;
+    typedef std::vector<Marker*>::const_iterator markerconstiterator;
 
     Composition();
     virtual ~Composition();
@@ -121,13 +104,10 @@ public:
     //////
     //
     //  INSTRUMENT & TRACK
+    Track* getTrackById(TrackId track);
 
-    Track* getTrackById(TrackId track) const;
-
-    Track* getTrackByPosition(int position) const;
+    Track* getTrackByPosition(int position);
  
-    int getTrackPositionById(TrackId track) const; // -1 if not found
-
     trackcontainer& getTracks() { return m_tracks; }
  
     const trackcontainer& getTracks() const { return m_tracks; }
@@ -139,9 +119,9 @@ public:
 
     TrackId getMaxTrackId() const;
 
-    const recordtrackcontainer &getRecordTracks() const { return m_recordTracks; }
-    void setTrackRecording(TrackId track, bool recording);
-    bool isTrackRecording(TrackId track) const;
+    TrackId getRecordTrack() const { return m_recordTrack; }
+
+    void setRecordTrack(TrackId recordTrack) { m_recordTrack = recordTrack; }
 
     // Get and set Solo Track
     //
@@ -293,78 +273,6 @@ public:
     bool weakDetachSegment(Segment*);
 
 
-    //////
-    //
-    //  TRIGGER SEGMENTS
-
-    triggersegmentcontainer &getTriggerSegments() { return m_triggerSegments; }
-    const triggersegmentcontainer &getTriggerSegments() const { return m_triggerSegments; }
-
-    /**
-     * Add a new trigger Segment with a given base pitch and base
-     * velocity, and return its record.  If pitch or velocity is -1,
-     * it will be taken from the first note event in the segment
-     */
-    TriggerSegmentRec *addTriggerSegment(Segment *, int pitch = -1, int velocity = -1);
-
-    /**
-     * Delete a trigger Segment.
-     */
-    void deleteTriggerSegment(TriggerSegmentId);
-
-    /**
-     * Detach a trigger Segment from the Composition.
-     */
-    void detachTriggerSegment(TriggerSegmentId);
-
-    /**
-     * Delete all trigger Segments.
-     */
-    void clearTriggerSegments();
-    
-    /**
-     * Return the TriggerSegmentId for the given Segment, or -1 if it is
-     * not a trigger Segment.
-     */
-    int getTriggerSegmentId(Segment *);
-    
-    /**
-     * Return the Segment for a given TriggerSegmentId
-     */
-    Segment *getTriggerSegment(TriggerSegmentId);
-
-    /**
-     * Return the TriggerSegmentRec (with Segment, base pitch, base velocity,
-     * references etc) for a given TriggerSegmentId
-     */
-    TriggerSegmentRec *getTriggerSegmentRec(TriggerSegmentId);
-
-    /**
-     * Add a new trigger Segment with a given ID and base pitch and
-     * velocity.  Fails and returns 0 if the ID is already in use.
-     * This is intended for use from file load or from undo/redo.
-     */
-    TriggerSegmentRec *addTriggerSegment(Segment *, TriggerSegmentId,
-					 int basePitch = -1, int baseVelocity = -1);
-
-    /**
-     * Get the ID of the next trigger segment that will be inserted.
-     */
-    TriggerSegmentId getNextTriggerSegmentId() const;
-
-    /**
-     * Specify the next trigger ID.  This is intended for use from file
-     * load only.  Do not use this function unless you know what you're
-     * doing.
-     */
-    void setNextTriggerSegmentId(TriggerSegmentId);
-
-    /**
-     * Update the trigger segment references for all trigger segments.
-     * To be called after file load.
-     */
-    void updateTriggerSegmentReferences();
-
 
     //////
     //
@@ -477,7 +385,7 @@ public:
 
     /**
      * Return the index of the last time signature change before
-     * or at the given time, in a range suitable for passing to 
+     * the given time, in a range suitable for passing to 
      * getTimeSignatureChange.  Return -1 if there has been no
      * time signature by this time.
      */
@@ -501,44 +409,37 @@ public:
     //  TEMPO
 
     /**
-     * Return the (approximate) number of quarters per minute for a
-     * given tempo.
+     * Return the tempo in effect at time t, in quarters per minute.
      */
-    static double getTempoQpm(tempoT tempo) { return double(tempo) / 100000.0; }
-    static tempoT getTempoForQpm(double qpm) { return tempoT(qpm * 100000 + 0.01); }
-
-    /**
-     * Return the tempo in effect at time t.  If a ramped tempo change
-     * is in effect at the time, it will be properly interpolated and
-     * a computed value returned.
-     */
-    tempoT getTempoAtTime(timeT t) const;
+    double getTempoAt(timeT t) const;
 
     /**
      * Return the tempo in effect at the current playback position.
      */
-    tempoT getCurrentTempo() const { return getTempoAtTime(getPosition()); }
+    double getTempo() const { return getTempoAt(getPosition()); }
 
     /**
      * Set a default tempo for the composition.  This will be
      * overridden by any tempo events encountered during playback.
      */
-    void setCompositionDefaultTempo(tempoT tempo) { m_defaultTempo = tempo; }
-    tempoT getCompositionDefaultTempo() const { return m_defaultTempo; }
+    void setDefaultTempo(double tempo) { m_defaultTempo = tempo; }
+    double getDefaultTempo() const { return m_defaultTempo; }
 
     /**
-     * Add a tempo-change event at the given time, to the given tempo.
-     * Removes any existing tempo event at that time.  Returns the
-     * index of the new tempo event in a form suitable for passing to
-     * removeTempoChange.
-     *
-     * If targetTempo == -1, adds a single constant tempo change.
-     * If targetTempo == 0, adds a smooth tempo ramp from this tempo
-     * change to the next.
-     * If targetTempo > 0, adds a smooth tempo ramp from this tempo
-     * ending at targetTempo at the time of the next tempo change.
+     * Add a tempo-change event at the given time, to the given
+     * tempo (in quarters per minute).  Removes any existing tempo
+     * event at that time.  Returns the index of the new tempo
+     * event in a form suitable for passing to removeTempoChange.
      */
-    int addTempoAtTime(timeT time, tempoT tempo, tempoT targetTempo = -1);
+    int addTempo(timeT time, double tempo);
+
+    /**
+     * Add a tempo-change event at the given time, to the given
+     * tempo (in quarters per hour).  Removes any existing tempo
+     * event at that time.  Returns the index of the new tempo
+     * event in a form suitable for passing to removeTempoChange.
+     */
+    int addRawTempo(timeT time, int tempo);
 
     /**
      * Return the number of tempo changes in the composition.
@@ -547,47 +448,23 @@ public:
 
     /**
      * Return the index of the last tempo change before the given
-     * time, in a range suitable for passing to getTempoChange.
+     * time, in a range suitable for passing to getRawTempoChange.
      * Return -1 if the default tempo is in effect at this time.
      */
     int getTempoChangeNumberAt(timeT time) const;
 
     /**
      * Return the absolute time of and tempo introduced by tempo
-     * change number n.  If the tempo is ramped, this returns only
-     * the starting tempo.
+     * change number n, in quarters per hour (this is the value that's
+     * actually stored)
      */
-    std::pair<timeT, tempoT> getTempoChange(int n) const;
-
-    /**
-     * Return whether the tempo change number n is a ramped tempo or
-     * not, and if it is, return the target tempo for the ramp.
-     * 
-     * If calculate is false, return a target tempo of 0 if the tempo
-     * change is defined to ramp to the following tempo.  If calculate
-     * is true, return a target tempo equal to the following tempo in
-     * this case.
-     */
-    std::pair<bool, tempoT> getTempoRamping(int n, bool calculate = true) const;
+    std::pair<timeT, long> getRawTempoChange(int n) const;
 
     /**
      * Remove tempo change event n from the composition.
      */
     void removeTempoChange(int n);
 
-    /**
-     * Get the slowest assigned tempo in the composition.
-     */
-    tempoT getMinTempo() const {
-	return ((m_minTempo != 0) ? m_minTempo : m_defaultTempo);
-    }
-
-    /**
-     * Get the fastest assigned tempo in the composition.
-     */
-    tempoT getMaxTempo() const { 
-	return ((m_maxTempo != 0) ? m_maxTempo : m_defaultTempo);
-    }
 
 
     //////
@@ -713,6 +590,9 @@ public:
     //
     virtual std::string toXmlString();
 
+    static RealTime getTempoTimestamp(const Event *e);
+    static void setTempoTimestamp(Event *e, RealTime r);
+
     // Who's making this racket?
     //
     Configuration &getMetadata() {
@@ -743,7 +623,6 @@ public:
 
     // Colour stuff
     ColourMap& getSegmentColourMap() { return m_segmentColourMap; }
-    const ColourMap& getSegmentColourMap() const { return m_segmentColourMap; }
     void setSegmentColourMap(Rosegarden::ColourMap &newmap);
 
     // General colourmap for non-segments
@@ -751,7 +630,6 @@ public:
     ColourMap& getGeneralColourMap() { return m_generalColourMap; }
     void setGeneralColourMap(Rosegarden::ColourMap &newmap);
 
-
     //////
     //
     // QUANTIZERS
@@ -796,15 +674,11 @@ public:
     void    addObserver(CompositionObserver *obs) { m_observers.push_back(obs); }
     void removeObserver(CompositionObserver *obs) { m_observers.remove(obs); }
 
-    //////
-    // DEBUG FACILITIES
-    void dump(std::ostream&, bool full=false) const;
-    
+
 protected:
 
     static const std::string TempoEventType; 
-    static const PropertyName TempoProperty;
-    static const PropertyName TargetTempoProperty;
+    static const PropertyName TempoProperty; // stored in quarters per hour
 
     static const PropertyName NoAbsoluteTimeProperty;
     static const PropertyName BarNumberProperty;
@@ -837,15 +711,14 @@ protected:
     void checkSelectedAndRecordTracks();
     TrackId getClosestValidTrackId(TrackId id) const;
     
-
     //--------------- Data members ---------------------------------
     //
     trackcontainer                    m_tracks;
     segmentcontainer                  m_segments;
 
-    // The tracks we are armed for record on
+    // The track we can record on
     //
-    recordtrackcontainer              m_recordTracks;
+    Rosegarden::TrackId               m_recordTrack;
 
     // Are we soloing and if so which Track?
     //
@@ -908,19 +781,8 @@ protected:
     /// affects m_tempoSegment
     void calculateTempoTimestamps() const;
     mutable bool m_tempoTimestampsNeedCalculating;
-    RealTime time2RealTime(timeT time, tempoT tempo) const;
-    RealTime time2RealTime(timeT time, tempoT tempo,
-			   timeT targetTempoTime, tempoT targetTempo) const;
-    timeT realTime2Time(RealTime rtime, tempoT tempo) const;
-    timeT realTime2Time(RealTime rtime, tempoT tempo,
-			timeT targetTempoTime, tempoT targetTempo) const;
-
-    bool getTempoTarget(ReferenceSegment::const_iterator i,
-			tempoT &target,
-			timeT &targetTime) const;
-
-    static RealTime getTempoTimestamp(const Event *e);
-    static void setTempoTimestamp(Event *e, RealTime r);
+    RealTime time2RealTime(timeT time, double tempo) const;
+    timeT realTime2Time(RealTime rtime, double tempo) const;
 
     typedef std::list<CompositionObserver *> ObserverSet;
     ObserverSet m_observers;
@@ -928,29 +790,22 @@ protected:
     void notifySegmentAdded(Segment *) const;
     void notifySegmentRemoved(Segment *) const;
     void notifySegmentRepeatChanged(Segment *, bool) const;
-    void notifySegmentRepeatEndChanged(Segment *, timeT) const;
     void notifySegmentEventsTimingChanged(Segment *s, timeT delay, RealTime rtDelay) const;
     void notifySegmentTransposeChanged(Segment *s, int transpose) const;
-    void notifySegmentTrackChanged(Segment *s, TrackId oldId, TrackId newId) const;
-    void notifySegmentEndMarkerChange(Segment *s, bool shorten) const;
+    void notifySegmentTrackChanged(Segment *s, TrackId id) const;
     void notifyEndMarkerChange(bool shorten) const;
     void notifyTrackChanged(Track*) const;
-    void notifyTrackDeleted(TrackId) const;
     void notifyMetronomeChanged() const;
     void notifyTimeSignatureChanged() const;
     void notifySoloChanged() const;
     void notifyTempoChanged() const;
     void notifySourceDeletion() const;
 
-    void updateExtremeTempos();
-
     BasicQuantizer                   *m_basicQuantizer;
     NotationQuantizer                *m_notationQuantizer;
 
     timeT                             m_position;
-    tempoT                            m_defaultTempo;
-    tempoT                            m_minTempo; // cached from tempo segment
-    tempoT                            m_maxTempo; // cached from tempo segment
+    double                            m_defaultTempo;
 
     // Notional Composition markers - these define buffers for the
     // start and end of the piece, Segments can still exist outside
@@ -977,11 +832,6 @@ protected:
     // User defined markers in the composition
     //
     markercontainer                   m_markers;
-
-    // Trigger segments (unsorted segments fired by events elsewhere)
-    //
-    triggersegmentcontainer           m_triggerSegments;
-    TriggerSegmentId                  m_nextTriggerSegmentId;
  
     ColourMap                         m_segmentColourMap;
     ColourMap                         m_generalColourMap;
@@ -1004,10 +854,6 @@ protected:
 class CompositionObserver
 {
 public:
-    CompositionObserver() : m_compositionDeleted(false) {}
-    
-    virtual ~CompositionObserver() {}
-    
     /**
      * Called after the segment has been added to the composition
      */
@@ -1024,11 +870,6 @@ public:
      */
     virtual void segmentRepeatChanged(const Composition *, Segment *, bool) { }
 
-    /**
-     * Called when the segment's repeat end time has changed
-     */
-    virtual void segmentRepeatEndChanged(const Composition *, Segment *, timeT) { }
-
     /**
      * Called when the segment's delay timing has changed
      */
@@ -1042,12 +883,6 @@ public:
     virtual void segmentTransposeChanged(const Composition *, Segment *,
                                          int /* transpose */) { }
 
-    /**
-     * Called when the segment's end marker time has changed
-     */
-    virtual void segmentEndMarkerChanged(const Composition *, Segment *,
-                                         bool /* shorten */) { }
-
     /**
      * Called when the segment's track has changed
      */
@@ -1065,11 +900,6 @@ public:
      */
     virtual void trackChanged(const Composition *, Track*) { }
 
-    /**
-     * Called when a track has been deleted
-     */
-    virtual void trackDeleted(const Composition *, TrackId) { }
-
     /**
      * Called when some time signature has changed
      */
@@ -1094,14 +924,7 @@ public:
     /**
      * Called from the composition dtor
      */
-    virtual void compositionDeleted(const Composition *) {
-        m_compositionDeleted = true;
-    }
-
-    bool isCompositionDeleted() { return m_compositionDeleted; }
-
-protected:
-    bool m_compositionDeleted;
+    virtual void compositionDeleted(const Composition *) { }
 };
 
 }
