@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,18 +23,15 @@
 #define _EXCEPTION_H_
 
 #include <string>
-#include <exception>
 
 namespace Rosegarden {
 
-class Exception : public virtual std::exception
+class Exception
 {
 public:
     Exception(std::string message);
     Exception(std::string message, std::string file, int line);
 
-    virtual ~Exception() throw () {}
-
     std::string getMessage() const { return m_message; }
 
 private:
