@@ -5,7 +5,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,11 +24,12 @@
 #define _NOTATION_TYPES_H_
 
 #include <list>
-#include <map>
 
 #include "Event.h"
 #include "Instrument.h"
 
+#include "StringHash.h"
+
 /*
  * NotationTypes.h
  *
@@ -118,7 +119,6 @@ typedef std::string Mark;
 namespace Marks //!!! This would be better as a class, these days
 {
     extern const Mark NoMark;         // " "
-
     extern const Mark Accent;         // ">"
     extern const Mark Tenuto;         // "-"  ("legato" in RG2.1)
     extern const Mark Staccato;       // "."
@@ -126,22 +126,12 @@ namespace Marks //!!! This would be better as a class, these days
     extern const Mark Marcato;        // "^"
     extern const Mark Sforzando;      // "sf"
     extern const Mark Rinforzando;    // "rf"
-
     extern const Mark Trill;          // "tr"
-    extern const Mark LongTrill;      // with wiggly line
-    extern const Mark TrillLine;      // line on its own
     extern const Mark Turn;           // "~"
-
     extern const Mark Pause;          // aka "fermata"
-
     extern const Mark UpBow;          // "v"
     extern const Mark DownBow;        // a square with the bottom side missing
 
-    extern const Mark Mordent;
-    extern const Mark MordentInverted;
-    extern const Mark MordentLong;
-    extern const Mark MordentLongInverted;
-
     /**
      * Given a string, return a mark that will be recognised as a
      * text mark containing that string.  For example, the Sforzando
@@ -236,7 +226,6 @@ public:
     typedef Exception BadClefName;
 
     static const std::string Treble;
-    static const std::string Soprano;
     static const std::string Tenor;
     static const std::string Alto;
     static const std::string Bass;
@@ -282,7 +271,7 @@ public:
     static bool isValid(const Event &e);
 
     /**
-     * Return the basic clef type (Treble, Soprano, Tenor, Alto, Bass)
+     * Return the basic clef type (Treble, Tenor, Alto, Bass)
      */
     std::string getClefType() const { return m_clef; }
 
@@ -297,18 +286,18 @@ public:
      * have to be lowered by in order to be drawn with the same height
      * and accidental in this clef
      */
-    int getTranspose() const;
+    int getTransposition() const;
 
     /**
-     * Return the octave component of getTranspose(), i.e. the number
+     * Return the octave component of getTransposition(), i.e. the number
      * of octaves difference in pitch between this clef and the treble
      */
     int getOctave() const;
 
     /**
-     * Return the intra-octave component of getTranspose(), i.e. the
+     * Return the intra-octave component of getTransposition(), i.e. the
      * number of semitones this clef is distinct in pitch from the treble
-     * besides the difference in octaves
+     * besides the different in octaves
      */
     int getPitchOffset() const;
 
@@ -521,7 +510,7 @@ private:
         std::string m_rg2name;
 	int    m_tonicPitch;
 
-        KeyDetails(); // ctor needed in order to live in a map
+        KeyDetails(); // ctor needed in order to live in a hash_map
 
         KeyDetails(bool sharps, bool minor, int sharpCount,
                    std::string equivalence, std::string rg2name,
@@ -533,7 +522,7 @@ private:
     };
 
 
-    typedef std::map<std::string, KeyDetails> KeyDetailMap;
+    typedef hash_string<KeyDetails> KeyDetailMap;
     static KeyDetailMap m_keyDetailMap;
     static void checkMap();
     void checkAccidentalHeights() const;
@@ -554,10 +543,10 @@ public:
     static const std::string EventType;
     static const int EventSubOrdering;
     static const PropertyName IndicationTypePropertyName;
+//    static const PropertyName IndicationDurationPropertyName;
     typedef Exception BadIndicationName;
 
     static const std::string Slur;
-    static const std::string PhrasingSlur;
     static const std::string Crescendo;
     static const std::string Decrescendo;
     static const std::string Glissando;
@@ -621,40 +610,17 @@ public:
     static const PropertyName TextPropertyName;
     static const PropertyName TextTypePropertyName;
 
-    /**
-     * Text styles
-     */
     static const std::string UnspecifiedType;
     static const std::string StaffName;
     static const std::string ChordName;
     static const std::string KeyName;
     static const std::string Lyric;
-    static const std::string Chord;
     static const std::string Dynamic;
     static const std::string Direction;
     static const std::string LocalDirection;
     static const std::string Tempo;
     static const std::string LocalTempo;
     static const std::string Annotation;
-    static const std::string LilypondDirective;
-
-    /**
-     * Special Lilypond directives
-     */
-    static const std::string Segno;       // print segno here
-    static const std::string Coda;        // print coda sign here
-    static const std::string Alternate1;  // first alternative ending
-    static const std::string Alternate2;  // second alternative ending
-    static const std::string BarDouble;   // next barline is double
-    static const std::string BarEnd;      // next barline is final double
-    static const std::string BarDot;      // next barline is dotted
-    static const std::string Gliss;       // \glissando on this note (to next note)
-    static const std::string Arpeggio;    // \arpeggio on this chord
-//    static const std::string ArpeggioUp;  // \ArpeggioUp on this chord
-//    static const std::string ArpeggioDn;  // \ArpeggioDown on this chord
-    static const std::string Tiny;        // begin \tiny font section
-    static const std::string Small;       // begin \small font section
-    static const std::string NormalSize;  // begin \normalsize font section
 
     Text(const Event &e)
 	/* throw (Event::NoData, Event::BadType) */;
@@ -675,11 +641,6 @@ public:
      */
     static std::vector<std::string> getUserStyles();
 
-    /**
-     * Return a list of available special Lilypond directives
-     */
-    static std::vector<std::string> getLilypondDirectives();
-
     /// Returned event is on heap; caller takes responsibility for ownership
     Event *getAsEvent(timeT absoluteTime) const;
 
@@ -774,25 +735,13 @@ public:
     int getPerformancePitch() const;
 
     /**
-     * Return the accidental for this pitch using a bool to prefer sharps over
-     * flats if there is any doubt.  This is the accidental
+     * Return the accidental for this pitch.  This is the accidental
      * that would be used to display this pitch outside of the context
      * of any key; that is, it may duplicate an accidental actually in
-     * the current key.  This should not be used if you need to get an
-     * explicit accidental returned for E#, Fb, B# or Cb.
-     *
-     * This version of the function exists to avoid breaking old code.
+     * the current key.  The useSharps argument is used to decide
+     * whether to prefer sharps over flats if there is any doubt.
      */
     Accidental getAccidental(bool useSharps) const;
-    
-    /**
-     * Return the accidental for this pitch, using a key.  This should be used
-     * if you need an explicit accidental returned for E#, Fb, B# or Cb, which
-     * can't be resolved correctly without knowing that their key requires
-     * them to take an accidental.  The provided key will also be used to
-     * determine whether to prefer sharps over flats.
-     */
-    Accidental getAccidental(const Key &key) const;
 
     /**
      * Return the accidental that should be used to display this pitch
@@ -1011,29 +960,25 @@ public:
     TimeSignature() :
         m_numerator(DefaultTimeSignature.m_numerator),
         m_denominator(DefaultTimeSignature.m_denominator),
-	m_common(false), m_hidden(false), m_hiddenBars(false) { }
+	m_common(false), m_hidden(false) { }
 
     /**
      * Construct a TimeSignature object describing a time signature
-     * with the given numerator and denominator.  If preferCommon is
-     * true and the time signature is a common or cut-common time, the
-     * constructed object will return true for isCommon; if hidden is
-     * true, the time signature is intended not to be displayed and
-     * isHidden will return true; if hiddenBars is true, the bar lines
-     * between this time signature and the next will not be shown.
+     * with the given numerator and denominator.  If preferCommon
+     * is true and the time signature is a common or cut-common
+     * time, the constructed object will return true for isCommon;
+     * if hidden is true, the time signature is intended not to
+     * be displayed and isHidden will return true.
      */
     TimeSignature(int numerator, int denominator,
-		  bool preferCommon = false,
-		  bool hidden = false,
-		  bool hiddenBars = false)
+		  bool preferCommon = false, bool hidden = false)
         /* throw (BadTimeSignature) */;
     
     TimeSignature(const TimeSignature &ts) :
         m_numerator(ts.m_numerator),
         m_denominator(ts.m_denominator),
 	m_common(ts.m_common),
-	m_hidden(ts.m_hidden),
-	m_hiddenBars(ts.m_hiddenBars) { }
+	m_hidden(ts.m_hidden) { }
 
     ~TimeSignature() { }
 
@@ -1051,7 +996,6 @@ public:
     
     bool isCommon()        const { return m_common; }
     bool isHidden()	   const { return m_hidden; }
-    bool hasHiddenBars()   const { return m_hiddenBars; }
 
     timeT getBarDuration() const;
 
@@ -1125,7 +1069,6 @@ public:
 
 private:
     friend class Composition;
-    friend class TimeTempoSelection;
 
     TimeSignature(const Event &e)
         /* throw (Event::NoData, Event::BadType, BadTimeSignature) */;
@@ -1136,7 +1079,6 @@ private:
     static const PropertyName DenominatorPropertyName;
     static const PropertyName ShowAsCommonTimePropertyName;
     static const PropertyName IsHiddenPropertyName;
-    static const PropertyName HasHiddenBarsPropertyName;
 
     /// Returned event is on heap; caller takes responsibility for ownership
     Event *getAsEvent(timeT absoluteTime) const;
@@ -1147,7 +1089,6 @@ private:
 
     bool m_common;
     bool m_hidden;
-    bool m_hiddenBars;
 
     mutable int  m_barDuration;
     mutable int  m_beatDuration;
@@ -1189,13 +1130,13 @@ public:
     };
 
     enum BarResetType {
-	BarResetNone,       // c# | c -> omit natural
+	BarResetTotal,      // c# | c -> omit natural
 	BarResetCautionary, // c# | c -> add natural to c in brackets
-	BarResetExplicit    // c# | c -> add natural to c
+	BarResetNaturals    // c# | c -> add natural to c
     };
 
     AccidentalTable(const Key &, const Clef &,
-		    OctaveType = OctavesCautionary,
+		    OctaveType = OctavesIndependent,
 		    BarResetType = BarResetCautionary);
 
     AccidentalTable(const AccidentalTable &);
