@@ -5,7 +5,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -142,32 +142,6 @@ public:
      */
     int getNextId() const;
 
-    /**
-     * Returns a MIDI pitch representing the highest suggested playable note for
-     * notation contained in this segment, as a convenience reminder to composers.
-     *
-     * This property, and its corresponding lowest note counterpart, initialize by
-     * default such that no limitation is imposed.  (lowest = 0, highest = 127)
-     */
-    int getHighestPlayable() { return m_highestPlayable; }
-
-    /**
-     * Set the highest suggested playable note for this segment
-     */
-    void setHighestPlayable(int pitch) { m_highestPlayable = pitch; }
-
-    /**
-     * Returns a MIDI pitch representing the lowest suggested playable note for
-     * notation contained in this segment, as a convenience reminder to composers
-     */
-    int getLowestPlayable() { return m_lowestPlayable; }
-
-    /**
-     * Set the highest suggested playable note for this segment
-     */
-    void setLowestPlayable(int pitch) { m_lowestPlayable = pitch; }
-
-
 
     //////
     //
@@ -241,7 +215,7 @@ public:
      * Return an iterator pointing to the nominal end of the
      * Segment.  This may be earlier than the end() iterator.
      */
-    iterator getEndMarker();
+    iterator getEndMarker() const;
 
     /**
      * Return true if the given iterator points earlier in the
@@ -264,7 +238,7 @@ public:
      * value is already beyond the end marker.  (Also takes the
      * Composition's end marker into account.)
      */
-    bool isBeforeEndMarker(const_iterator) const;
+    bool isBeforeEndMarker(iterator) const;
 
     /**
      * Remove the end marker, thus making the Segment end
@@ -306,7 +280,7 @@ public:
     /**
      * Get the quantizer currently in (or not in) use.
      */
-    const BasicQuantizer *getQuantizer() const;
+    const BasicQuantizer *const getQuantizer() const;
 
 
 
@@ -344,32 +318,20 @@ public:
      * Returns an iterator pointing to that specific element,
      * end() otherwise
      */
-    iterator findSingle(Event*);
-
-    const_iterator findSingle(Event *e) const {
-	return const_iterator(((Segment *)this)->findSingle(e));
-    }
+    iterator findSingle(Event*) const;
 
     /**
      * Returns an iterator pointing to the first element starting at
      * or beyond the given absolute time
      */
-    iterator findTime(timeT time);
-
-    const_iterator findTime(timeT time) const {
-	return const_iterator(((Segment *)this)->findTime(time));
-    }
+    iterator findTime(timeT time) const;
 
     /**
      * Returns an iterator pointing to the first element starting at
      * or before the given absolute time (so returns end() if the
      * time precedes the first event, not if it follows the last one)
      */
-    iterator findNearestTime(timeT time);
-
-    const_iterator findNearestTime(timeT time) const {
-	return const_iterator(((Segment *)this)->findNearestTime(time));
-    }
+    iterator findNearestTime(timeT time) const;
 
 
     //////
@@ -379,12 +341,7 @@ public:
     /**
      * Returns the range [start, end[ of events which are at absoluteTime
      */
-    void getTimeSlice(timeT absoluteTime, iterator &start, iterator &end);
-
-    /**
-     * Returns the range [start, end[ of events which are at absoluteTime
-     */
-    void getTimeSlice(timeT absoluteTime, const_iterator &start, const_iterator &end) const;
+    void getTimeSlice(timeT absoluteTime, iterator &start, iterator &end) const;
     
     /**
      * Return the starting time of the bar that contains time t.  This
@@ -558,10 +515,10 @@ public:
     };
 
 
-    /// For use by SegmentObserver objects like Composition & Staff
+    /// For use by SegmentObserver objects like Composition & ViewElementsManager
     void    addObserver(SegmentObserver *obs) { m_observers.push_back(obs); }
 
-    /// For use by SegmentObserver objects like Composition & Staff
+    /// For use by SegmentObserver objects like Composition & ViewElementsManager
     void removeObserver(SegmentObserver *obs) { m_observers.remove(obs); }
 
     // List of visible EventRulers attached to this segment
@@ -633,9 +590,6 @@ private:
     timeT m_delay;              // all Events delay
     RealTime m_realTimeDelay;   // all Events delay (the delays are cumulative)
 
-    int m_highestPlayable;      // suggestion for highest playable note (notation)
-    int m_lowestPlayable;       // suggestion for lowest playable note (notation)
-
     RefreshStatusArray<SegmentRefreshStatus> m_refreshStatusArray;
 
     struct ClefKeyCmp {
@@ -655,8 +609,7 @@ private: // stuff to support SegmentObservers
 
     void notifyAdd(Event *) const;
     void notifyRemove(Event *) const;
-    void notifyAppearanceChange() const;
-    void notifyEndMarkerChange(bool shorten);
+    void notifyEndMarkerChange(bool shorten) const;
     void notifySourceDeletion() const;
 
 private: // assignment operator not provided
@@ -688,36 +641,25 @@ private: // assignment operator not provided
 class SegmentObserver
 {
 public:
-    virtual ~SegmentObserver() {}
-
     /**
      * Called after the event has been added to the segment
      */
-    virtual void eventAdded(const Segment *, Event *) { }
+    virtual void eventAdded(const Segment *, Event *) = 0;
 
     /**
      * Called after the event has been removed from the segment,
      * and just before it is deleted
      */
-    virtual void eventRemoved(const Segment *, Event *) { }
-
-    /**
-     * Called after a change in the segment that will change the way its displays,
-     * like a label change for instance
-     */
-    virtual void appearanceChanged(const Segment *) { }
+    virtual void eventRemoved(const Segment *, Event *) = 0;
 
     /**
      * Called after the segment's end marker time has been
      * changed
-     *
-     * @param shorten true if the marker change shortens the segment's duration
      */
-    virtual void endMarkerTimeChanged(const Segment *, bool /*shorten*/) { }
+    virtual void endMarkerTimeChanged(const Segment *, bool shorten) = 0;
 
     /**
      * Called from the segment dtor
-     * MUST BE IMPLEMENTED BY ALL OBSERVERS
      */
     virtual void segmentDeleted(const Segment *) = 0;
 };
@@ -739,7 +681,7 @@ protected:
     Segment::iterator begin() { return segment().begin(); }
     Segment::iterator end()   { return segment().end();   }
 
-    bool isBeforeEndMarker(Segment::const_iterator i) {
+    bool isBeforeEndMarker(Segment::iterator i) {
 	return segment().isBeforeEndMarker(i);
     }
 
