@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -26,11 +26,12 @@
 #include "PropertyName.h"
 #include "Event.h"
 #include "Segment.h"
-#include "NotationTypes.h"
-#include "Composition.h"
 
 namespace Rosegarden {
 
+class Composition;
+
+
 /**
  * EventSelection records a (possibly non-contiguous) selection
  * of Events in a single Segment, used for cut'n paste operations.
@@ -167,97 +168,6 @@ public:
 };
 
 
-/**
- * A selection that includes (only) time signatures.  Unlike
- * EventSelection, this does copy its contents, not just refer to
- * them.
- */
-class TimeSignatureSelection
-{
-public:
-    /**
-     * Construct an empty TimeSignatureSelection.
-     */
-    TimeSignatureSelection();
-
-    /**
-     * Construct a TimeSignatureSelection containing all the time
-     * signatures in the given range of the given Composition.
-     *
-     * If includeOpeningTimeSig is true, the selection will start with
-     * a duplicate of the time signature (if any) that is already in
-     * force at beginTime.  Otherwise the selection will only start
-     * with a time signature at beginTime if there is an explicit
-     * signature there in the source composition.
-     */
-    TimeSignatureSelection(Composition &, timeT beginTime, timeT endTime,
-			   bool includeOpeningTimeSig);
-
-    virtual ~TimeSignatureSelection();
-
-    /**
-     * Add a time signature to the selection.
-     */
-    void addTimeSignature(timeT t, TimeSignature timeSig);
-    
-    typedef std::multimap<timeT, TimeSignature> timesigcontainer;
-
-    const timesigcontainer &getTimeSignatures() const { return m_timeSignatures; }
-    timesigcontainer::const_iterator begin() const { return m_timeSignatures.begin(); }
-    timesigcontainer::const_iterator end() const { return m_timeSignatures.end(); }
-    bool empty() const { return begin() == end(); }
-
-protected:
-    timesigcontainer m_timeSignatures;
-};
- 
-
-/**
- * A selection that includes (only) tempo changes.
- */
-
-class TempoSelection
-{
-public:
-    /**
-     * Construct an empty TempoSelection.
-     */
-    TempoSelection();
-
-    /**
-     * Construct a TempoSelection containing all the time
-     * signatures in the given range of the given Composition.
-     *
-     * If includeOpeningTempo is true, the selection will start with a
-     * duplicate of the tempo (if any) that is already in force at
-     * beginTime.  Otherwise the selection will only start with a
-     * tempo at beginTime if there is an explicit tempo change there
-     * in the source composition.
-     */
-    TempoSelection(Composition &, timeT beginTime, timeT endTime,
-		   bool includeOpeningTempo);
-
-    virtual ~TempoSelection();
-
-    /**
-     * Add a time signature to the selection.
-     */
-    void addTempo(timeT t, tempoT tempo, tempoT targetTempo = -1);
-
-    typedef std::pair<tempoT, tempoT> tempochange;
-    typedef std::multimap<timeT, tempochange> tempocontainer;
-
-    const tempocontainer &getTempos() const { return m_tempos; }
-    tempocontainer::const_iterator begin() const { return m_tempos.begin(); }
-    tempocontainer::const_iterator end() const { return m_tempos.end(); }
-    bool empty() const { return begin() == end(); }
-
-protected:
-    tempocontainer m_tempos;
-};
-    
-
-
 }
 
 #endif
