@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -31,7 +31,6 @@
 
 #include "XmlExportable.h"
 #include "Instrument.h"
-#include "Device.h"
 
 namespace Rosegarden
 {
@@ -81,9 +80,6 @@ public:
     void setLabel(const std::string &label);
     std::string getLabel() const { return m_label; }
 
-    void setPresetLabel(const std::string &label);
-    std::string getPresetLabel() const { return m_presetLabel; }
-
     void setInstrument(InstrumentId instrument);
     InstrumentId getInstrument() const { return m_instrument; }
 
@@ -93,30 +89,6 @@ public:
 
     Composition* getOwningComposition() { return m_owningComposition; }
 
-    void setMidiInputDevice(DeviceId id);
-    DeviceId getMidiInputDevice() const { return m_input_device; }
-
-    void setMidiInputChannel(char ic);
-    char getMidiInputChannel() const { return m_input_channel; }
-
-    int getClef() { return m_clef; }
-    void setClef(int clef) { m_clef = clef; }
-
-    int getTranspose() { return m_transpose; }
-    void setTranspose(int transpose) { m_transpose = transpose; }
-
-    int getColor() { return m_color; }
-    void setColor(int color) { m_color = color; }
-
-    int getHighestPlayable() { return m_highestPlayable; }
-    void setHighestPlayable(int pitch) { m_highestPlayable = pitch; }
-    
-    int getLowestPlayable() { return m_lowestPlayable; }
-    void setLowestPlayable(int pitch) { m_lowestPlayable = pitch; }
-    
-    bool isArmed() const { return m_armed; }
-    void setArmed(bool armed);
-
 protected: // For Composition use only
     void setOwningComposition(Composition* comp) { m_owningComposition = comp; }
 
@@ -126,22 +98,10 @@ private:
     TrackId        m_id;
     bool           m_muted;
     std::string    m_label;
-    std::string    m_presetLabel;
     int            m_position;
     InstrumentId   m_instrument;
 
     Composition*   m_owningComposition;
-
-    DeviceId       m_input_device;
-    char           m_input_channel;
-    bool           m_armed;
-
-    // default parameters for new segments created belonging to this track
-    int		   m_clef;
-    int		   m_transpose;
-    int		   m_color;
-    int		   m_highestPlayable;
-    int		   m_lowestPlayable;
 };
 
 }
