@@ -3,7 +3,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -40,7 +40,6 @@
 #include <kio/netaccess.h>
 #include <kaction.h>
 #include <kstdaction.h>
-#include <kdialogbase.h>
 
 #include "audiomanagerdialog.h"
 #include "dialogs.h"
@@ -48,7 +47,6 @@
 #include "multiviewcommandhistory.h"
 #include "rosegardenguiview.h"
 #include "rosestrings.h"
-#include "rgapplication.h"
 #include "rosedebug.h"
 
 #include "WAVAudioFile.h"
@@ -74,7 +72,7 @@ public:
 
     AudioListItem(KListView *parent,
                   QString label,
-                  AudioFileId id):
+                  Rosegarden::AudioFileId id):
                       KListViewItem(parent,
                                     label,
                                     "", "", "", "", "", "", ""),
@@ -83,7 +81,7 @@ public:
 
     AudioListItem(KListViewItem *parent, 
                   QString label,
-                  AudioFileId id):
+                  Rosegarden::AudioFileId id):
                       KListViewItem(parent,
                                     label,
                                     "", "", "", "", "", "", ""),
@@ -91,29 +89,29 @@ public:
                                     m_segment(0) {;}
 
 
-    AudioFileId getId() { return m_id; }
+    Rosegarden::AudioFileId getId() { return m_id; }
 
-    void setStartTime(const RealTime &time)
+    void setStartTime(const Rosegarden::RealTime &time)
         { m_startTime = time; }
-    RealTime getStartTime() { return m_startTime; }
+    Rosegarden::RealTime getStartTime() { return m_startTime; }
 
-    void setDuration(const RealTime &time)
+    void setDuration(const Rosegarden::RealTime &time)
         { m_duration = time; }
-    RealTime getDuration() { return m_duration; }
+    Rosegarden::RealTime getDuration() { return m_duration; }
 
-    void setSegment(Segment *segment)
+    void setSegment(Rosegarden::Segment *segment)
         { m_segment = segment; }
-    Segment *getSegment() { return m_segment; }
+    Rosegarden::Segment *getSegment() { return m_segment; }
 
 protected:
-    AudioFileId m_id;
+    Rosegarden::AudioFileId m_id;
 
     // for audio segments
-    RealTime m_startTime;
-    RealTime m_duration;
+    Rosegarden::RealTime m_startTime;
+    Rosegarden::RealTime m_duration;
 
     // pointer to a segment
-    Segment *m_segment;
+    Rosegarden::Segment *m_segment;
 
 };
 
@@ -180,31 +178,17 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
     setCaption(i18n("Audio File Manager"));
     setWFlags(WDestructiveClose);
 
-    QVBox *box = new QVBox(this);
-    setCentralWidget(box);
-    box->setMargin(10);
-    box->setSpacing(5);
+    QHBox *h = new QHBox(this);
+    setCentralWidget(h);
+    h->setMargin(10);
+    h->setSpacing(5);
 
-    m_sampleRate = 0;
-    
-    QCString replyType;
-    QByteArray replyData;
-    if (rgapp->sequencerCall("getSampleRate()", replyType, replyData)) {
-        QDataStream streamIn(replyData, IO_ReadOnly);
-        unsigned int result;
-        streamIn >> result;
-        m_sampleRate = result;
-    }
-
-    m_fileList = new AudioListView(box);
-
-    m_wrongSampleRates = new QLabel(i18n("* Some audio files are encoded at a sample rate different from that of the JACK audio server.\nRosegarden will play them at the correct speed, but they will sound terrible.\nPlease consider resampling such files externally, or adjusting the sample rate of the JACK server."), box);
-    m_wrongSampleRates->hide();
+    m_fileList = new AudioListView(h);
 
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
     QIconSet icon(QPixmap(pixmapDir + "/toolbar/transport-play.xpm"));
 
-    new KAction(i18n("&Add Audio File..."), "fileopen", 0, this,
+    new KAction(i18n("&Add Audio File"), "fileopen", 0, this,
 		SLOT(slotAdd()), actionCollection(), "add_audio");
 
     new KAction(i18n("&Unload Audio File"), "editdelete", 0, this,
@@ -216,11 +200,9 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
 		SLOT(slotPlayPreview()), 
 		actionCollection(), "preview_audio");
 
-/*!!! Not actually implemented -- this never worked right!
     new KAction(i18n("Re&label"), 0, 0, this,
 		SLOT(slotRename()), 
 		actionCollection(), "rename_audio");
-*/
 
     icon = QIconSet(QPixmap(pixmapDir + "/toolbar/insert_audio_into_track.xpm"));
     new KAction(i18n("&Insert into Selected Audio Track"), 
@@ -231,15 +213,11 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
 		SLOT(slotRemoveAll()), 
 		actionCollection(), "remove_all_audio");
 
-    new KAction(i18n("Unload all &Unused Audio Files"), 0, 0, this,
+    new KAction(i18n("Unload &all Unused Audio Files"), 0, 0, this,
 		SLOT(slotRemoveAllUnused()), 
 		actionCollection(), "remove_all_unused_audio");
 
-    new KAction(i18n("&Delete Unused Audio Files..."), 0, 0, this,
-		SLOT(slotDeleteUnused()), 
-		actionCollection(), "delete_unused_audio");
-
-    new KAction(i18n("&Export Audio File..."), "fileexport", 0, this,
+    new KAction(i18n("&Export Audio File"), "fileexport", 0, this,
 		SLOT(slotExportAudio()), 
 		actionCollection(), "export_audio");
 
@@ -251,19 +229,19 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
 
     // Set the column names
     //
-    m_fileList->addColumn(i18n("Name"));           // 0
-    m_fileList->addColumn(i18n("Duration"));       // 1
-    m_fileList->addColumn(i18n("Envelope"));       // 2
-    m_fileList->addColumn(i18n("Sample rate"));    // 3
-    m_fileList->addColumn(i18n("Channels"));       // 4
-    m_fileList->addColumn(i18n("Resolution"));     // 5
-    m_fileList->addColumn(i18n("File"));           // 6
+    m_fileList->addColumn(i18n("Name"));
+    m_fileList->addColumn(i18n("Duration"));
+    m_fileList->addColumn(i18n("Envelope"));
+    m_fileList->addColumn(i18n("File"));
+    m_fileList->addColumn(i18n("Resolution"));
+    m_fileList->addColumn(i18n("Channels"));
+    m_fileList->addColumn(i18n("Sample rate"));
 
     m_fileList->setColumnAlignment(1, Qt::AlignHCenter);
     m_fileList->setColumnAlignment(2, Qt::AlignHCenter);
-    m_fileList->setColumnAlignment(3, Qt::AlignHCenter);
     m_fileList->setColumnAlignment(4, Qt::AlignHCenter);
     m_fileList->setColumnAlignment(5, Qt::AlignHCenter);
+    m_fileList->setColumnAlignment(6, Qt::AlignHCenter);
 
     m_fileList->restoreLayout(kapp->config(), m_listViewLayoutName);
 
@@ -333,8 +311,8 @@ AudioManagerDialog::slotPopulateFileList()
     //
     AudioListItem *selectedItem =
         dynamic_cast<AudioListItem*>(m_fileList->selectedItem());
-    AudioFileId lastId = 0;
-    Segment *lastSegment = 0;
+    Rosegarden::AudioFileId lastId = 0;
+    Rosegarden::Segment *lastSegment = 0;
     bool findSelection = false;
     bool foundSelection = false;
 
@@ -379,19 +357,18 @@ AudioManagerDialog::slotPopulateFileList()
 
     // Create a vector of audio Segments only
     //
-    std::vector<Segment*> segments;
-    std::vector<Segment*>::const_iterator iit;
+    std::vector<Rosegarden::Segment*> segments;
+    std::vector<Rosegarden::Segment*>::const_iterator iit;
 
     for (Composition::iterator it = m_doc->getComposition().begin();
              it != m_doc->getComposition().end(); ++it)
     {
-        if ((*it)->getType() == Segment::Audio)
+        if ((*it)->getType() == Rosegarden::Segment::Audio)
             segments.push_back(*it);
     }
 
     // duration
-    RealTime segmentDuration;
-    bool wrongSampleRates = false;
+    Rosegarden::RealTime segmentDuration;
 
     for (std::vector<AudioFile*>::const_iterator
              it = m_doc->getAudioFileManager().begin();
@@ -406,7 +383,7 @@ AudioManagerDialog::slotPopulateFileList()
                                 (*it)->getLength(),
                                 audioPixmap);
         }
-        catch (Rosegarden::Exception e)
+        catch(std::string e)
         {
             audioPixmap->fill(); // white
             QPainter p(audioPixmap);
@@ -414,9 +391,6 @@ AudioManagerDialog::slotPopulateFileList()
             p.drawText(10, m_previewHeight / 2, QString("<no preview>"));
         }
 
-	//!!! Why isn't the label the label the user assigned to the file?
-	// Why do we allow the user to assign a label at all, then?
-
         QString label = QString((*it)->getShortFilename().c_str());
              
         // Set the label, duration, envelope pixmap and filename
@@ -430,7 +404,7 @@ AudioManagerDialog::slotPopulateFileList()
         item->setText(1, QString("%1.%2s").arg(length.sec).arg(msecs));
 
         // set start time and duration
-        item->setStartTime(RealTime::zeroTime);
+        item->setStartTime(Rosegarden::RealTime::zeroTime);
         item->setDuration(length);
 
         // Envelope pixmap
@@ -439,27 +413,22 @@ AudioManagerDialog::slotPopulateFileList()
 
         // File location
         //
-        item->setText(6, QString(
+        item->setText(3, QString(
                     m_doc->getAudioFileManager().
                         substituteHomeForTilde((*it)->getFilename()).c_str()));
                                        
         // Resolution
         //
-        item->setText(5, QString("%1 bits").arg((*it)->getBitsPerSample()));
+        item->setText(4, QString("%1 bits").arg((*it)->getBitsPerSample()));
 
         // Channels
         //
-        item->setText(4, QString("%1").arg((*it)->getChannels()));
+        item->setText(5, QString("%1").arg((*it)->getChannels()));
 
         // Sample rate
         //
-	if (m_sampleRate != 0 && (*it)->getSampleRate() != m_sampleRate) {
-	    sRate.sprintf("%.1f KHz *", float((*it)->getSampleRate())/ 1000.0);
-	    wrongSampleRates = true;
-	} else {
-	    sRate.sprintf("%.1f KHz", float((*it)->getSampleRate())/ 1000.0);
-	}
-        item->setText(3, sRate);
+        sRate.sprintf("%.1f KHz", float((*it)->getSampleRate())/ 1000.0);
+        item->setText(6, sRate);
 
         // Test audio file element for selection criteria
         //
@@ -504,7 +473,7 @@ AudioManagerDialog::slotPopulateFileList()
                                                (*iit)->getAudioEndTime(),
                                                audioPixmap);
                 }
-                catch (Rosegarden::Exception e)
+                catch(std::string e)
                 {
                     // should already be set to "no file"
                 }
@@ -531,12 +500,6 @@ AudioManagerDialog::slotPopulateFileList()
 
     updateActionState(foundSelection);
 
-    if (wrongSampleRates) {
-	m_wrongSampleRates->show();
-    } else {
-	m_wrongSampleRates->hide();
-    }
-
     m_fileList->blockSignals(false);
 }
 
@@ -572,14 +535,14 @@ AudioManagerDialog::slotExportAudio()
     AudioListItem *item =
         dynamic_cast<AudioListItem*>(m_fileList->selectedItem());
     
-    Segment *segment = item->getSegment();
+    Rosegarden::Segment *segment = item->getSegment();
 
     QString saveFile =
         KFileDialog::getSaveFileName(":WAVS",
-                                     i18n("*.wav|WAV files (*.wav)"),
-                                     this, i18n("Choose a name to save this file as"));
+                                 QString(i18n("*.wav|WAV files (*.wav)")),
+                                 this, i18n("Choose a name to save this file as"));
     
-    if (sourceFile == 0 || item == 0 || saveFile.isEmpty())
+    if (sourceFile == 0 || item == 0 || segment == 0 || saveFile.isEmpty())
         return;
 
     // Check for a dot extension and append ".wav" if not found
@@ -593,13 +556,8 @@ AudioManagerDialog::slotExportAudio()
 
     progressDlg.progressBar()->setProgress(0);
 
-    RealTime clipStartTime = RealTime::zeroTime;
-    RealTime clipDuration = sourceFile->getLength();
-
-    if (segment) {
-	clipStartTime = segment->getAudioStartTime();
-	clipDuration = segment->getAudioEndTime() - clipStartTime;
-    }
+    Rosegarden::RealTime segmentDuration 
+        = segment->getAudioEndTime() - segment->getAudioStartTime();
     
     WAVAudioFile *destFile 
         = new WAVAudioFile(qstrtostr(saveFile),
@@ -617,8 +575,10 @@ AudioManagerDialog::slotExportAudio()
     
     destFile->write();
 
-    sourceFile->scanTo(clipStartTime);
-    destFile->appendSamples(sourceFile->getSampleFrameSlice(clipDuration));
+    sourceFile->scanTo(segment->getAudioStartTime());
+
+    destFile->appendSamples
+        (sourceFile->getSampleFrameSlice(segmentDuration));
 
     destFile->close();
     sourceFile->close();    
@@ -657,8 +617,8 @@ AudioManagerDialog::slotRemove()
         // Get the id and segment of the next item so that we can
         // match against it
         //
-        AudioFileId id = 0;
-        Segment *segment = 0;
+        Rosegarden::AudioFileId id = 0;
+        Rosegarden::Segment *segment = 0;
         AudioListItem *aItem = dynamic_cast<AudioListItem*>(newItem);
         
         if (aItem)
@@ -674,53 +634,36 @@ AudioManagerDialog::slotRemove()
 
         // Do it - will force update
         //
-        SegmentSelection selection;
+        Rosegarden::SegmentSelection selection;
         selection.insert(item->getSegment());
         emit deleteSegments(selection);
 
         return;
     }
 
+    QString question = QString(i18n("This will unload audio file \"%1\" and remove all associated segments.  Are you sure?"))
+        .arg(QString(audioFile->getFilename().c_str()));
+
+    // Ask the question
+    int reply = KMessageBox::warningContinueCancel(this, question);
+
+    if (reply != KMessageBox::Continue)
+        return;
+
     // remove segments along with audio file
     //
-    AudioFileId id = audioFile->getId();
-    SegmentSelection selection;
+    Rosegarden::AudioFileId id = audioFile->getId();
+    Rosegarden::SegmentSelection selection;
     Composition &comp = m_doc->getComposition();
 
-    bool haveSegments = false;
     for (Composition::iterator it = comp.begin(); it != comp.end(); ++it)
     {
-        if ((*it)->getType() == Segment::Audio &&
-            (*it)->getAudioFileId() == id) {
-	    haveSegments = true;
-	    break;
-	}
-    }
-
-    if (haveSegments) {
-
-	QString question = i18n("This will unload audio file \"%1\" and remove all associated segments.  Are you sure?")
-	    .arg(QString(audioFile->getFilename().c_str()));
-
-	// Ask the question
-	int reply = KMessageBox::warningContinueCancel(this, question);
-
-	if (reply != KMessageBox::Continue)
-	    return;
-    }
-
-    for (Composition::iterator it = comp.begin(); it != comp.end(); ++it)
-    {
-        if ((*it)->getType() == Segment::Audio &&
+        if ((*it)->getType() == Rosegarden::Segment::Audio &&
             (*it)->getAudioFileId() == id)
             selection.insert(*it);
     }
     emit deleteSegments(selection);
 
-    if (m_doc->getAudioFileManager().wasAudioFileRecentlyRecorded(audioFile->getId())) {
-	m_doc->addOrphanedAudioFile(strtoqstr(audioFile->getFilename()));
-    }
-
     m_doc->getAudioFileManager().removeFile(id);
 
     // tell the sequencer
@@ -790,9 +733,13 @@ void
 AudioManagerDialog::slotAdd()
 {
     KURL::List kurlList =
-        KFileDialog::getOpenURLs(":WAVS",
-//                                 i18n("*.wav|WAV files (*.wav)\n*.mp3|MP3 files (*.mp3)"),
-                                 i18n("*.wav|WAV files (*.wav)"),
+        KFileDialog::getOpenURLs(
+#if KDE_VERSION >= 196614
+                                 ":WAVS",
+#else
+                                 QString::null,
+#endif
+                                 i18n("*.wav|WAV files (*.wav)\n*.mp3|MP3 files (*.mp3)"),
                                  this, i18n("Select one or more audio files"));
 
     KURL::List::iterator it;
@@ -845,7 +792,7 @@ AudioManagerDialog::slotInsert()
     RG_DEBUG << "AudioManagerDialog::slotInsert\n";
 
     emit insertAudioSegment(audioFile->getId(),
-                            RealTime::zeroTime,
+                            Rosegarden::RealTime::zeroTime,
                             audioFile->getLength());
 }
 
@@ -853,35 +800,24 @@ void
 AudioManagerDialog::slotRemoveAll()
 {
     QString question =
-        i18n("This will unload all audio files and remove their associated segments.\nThis action cannot be undone, and associations with these files will be lost.\nFiles will not be removed from your disk.\nAre you sure?");
+        i18n("This will unload all audio files and remove their associated segments.  Are you sure?");
 
     int reply = KMessageBox::warningContinueCancel(this, question);
 
     if (reply != KMessageBox::Continue)
         return;
 
-    SegmentSelection selection;
+    Rosegarden::SegmentSelection selection;
     Composition &comp = m_doc->getComposition();
 
     for (Composition::iterator it = comp.begin(); it != comp.end(); ++it)
     {
-        if ((*it)->getType() == Segment::Audio)
+        if ((*it)->getType() == Rosegarden::Segment::Audio)
             selection.insert(*it);
     }
     // delete segments
     emit deleteSegments(selection);
 
-    for (std::vector<AudioFile*>::const_iterator
-	     aIt = m_doc->getAudioFileManager().begin();
-         aIt != m_doc->getAudioFileManager().end(); ++aIt)
-    {
-	if (m_doc->getAudioFileManager().wasAudioFileRecentlyRecorded((*aIt)->getId())) {
-	    m_doc->addOrphanedAudioFile(strtoqstr((*aIt)->getFilename()));
-	}
-    }
-
-    m_doc->getAudioFileManager().clear();
-
     // and now the audio files
     emit deleteAllAudioFiles();
 
@@ -894,23 +830,23 @@ void
 AudioManagerDialog::slotRemoveAllUnused()
 {
     QString question =
-        i18n("This will unload all audio files that are not associated with any segments in this composition.\nThis action cannot be undone, and associations with these files will be lost.\nFiles will not be removed from your disk.\nAre you sure?");
+        i18n("This will unload all audio files that have no segments used in this composition.  Are you sure?");
 
     int reply = KMessageBox::warningContinueCancel(this, question);
 
     if (reply != KMessageBox::Continue)
         return;
 
-    std::set<AudioFileId> audioFiles;
+    std::set<Rosegarden::AudioFileId> audioFiles;
     Composition &comp = m_doc->getComposition();
 
     for (Composition::iterator it = comp.begin(); it != comp.end(); ++it)
     {
-        if ((*it)->getType() == Segment::Audio)
+        if ((*it)->getType() == Rosegarden::Segment::Audio)
             audioFiles.insert((*it)->getAudioFileId());
     }
 
-    std::vector<AudioFileId> toDelete;
+    std::vector<Rosegarden::AudioFileId> toDelete;
     for (std::vector<AudioFile*>::const_iterator
          aIt = m_doc->getAudioFileManager().begin();
          aIt != m_doc->getAudioFileManager().end(); ++aIt)
@@ -921,16 +857,9 @@ AudioManagerDialog::slotRemoveAllUnused()
 
     // Delete the audio files from the AFM
     //
-    for (std::vector<AudioFileId>::iterator dIt = toDelete.begin();
-            dIt != toDelete.end(); ++dIt) {
-
-	if (m_doc->getAudioFileManager().wasAudioFileRecentlyRecorded(*dIt)) {
-	    AudioFile *file = m_doc->getAudioFileManager().getAudioFile(*dIt);
-	    if (file) {
-		m_doc->addOrphanedAudioFile(strtoqstr(file->getFilename()));
-	    }
-	}
-
+    for (std::vector<Rosegarden::AudioFileId>::iterator dIt = toDelete.begin();
+            dIt != toDelete.end(); ++dIt)
+    {
         m_doc->getAudioFileManager().removeFile(*dIt);
         emit deleteAudioFile(*dIt);
     }
@@ -940,128 +869,6 @@ AudioManagerDialog::slotRemoveAllUnused()
     slotPopulateFileList();
 }
 
-UnusedAudioSelectionDialog::UnusedAudioSelectionDialog(QWidget *parent,
-						       QString introductoryText,
-						       std::vector<QString> fileNames,
-						       bool offerCancel) :
-    KDialogBase(parent, 0, true, i18n("Select Unused Audio Files"), (offerCancel ? (Ok | Cancel) : Ok))
-{
-    QVBox *vbox = makeVBoxMainWidget();
-    new QLabel(introductoryText, vbox);
-
-    m_listView = new KListView(vbox);
-
-    m_listView->addColumn(i18n("File name"));
-    m_listView->addColumn(i18n("File size"));
-    m_listView->addColumn(i18n("Last modified date"));
-
-    for (unsigned int i = 0; i < fileNames.size(); ++i) {
-	QString fileName = fileNames[i];
-	QFileInfo info(fileName);
-	QString fileSize = i18n(" (not found) ");
-	QString fileDate;
-	if (info.exists()) {
-	    fileSize = QString(" %1 ").arg(info.size());
-	    fileDate = QString(" %1 ").arg(info.lastModified().toString());
-	}
-	QListViewItem *item = new KListViewItem
-	    (m_listView, fileName, fileSize, fileDate);
-    }
-
-    m_listView->setSelectionMode(QListView::Multi);
-}
-
-std::vector<QString> 
-UnusedAudioSelectionDialog::getSelectedAudioFileNames() const
-{
-    std::vector<QString> selectedNames;
-
-    QListViewItem *item = m_listView->firstChild();
-
-    while (item) {
-
-	if (m_listView->isSelected(item)) {
-	    selectedNames.push_back(item->text(0));
-	}
-
-	item = item->nextSibling();
-    }
-
-    return selectedNames;
-}
-
-void
-AudioManagerDialog::slotDeleteUnused()
-{
-    std::set<AudioFileId> audioFiles;
-    Composition &comp = m_doc->getComposition();
-
-    for (Composition::iterator it = comp.begin(); it != comp.end(); ++it)
-    {
-        if ((*it)->getType() == Segment::Audio)
-            audioFiles.insert((*it)->getAudioFileId());
-    }
-
-    std::vector<QString> toDelete;
-    std::map<QString, AudioFileId> nameMap;
-
-    for (std::vector<AudioFile*>::const_iterator
-         aIt = m_doc->getAudioFileManager().begin();
-         aIt != m_doc->getAudioFileManager().end(); ++aIt)
-    {
-        if (audioFiles.find((*aIt)->getId()) == audioFiles.end()) {
-            toDelete.push_back(strtoqstr((*aIt)->getFilename()));
-	    nameMap[strtoqstr((*aIt)->getFilename())] = (*aIt)->getId();
-	}
-    }
-
-    UnusedAudioSelectionDialog *dialog = new UnusedAudioSelectionDialog
-	(this,
-	 i18n("The following audio files are not used in the current composition.\n\nPlease select the ones you wish to delete permanently from the hard disk.\n"),
-	 toDelete);
-
-    if (dialog->exec() == QDialog::Accepted) {
-
-	std::vector<QString> names = dialog->getSelectedAudioFileNames();
-
-	if (names.size() > 0) {
-	
-	    QString question =
-		i18n("About to delete 1 audio file permanently from the hard disk.\nThis action cannot be undone, and there will be no way to recover this file.\nAre you sure?", "About to delete %n audio files permanently from the hard disk.\nThis action cannot be undone, and there will be no way to recover these files.\nAre you sure?", names.size());
-	    
-	    int reply = KMessageBox::warningContinueCancel(this, question);
-
-	    if (reply != KMessageBox::Continue) {
-		delete dialog;
-		return;
-	    }
-
-	    for (int i = 0; i < names.size(); ++i) {
-		std::cerr << i << ": " << names[i] << std::endl;
-		QFile file(names[i]);
-		if (!file.remove()) {
-		    KMessageBox::error(this, i18n("File %1 could not be deleted.").arg(names[i]));
-		} else {
-		    if (nameMap.find(names[i]) != nameMap.end()) {
-			m_doc->getAudioFileManager().removeFile(nameMap[names[i]]);
-			emit deleteAudioFile(nameMap[names[i]]);
-		    } else {
-			std::cerr << "WARNING: Audio file name " << names[i] << " not in name map" << std::endl;
-		    }
-
-		    QFile peakFile(QString("%1.pk").arg(names[i]));
-		    peakFile.remove();
-		}
-	    }
-	}
-    }
-
-    m_fileList->clear();
-    slotPopulateFileList();
-    
-    delete dialog;
-}
-
 
 void
 AudioManagerDialog::slotRename()
@@ -1096,7 +903,7 @@ AudioManagerDialog::slotSelectionChanged(QListViewItem *item)
     //
     if (aItem && aItem->getSegment())
     {
-        SegmentSelection selection;
+        Rosegarden::SegmentSelection selection;
         selection.insert(aItem->getSegment());
         emit segmentsSelected(selection);
     }
@@ -1110,8 +917,8 @@ AudioManagerDialog::slotSelectionChanged(QListViewItem *item)
 // purpose.  Set segment to 0 for parent audio entries.
 //
 void
-AudioManagerDialog::setSelected(AudioFileId id, 
-                                const Segment *segment,
+AudioManagerDialog::setSelected(Rosegarden::AudioFileId id,
+                                Rosegarden::Segment *segment,
                                 bool propagate)
 {
     QListViewItem *it = m_fileList->firstChild();
@@ -1149,7 +956,7 @@ AudioManagerDialog::setSelected(AudioFileId id,
                         // Only propagate to segmentcanvas if asked to
                         if (propagate)
                         {
-                            SegmentSelection selection;
+                            Rosegarden::SegmentSelection selection;
                             selection.insert(aItem->getSegment());
                             emit segmentsSelected(selection);
                         }
@@ -1199,14 +1006,14 @@ AudioManagerDialog::slotCommandExecuted(KCommand*)
 
 void
 AudioManagerDialog::slotSegmentSelection(
-        const SegmentSelection &segments)
+        const Rosegarden::SegmentSelection &segments)
 {
-    const Segment *segment = 0;
+    Rosegarden::Segment *segment = 0;
 
-    for (SegmentSelection::const_iterator it = segments.begin();
+    for (SegmentSelection::iterator it = segments.begin();
                                     it != segments.end(); ++it)
     {
-        if ((*it)->getType() == Segment::Audio) 
+        if ((*it)->getType() == Rosegarden::Segment::Audio) 
         {
             // Only get one audio segment
             if (segment == 0)
@@ -1239,7 +1046,7 @@ AudioManagerDialog::slotCancelPlayingAudioFile()
 
 
 void
-AudioManagerDialog::closePlayingDialog(AudioFileId id)
+AudioManagerDialog::closePlayingDialog(Rosegarden::AudioFileId id)
 {
     //std::cout << "AudioManagerDialog::closePlayingDialog" << std::endl;
     if (m_audioPlayingDialog && id == m_playingAudioFile)
@@ -1254,7 +1061,7 @@ AudioManagerDialog::closePlayingDialog(AudioFileId id)
 bool
 AudioManagerDialog::addFile(const KURL& kurl)
 {
-    AudioFileId id = 0;
+    Rosegarden::AudioFileId id = 0;
 
     // Now set the "last add" path so that next time we use "file add"
     // we start looking in the same place.
@@ -1275,7 +1082,8 @@ AudioManagerDialog::addFile(const KURL& kurl)
 
     } else { // download locally
         if (KIO::NetAccess::download(kurl, newFilePath) == false) {
-            KMessageBox::error(this, i18n("Cannot download file %1").arg(kurl.prettyURL()));
+            KMessageBox::error(this, QString(i18n("Cannot download file %1"))
+                               .arg(kurl.prettyURL()));
             return false;
         }
     }
@@ -1285,16 +1093,16 @@ AudioManagerDialog::addFile(const KURL& kurl)
         id = m_doc->
             getAudioFileManager().addFile(std::string(newFilePath.data()));
     }
-    catch (AudioFileManager::BadAudioPathException e)
+    catch(std::string e)
     {
         CurrentProgressDialog::freeze();
 
         QString errorString = i18n("Cannot add file %1: %2")
-	    .arg(kurl.prettyURL()).arg(strtoqstr(e.getMessage()));
+	    .arg(kurl.prettyURL()).arg(strtoqstr(e));
         KMessageBox::sorry(this, errorString);
         return false;
     }
-    catch (QString e) //???
+    catch(QString e)
     {
         CurrentProgressDialog::freeze();
 
@@ -1313,11 +1121,11 @@ AudioManagerDialog::addFile(const KURL& kurl)
     {
         m_doc->getAudioFileManager().generatePreview(id);
     }
-    catch (Rosegarden::Exception e)
+    catch(std::string e)
     {
         CurrentProgressDialog::freeze();
 
-        QString message = strtoqstr(e.getMessage()) + "\n\n" +
+        QString message = strtoqstr(e) + "\n\n" +
                           i18n("Try copying this file to a directory where you have write permission and re-add it");
         KMessageBox::information(this, message);
         //return false;
@@ -1402,18 +1210,18 @@ AudioManagerDialog::addAudioFile(const QString &filePath)
 bool
 AudioManagerDialog::isSelectedTrackAudio()
 {
-    Composition &comp = m_doc->getComposition();
-    Studio &studio = m_doc->getStudio();
+    Rosegarden::Composition &comp = m_doc->getComposition();
+    Rosegarden::Studio &studio = m_doc->getStudio();
 
-    TrackId currentTrackId = comp.getSelectedTrack();
-    Track *track = comp.getTrackById(currentTrackId);
+    Rosegarden::TrackId currentTrackId = comp.getSelectedTrack();
+    Rosegarden::Track *track = comp.getTrackById(currentTrackId);
 
     if (track) {
-	InstrumentId ii = track->getInstrument();
-	Instrument *instrument = studio.getInstrumentById(ii);
+	Rosegarden::InstrumentId ii = track->getInstrument();
+	Rosegarden::Instrument *instrument = studio.getInstrumentById(ii);
 
 	if (instrument &&
-	    instrument->getType() == Instrument::Audio)
+	    instrument->getType() == Rosegarden::Instrument::Audio)
             return true;
     }
     
@@ -1426,11 +1234,11 @@ AudioManagerDialog::slotDistributeOnMidiSegment()
 {
     RG_DEBUG << "AudioManagerDialog::slotDistributeOnMidiSegment" << endl;
 
-    //Composition &comp = m_doc->getComposition();
+    //Rosegarden::Composition &comp = m_doc->getComposition();
 
     QList<RosegardenGUIView>& viewList = m_doc->getViewList();
     RosegardenGUIView *w = 0;
-    SegmentSelection selection;
+    Rosegarden::SegmentSelection selection;
 
     for(w = viewList.first(); w != 0; w = viewList.next())
     {
@@ -1439,18 +1247,18 @@ AudioManagerDialog::slotDistributeOnMidiSegment()
 
     // Store the insert times in a local vector
     //
-    std::vector<timeT> insertTimes;
+    std::vector<Rosegarden::timeT> insertTimes;
 
-    for (SegmentSelection::iterator i = selection.begin();
+    for (Rosegarden::SegmentSelection::iterator i = selection.begin();
          i != selection.end(); ++i)
     {
         // For MIDI (Internal) Segments only of course
         //
-        if ((*i)->getType() == Segment::Internal)
+        if ((*i)->getType() == Rosegarden::Segment::Internal)
         {
             for (Segment::iterator it = (*i)->begin(); it != (*i)->end(); ++it)
             {
-                if ((*it)->isa(Note::EventType))
+                if ((*it)->isa(Rosegarden::Note::EventType))
                     insertTimes.push_back((*it)->getAbsoluteTime());
             }
         }
@@ -1469,4 +1277,3 @@ const char* const AudioManagerDialog::AudioManagerDialogConfigGroup = "AudioMana
  
 }
 
-#include "audiomanagerdialog.moc"
