@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -57,20 +57,14 @@ class KLineEdit;
 class MidiDeviceListViewItem : public KListViewItem
 {
 public:
-    // Device
     MidiDeviceListViewItem(Rosegarden::DeviceId id,
                            QListView* parent, QString name);
 
-    // Bank
     MidiDeviceListViewItem(Rosegarden::DeviceId id,
                            QListViewItem* parent, QString name,
 			   bool percussion,
                            int msb, int lsb);
 
-    // Key Mapping
-    MidiDeviceListViewItem(Rosegarden::DeviceId id,
-                           QListViewItem* parent, QString name);
-
     Rosegarden::DeviceId getDeviceId() const { return m_deviceId; }
 
     virtual int compare(QListViewItem *i, int col, bool ascending) const;
@@ -93,7 +87,6 @@ public:
     int getBank()     { return m_bankNb; }
 
     void setPercussion(bool percussion);
-    bool isPercussion() const { return m_percussion; }
     void setMSB(int msb);
     void setLSB(int msb);
 
@@ -102,62 +95,10 @@ public:
 protected:
 
     //--------------- Data members ---------------------------------
-    bool   m_percussion;
     int    m_bankNb;
 };
 
-class MidiKeyMapListViewItem : public MidiDeviceListViewItem
-{
-public:
-    MidiKeyMapListViewItem(Rosegarden::DeviceId deviceId,
-			   QListViewItem* parent, QString name);
-
-    virtual int compare(QListViewItem *i, int col, bool ascending) const;
-
-    QString getName() const { return m_name; }
-
-protected:
-    QString m_name;
-};
-
-class NameSetEditor : public QVGroupBox
-{
-    Q_OBJECT
-public:
-    virtual void clearAll() = 0;
-
-    virtual void populate(QListViewItem *) = 0;
-    virtual void reset() = 0;
-
-public slots:
-    virtual void slotNameChanged(const QString&) = 0;
-    virtual void slotEntryButtonPressed() = 0;
-    void slotToggleInitialLabel();
-
-protected:
-    NameSetEditor(BankEditorDialog *bankEditor,
-		  QString title,
-		  QWidget *parent,
-		  const char *name,
-		  QString headingPrefix = "",
-		  bool showEntryButtons = false);
-
-    QPushButton *getEntryButton(int n) { return m_entryButtons[n]; }
-    const QPushButton *getEntryButton(int n) const { return m_entryButtons[n]; }
-
-    QGridLayout             *m_mainLayout;
-    BankEditorDialog*        m_bankEditor;
-    KCompletion              m_completion;
-    QPushButton             *m_initialLabel;
-    std::vector<QLabel*>     m_labels;
-    std::vector<KLineEdit*>  m_names;
-    QFrame                  *m_mainFrame;
-    QLabel                  *m_librarian;
-    QLabel                  *m_librarianEmail;
-    std::vector<QPushButton *> m_entryButtons;
-};
-
-class MidiProgramsEditor : public NameSetEditor
+class MidiProgramsEditor : public QVGroupBox
 {
     Q_OBJECT
 public:
@@ -165,26 +106,6 @@ public:
                        QWidget *parent,
                        const char *name = 0);
 
-    void clearAll();
-    void populate(QListViewItem*);
-    void reset();
-
-public slots:
-
-    // Check that any new MSB/LSB combination is unique for this device
-    //
-    void slotNewMSB(int value);
-    void slotNewLSB(int value);
-    void slotNewPercussion(); // gets value from checkbox
-
-    virtual void slotNameChanged(const QString &);
-    virtual void slotEntryButtonPressed();
-    void slotEntryMenuItemSelected(int);
-
-protected:
-
-    Rosegarden::MidiBank* getCurrentBank();
-
     int ensureUniqueMSB(int msb, bool ascending);
     int ensureUniqueLSB(int lsb, bool ascending);
 
@@ -194,6 +115,8 @@ protected:
 
     Rosegarden::ProgramList getBankSubset(const Rosegarden::MidiBank &);
 
+    Rosegarden::MidiBank* getCurrentBank();
+
     /// Set the currently loaded programs to new MSB and LSB
     void modifyCurrentPrograms(const Rosegarden::MidiBank &oldBank,
 			       const Rosegarden::MidiBank &newBank);
@@ -204,53 +127,46 @@ protected:
 
     void setBankName(const QString& s);
 
-    virtual QWidget *makeAdditionalWidget(QWidget *parent);
+    void clearAll();
+
+    void populateBank(QListViewItem*);
+
+    void resetMSBLSB();
+
+public slots:
+
+    // Check that any new MSB/LSB combination is unique for this device
+    //
+    void slotNewMSB(int value);
+    void slotNewLSB(int value);
+    void slotNewPercussion(); // gets value from checkbox
+
+    void slotProgramChanged(const QString&);
+
+protected:
 
     void blockAllSignals(bool block);
 
     //--------------- Data members ---------------------------------
+    BankEditorDialog*        m_bankEditor;
+
+    KCompletion              m_completion;
+    std::vector<KLineEdit*>  m_programNames;
+
+    QFrame                   *m_mainFrame;
+
     QCheckBox                *m_percussion;
     QSpinBox                 *m_msb;
     QSpinBox                 *m_lsb;
 
-    Rosegarden::MidiDevice   *m_device;
+    QLabel                   *m_librarian;
+    QLabel                   *m_librarianEmail;
 
     Rosegarden::MidiBank     *m_currentBank;
     Rosegarden::BankList     &m_bankList;
     Rosegarden::ProgramList  &m_programList;
 
     Rosegarden::MidiBank      m_oldBank;
-
-    unsigned int              m_currentMenuProgram;
-};
-
-class MidiKeyMappingEditor : public NameSetEditor
-{
-    Q_OBJECT
-
-public:
-    MidiKeyMappingEditor(BankEditorDialog *bankEditor,
-			 QWidget *parent,
-			 const char *name = 0);
-
-    void clearAll();
-    void populate(QListViewItem *);
-    Rosegarden::MidiKeyMapping &getMapping() { return m_mapping; }
-    void reset();
-
-public slots:
-    virtual void slotNameChanged(const QString &);
-    virtual void slotEntryButtonPressed();
-
-protected:
-    virtual QWidget *makeAdditionalWidget(QWidget *parent);
-    void blockAllSignals(bool block);
-
-    //--------------- Data members ---------------------------------
-
-    Rosegarden::MidiDevice *m_device;
-    std::string m_mappingName;
-    Rosegarden::MidiKeyMapping m_mapping;
 };
 
 class BankEditorDialog : public KMainWindow
@@ -276,6 +192,8 @@ public:
 
     void setCurrentDevice(Rosegarden::DeviceId device);
 
+    Rosegarden::MidiBank* getCurrentBank() { return m_programEditor->getCurrentBank(); }
+
     // Get a MidiDevice from an index number
     //
     Rosegarden::MidiDevice* getMidiDevice(Rosegarden::DeviceId);
@@ -284,8 +202,6 @@ public:
     Rosegarden::BankList&   getBankList()     { return m_bankList; }
     Rosegarden::ProgramList&getProgramList()  { return m_programList; }
 
-    Rosegarden::Studio *getStudio() { return m_studio; }
-
     void setModified(bool value);
 
     void checkModified();
@@ -308,9 +224,8 @@ public slots:
     void slotUpdate();
 
     void slotAddBank();
-    void slotAddKeyMapping();
-    void slotDelete();
-    void slotDeleteAll();
+    void slotDeleteBank();
+    void slotDeleteAllBanks();
 
     void slotImport();
     void slotExport();
@@ -357,8 +272,8 @@ protected:
     Rosegarden::Studio      *m_studio;
     RosegardenGUIDoc        *m_doc;
 
+    
     MidiProgramsEditor      *m_programEditor;
-    MidiKeyMappingEditor    *m_keyMappingEditor;
     KListView               *m_listView;
 
     QGroupBox               *m_optionBox;
@@ -370,9 +285,8 @@ protected:
     QPushButton             *m_applyButton;
 
     QPushButton             *m_addBank;
-    QPushButton             *m_addKeyMapping;
-    QPushButton             *m_delete;
-    QPushButton             *m_deleteAll;
+    QPushButton             *m_deleteBank;
+    QPushButton             *m_deleteAllBanks;
 
     QPushButton             *m_importBanks;
     QPushButton             *m_exportBanks;
@@ -388,7 +302,7 @@ protected:
 
     bool                     m_modified;
     bool                     m_keepBankList;
-    bool                     m_deleteAllReally;
+    bool                     m_deleteAll;
 
     Rosegarden::DeviceId     m_lastDevice;
     Rosegarden::MidiBank     m_lastBank;
