@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -33,7 +33,6 @@
 
 #include <klocale.h>
 #include <klineeditdlg.h>
-// #include <kactioncollection.h>
 
 #include "MidiTypes.h"
 #include "Selection.h"
@@ -193,13 +192,10 @@ bool ControllerEventAdapter::getValue(long& val)
     }
     else if (m_event->getType() == Rosegarden::PitchBend::EventType)
     {
-	long msb = 0, lsb = 0;
-        m_event->get<Rosegarden::Int>(Rosegarden::PitchBend::MSB, msb);
-        m_event->get<Rosegarden::Int>(Rosegarden::PitchBend::LSB, lsb);
-	
-        long value = msb;
+        long value = 0;
+        value = m_event->get<Rosegarden::Int>(Rosegarden::PitchBend::MSB);
         value <<= 7;
-        value |= lsb;
+        value |= m_event->get<Rosegarden::Int>(Rosegarden::PitchBend::LSB);
 
         //RG_DEBUG << "PitchBend Get Value = " << value << endl;
 
@@ -334,8 +330,6 @@ void ControlItem::updateValue()
 
 void ControlItem::updateFromValue()
 {
-    RG_DEBUG << "ControlItem::updateFromValue() : " << this << endl;
-
     if (m_elementAdapter->getValue(m_value)) {
 //         RG_DEBUG << "ControlItem::updateFromValue() : value = " << m_value << endl;
         setHeight(m_controlRuler->valueToHeight(m_value));
@@ -436,7 +430,7 @@ void ControlItem::handleMouseMove(QMouseEvent*, int /*deltaX*/, int deltaY)
 
 void ControlItem::handleMouseWheel(QWheelEvent *)
 {
-//     RG_DEBUG << "ControlItem::handleMouseWheel - got wheel event" << endl;
+    RG_DEBUG << "ControlItem::handleMouseWheel - got wheel event" << endl;
 }
 
 void ControlItem::setSelected(bool s)
@@ -672,7 +666,6 @@ ControlRuler::ControlRuler(Segment *segment,
                            const char* name, WFlags f) :
     RosegardenCanvasView(c, parent, name, f),
     m_parentEditView(parentView),
-    m_mainHorizontalScrollBar(0),
     m_rulerScale(rulerScale),
     m_eventSelection(new EventSelection(*segment)),
     m_segment(segment),
@@ -700,16 +693,11 @@ ControlRuler::ControlRuler(Segment *segment,
     m_numberFloat = new RosegardenTextFloat(this);
     m_numberFloat->hide();
 
-    m_segment->addObserver(this);
-
     emit stateChange("have_controller_item_selected", false);
 }
 
 ControlRuler::~ControlRuler()
 {
-    if (m_segment) {
-        m_segment->removeObserver(this);
-    }
 }
 
 void ControlRuler::slotUpdate()
@@ -760,12 +748,6 @@ void ControlRuler::setControlTool(ControlTool* tool)
     m_tool = tool;
 }
 
-void
-ControlRuler::segmentDeleted(const Rosegarden::Segment *)
-{
-    m_segment = 0;
-}
-
 void ControlRuler::contentsMousePressEvent(QMouseEvent* e)
 {
     if (e->button() != Qt::LeftButton)
@@ -834,7 +816,7 @@ void ControlRuler::contentsMousePressEvent(QMouseEvent* e)
         }
     }
 
-    if (topItem && !m_selectedItems.contains(topItem)) { // select the top item
+    if (topItem) { // select the top item
         m_selectedItems << topItem;
         topItem->setSelected(true);
         topItem->handleMouseButtonPress(e);
@@ -937,7 +919,7 @@ void ControlRuler::contentsMouseMoveEvent(QMouseEvent* e)
 //            ElementAdapter* adapter = item->getElementAdapter();
 
             // set value to highest in selection
-            if (item->getValue() >= value)
+            if (item->getValue() > value)
             {
                 value = item->getValue();
                 m_numberFloat->setText(QString("%1").arg(value));
@@ -957,11 +939,6 @@ ControlRuler::contentsWheelEvent(QWheelEvent *e)
     QCanvasView::contentsWheelEvent(e);
 }
 
-QScrollBar* ControlRuler::getMainHorizontalScrollBar()
-{
-    return m_mainHorizontalScrollBar ? m_mainHorizontalScrollBar : horizontalScrollBar();
-}
-
 void ControlRuler::updateSelection()
 {
     clearSelectedItems();
@@ -1029,12 +1006,11 @@ ControlRuler::clearSelectedItems()
 
 void ControlRuler::clear()
 {
-    QCanvasItemList allItems = canvas()->allItems();
-
-    for (QCanvasItemList::Iterator it=allItems.begin(); it!=allItems.end(); ++it) {
-        if (ControlItem *item = dynamic_cast<ControlItem*>(*it)) {
-            delete item;
-        }
+    QCanvasItemList list = canvas()->allItems();
+    QCanvasItemList::Iterator it = list.begin();
+    for (; it != list.end(); ++it) {
+	if (*it != m_selectionRect)
+	    delete *it;
     }
 }
 
@@ -1057,6 +1033,9 @@ long ControlRuler::heightToValue(int h)
     val *= getMaxItemValue();
     val /= (ItemHeightRange);
     val = std::min(val, long(getMaxItemValue()));
+
+     RG_DEBUG << "ControlRuler::heightToValue : height = " << h << " - val = " << val << endl;
+
     return val;
 }
 
@@ -1168,11 +1147,9 @@ PropertyControlRuler::setStaff(Rosegarden::Staff *staff)
     RG_DEBUG << "PropertyControlRuler::setStaff(" << staff << ")" << endl;
 
     m_staff->removeObserver(this);
-    m_segment->removeObserver(this);
     m_staff = staff;
     m_segment = &m_staff->getSegment();
     m_staff->addObserver(this);
-    m_segment->addObserver(this);
 
     //!!! need to delete the control items here
 
@@ -1223,9 +1200,8 @@ PropertyControlRuler::drawBackground()
 
 PropertyControlRuler::~PropertyControlRuler()
 {
-    if (m_staff) {
+    if (m_staff)
         m_staff->removeObserver(this);
-    }
 }
 
 QString PropertyControlRuler::getName()
@@ -1245,8 +1221,6 @@ void PropertyControlRuler::init()
     for(ViewElementList::iterator i = viewElementList->begin();
         i != viewElementList->end(); ++i) {
 
-	if ((*i)->event()->isa(Rosegarden::Note::EventRestType)) continue;
-
  	double x = m_rulerScale->getXForTime((*i)->getViewAbsoluteTime());
  	new ControlItem(this, new ViewElementAdapter(*i, getPropertyName()), int(x + m_staffOffset),
                         int(m_rulerScale->getXForTime((*i)->getViewAbsoluteTime() +
@@ -1259,8 +1233,6 @@ void PropertyControlRuler::elementAdded(const Rosegarden::Staff *, ViewElement *
 {
     RG_DEBUG << "PropertyControlRuler::elementAdded()\n";
 
-    if (el->event()->isa(Rosegarden::Note::EventRestType)) return;
-
     double x = m_rulerScale->getXForTime(el->getViewAbsoluteTime());
 
     new ControlItem(this, new ViewElementAdapter(el, getPropertyName()), int(x + m_staffOffset),
@@ -1292,19 +1264,6 @@ void PropertyControlRuler::staffDeleted(const Rosegarden::Staff *)
     m_staff = 0;
 }
 
-void
-PropertyControlRuler::endMarkerTimeChanged(const Rosegarden::Segment *s, bool)
-{
-    timeT endMarkerTime = s->getEndMarkerTime();
-
-    RG_DEBUG << "PropertyControlRuler::endMarkerTimeChanged() " << endMarkerTime << endl;
-
-    clearSelectedItems();
-
-    clear();
-    init();
-}
-
 void PropertyControlRuler::computeStaffOffset()
 {
     LinedStaff* lStaff = dynamic_cast<LinedStaff*>(m_staff);
@@ -1314,7 +1273,7 @@ void PropertyControlRuler::computeStaffOffset()
 
 void PropertyControlRuler::startPropertyLine()
 {
-    RG_DEBUG << "PropertyControlRuler::startPropertyLine\n";
+    RG_DEBUG << "PropertyControlRuler::startPropertyLine" << endl;
     m_propertyLineShowing = true;
     this->setCursor(Qt::pointingHandCursor);
 }
@@ -1322,7 +1281,7 @@ void PropertyControlRuler::startPropertyLine()
 void
 PropertyControlRuler::contentsMousePressEvent(QMouseEvent *e)
 {
-    RG_DEBUG << "PropertyControlRuler::contentsMousePressEvent\n";
+    RG_DEBUG << "PropertyControlRuler::contentsMousePressEvent" << endl;
 
     if (!m_propertyLineShowing)
     {
@@ -1359,7 +1318,7 @@ PropertyControlRuler::contentsMousePressEvent(QMouseEvent *e)
 void 
 PropertyControlRuler::contentsMouseReleaseEvent(QMouseEvent *e)
 {
-    RG_DEBUG << "PropertyControlRuler::contentsMouseReleaseEvent\n";
+    RG_DEBUG << "PropertyControlRuler::contentsMouseReleaseEvent" << endl;
 
     /*
     if (m_propertyLineShowing)
@@ -1409,7 +1368,7 @@ PropertyControlRuler::contentsMouseReleaseEvent(QMouseEvent *e)
 void 
 PropertyControlRuler::contentsMouseMoveEvent(QMouseEvent *e)
 {
-    RG_DEBUG << "PropertyControlRuler::contentsMouseMoveEvent\n";
+    RG_DEBUG << "PropertyControlRuler::contentsMouseMoveEvent" << endl;
 
     if (!m_propertyLineShowing)
     {
@@ -1431,30 +1390,6 @@ PropertyControlRuler::contentsMouseMoveEvent(QMouseEvent *e)
     canvas()->update();
 }
 
-void PropertyControlRuler::contentsContextMenuEvent(QContextMenuEvent* e)
-{
-    RG_DEBUG << "PropertyControlRuler::contentsContextMenuEvent\n";
-
-    // check if we actually have some control items
-    QCanvasItemList list = canvas()->allItems();
-    bool haveItems = false;
-    
-    QCanvasItemList::Iterator it = list.begin();
-    for (; it != list.end(); ++it) {
-        if (dynamic_cast<ControlItem*>(*it)) {
-            haveItems = true;
-            break;
-        }
-    }
-
-    RG_DEBUG << "PropertyControlRuler::contentsContextMenuEvent : haveItems = "
-             << haveItems << endl;
-
-    emit stateChange("have_note_events_in_segment", haveItems);
-
-    ControlRuler::contentsContextMenuEvent(e);
-}
-
 void 
 PropertyControlRuler::drawPropertyLine(Rosegarden::timeT startTime,
                                        Rosegarden::timeT endTime,
@@ -1467,8 +1402,8 @@ PropertyControlRuler::drawPropertyLine(Rosegarden::timeT startTime,
         std::swap(startValue, endValue);
     }
 
-    RG_DEBUG << "PropertyControlRuler::drawPropertyLine - set velocity from "
-             << startTime 
+    RG_DEBUG << "PropertyControlRuler::drawPropertyLine - "
+             << "set velocity from " << startTime 
              << " to " << endTime << endl;
 
     // Add the "true" to catch Events overlapping this line
@@ -1476,24 +1411,15 @@ PropertyControlRuler::drawPropertyLine(Rosegarden::timeT startTime,
     Rosegarden::EventSelection selection(*m_segment, startTime, endTime, true);
     Rosegarden::PropertyPattern pattern = Rosegarden::DecrescendoPattern;
 
-    bool haveNotes = selection.contains(Rosegarden::Note::EventType);
+    SelectionPropertyCommand *command = 
+        new SelectionPropertyCommand(&selection,
+                                     Rosegarden::BaseProperties::VELOCITY,
+                                     pattern,
+                                     startValue,
+                                     endValue);
 
-    if (haveNotes) {
-        
-        SelectionPropertyCommand *command = 
-            new SelectionPropertyCommand(&selection,
-                                         Rosegarden::BaseProperties::VELOCITY,
-                                         pattern,
-                                         startValue,
-                                         endValue);
+    m_parentEditView->addCommandToHistory(command);
 
-        m_parentEditView->addCommandToHistory(command);
-
-    } else {
-
-        RG_DEBUG << "PropertyControlRuler::drawPropertyLine - no notes in selection\n";
-
-    }
 }
 
 void
@@ -1536,22 +1462,24 @@ PropertyControlRuler::selectAllProperties()
     emit stateChange("have_controller_item_selected", true);
 }
 
-
 //----------------------------------------
 ControllerEventsRuler::ControllerEventsRuler(Rosegarden::Segment *segment,
                                              Rosegarden::RulerScale* rulerScale,
                                              EditViewBase* parentView,
                                              QCanvas* c,
                                              QWidget* parent,
-                                             const ControlParameter *controller,
+                                             ControlParameter *controller,
                                              const char* name, WFlags f)
     : ControlRuler(segment, rulerScale, parentView, c, parent, name, f),
+      m_segmentDeleted(false),
       m_defaultItemWidth(20),
       m_controlLine(new QCanvasLine(canvas())),
       m_controlLineShowing(false),
       m_controlLineX(0),
       m_controlLineY(0)
 {
+    m_segment->addObserver(this);
+
     // Make a copy of the ControlParameter if we have one
     //
     if (controller)
@@ -1670,6 +1598,8 @@ ControllerEventsRuler::drawBackground()
 
 ControllerEventsRuler::~ControllerEventsRuler()
 {
+    if (!m_segmentDeleted)
+        m_segment->removeObserver(this);
 }
 
 
@@ -1749,6 +1679,16 @@ void ControllerEventsRuler::eventRemoved(const Segment*, Event *e)
     }
 }
 
+void ControllerEventsRuler::endMarkerTimeChanged(const Segment*, bool)
+{
+    // nothing to do
+}
+
+void ControllerEventsRuler::segmentDeleted(const Segment*)
+{
+    m_segmentDeleted = false;
+}
+
 void ControllerEventsRuler::insertControllerEvent()
 {
     timeT insertTime = m_rulerScale->getTimeForX(m_lastEventPos.x());
@@ -2027,7 +1967,7 @@ PropertyViewRuler::PropertyViewRuler(RulerScale *rulerScale,
     m_boldFont.setBold(true);
     m_fontMetrics = QFontMetrics(m_boldFont);
 
-    setBackgroundColor(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::SegmentCanvas));
+    setBackgroundColor(RosegardenGUIColours::SegmentCanvas);
 
     QString tip = i18n("%1 controller").arg(strtoqstr(property));
     QToolTip::add(this, tip);
@@ -2088,7 +2028,7 @@ PropertyViewRuler::paintEvent(QPaintEvent* e)
 
     if (getHScaleFactor() != 1.0) paint.scale(getHScaleFactor(), 1.0);
 
-    paint.setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::MatrixElementBorder));
+    paint.setPen(RosegardenGUIColours::MatrixElementBorder);
 
     QRect clipRect = e->rect().normalize();
 
@@ -2160,8 +2100,8 @@ PropertyBox::paintEvent(QPaintEvent *e)
 {
     QPainter paint(this);
 
-    paint.setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::MatrixElementBorder));
-    //paint.setBrush(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::MatrixElementBlock));
+    paint.setPen(RosegardenGUIColours::MatrixElementBorder);
+    //paint.setBrush(RosegardenGUIColours::MatrixElementBlock);
 
     paint.setClipRegion(e->region());
     paint.setClipRect(e->rect().normalize());
@@ -2261,4 +2201,3 @@ PropertyBox::paintEvent(QPaintEvent *e)
 // }
 
 // ControlRulerCanvasRepository* ControlRulerCanvasRepository::m_instance = 0;
-#include "controlruler.moc"
