@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -31,7 +31,7 @@
 #include "PropertyName.h"
 
 #include "rosegardencanvasview.h"
-#include "hzoomable.h"
+#include "widgets.h"
 
 namespace Rosegarden { class RulerScale; class EventSelection; class ControlParameter; }
 
@@ -48,7 +48,7 @@ class QPopupMenu;
 /**
  * ControlRuler : base class for Control Rulers
  */
-class ControlRuler : public RosegardenCanvasView, public Rosegarden::SegmentObserver
+class ControlRuler : public RosegardenCanvasView
 {
     Q_OBJECT
 
@@ -77,9 +77,6 @@ public:
 
     Rosegarden::RulerScale* getRulerScale() { return m_rulerScale; }
 
-    // SegmentObserver interface
-    virtual void segmentDeleted(const Rosegarden::Segment *);
-
     static const int DefaultRulerHeight;
     static const int MinItemHeight;
     static const int MaxItemHeight;
@@ -88,8 +85,6 @@ public:
     void flipForwards();
     void flipBackwards();
 
-    void setMainHorizontalScrollBar(QScrollBar* s ) { m_mainHorizontalScrollBar = s; }
-
 signals:
     void stateChange(const QString&, bool);
 
@@ -105,14 +100,10 @@ protected:
     virtual void contentsWheelEvent(QWheelEvent*);
     virtual void contentsContextMenuEvent(QContextMenuEvent*);
 
-    virtual QScrollBar* getMainHorizontalScrollBar();
-
     virtual void computeStaffOffset() {};
 
     virtual void layoutItem(ControlItem*);
 
-
-
     // Stacking of the SegmentItems on the canvas
     //
     std::pair<int, int> getZMinMax();
@@ -133,7 +124,6 @@ protected:
     //--------------- Data members ---------------------------------
 
     EditViewBase*               m_parentEditView;
-    QScrollBar*                 m_mainHorizontalScrollBar;
     Rosegarden::RulerScale*     m_rulerScale;
     Rosegarden::EventSelection* m_eventSelection;
     Rosegarden::Segment*        m_segment;
@@ -160,8 +150,6 @@ protected:
     QPopupMenu* m_menu;
 
     RosegardenTextFloat  *m_numberFloat;
-
-    bool m_hposUpdatePending;
 };
 
 /**
@@ -196,15 +184,11 @@ public:
     virtual void startPropertyLine();
     virtual void selectAllProperties();
 
-    /// SegmentObserver interface
-    virtual void endMarkerTimeChanged(const Rosegarden::Segment *, bool shorten);
-
 protected:
 
     virtual void contentsMousePressEvent(QMouseEvent*);
     virtual void contentsMouseReleaseEvent(QMouseEvent*);
     virtual void contentsMouseMoveEvent(QMouseEvent*);
-    virtual void contentsContextMenuEvent(QContextMenuEvent*);
 
     void drawPropertyLine(Rosegarden::timeT startTime,
                           Rosegarden::timeT endTime,
@@ -231,7 +215,7 @@ protected:
 /**
  * ControllerEventsRuler : edit Controller events
  */
-class ControllerEventsRuler : public ControlRuler
+class ControllerEventsRuler : public ControlRuler, public Rosegarden::SegmentObserver
 {
 public:
     ControllerEventsRuler(Rosegarden::Segment*,
@@ -239,7 +223,7 @@ public:
                           EditViewBase* parentView,
                           QCanvas*,
                           QWidget* parent=0,
-                          const Rosegarden::ControlParameter *controller = 0,
+                          Rosegarden::ControlParameter *controller = 0,
                           const char* name=0, WFlags f=0);
 
     virtual ~ControllerEventsRuler();
@@ -255,6 +239,8 @@ public:
     /// SegmentObserver interface
     virtual void eventAdded(const Rosegarden::Segment *, Rosegarden::Event *);
     virtual void eventRemoved(const Rosegarden::Segment *, Rosegarden::Event *);
+    virtual void endMarkerTimeChanged(const Rosegarden::Segment *, bool shorten);
+    virtual void segmentDeleted(const Rosegarden::Segment *);
 
     virtual void insertControllerEvent();
     virtual void eraseControllerEvent();
@@ -282,6 +268,7 @@ protected:
                          int endValue);
 
     //--------------- Data members ---------------------------------
+    bool                          m_segmentDeleted;
     int                           m_defaultItemWidth;
 
     Rosegarden::ControlParameter  *m_controller;
