@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -21,7 +21,6 @@
 
 #include "devicemanager.h"
 #include "constants.h"
-#include "dialogs.h"
 
 #include <qtable.h>
 #include <qvbox.h>
@@ -265,10 +264,10 @@ DeviceManagerDialog::populate()
 {
     Rosegarden::DeviceList *devices = m_studio->getDevices();
 
-    //KConfig *config = kapp->config();
-    //config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
-    //Rosegarden::DeviceId recordDevice =
-	//config->readUnsignedNumEntry("midirecorddevice");
+    KConfig *config = kapp->config();
+    config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
+    Rosegarden::DeviceId recordDevice =
+	config->readUnsignedNumEntry("midirecorddevice");
 
     m_playDevices.clear();
     m_recordDevices.clear();
@@ -351,11 +350,9 @@ DeviceManagerDialog::populate()
 	m_recordTable->setItem(deviceCount, RECORD_CONNECTION_COL, item);
 
 	QCheckTableItem *check = new QCheckTableItem(m_recordTable, QString());
-	//check->setChecked((*it)->getId() == recordDevice);
-	//check->setText(((*it)->getId() == recordDevice) ?
-	//	       i18n("Yes") : i18n("No"));
-	check->setChecked((*it)->isRecording());
-	check->setText((*it)->isRecording() ? i18n("Yes") : i18n("No"));
+	check->setChecked((*it)->getId() == recordDevice);
+	check->setText(((*it)->getId() == recordDevice) ?
+		       i18n("Yes") : i18n("No"));
 	m_recordTable->setItem(deviceCount, RECORD_CURRENT_COL, check);
 
 	m_recordTable->adjustRow(deviceCount);
@@ -438,43 +435,33 @@ DeviceManagerDialog::closeEvent(QCloseEvent *e)
 class ChangeRecordDeviceCommand : public KNamedCommand
 {
 public:
-    ChangeRecordDeviceCommand(Rosegarden::DeviceId deviceId, bool action) :
+    ChangeRecordDeviceCommand(Rosegarden::DeviceId deviceId) :
 	KNamedCommand(i18n("Change Record Device")),
-	m_deviceId(deviceId), m_action(action) { }
+	m_deviceId(deviceId) { }
     
     virtual void execute() { swap(); }
     virtual void unexecute() { swap(); }
 
 private:
     Rosegarden::DeviceId m_deviceId;
-    bool m_action;
     void swap() {
 
 	KConfig *config = kapp->config();
 	config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
-	QStringList devList = config->readListEntry("midirecorddevice");
-	QString sdevice = QString::number(m_deviceId);
-	if (m_action) 
-	{
-	    if(!devList.contains(sdevice))
-		devList.append(sdevice);
-	}
-	else
-	{
-	    if(devList.contains(sdevice))
-	    	devList.remove(sdevice);
-	}
-	config->writeEntry("midirecorddevice", devList);
+	Rosegarden::DeviceId oldDeviceId = config->readUnsignedNumEntry
+	    ("midirecorddevice", 0);
+
+	Rosegarden::DeviceId newDeviceId = m_deviceId;
+	config->writeEntry("midirecorddevice", newDeviceId);
 
         // send the selected device to the sequencer
         Rosegarden::MappedEvent mEdevice
-	    (Rosegarden::MidiInstrumentBase, 
+	    (Rosegarden::MidiInstrumentBase, // InstrumentId
 	     Rosegarden::MappedEvent::SystemRecordDevice,
-	     Rosegarden::MidiByte(m_deviceId),
-	     Rosegarden::MidiByte(m_action));
+	     Rosegarden::MidiByte(newDeviceId));
         Rosegarden::StudioControl::sendMappedEvent(mEdevice);
 
-	m_action = !m_action;
+	m_deviceId = oldDeviceId;
     }
 };
 
@@ -536,11 +523,6 @@ DeviceManagerDialog::slotDeletePlayDevice()
     CreateOrDeleteDeviceCommand *command = new CreateOrDeleteDeviceCommand
 	(m_studio, id);
     m_document->getCommandHistory()->addCommand(command);
-
-    QByteArray data;
-    QDataStream arg(data, IO_WriteOnly);
-    arg << (unsigned int)id;
-    rgapp->sequencerSend("removeDevice(unsigned int)", data);
 }
 
 void
@@ -574,18 +556,9 @@ DeviceManagerDialog::slotPlayValueChanged(int row, int col)
     {
 	std::string name = qstrtostr(m_playTable->text(row, col));
 	if (device->getName() != name) {
-
 	    m_document->getCommandHistory()->addCommand
 		(new RenameDeviceCommand(m_studio, id, name));
 	    emit deviceNamesChanged();
-
-	    QByteArray data;
-	    QDataStream arg(data, IO_WriteOnly);
-
-	    arg << (unsigned int)id;
-	    arg << m_playTable->text(row, col);
-
-	    rgapp->sequencerSend("renameDevice(unsigned int, QString)", data);
 	}
     }
     break;
@@ -624,18 +597,9 @@ DeviceManagerDialog::slotRecordValueChanged(int row, int col)
     {
 	std::string name = qstrtostr(m_recordTable->text(row, col));
 	if (device->getName() != name) {
-
 	    m_document->getCommandHistory()->addCommand
 		(new RenameDeviceCommand(m_studio, id, name));
 	    emit deviceNamesChanged();
-
-	    QByteArray data;
-	    QDataStream arg(data, IO_WriteOnly);
-
-	    arg << (unsigned int)id;
-	    arg << m_recordTable->text(row, col);
-
-	    rgapp->sequencerSend("renameDevice(unsigned int, QString)", data);
 	}
     }
     break;
@@ -657,22 +621,32 @@ DeviceManagerDialog::slotRecordValueChanged(int row, int col)
 	QCheckTableItem *check =
 	    dynamic_cast<QCheckTableItem *>(m_recordTable->item(row, col));
 	if (!check) return;
-	
-	bool actionConnect = check->isChecked();
 
-	// The following lines are not strictly needed, but give the checkboxes 
-	// a smoother behavior while waiting a confirmation from the sequencer.
-	//
-	check->setText(actionConnect ? i18n("Yes") : i18n("No"));
-	Rosegarden::MidiDevice *device = 
-	    dynamic_cast<Rosegarden::MidiDevice*>(m_studio->getDevice(id));
-	device->setRecording(actionConnect);
+	check->setText(i18n("Yes"));
+	check->setChecked(true);
+
+	for (int i = 0; i < m_recordTable->numRows(); ++i) {
+	    if (i == row) continue;
+	    QCheckTableItem *othercheck =
+		dynamic_cast<QCheckTableItem *>(m_recordTable->item(i, col));
+	    if (othercheck) {
+		othercheck->setChecked(false);
+		othercheck->setText(i18n("No"));
+	    }
+	}
 
 	m_recordTable->setCurrentCell(row, 0);
 
-	m_document->getCommandHistory()->addCommand
-	    (new ChangeRecordDeviceCommand(id, actionConnect));
-		
+	KConfig *config = kapp->config();
+	config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
+	Rosegarden::DeviceId oldRecordId = config->readUnsignedNumEntry
+	    ("midirecorddevice", 0);
+
+	if (oldRecordId != id) {
+	    m_document->getCommandHistory()->addCommand
+		(new ChangeRecordDeviceCommand(id));
+	}
+
 	m_recordTable->blockSignals(false);
     }
     break;
@@ -716,21 +690,25 @@ DeviceManagerDialog::slotImport()
     }
 
     KURL url = KFileDialog::getOpenURL
-        (deviceDir,
+        (
+#if KDE_VERSION >= 196614
+         deviceDir,
+#else
+         QString::null,
+#endif
          "audio/x-rosegarden-device audio/x-rosegarden audio/x-soundfont",
          this, i18n("Import from Device in File"));
 
     if (url.isEmpty()) return;
 
     ImportDeviceDialog *dialog = new ImportDeviceDialog(this, url);
-    if (dialog->doImport() && dialog->exec() == QDialog::Accepted) {
+    if (dialog->exec() == QDialog::Accepted) {
 
 	ModifyDeviceCommand *command = 0;
 
 	Rosegarden::BankList banks(dialog->getBanks());
 	Rosegarden::ProgramList programs(dialog->getPrograms());
 	Rosegarden::ControlList controls(dialog->getControllers());
-	Rosegarden::KeyMappingList keyMappings(dialog->getKeyMappings());
 	Rosegarden::MidiDevice::VariationType variation(dialog->getVariationType());
 	std::string librarianName(dialog->getLibrarianName());
 	std::string librarianEmail(dialog->getLibrarianEmail());
@@ -749,19 +727,14 @@ DeviceManagerDialog::slotImport()
                                           librarianName,
                                           librarianEmail);
         
-        if (dialog->shouldOverwriteBanks()) {
+        if (dialog->shouldOverwriteBanks())
             command->setVariation(variation);
-	}
         if (dialog->shouldImportBanks()) {
             command->setBankList(banks);
             command->setProgramList(programs);
         }
-        if (dialog->shouldImportControllers()) {
+        if (dialog->shouldImportControllers())
             command->setControlList(controls);
-	}
-	if (dialog->shouldImportKeyMappings()) {
-	    command->setKeyMappingList(keyMappings);
-	}
         
         command->setOverwrite(dialog->shouldOverwriteBanks());
         command->setRename(dialog->shouldRename());
@@ -846,4 +819,3 @@ DeviceManagerDialog::slotSetControllers()
     emit editControllers(id);
 }
 
-#include "devicemanager.moc"
