@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -26,15 +26,12 @@
 #include <qstring.h>
 #include <qcanvas.h>
 #include <qspinbox.h>
-#include <kcombobox.h>
 
 #include <string>
 
 #include "NotationTypes.h"
 #include "editcommands.h"
 #include "notepixmapfactory.h"
-#include "commondialogs.h" // HSpinBox
-#include "widgets.h" // RosegardenPitchChooser
 
 class QWidget;
 class QLineEdit;
@@ -100,7 +97,6 @@ protected:
 
     QCheckBox *m_commonTimeButton;
     QCheckBox *m_hideSignatureButton;
-    QCheckBox *m_hideBarsButton;
     QCheckBox *m_normalizeRestsButton;
 
     QRadioButton *m_asGivenButton;
@@ -134,7 +130,6 @@ public:
     Rosegarden::Key getKey() const;
 
     bool shouldApplyToAll() const;
-    bool shouldBeTransposed() const; 
     ConversionType getConversionType() const;
 
 public slots:
@@ -164,7 +159,6 @@ protected:
     QLabel *m_explanatoryLabel;
 
     QRadioButton *m_applyToAllButton;
-    QRadioButton *m_yesTransposeButton;
 
     QRadioButton *m_noConversionButton;
     QRadioButton *m_convertButton;
@@ -211,13 +205,11 @@ public:
     Rosegarden::Note::Type getUnitType() const;
     int getUntupledCount() const;
     int getTupledCount() const;
-    bool hasTimingAlready() const;
 
 public slots:
     void slotUnitChanged(const QString &);
     void slotUntupledChanged(const QString &);
     void slotTupledChanged(const QString &);
-    void slotHasTimingChanged();
 
 protected:
 
@@ -231,9 +223,6 @@ protected:
     KComboBox *m_untupledCombo;
     KComboBox *m_tupledCombo;
 
-    QCheckBox *m_hasTimingAlready;
-
-    QGroupBox *m_timingDisplayBox;
     QLabel *m_selectionDurationDisplay;
     QLabel *m_untupledDurationCalculationDisplay;
     QLabel *m_untupledDurationDisplay;
@@ -266,59 +255,19 @@ public slots:
     void slotTextChanged(const QString &);
     void slotTypeChanged(const QString &);
 
-    /*
-     * Save previous state of assorted widgets for restoration in the next
-     * instance
-     */
-    void slotOK();
-
-    // convenience canned texts
-    void slotDynamicShortcutChanged(const QString &);
-    void slotDirectionShortcutChanged(const QString &);
-    void slotLocalDirectionShortcutChanged(const QString &);
-    void slotTempoShortcutChanged(const QString &);
-    void slotLocalTempoShortcutChanged(const QString &);
-
-    //
-    // special Lilypond directives, initial phase, as cheap text events; will
-    // eventually move out of Rosegarden::Text, and out of this dialog into
-    // some other less cheesy interface 
-    //
-    void slotLilypondDirectiveChanged(const QString &);
-
 protected:
 
     //--------------- Data members ---------------------------------
 
     QLineEdit *m_text;
     KComboBox *m_typeCombo;
-    KComboBox *m_dynamicShortcutCombo;
-    KComboBox *m_directionShortcutCombo;
-    KComboBox *m_localDirectionShortcutCombo;
-    KComboBox *m_tempoShortcutCombo;
-    KComboBox *m_localTempoShortcutCombo;
-    // temporary home:
-    KComboBox *m_lilypondDirectiveCombo;
-
 
     QLabel *m_staffAboveLabel;
     QLabel *m_textExampleLabel;
     QLabel *m_staffBelowLabel;
-    QLabel *m_dynamicShortcutLabel;
-    QLabel *m_directionShortcutLabel;
-    QLabel *m_localDirectionShortcutLabel;
-    QLabel *m_tempoShortcutLabel;
-    QLabel *m_localTempoShortcutLabel;
-    // temporary home:
-    QLabel *m_directiveLabel;
-
-    QString m_prevChord;
-    QString m_prevLyric;
-    QString m_prevAnnotation;
 
     NotePixmapFactory *m_notePixmapFactory;
     std::vector<std::string> m_styles;
-//    std::vector<std::string> m_directives;
 
     std::string getTextType() const;
     std::string getTextString() const;
@@ -429,7 +378,7 @@ public:
 		          bool inserting = false); // inserting or editing
 
     bool isModified() const { return m_modified; }
-    Rosegarden::Event getEvent();
+    Rosegarden::Event getEvent() const;
 
     // Setup the dialog for a new event type
     void setupForEvent();
@@ -438,38 +387,30 @@ public slots:
     void slotEventTypeChanged(int value);
     void slotAbsoluteTimeChanged(int value);
     void slotDurationChanged(int value);
-    void slotNotationAbsoluteTimeChanged(int value);
-    void slotNotationDurationChanged(int value);
     void slotPitchChanged(int value);
     void slotVelocityChanged(int value);
     void slotMetaChanged(const QString &);
     void slotEditAbsoluteTime();
-    void slotEditNotationAbsoluteTime();
     void slotEditDuration();
-    void slotEditNotationDuration();
-    void slotLockNotationChanged();
     void slotEditPitch();
-    void slotSysexLoad();
-    void slotSysexSave();
 
 protected:
+
+    const Rosegarden::Event &m_originalEvent;
     Rosegarden::Event        m_event;
     RosegardenGUIDoc        *m_doc;
 
     std::string              m_type;
     Rosegarden::timeT        m_absoluteTime;
-    Rosegarden::timeT        m_notationAbsoluteTime;
     Rosegarden::timeT        m_duration;
-    Rosegarden::timeT        m_notationDuration;
 
     KComboBox               *m_typeCombo;
-    QLabel                  *m_typeLabel;
-
     QLabel                  *m_timeLabel;
     QLabel                  *m_durationLabel;
     QLabel                  *m_pitchLabel;
     QLabel                  *m_velocityLabel;
     QLabel                  *m_metaLabel;
+
     QLabel                  *m_controllerLabel;
     QLabel                  *m_controllerLabelValue;
 
@@ -481,17 +422,6 @@ protected:
     QPushButton             *m_timeEditButton;
     QPushButton             *m_durationEditButton;
     QPushButton             *m_pitchEditButton;
-    QPushButton             *m_sysexLoadButton;
-    QPushButton             *m_sysexSaveButton;
-
-    QGroupBox               *m_notationGroupBox;
-    QLabel                  *m_notationTimeLabel;
-    QLabel                  *m_notationDurationLabel;
-    QSpinBox                *m_notationTimeSpinBox;
-    QSpinBox                *m_notationDurationSpinBox;
-    QPushButton             *m_notationTimeEditButton;
-    QPushButton             *m_notationDurationEditButton;
-    QCheckBox               *m_lockNotationValues;
 
     QLineEdit               *m_metaEdit;
 
@@ -499,6 +429,68 @@ protected:
 };
 
 
+class TempoDialog : public KDialogBase
+{
+    Q_OBJECT
+public:
+    typedef enum{
+        AddTempo,
+        ReplaceTempo,
+        AddTempoAtBarStart,
+        GlobalTempo,
+        GlobalTempoWithDefault
+    } TempoDialogAction;
+
+    TempoDialog(QWidget *parent, RosegardenGUIDoc *doc,
+		bool timeEditable = false);
+    ~TempoDialog();
+
+    // Set the position at which we're checking the tempo
+    //
+    void setTempoPosition(Rosegarden::timeT time);
+
+public slots:
+    virtual void slotOk();
+    void slotActionChanged();
+    void slotTempoChanged(const QString &);
+
+signals:
+    // Return results in this signal
+    //
+    void changeTempo(Rosegarden::timeT,  // tempo change time
+                     double,             // tempo value
+                     TempoDialog::TempoDialogAction); // tempo action
+
+protected:
+    void populateTempo();
+    void updateBeatLabels(double newTempo);
+
+    //--------------- Data members ---------------------------------
+
+    RosegardenGUIDoc     *m_doc;
+    Rosegarden::timeT     m_tempoTime;
+    double                m_tempoValue;
+    RosegardenSpinBox    *m_tempoValueSpinBox;
+
+    QLabel	         *m_tempoBeatLabel;
+    QLabel	         *m_tempoBeat;
+    QLabel	         *m_tempoBeatsPerMinute;
+
+    RosegardenTimeWidget *m_timeEditor;
+
+    QLabel               *m_tempoTimeLabel;
+    QLabel               *m_tempoBarLabel;
+    QLabel               *m_tempoStatusLabel;
+    
+    QRadioButton         *m_tempoChangeHere;
+    QRadioButton         *m_tempoChangeBefore;
+    QLabel	         *m_tempoChangeBeforeAt;
+    QRadioButton         *m_tempoChangeStartOfBar;
+    QRadioButton         *m_tempoChangeGlobal;
+    QCheckBox            *m_defaultBox;
+};
+
+
 class ClefDialog : public KDialogBase
 {
     Q_OBJECT
@@ -507,7 +499,7 @@ public:
     enum ConversionType {
 	NoConversion,
 	ChangeOctave,
-	Transpose,
+	Transpose
     };
 
     ClefDialog(QWidget *parent,
@@ -758,28 +750,13 @@ private:
 };
 
 
-class SplitByRecordingSrcDialog : public KDialogBase
-{
-    Q_OBJECT
-public:
-    SplitByRecordingSrcDialog(QWidget *parent, RosegardenGUIDoc *doc);
-    
-    int getChannel();
-    int getDevice();
-    
-private:
-    std::vector<int> m_deviceIds;
-    KComboBox *m_channel;
-    KComboBox *m_device;
-};
-
 class InterpretDialog : public KDialogBase
 {
     Q_OBJECT
 public:
     InterpretDialog(QWidget *parent);
 
-    // an OR from AdjustMenuInterpretCommand's constants
+    // an OR from TransformsMenuInterpretCommand's constants
     int getInterpretations();
 
 protected slots:
@@ -840,10 +817,6 @@ signals:
     void stopped();   // someone pushed the stop button
 
 protected:
-    void setPastEndMode();
-
-    bool          m_pastEndMode;
-
     int           m_totalTime;
 
     QLabel       *m_label;
@@ -874,32 +847,24 @@ public slots:
     void slotResolutionChanged(int);
     void slotPreviewPitch(int);
     void slotInstrumentChanged(int);
-    void slotPitchSelectorChanged(int);
-    void slotPitchChanged(int);
     void populate(int dev);
 
 protected:
 
     //--------------- Data members ---------------------------------
 
-    RosegardenGUIDoc       *m_doc;
+    RosegardenGUIDoc   *m_doc;
 
     KComboBox              *m_metronomeDevice;
     KComboBox              *m_metronomeInstrument;
     KComboBox              *m_metronomeResolution;
-    KComboBox              *m_metronomePitchSelector;
     RosegardenPitchChooser *m_metronomePitch;
     QSpinBox               *m_metronomeBarVely;
     QSpinBox               *m_metronomeBeatVely;
     QSpinBox               *m_metronomeSubBeatVely;
     InstrumentParameterBox *m_instrumentParameterBox;
-    QCheckBox              *m_playEnabled;
-    QCheckBox              *m_recordEnabled;
-    	
-    bool                   m_modified;
-    Rosegarden::MidiByte   m_barPitch;
-    Rosegarden::MidiByte   m_beatPitch;
-    Rosegarden::MidiByte   m_subBeatPitch;
+
+    bool                m_modified;
 };
 
 class LilypondOptionsDialog : public KDialogBase
@@ -907,9 +872,7 @@ class LilypondOptionsDialog : public KDialogBase
     Q_OBJECT
 
 public:
-    LilypondOptionsDialog(QWidget *parent,
-			  QString windowCaption = "",
-			  QString heading = "");
+    LilypondOptionsDialog(QWidget *parent);
 
 public slots:
     void slotOk();
@@ -925,8 +888,6 @@ protected:
     QCheckBox *m_lilyExportPointAndClick;
     QCheckBox *m_lilyExportBarChecks;
     QCheckBox *m_lilyExportBeams;
-    QCheckBox *m_lilyExportStaffGroup;
-    QCheckBox *m_lilyExportStaffMerge;
 };
 
 
@@ -945,133 +906,4 @@ protected:
 };
 
 
-class MakeOrnamentDialog : public KDialogBase
-{
-    Q_OBJECT
-
-public:
-    MakeOrnamentDialog(QWidget *parent, QString defaultName, int defaultBasePitch);
-    
-    QString getName() const;
-    int getBasePitch() const;
-
-protected:
-    QLineEdit *m_name;
-    RosegardenPitchChooser *m_pitch;
-};
-
-
-class UseOrnamentDialog : public KDialogBase
-{
-    Q_OBJECT
-
-public:
-    UseOrnamentDialog(QWidget *parent, Rosegarden::Composition *);
-
-    Rosegarden::TriggerSegmentId getId() const;
-    Rosegarden::Mark getMark() const;
-    bool getRetune() const;
-    std::string getTimeAdjust() const;
-
-public slots:
-    void slotOk();
-    void slotMarkChanged(int);
-
-protected:
-    void setupFromConfig();
-
-    std::vector<Rosegarden::Mark> m_marks;
-
-    Rosegarden::Composition  *m_composition;
-    KComboBox                *m_ornament;
-    KComboBox                *m_mark;
-    QLabel                   *m_textLabel;
-    QLineEdit                *m_text;
-    QCheckBox                *m_retune;
-    KComboBox                *m_adjustTime;
-};
-
-class TriggerSegmentDialog : public KDialogBase
-{
-    Q_OBJECT
-
-public:
-    TriggerSegmentDialog(QWidget *parent, Rosegarden::Composition *);
-
-    Rosegarden::TriggerSegmentId getId() const;
-    bool getRetune() const;
-    std::string getTimeAdjust() const;
-
-public slots:
-    void slotOk();
-
-protected:
-    void setupFromConfig();
-
-    Rosegarden::Composition  *m_composition;
-    KComboBox                *m_segment;
-    QCheckBox                *m_retune;
-    KComboBox                *m_adjustTime;
-};
-
-/**
- * ask the user to give us information about the selected audio segment for
- * Tempo calculations
- */
-class BeatsBarsDialog : public KDialogBase
-{
-    Q_OBJECT
-	
-public:
-    BeatsBarsDialog();
-    BeatsBarsDialog(QWidget *parent);
-
-    int getQuantity() { return m_spinBox->value(); }
-    int getMode()     { return m_comboBox->currentItem();   } 
-
-protected:
-    QSpinBox  *m_spinBox;
-    KComboBox *m_comboBox;
-};
-
-
-class IdentifyTextCodecDialog : public KDialogBase
-{
-    Q_OBJECT
-    
-public:
-    IdentifyTextCodecDialog(QWidget *parent, std::string text);
-
-    std::string getCodec() const { return m_codec; }
-
-protected slots:
-    void slotCodecSelected(int);
-
-protected:
-    std::string m_text;
-    std::string m_codec;
-    std::vector<std::string> m_codecs;
-    QLabel *m_example;
-};
-
-
-/*
- * Creates a small dialog box containing a RosegardenPitchChooser widget.  The
- * info paramter provides extra information as a reminder what this particular
- * picker is for, eg. Highest, Lowest, From, To
- */
-class PitchPickerDialog : public KDialogBase
-{
-    Q_OBJECT
-
-public:
-
-    PitchPickerDialog(QWidget* parent, int initialPitch, QString info);
-    ~PitchPickerDialog();
-
-    int getPitch() { return m_pitch->getPitch(); }
-    
-private:
-    RosegardenPitchChooser* m_pitch;
-};
 #endif
