@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -28,7 +28,6 @@
 #include "NotationTypes.h"
 #include "Selection.h"
 #include "SegmentNotationHelper.h"
-#include "SegmentMatrixHelper.h"
 #include "BaseProperties.h"
 #include "Clipboard.h"
 #include "Profiler.h"
@@ -124,7 +123,8 @@ CutAndCloseCommand::CloseCommand::execute()
 
     for (Segment::iterator i = m_segment->findTime(m_gapEnd);
 	 m_segment->isBeforeEndMarker(i); ++i) {
-	events.push_back((*i)->copyMoving(-timeDifference));
+	events.push_back(new Event
+			 (**i, (*i)->getAbsoluteTime() - timeDifference));
     }
 
     timeT oldEndTime = m_segment->getEndTime();
@@ -183,7 +183,8 @@ CutAndCloseCommand::CloseCommand::unexecute()
     for (Segment::iterator i = starti; m_segment->isBeforeEndMarker(i); ) {
 	Segment::iterator j(i);
 	++j;
-	events.push_back((*i)->copyMoving(timeDifference));
+	events.push_back(new Event
+			 (**i, (*i)->getAbsoluteTime() + timeDifference));
 	m_segment->erase(i);
 	i = j;
     }
@@ -207,7 +208,6 @@ CopyCommand::CopyCommand(EventSelection &selection,
     m_targetClipboard(clipboard)
 {
     m_sourceClipboard = new Rosegarden::Clipboard;
-    m_savedClipboard = 0;
     m_sourceClipboard->newSegment(&selection)->setLabel
 	(selection.getSegment().getLabel() + " " + qstrtostr(i18n("(excerpt)")));
 }
@@ -218,164 +218,112 @@ CopyCommand::CopyCommand(SegmentSelection &selection,
     m_targetClipboard(clipboard)
 {
     m_sourceClipboard = new Rosegarden::Clipboard;
-    m_savedClipboard = 0;
 
     for (SegmentSelection::iterator i = selection.begin();
 	 i != selection.end(); ++i) {
-	QString newLabel = strtoqstr((*i)->getLabel());
-	if (newLabel.contains(i18n("(copied)"))) {
-	    m_sourceClipboard->newSegment(*i);
-	} else {
-	    m_sourceClipboard->newSegment(*i)->
-		setLabel(qstrtostr(i18n("%1 (copied)").arg(newLabel)));
-	}
+	m_sourceClipboard->newSegment(*i)->setLabel((*i)->getLabel() + " " +
+						    qstrtostr(i18n("(copied)")));
     }
 }
 
-CopyCommand::CopyCommand(Rosegarden::Composition *composition,
-			 Rosegarden::timeT beginTime,
-			 Rosegarden::timeT endTime,
-			 Rosegarden::Clipboard *clipboard) :
-    KNamedCommand(i18n("Copy Range")),
-    m_targetClipboard(clipboard)
-{
-    m_sourceClipboard = new Rosegarden::Clipboard;
-    m_savedClipboard = 0;
-
-    for (Rosegarden::Composition::iterator i = composition->begin();
-	 i != composition->end(); ++i) {
-	if ((*i)->getStartTime() < endTime &&
-	    (*i)->getRepeatEndTime() > beginTime) {
-	    m_sourceClipboard->newSegment(*i, beginTime, endTime, true);
-	}
-    }
-
-    Rosegarden::TimeSignatureSelection tsigsel
-	(*composition, beginTime, endTime, true);
-    m_sourceClipboard->setTimeSignatureSelection(tsigsel);
-
-    Rosegarden::TempoSelection temposel
-	(*composition, beginTime, endTime, true);
-    m_sourceClipboard->setTempoSelection(temposel);
-
-    m_sourceClipboard->setNominalRange(beginTime, endTime);
-}
-
 CopyCommand::~CopyCommand()
 {
     delete m_sourceClipboard;
-    delete m_savedClipboard;
 }
 
 void
 CopyCommand::execute()
 {
-    if (!m_savedClipboard) {
-	m_savedClipboard = new Rosegarden::Clipboard(*m_targetClipboard);
-    }
+//    RG_DEBUG << "CopyCommand::execute" << endl;
 
+    Rosegarden::Clipboard temp(*m_targetClipboard);
     m_targetClipboard->copyFrom(m_sourceClipboard);
+    m_sourceClipboard->copyFrom(&temp);
 }
 
 void
 CopyCommand::unexecute()
 {
-    m_targetClipboard->copyFrom(m_savedClipboard);
+//    RG_DEBUG << "CopyCommand::unexecute" << endl;
+
+    Rosegarden::Clipboard temp(*m_sourceClipboard);
+    m_sourceClipboard->copyFrom(m_targetClipboard);
+    m_targetClipboard->copyFrom(&temp);
 }
 
 
 PasteSegmentsCommand::PasteSegmentsCommand(Rosegarden::Composition *composition,
 					   Rosegarden::Clipboard *clipboard,
-					   Rosegarden::timeT pasteTime,
-					   Rosegarden::TrackId baseTrack,
-					   bool useExactTracks) :
+					   Rosegarden::timeT pasteTime) :
     KNamedCommand(getGlobalName()),
     m_composition(composition),
-    m_clipboard(new Rosegarden::Clipboard(*clipboard)),
-    m_pasteTime(pasteTime),
-    m_baseTrack(baseTrack),
-    m_exactTracks(useExactTracks),
-    m_detached(false)
+    m_clipboard(clipboard),
+    m_pasteTime(pasteTime)
 {
     // nothing else
 }
 
 PasteSegmentsCommand::~PasteSegmentsCommand()
 {
-    if (m_detached) {
-	for (unsigned int i = 0; i < m_addedSegments.size(); ++i) {
-	    delete m_addedSegments[i];
-	}
+    for (unsigned int i = 0; i < m_addedSegments.size(); ++i) {
+	delete m_addedSegments[i];
     }
-
-    delete m_clipboard;
 }
 
 void
 PasteSegmentsCommand::execute()
 {
+    if (m_clipboard->isEmpty()) return;
+
     if (m_addedSegments.size() > 0) {
 	// been here before
 	for (unsigned int i = 0; i < m_addedSegments.size(); ++i) {
+            m_addedSegments[i]->setTrack(m_composition->getSelectedTrack());
 	    m_composition->addSegment(m_addedSegments[i]);
 	}
 	return;
     }
 
-    if (m_clipboard->isEmpty()) return;
-
     // We want to paste such that the earliest Segment starts at
-    // m_pasteTime and the others start at the same times relative to
-    // that as they did before.  Likewise for track, unless
-    // m_exactTracks is set.
+    // m_pasteTime and the others start at the same times relative
+    // to that as they did before
 
-    timeT earliestStartTime = m_clipboard->getBaseTime();
+    timeT earliestStartTime = 0;
     timeT latestEndTime = 0;
-    int lowestTrackPos = -1;
+    int trackOffset = 0;
 
     for (Rosegarden::Clipboard::iterator i = m_clipboard->begin();
 	 i != m_clipboard->end(); ++i) {
 
-	int trackPos = m_composition->getTrackPositionById((*i)->getTrack());
-	if (trackPos >= 0 &&
-	    (lowestTrackPos < 0 || trackPos < lowestTrackPos)) {
-	    lowestTrackPos = trackPos;
+	if (i == m_clipboard->begin() ||
+	    (*i)->getStartTime() < earliestStartTime) {
+	    earliestStartTime = (*i)->getStartTime();
+            trackOffset = (*i)->getTrack();
 	}
 
-        if ((*i)->getEndMarkerTime() > latestEndTime) {
+        if ((*i)->getEndTime() > latestEndTime)
             latestEndTime = (*i)->getEndMarkerTime();
-	}
     }
 
-    if (m_exactTracks) lowestTrackPos = 0;
-    if (lowestTrackPos < 0) lowestTrackPos = 0;
     timeT offset = m_pasteTime - earliestStartTime;
-    int baseTrackPos = m_composition->getTrackPositionById(m_baseTrack);
-    int trackOffset = baseTrackPos - lowestTrackPos;
 
     for (Rosegarden::Clipboard::iterator i = m_clipboard->begin();
 	 i != m_clipboard->end(); ++i) {
 
-	int newTrackPos = trackOffset +
-	    m_composition->getTrackPositionById((*i)->getTrack());
+        TrackId newTrackId = m_composition->getSelectedTrack() 
+            + (*i)->getTrack()
+            - trackOffset;
 
-	Rosegarden::Track *track = m_composition->getTrackByPosition(newTrackPos);
-
-	if (!track) {
-	    newTrackPos = 0;
-	    track = m_composition->getTrackByPosition(newTrackPos);
-	}
-
-	TrackId newTrackId = track->getId();
+        // needs to check for valid id
+        if (newTrackId < m_composition->getMinTrackId() ||
+            newTrackId > m_composition->getMaxTrackId()) continue;
 
 	Segment *segment = new Segment(**i);
 	segment->setStartTime(segment->getStartTime() + offset);
         segment->setTrack(newTrackId);
         m_composition->addSegment(segment);
-	if (m_clipboard->isPartial()) {
-	    segment->normalizeRests(segment->getStartTime(),
-				    segment->getEndMarkerTime());
-	}
+	if (m_clipboard->isPartial()) segment->normalizeRests(segment->getStartTime(),
+							      segment->getEndTime());
 	m_addedSegments.push_back(segment);
     }
 
@@ -383,8 +331,6 @@ PasteSegmentsCommand::execute()
     m_composition->setPosition(latestEndTime 
                                + m_pasteTime 
                                - earliestStartTime);
-    
-    m_detached = false;
 }
 
 void
@@ -393,7 +339,6 @@ PasteSegmentsCommand::unexecute()
     for (unsigned int i = 0; i < m_addedSegments.size(); ++i) {
 	m_composition->detachSegment(m_addedSegments[i]);
     }
-    m_detached = true;
 }
     
 
@@ -404,7 +349,7 @@ PasteEventsCommand::PasteEventsCommand(Rosegarden::Segment &segment,
     BasicCommand(getGlobalName(), segment, pasteTime,
 		 getEffectiveEndTime(segment, clipboard, pasteTime)),
     m_relayoutEndTime(getEndTime()),
-    m_clipboard(new Rosegarden::Clipboard(*clipboard)),
+    m_clipboard(clipboard),
     m_pasteType(pasteType)
 {
     if (pasteType != OpenAndPaste) {
@@ -432,16 +377,11 @@ PasteEventsCommand::PasteEventsCommand(Rosegarden::Segment &segment,
 				       PasteType pasteType) :
     BasicCommand(getGlobalName(), segment, pasteTime, pasteEndTime),
     m_relayoutEndTime(getEndTime()),
-    m_clipboard(new Rosegarden::Clipboard(*clipboard)),
+    m_clipboard(clipboard),
     m_pasteType(pasteType)
 {
 }
 
-PasteEventsCommand::~PasteEventsCommand()
-{
-    delete m_clipboard;
-}
-
 PasteEventsCommand::PasteTypeMap
 PasteEventsCommand::getPasteTypes()
 {
@@ -538,19 +478,6 @@ PasteEventsCommand::modifySegment()
     RG_DEBUG << "PasteEventsCommand::modifySegment() : paste type = "
              << m_pasteType << " - pasteTime = "
              << pasteTime << " - origin = " << origin << endl;
-
-    // First check for group IDs, which we want to make unique in the
-    // copies in the destination segment
-
-    std::map<long, long> groupIdMap;
-    for (Segment::iterator i = source->begin(); i != source->end(); ++i) {
-	long groupId = -1;
-	if ((*i)->get<Int>(BEAMED_GROUP_ID, groupId)) {
-	    if (groupIdMap.find(groupId) == groupIdMap.end()) {
-		groupIdMap[groupId] = destination->getNextId();
-	    }
-	}
-    }
     
     switch (m_pasteType) {
 
@@ -572,10 +499,7 @@ PasteEventsCommand::modifySegment()
 	std::vector<Event *> copies;
 	for (Segment::iterator i = destination->findTime(pasteTime);
 	     i != destination->end(); ++i) {
-	    Event *e = (*i)->copyMoving(duration);
-	    if (e->has(BEAMED_GROUP_ID)) {
-		e->set<Int>(BEAMED_GROUP_ID, groupIdMap[e->get<Int>(BEAMED_GROUP_ID)]);
-	    }
+	    Event *e = new Event(**i, (*i)->getAbsoluteTime() + duration);
 	    copies.push_back(e);
 	}
 
@@ -592,15 +516,19 @@ PasteEventsCommand::modifySegment()
     case NoteOverlay:
 	for (Segment::iterator i = source->begin(); i != source->end(); ++i) {
 	    if ((*i)->isa(Note::EventRestType)) continue;
-	    Event *e = (*i)->copyMoving(pasteTime - origin);
-	    if (e->has(BEAMED_GROUP_ID)) {
-		e->set<Int>(BEAMED_GROUP_ID,
-			    groupIdMap[e->get<Int>(BEAMED_GROUP_ID)]);
-	    }
 	    if ((*i)->isa(Note::EventType)) {
-		helper.insertNote(e); // e is model event: we retain ownership of it
-		delete e;
+		long pitch = 0;
+		Accidental explicitAccidental = NoAccidental;
+		(*i)->get<String>(ACCIDENTAL, explicitAccidental);
+		if ((*i)->get<Int>(PITCH, pitch)) {
+		    helper.insertNote
+			((*i)->getAbsoluteTime() - origin + pasteTime,
+			 Note::getNearestNote((*i)->getDuration()),
+			 pitch, explicitAccidental);
+		}
 	    } else {
+		Event *e = new Event
+		    (**i, (*i)->getAbsoluteTime() - origin + pasteTime);
 		destination->insert(e);
 	    }
 	}
@@ -613,7 +541,8 @@ PasteEventsCommand::modifySegment()
 
 	    if ((*i)->isa(Note::EventRestType)) continue;
 
-	    Event *e = (*i)->copyMoving(pasteTime - origin);
+	    Event *e = new Event
+		(**i, (*i)->getAbsoluteTime() - origin + pasteTime);
 
 	    if (e->has(BEAMED_GROUP_TYPE) &&
 		e->get<String>(BEAMED_GROUP_TYPE) == GROUP_TYPE_BEAMED) {
@@ -621,10 +550,6 @@ PasteEventsCommand::modifySegment()
 		e->unset(BEAMED_GROUP_TYPE);
 	    }
 
-	    if (e->has(BEAMED_GROUP_ID)) {
-		e->set<Int>(BEAMED_GROUP_ID, groupIdMap[e->get<Int>(BEAMED_GROUP_ID)]);
-	    }
-
 	    destination->insert(e);
 	}
 
@@ -637,10 +562,8 @@ PasteEventsCommand::modifySegment()
     RG_DEBUG << "PasteEventsCommand::modifySegment() - inserting\n";
 
     for (Segment::iterator i = source->begin(); i != source->end(); ++i) {
-	Event *e = (*i)->copyMoving(pasteTime - origin);
-	if (e->has(BEAMED_GROUP_ID)) {
-	    e->set<Int>(BEAMED_GROUP_ID, groupIdMap[e->get<Int>(BEAMED_GROUP_ID)]);
-	}
+	Event *e = new Event
+	    (**i, (*i)->getAbsoluteTime() - origin + pasteTime);
 	destination->insert(e);
     }
 
@@ -728,7 +651,7 @@ EventEditCommand::modifySegment()
 
 // -------------------- SelectionPropertyCommand -----------------
 //
-// 
+//
 SelectionPropertyCommand::SelectionPropertyCommand(
         Rosegarden::EventSelection *selection,
         const Rosegarden::PropertyName &property,
@@ -754,21 +677,16 @@ SelectionPropertyCommand::modifySegment()
 
     Rosegarden::timeT endTime = 0;
     Rosegarden::timeT startTime = 0;
-    bool haveStart = false, haveEnd = false;
 
     // Get start and end times
     //
     for (;i != m_selection->getSegmentEvents().end(); ++i)
     {
-        if ((*i)->getAbsoluteTime() < startTime || !haveStart) {
+        if ((*i)->getAbsoluteTime() < startTime)
             startTime = (*i)->getAbsoluteTime();
-	    haveStart = true;
-	}
         
-        if ((*i)->getAbsoluteTime() > endTime || !haveEnd) {
+        if ((*i)->getAbsoluteTime() > endTime)
             endTime = (*i)->getAbsoluteTime();
-	    haveEnd = true;
-	}
     }
 
     double step = double(m_value1 - m_value2) / double(endTime - startTime);
@@ -777,7 +695,6 @@ SelectionPropertyCommand::modifySegment()
     for (i = m_selection->getSegmentEvents().begin();
          i != m_selection->getSegmentEvents().end(); ++i)
     {
-	// flat
         if (m_pattern == Rosegarden::FlatPattern)
             (*i)->set<Rosegarden::Int>(m_property, m_value1);
         else if (m_pattern == Rosegarden::AlternatingPattern)
@@ -787,28 +704,26 @@ SelectionPropertyCommand::modifySegment()
             else
                 (*i)->set<Rosegarden::Int>(m_property, m_value2);
 
-	// crescendo, decrescendo
-	// (determined by step, above, which is in turn influenced by whether
-	// value1 is greater than value2)
-        } else if ((m_pattern == Rosegarden::CrescendoPattern)||
-	          (m_pattern == Rosegarden::DecrescendoPattern))
+        } else if (m_pattern == Rosegarden::CrescendoPattern)
+        {
+
+            (*i)->set<Rosegarden::Int>(m_property,
+                                       m_value2 +
+                                       int(step * (*i)->getAbsoluteTime()));
+        } else if (m_pattern == Rosegarden::DecrescendoPattern)
         {
             (*i)->set<Rosegarden::Int>(m_property,
                                        m_value1 -
-                                       int(step *
-					   ((*i)->getAbsoluteTime() - startTime)));
-	// ringing
+                                       int(step * (*i)->getAbsoluteTime()));
         } else if (m_pattern == Rosegarden::RingingPattern)
         {
             if (count % 2 == 0)
                 (*i)->set<Rosegarden::Int>
                     (m_property,
-                     m_value1 - int(step * 
-				    ((*i)->getAbsoluteTime() - startTime)));
+                     m_value1 - int(step * (*i)->getAbsoluteTime()));
             else
             {
-                int value = m_value2 - int(lowStep *
-					   ((*i)->getAbsoluteTime() - startTime));
+                int value = m_value2 - int(lowStep * (*i)->getAbsoluteTime());
                 if (value < 0) value = 0;
 
                 (*i)->set<Rosegarden::Int>(m_property, value);
@@ -1115,52 +1030,6 @@ EventUnquantizeCommand::modifySegment()
 }
 
 
-//-----------------Collapse Notes Command-------------------
-//
-//
-void
-AdjustMenuCollapseNotesCommand::modifySegment()
-{
-    SegmentNotationHelper helper(getSegment());
-    timeT endTime = getEndTime();
-
-    // This is really nasty stuff.  We can't go in forward direction
-    // using the j-iterator trick because collapseNoteAggressively may
-    // erase the following iterator as well as the preceding one.  We
-    // can't go backward naively, because collapseNoteAggressively
-    // erases i from the EventSelection now that it's a
-    // SegmentObserver.  We need the fancy hybrid j-iterator-backward
-    // technique applied to selections instead of segments.
-    
-    EventSelection::eventcontainer::iterator i =
-	m_selection->getSegmentEvents().end();
-    EventSelection::eventcontainer::iterator j = i;
-    EventSelection::eventcontainer::iterator beg =
-	m_selection->getSegmentEvents().begin();
-    bool thisOne = false;
-
-    while (i != beg && (!thisOne || (*i != *beg))) {
-	
-	--j;
-
-	if (thisOne) {
-	    helper.collapseNoteAggressively(*i, endTime);
-	}
-	
-	// rather than "true" one could perform a test to see
-	// whether j pointed to a candidate for collapsing:
-	thisOne = true;
-	
-	i = j;
-    }
-    
-    if (thisOne) {
-	helper.collapseNoteAggressively(*i, endTime);
-    }
-}
-
-
-
 SetLyricsCommand::SetLyricsCommand(Segment *segment, QString newLyricData) :
     KNamedCommand(getGlobalName()),
     m_segment(segment),
@@ -1304,12 +1173,10 @@ TransposeCommand::modifySegment()
 	 i != m_selection->getSegmentEvents().end(); ++i) {
 
 	if ((*i)->isa(Note::EventType)) {
-	    try {
-		long pitch = (*i)->get<Int>(PITCH);
-		pitch += m_semitones;
-		(*i)->set<Int>(PITCH, pitch); 
-		(*i)->unset(ACCIDENTAL);
-	    } catch (...) { }
+	    long pitch = (*i)->get<Int>(PITCH);
+	    pitch += m_semitones;
+	    (*i)->set<Int>(PITCH, pitch); 
+	    (*i)->unset(ACCIDENTAL);
 	}
     }
 }
@@ -1320,7 +1187,7 @@ RescaleCommand::RescaleCommand(EventSelection &sel,
 			       bool closeGap) :
     BasicCommand(getGlobalName(), sel.getSegment(),
 		 sel.getStartTime(),
-		 getAffectedEndTime(sel, newDuration, closeGap),
+		 closeGap ? sel.getSegment().getEndMarkerTime() : sel.getEndTime(),
 		 true),
     m_selection(&sel),
     m_oldDuration(sel.getTotalDuration()),
@@ -1330,25 +1197,6 @@ RescaleCommand::RescaleCommand(EventSelection &sel,
     // nothing else
 }
 
-timeT
-RescaleCommand::getAffectedEndTime(EventSelection &sel,
-				   timeT newDuration,
-				   bool closeGap)
-{
-    timeT preScaleEnd = sel.getEndTime();
-    if (closeGap) preScaleEnd = sel.getSegment().getEndMarkerTime();
-
-    // dupe of rescale(), but we can't use that here as the m_
-    // variables may not have been set
-    double d = preScaleEnd;
-    d *= newDuration;
-    d /= sel.getTotalDuration();
-    d += 0.5;
-    timeT postScaleEnd = (timeT)d;
-    
-    return std::max(preScaleEnd, postScaleEnd);
-}
-
 timeT
 RescaleCommand::rescale(timeT t)
 {
@@ -1391,7 +1239,7 @@ RescaleCommand::modifySegment()
 	     i != segment.end(); ++i) {
 	    // move all events including any following the end marker
 	    toErase.push_back(*i);
-	    toInsert.push_back((*i)->copyMoving(diff));
+	    toInsert.push_back(new Event(**i, (*i)->getAbsoluteTime() + diff));
 	}
     }
 
@@ -1461,23 +1309,15 @@ MoveCommand::modifySegment()
     for (i  = m_selection->getSegmentEvents().begin();
 	 i != m_selection->getSegmentEvents().end(); ++i) {
 
-	RG_DEBUG << "MoveCommand::modifySegment: event at " << (*i)->getAbsoluteTime() << " type " << (*i)->getType() << endl;
-
 	if ((*i)->isa(Note::EventRestType)) continue;
 
 	toErase.push_back(*i);
 	timeT newTime =
 	    (m_useNotationTimings ?
 	     (*i)->getNotationAbsoluteTime() : (*i)->getAbsoluteTime()) + m_delta;
-
-	Event *e;
-	if (m_useNotationTimings) {
-	    e = new Event(**i, newTime, (*i)->getDuration(), (*i)->getSubOrdering(),
-			  newTime, (*i)->getNotationDuration());
-	} else {
-	    e = new Event(**i, newTime);
-	}
-
+	Event *e = new Event(**i, newTime);
+	if (m_useNotationTimings)
+	    e->setNotationDuration((*i)->getNotationDuration());
 	toInsert.push_back(e);
     }
 
@@ -1485,12 +1325,7 @@ MoveCommand::modifySegment()
 
     for (unsigned int j = 0; j < toErase.size(); ++j) {
 	Segment::iterator jtr(segment.findSingle(toErase[j]));
-	if (jtr != segment.end()) {
-	    RG_DEBUG << "found event " << j << endl;
-	    segment.erase(jtr);
-	} else {
-	    RG_DEBUG << "failed to find event " << j << endl;
-	}	    
+	if (jtr != segment.end()) segment.erase(jtr);
     }
 
     for (unsigned int j = 0; j < toInsert.size(); ++j) {
@@ -1740,235 +1575,3 @@ ModifyMarkerCommand::unexecute()
 }
 
 
-void
-SetTriggerCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if (!m_notesOnly || (*i)->isa(Note::EventType)) {
-	    (*i)->set<Int>(TRIGGER_SEGMENT_ID, m_triggerSegmentId);
-	    (*i)->set<Rosegarden::Bool>(TRIGGER_SEGMENT_RETUNE, m_retune);
-	    (*i)->set<Rosegarden::String>(TRIGGER_SEGMENT_ADJUST_TIMES, m_timeAdjust);
-	    if (m_mark != Rosegarden::Marks::NoMark) {
-		Rosegarden::Marks::addMark(**i, m_mark, true);
-	    }
-	}
-    }
-
-    // Update the rec references here, without bothering to do so in unexecute
-    // or in ClearTriggersCommand -- because it doesn't matter if a trigger
-    // has references to segments that don't actually trigger it, whereas it
-    // does matter if it loses a reference to something that does
-
-    Rosegarden::TriggerSegmentRec *rec =
-	m_selection->getSegment().getComposition()->getTriggerSegmentRec
-	(m_triggerSegmentId);
-
-    if (rec) rec->updateReferences();
-}
-
-void
-ClearTriggersCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	(*i)->unset(TRIGGER_SEGMENT_ID);
-	(*i)->unset(TRIGGER_SEGMENT_RETUNE);
-	(*i)->unset(TRIGGER_SEGMENT_ADJUST_TIMES);
-    }
-}
-
-
-InsertTriggerNoteCommand::InsertTriggerNoteCommand(Rosegarden::Segment &segment,
-						   Rosegarden::timeT time,
-						   Rosegarden::Note note,
-						   int pitch,
-						   int velocity,
-						   NoteStyleName noteStyle,
-						   Rosegarden::TriggerSegmentId id,
-						   bool retune,
-						   std::string timeAdjust,
-						   Rosegarden::Mark mark) :
-    BasicCommand(i18n("Insert Trigger Note"), segment,
-		 time, time + note.getDuration()),
-    m_time(time),
-    m_note(note),
-    m_pitch(pitch),
-    m_velocity(velocity),
-    m_noteStyle(noteStyle),
-    m_id(id),
-    m_retune(retune),
-    m_timeAdjust(timeAdjust),
-    m_mark(mark)
-{
-    // nothing
-}
-
-InsertTriggerNoteCommand::~InsertTriggerNoteCommand()
-{
-    // nothing
-}
-
-void
-InsertTriggerNoteCommand::modifySegment()
-{
-    // Insert via a model event, so as to apply the note style.
-    // This is a subset of the work done by NoteInsertionCommand
-    
-    Event *e = new Event(Note::EventType, m_time, m_note.getDuration());
-
-    e->set<Int>(PITCH, m_pitch);
-    e->set<Int>(VELOCITY, m_velocity);
-
-    if (m_noteStyle != NoteStyleFactory::DefaultStyle) {
-	e->set<String>(NotationProperties::NOTE_STYLE, m_noteStyle);
-    }
-
-    e->set<Int>(TRIGGER_SEGMENT_ID, m_id);
-    e->set<Rosegarden::Bool>(TRIGGER_SEGMENT_RETUNE, m_retune);
-    e->set<Rosegarden::String>(TRIGGER_SEGMENT_ADJUST_TIMES, m_timeAdjust);
-
-    if (m_mark != Rosegarden::Marks::NoMark) {
-	Rosegarden::Marks::addMark(*e, m_mark, true);
-    }
-
-    Segment &s(getSegment());
-    Segment::iterator i = Rosegarden::SegmentMatrixHelper(s).insertNote(e);
-
-    Segment::iterator j = i;
-    while (++j != s.end()) {
-	if ((*j)->getAbsoluteTime() >
-	    (*i)->getAbsoluteTime() + (*i)->getDuration()) break;
-	if ((*j)->isa(Note::EventType)) {
-	    if ((*j)->getAbsoluteTime() ==
-		(*i)->getAbsoluteTime() + (*i)->getDuration()) {
-		if ((*j)->has(TIED_BACKWARD) && (*j)->get<Rosegarden::Bool>(TIED_BACKWARD) &&
-		    (*j)->has(PITCH) && ((*j)->get<Int>(PITCH) == m_pitch)) {
-		    (*i)->set<Rosegarden::Bool>(TIED_FORWARD, true);
-		}
-	    }
-	}
-    }
-
-    Rosegarden::TriggerSegmentRec *rec =
-	getSegment().getComposition()->getTriggerSegmentRec(m_id);
-
-    if (rec) rec->updateReferences();
-}
-
-
-void
-SetNoteTypeCommand::modifySegment()
-{
-    std::vector<Event *> toErase;
-    std::vector<Event *> toInsert;
-    
-    EventSelection::eventcontainer::iterator i;
-    timeT endTime = getEndTime();
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if ((*i)->isa(Rosegarden::Note::EventType)) {
-	    toErase.push_back(*i);
-	    
-	    Event *e;
-	    if (m_notationOnly) {
-		e = new Event(**i,
-			      (*i)->getAbsoluteTime(),
-			      (*i)->getDuration(),
-			      (*i)->getSubOrdering(),
-			      (*i)->getNotationAbsoluteTime(),
-			      Rosegarden::Note(m_type).getDuration());
-	    } else {
-		e = new Event(**i,
-			      (*i)->getNotationAbsoluteTime(),
-			      Rosegarden::Note(m_type).getDuration());
-	    }
-		
-	    if (e->getNotationAbsoluteTime() + e->getNotationDuration() > endTime) {
-		endTime = e->getNotationAbsoluteTime() + e->getNotationDuration();
-	    }
-
-	    toInsert.push_back(e);
-	}
-    }
-
-    for (std::vector<Event *>::iterator i = toErase.begin(); i != toErase.end(); ++i) {
-	m_selection->getSegment().eraseSingle(*i);
-    }
-
-    for (std::vector<Event *>::iterator i = toInsert.begin(); i != toInsert.end(); ++i) {
-	m_selection->getSegment().insert(*i);
-	m_selection->addEvent(*i);
-    }
-
-    m_selection->getSegment().normalizeRests(getStartTime(), endTime);
-}
-
-void
-AddDotCommand::modifySegment()
-{
-    std::vector<Event *> toErase;
-    std::vector<Event *> toInsert;
-    
-    EventSelection::eventcontainer::iterator i;
-    timeT endTime = getEndTime();
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if ((*i)->isa(Rosegarden::Note::EventType)) {
-
-	    Rosegarden::Note note = Rosegarden::Note::getNearestNote
-		((*i)->getNotationDuration());
-	    int dots = note.getDots();
-	    if (++dots > 2) dots = 0;
-
-	    toErase.push_back(*i);
-
-	    Event *e;
-
-	    if (m_notationOnly) {
-		e = new Event(**i,
-			      (*i)->getAbsoluteTime(),
-			      (*i)->getDuration(),
-			      (*i)->getSubOrdering(),
-			      (*i)->getNotationAbsoluteTime(),
-			      Rosegarden::Note(note.getNoteType(),
-					       dots).getDuration());
-
-	    } else {
-		e = new Event(**i,
-			      (*i)->getNotationAbsoluteTime(),
-			      Rosegarden::Note(note.getNoteType(),
-					       dots).getDuration());
-	    }
-
-	    if (e->getNotationAbsoluteTime() + e->getNotationDuration() > endTime) {
-		endTime = e->getNotationAbsoluteTime() + e->getNotationDuration();
-	    }
-
-	    toInsert.push_back(e);
-	}
-    }
-
-    for (std::vector<Event *>::iterator i = toErase.begin(); i != toErase.end(); ++i) {
-	m_selection->getSegment().eraseSingle(*i);
-    }
-
-    for (std::vector<Event *>::iterator i = toInsert.begin(); i != toInsert.end(); ++i) {
-	m_selection->getSegment().insert(*i);
-	m_selection->addEvent(*i);
-    }
-
-    m_selection->getSegment().normalizeRests(getStartTime(), endTime);
-}
-
-#include "editcommands.moc"
