@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,15 +24,12 @@
 
 
 #include "basiccommand.h"
-#include "notestyle.h"
 
 #include "Quantizer.h"
-#include "TriggerSegment.h"
 #include <klocale.h>
 
 namespace Rosegarden {
     class Clipboard;
-    class Composition;
     class EventSelection;
     class SegmentSelection;
     class Marker;
@@ -48,6 +45,7 @@ namespace Rosegarden {
         DecrescendoPattern,   // decreasing from velocity 1 to velocity 2.
         RingingPattern        // between velocity 1 and 2, dying away.
     } PropertyPattern;
+
 }
 
 
@@ -115,12 +113,6 @@ public:
     CopyCommand(Rosegarden::SegmentSelection &selection,
 		Rosegarden::Clipboard *clipboard);
 
-    /// Make a CopyCommand that copies a range of a Composition
-    CopyCommand(Rosegarden::Composition *composition,
-		Rosegarden::timeT beginTime,
-		Rosegarden::timeT endTime,
-		Rosegarden::Clipboard *clipboard);
-
     virtual ~CopyCommand();
 
     static QString getGlobalName() { return i18n("&Copy"); }
@@ -131,7 +123,6 @@ public:
 protected:
     Rosegarden::Clipboard *m_sourceClipboard;
     Rosegarden::Clipboard *m_targetClipboard;
-    Rosegarden::Clipboard *m_savedClipboard;
 };
 
 
@@ -142,9 +133,7 @@ class PasteSegmentsCommand : public KNamedCommand
 public:
     PasteSegmentsCommand(Rosegarden::Composition *composition,
 			 Rosegarden::Clipboard *clipboard,
-			 Rosegarden::timeT pasteTime,
-			 Rosegarden::TrackId baseTrack,
-			 bool useExactTracks);
+			 Rosegarden::timeT pasteTime);
 
     virtual ~PasteSegmentsCommand();
 
@@ -157,10 +146,7 @@ protected:
     Rosegarden::Composition *m_composition;
     Rosegarden::Clipboard *m_clipboard;
     Rosegarden::timeT m_pasteTime;
-    Rosegarden::TrackId m_baseTrack;
-    bool m_exactTracks;
     std::vector<Rosegarden::Segment *> m_addedSegments;
-    bool m_detached;
 };
 
 
@@ -204,8 +190,6 @@ public:
 		       Rosegarden::timeT pasteEndTime,
 		       PasteType pasteType);
 
-    virtual ~PasteEventsCommand();
-
     static QString getGlobalName() { return i18n("&Paste"); }
 
     /// Determine whether this paste will succeed (without executing it yet)
@@ -315,25 +299,6 @@ private:
     Rosegarden::Quantizer *makeQuantizer(QString, bool);
 };
 
-// Collapse equal-pitch notes into one event
-//
-class AdjustMenuCollapseNotesCommand : public BasicSelectionCommand
-{
-public:
-    AdjustMenuCollapseNotesCommand(Rosegarden::EventSelection &selection) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection) { }
-
-    static QString getGlobalName() { return i18n("Collapse &Equal-Pitch Notes"); }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
-
-
 // Set the (numerical) property of a selection according given pattern.
 //
 class SelectionPropertyCommand : public BasicSelectionCommand
@@ -443,9 +408,6 @@ protected:
 
 private:
     Rosegarden::timeT rescale(Rosegarden::timeT);
-    Rosegarden::timeT getAffectedEndTime(Rosegarden::EventSelection &selection,
-					 Rosegarden::timeT newDuration,
-					 bool closeGap);
 
     Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
     Rosegarden::timeT m_oldDuration;
@@ -592,141 +554,4 @@ protected:
 
 };
 
-
-class SetTriggerCommand : public BasicSelectionCommand
-{
-public:
-    SetTriggerCommand(Rosegarden::EventSelection &selection,
-		      Rosegarden::TriggerSegmentId triggerSegmentId,
-		      bool notesOnly,
-		      bool retune,
-		      std::string timeAdjust,
-		      Rosegarden::Mark mark,
-		      QString name = 0) :
-	BasicSelectionCommand(name ? name : getGlobalName(), selection, true),
-	m_selection(&selection),
-	m_triggerSegmentId(triggerSegmentId),
-	m_notesOnly(notesOnly),
-	m_retune(retune),
-	m_timeAdjust(timeAdjust),
-	m_mark(mark)
-    { }
-
-    static QString getGlobalName() {
-	return i18n("Tri&gger Segment");
-    }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    Rosegarden::TriggerSegmentId m_triggerSegmentId;
-    bool m_notesOnly;
-    bool m_retune;
-    std::string m_timeAdjust;
-    Rosegarden::Mark m_mark;
-};
-
-
-class ClearTriggersCommand : public BasicSelectionCommand
-{
-public:
-    ClearTriggersCommand(Rosegarden::EventSelection &selection,
-			 QString name = 0) :
-	BasicSelectionCommand(name ? name : getGlobalName(), selection, true),
-	m_selection(&selection)
-    { }
-
-    static QString getGlobalName() {
-	return i18n("&Clear Triggers");
-    }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
-
-
-class InsertTriggerNoteCommand : public BasicCommand
-{
-public:
-    InsertTriggerNoteCommand(Rosegarden::Segment &,
-			     Rosegarden::timeT time,
-			     Rosegarden::Note note,
-			     int pitch,
-			     int velocity,
-			     NoteStyleName noteStyle,
-			     Rosegarden::TriggerSegmentId id,
-			     bool retune,
-			     std::string timeAdjust,
-			     Rosegarden::Mark mark);
-    virtual ~InsertTriggerNoteCommand();
-
-protected:
-    virtual void modifySegment();
-
-    Rosegarden::timeT m_time;
-    Rosegarden::Note m_note;
-    int m_pitch;
-    int m_velocity;
-    NoteStyleName m_noteStyle;
-    Rosegarden::TriggerSegmentId m_id;
-    bool m_retune;
-    std::string m_timeAdjust;
-    Rosegarden::Mark m_mark;
-};
-
-
-class SetNoteTypeCommand : public BasicSelectionCommand
-{
-public:
-    SetNoteTypeCommand(Rosegarden::EventSelection &selection,
-		       Rosegarden::Note::Type type,
-		       bool notationOnly) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection),
-	m_type(type),
-	m_notationOnly(notationOnly)
-    { }
-
-    static QString getGlobalName() {
-	return i18n("&Set Note Type");
-    }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    Rosegarden::Note::Type m_type;
-    bool m_notationOnly;
-};
-
-
-class AddDotCommand : public BasicSelectionCommand
-{
-public:
-    AddDotCommand(Rosegarden::EventSelection &selection, bool notationOnly) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection),
-	m_notationOnly(notationOnly)
-    { }
-
-    static QString getGlobalName() {
-	return i18n("&Add Dot");
-    }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    bool m_notationOnly;
-};
-
-
-
 #endif
