@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,7 +23,6 @@
 #include <qpopupmenu.h>
 #include <qinputdialog.h>
 #include <qobjectlist.h>
-#include <qbutton.h>
 
 #include <kapp.h>
 #include <kconfig.h>
@@ -33,7 +32,11 @@
 #include <kstatusbar.h>
 #include <klistbox.h>
 
+#if KDE_VERSION >= 197120 // 320
 #include <ktabwidget.h>
+#else
+#include "kde32_ktabwidget.h"
+#endif
 
 #include <kiconloader.h>
 
@@ -43,7 +46,6 @@
 #include "AnalysisTypes.h"
 #include "CompositionTimeSliceAdapter.h"
 #include "MidiTypes.h"
-#include "SoftSynthDevice.h"
 
 #include "editview.h"
 #include "rosestrings.h"
@@ -58,8 +60,6 @@
 #include "segmentcommands.h"
 #include "controlruler.h"
 #include "loopruler.h"
-#include "editcommands.h"
-#include "dialogs.h"
 
 #include "rosedebug.h"
 
@@ -92,7 +92,11 @@ EditView::EditView(RosegardenGUIDoc *doc,
     m_topBarButtons(0),
     m_bottomBarButtons(0),
     m_controlRuler(0),
+#if KDE_VERSION < 197120
+    m_controlRulers(new KDE32Backport::KTabWidget(getBottomWidget(), "controlrulers"))
+#else
     m_controlRulers(new KTabWidget(getBottomWidget(), "controlrulers"))
+#endif
 {
     m_controlRulers->setHoverCloseButton(true);
     m_controlRulers->setHoverCloseButtonDelayed(false); 
@@ -108,6 +112,7 @@ EditView::EditView(RosegardenGUIDoc *doc,
     
     m_controlRulers->hide();
     m_controlRulers->setTabPosition(QTabWidget::Bottom);
+
 }
 
 EditView::~EditView()
@@ -123,9 +128,9 @@ void EditView::updateBottomWidgetGeometry()
     getCanvasView()->updateBottomWidgetGeometry();
 }
 
+
 void EditView::paintEvent(QPaintEvent* e)
 {
-    RG_DEBUG << "EditView::paintEvent()\n";
     EditViewBase::paintEvent(e);
     
     if (m_needUpdate)  {
@@ -178,20 +183,19 @@ void EditView::setControlRulersZoom(QWMatrix zoomMatrix)
 
 void EditView::setControlRulersCurrentSegment()
 {
-    RG_DEBUG << "EditView::setControlRulersCurrentSegment: visible is " << m_controlRulers->isVisible() << endl;
-
     bool visible = m_controlRulers->isVisible();
 
     delete m_controlRulers;
+    
+#if KDE_VERSION < 197120
+    m_controlRulers = new KDE32Backport::KTabWidget(getBottomWidget(), "controlrulers");
+#else
     m_controlRulers = new KTabWidget(getBottomWidget(), "controlrulers");
+#endif
 
-    bool haveTabs = setupControllerTabs();
-    setupAddControlRulerMenu();
+    setupControllerTabs();
 
-    if (haveTabs) m_controlRulers->show();
-    else m_controlRulers->hide();
-
-    updateBottomWidgetGeometry();
+    if (visible) m_controlRulers->show();
 
 /*
     for (int i = 0; i < m_controlRulers->count(); ++i) {
@@ -285,7 +289,7 @@ void EditView::addRuler(QWidget* w)
                 w, SLOT(slotScrollHoriz(int)));
         connect(m_canvasView->horizontalScrollBar(), SIGNAL(sliderMoved(int)),
                 w, SLOT(slotScrollHoriz(int)));
-    }    
+    }
 }
 
 void EditView::addPropertyBox(QWidget *w)
@@ -306,12 +310,10 @@ PropertyControlRuler* EditView::makePropertyControlRuler(PropertyName propertyNa
 	(propertyName, getCurrentStaff(), getHLayout(), this,
 	 controlRulerCanvas, m_controlRulers);
 
-    controlRuler->setMainHorizontalScrollBar(m_canvasView->horizontalScrollBar());
-
     return controlRuler;
 }
 
-ControllerEventsRuler* EditView::makeControllerEventRuler(const ControlParameter *controller)
+ControllerEventsRuler* EditView::makeControllerEventRuler(ControlParameter *controller)
 {
     QCanvas* controlRulerCanvas = new QCanvas(this);
     QSize viewSize = getViewSize();
@@ -324,8 +326,6 @@ ControllerEventsRuler* EditView::makeControllerEventRuler(const ControlParameter
 	(getCurrentSegment(), getHLayout(), this,
 	 controlRulerCanvas, m_controlRulers, controller);
 
-    controlRuler->setMainHorizontalScrollBar(m_canvasView->horizontalScrollBar());
-
     return controlRuler;
 }
 
@@ -342,9 +342,7 @@ void EditView::addControlRuler(ControlRuler* ruler)
         connect(m_canvasView->horizontalScrollBar(), SIGNAL(sliderMoved(int)),
                 ruler->horizontalScrollBar(), SIGNAL(sliderMoved(int)));
     }
-
-    connect(ruler, SIGNAL(stateChange(const QString&, bool)),
-            this, SLOT(slotStateChanged(const QString&, bool)));
+    
 
     stateChanged("have_control_ruler", KXMLGUIClient::StateReverse);
 }
@@ -790,26 +788,19 @@ EditView::setupActions()
 void
 EditView::setupAddControlRulerMenu()
 {
-    RG_DEBUG << "EditView::setupAddControlRulerMenu" << endl;
-
     QPopupMenu* addControlRulerMenu = dynamic_cast<QPopupMenu*>
         (factory()->container("add_control_ruler", this));
 
     if (addControlRulerMenu) {
 
-	addControlRulerMenu->clear();
-
 	//!!! problem here with notation view -- current segment can
 	// change after construction, but this function isn't used again
 
-	Rosegarden::Controllable *c = 
-	    dynamic_cast<Rosegarden::MidiDevice *>(getCurrentDevice());
-	if (!c) {
-	    c = dynamic_cast<Rosegarden::SoftSynthDevice *>(getCurrentDevice());
-	    if (!c) return;
-	}
+	Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>
+	    (getCurrentDevice());
+	if (!md) return;
 
-        const Rosegarden::ControlList &list = c->getControlParameters();
+        const Rosegarden::ControlList &list = md->getControlParameters();
 
         int i = 0;
         QString itemStr;
@@ -840,11 +831,9 @@ EditView::setupAddControlRulerMenu()
 
 }
 
-bool
+void
 EditView::setupControllerTabs()
 {
-    bool have = false;
-
     // Setup control rulers the Segment already has some stored against it.
     //
     Rosegarden::Segment *segment = getCurrentSegment();
@@ -852,22 +841,11 @@ EditView::setupControllerTabs()
 
     RG_DEBUG << "EditView::setupControllerTabs - got " << list.size() << " EventRulers" << endl;
 
-    RG_DEBUG << "Segment view features: " << segment->getViewFeatures() << endl;
-    if (segment->getViewFeatures() & FeatureShowVelocity) {
-	showPropertyControlRuler(Rosegarden::BaseProperties::VELOCITY);
-	have = true;
-    }
-
     if (list.size())
     {
-	Rosegarden::Controllable *c = 
-	    dynamic_cast<Rosegarden::MidiDevice *>(getCurrentDevice());
-	if (!c) {
-	    c = dynamic_cast<Rosegarden::SoftSynthDevice *>(getCurrentDevice());
-	    if (!c) return have;
-	}
-
-	have = true;
+	Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>
+	    (getCurrentDevice());
+	if (!md) return;
 
         Rosegarden::Segment::EventRulerListIterator it;
 
@@ -875,9 +853,8 @@ EditView::setupControllerTabs()
         {
             // Get ControlParameter object from controller value
             //
-            const ControlParameter *controlParameter = 
-		c->getControlParameter((*it)->m_type,
-				       Rosegarden::MidiByte((*it)->m_controllerValue));
+            ControlParameter *controlParameter = 
+                md->getControlParameter((*it)->m_type, Rosegarden::MidiByte((*it)->m_controllerValue));
 
             RG_DEBUG << "EditView::setupControllerTabs - " 
                      << "Control Parameter type = " << (*it)->m_type << endl;
@@ -895,8 +872,6 @@ EditView::setupControllerTabs()
 
         updateBottomWidgetGeometry();
     }
-
-    return have;
 }
 
 
@@ -907,14 +882,11 @@ EditView::slotAddControlRuler(int controller)
     RG_DEBUG << "EditView::slotAddControlRuler - item = " 
              << controller << endl;
 
-    Rosegarden::Controllable *c = 
-	dynamic_cast<Rosegarden::MidiDevice *>(getCurrentDevice());
-    if (!c) {
-	c = dynamic_cast<Rosegarden::SoftSynthDevice *>(getCurrentDevice());
-	if (!c) return;
-    }
-    
-    const Rosegarden::ControlList &list = c->getControlParameters();
+    Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>
+	(getCurrentDevice());
+    if (!md) return;
+
+    const Rosegarden::ControlList &list = md->getControlParameters();
     ControlParameter control = list[controller];
 
     int index = 0;
@@ -1089,14 +1061,18 @@ EditView::createInsertPitchActionMenu()
 
 int
 EditView::getPitchFromNoteInsertAction(QString name,
-				       Rosegarden::Accidental &accidental,
-				       const Rosegarden::Clef &clef,
-				       const Rosegarden::Key &key)
+				       Rosegarden::Accidental &accidental)
 {
     using namespace Rosegarden::Accidentals;
 
     accidental = NoAccidental;
 
+    Rosegarden::Key key;
+    Rosegarden::Clef clef;
+
+    //!!! need to be able to get clef & key -- how?
+    //!!! modify to use Pitch class
+
     if (name.left(7) == "insert_") {
 
 	name = name.right(name.length()-7);
@@ -1136,10 +1112,31 @@ EditView::getPitchFromNoteInsertAction(QString name,
 	    scalePitch = 0;
 	}
 
+	//!!! needs testing before we remove old stuff
 	Rosegarden::Pitch pitch
-	    (scalePitch, 4 + octave + clef.getOctave(), key, accidental);
+	    (scalePitch, 5 + octave + clef.getOctave(), key, accidental);
 	return pitch.getPerformancePitch();
 
+/*!!!
+	int pitch =
+	    key.getTonicPitch() + 60 + 12*(octave + clef.getOctave()) + modify;
+
+	static int scale[] = { 0, 2, 4, 5, 7, 9, 11 };
+	pitch += scale[scalePitch];
+*/
+/*!!!
+	if (accidental != NoAccidental) {
+	    Rosegarden::NotationDisplayPitch ndp(pitch, clef, key);
+	    int height = ndp.getHeightOnStaff();
+	    Rosegarden::Accidental defaultAcc = key.getAccidentalAtHeight(height, clef);
+	    if ((defaultAcc == Sharp || defaultAcc == Flat) &&
+		defaultAcc != accidental) accidental = Natural;
+	    else if (defaultAcc == Sharp) accidental = DoubleSharp;
+	    else                          accidental = DoubleFlat;
+	}
+*/
+//!!!	return pitch;
+
     } else {
 
 	throw Rosegarden::Exception("Not an insert action",
@@ -1155,14 +1152,10 @@ void EditView::slotAddTempo()
 
     connect(&tempoDlg,
             SIGNAL(changeTempo(Rosegarden::timeT,
-                               Rosegarden::tempoT,
-                               Rosegarden::tempoT,
-			       TempoDialog::TempoDialogAction)),
+                               double, TempoDialog::TempoDialogAction)),
             this,
             SIGNAL(changeTempo(Rosegarden::timeT,
-                               Rosegarden::tempoT,
-                               Rosegarden::tempoT,
-			       TempoDialog::TempoDialogAction)));
+                               double, TempoDialog::TempoDialogAction)));
         
     tempoDlg.setTempoPosition(insertionTime);
     tempoDlg.exec();
@@ -1474,6 +1467,53 @@ void EditView::slotJogRight()
                 *m_currentEventSelection));
 }
 
+void
+EditView::keyPressEvent(QKeyEvent *event)
+{
+    switch(event->key())
+    {
+        case Key_Shift:
+            m_shiftDown = true;
+
+            break;
+
+        case Key_Control:
+            m_controlDown = true;
+            break;
+
+        default:
+            event->ignore();
+            break;
+    }
+
+    if (m_bottomBarButtons)
+        m_bottomBarButtons->getLoopRuler()->slotSetLoopingMode(m_shiftDown);
+}
+
+
+
+void
+EditView::keyReleaseEvent(QKeyEvent *event)
+{
+    switch(event->key())
+    {
+        case Key_Shift:
+            m_shiftDown = false;
+            break;
+
+        case Key_Control:
+            m_controlDown = false;
+            break;
+
+        default:
+            event->ignore();
+            break;
+    }
+
+    if (m_bottomBarButtons)
+        m_bottomBarButtons->getLoopRuler()->slotSetLoopingMode(m_shiftDown);
+}
+
 void
 EditView::slotFlipForwards()
 {
@@ -1490,4 +1530,3 @@ EditView::slotFlipBackwards()
 
 
 
-#include "editview.moc"
