@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -25,12 +25,11 @@
 #include <vector>
 
 #include <qaccel.h>
-#include <qwmatrix.h>
 
 #include <kdeversion.h>
 
 #include "editviewbase.h"
-#include "tempodialog.h"
+#include "dialogs.h" // ugh -- for TempoDialog::TempoDialogAction
 
 #include "Event.h"
 #include "Selection.h"
@@ -47,7 +46,11 @@ class QScrollBar;
 
 class KCommand;
 class KToggleAction;
+#if KDE_VERSION >= 197120
 class KTabWidget;
+#else
+namespace KDE32Backport { class KTabWidget; }
+#endif
 
 class RosegardenGUIDoc;
 class MultiViewCommandHistory;
@@ -133,12 +136,10 @@ public:
         { return m_currentEventSelection; }
 
     RosegardenCanvasView* getRawCanvasView() { return m_canvasView; }
-    virtual RosegardenCanvasView* getCanvasView();
 
 signals:
     void changeTempo(Rosegarden::timeT,  // tempo change time
-                     Rosegarden::tempoT,  // tempo value
-                     Rosegarden::tempoT,  // target value
+                     double,             // tempo value
                      TempoDialog::TempoDialogAction); // tempo action
 
 public slots:
@@ -249,7 +250,7 @@ protected:
     /**
      * Make a ruler for controller events
      */
-    ControllerEventsRuler* makeControllerEventRuler(const Rosegarden::ControlParameter *controller = 0);
+    ControllerEventsRuler* makeControllerEventRuler(Rosegarden::ControlParameter *controller = 0);
 
     /**
      * Add control ruler
@@ -308,10 +309,9 @@ protected:
     void setupAddControlRulerMenu();
 
     /**
-     * Do this after any other segment setup in a subordinate view.
-     * Returns true if there were any tabs to set up.
+     * Do this after any other segment setup in a subordinate view
      */
-    bool setupControllerTabs();
+    void setupControllerTabs();
 
     /**
      * Create an action menu for inserting notes from the PC keyboard,
@@ -327,9 +327,7 @@ protected:
      * returns any specified accidental through the reference arg.
      */
     int getPitchFromNoteInsertAction(QString actionName,
-				     Rosegarden::Accidental &acc,
-				     const Rosegarden::Clef &clef,
-				     const Rosegarden::Key &key);
+				     Rosegarden::Accidental &acc);
 
     /**
      * Abstract method to get the view size
@@ -356,6 +354,11 @@ protected:
     virtual Rosegarden::timeT getInsertionTime(Rosegarden::Clef &clef,
 					       Rosegarden::Key &key);
 
+    /**
+     * Abstract method to get current segment
+     */
+    virtual Rosegarden::Segment *getCurrentSegment() = 0;
+
     /**
      * Abstract method to get current staff (the returned staff will be
      * that representing the segment of getCurrentSegment())
@@ -367,8 +370,12 @@ protected:
      */
     Rosegarden::Device *getCurrentDevice();
 
+    virtual RosegardenCanvasView* getCanvasView();
     virtual void setCanvasView(RosegardenCanvasView *cv);
 
+    virtual void keyPressEvent(QKeyEvent *event);
+    virtual void keyReleaseEvent(QKeyEvent *event);
+
     //--------------- Data members ---------------------------------
 
     /// The current selection of Events (for cut/copy/paste)
@@ -384,7 +391,11 @@ protected:
     BarButtons   *m_topBarButtons;
     BarButtons   *m_bottomBarButtons;
     ControlRuler *m_controlRuler;
+#if KDE_VERSION >= 197120
     KTabWidget   *m_controlRulers;
+#else
+    KDE32Backport::KTabWidget   *m_controlRulers;
+#endif
     QWMatrix      m_currentRulerZoomMatrix;
 
     static const unsigned int RULERS_ROW;
