@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -46,7 +46,6 @@
 #include "barbuttons.h"
 #include "Clipboard.h"
 #include "sequencemanager.h"
-#include "segmentcommands.h"
 
 #include "rosedebug.h"
 
@@ -59,11 +58,14 @@ public:
 	m_composition->addObserver(this);
     }
     virtual ~EditViewTimeSigNotifier() {
-	if (!isCompositionDeleted()) m_composition->removeObserver(this);
+	if (m_composition) m_composition->removeObserver(this);
     }
     virtual void timeSignatureChanged(const Rosegarden::Composition *c) {
 	if (c == m_composition) m_timeSigChanged = true;
     }
+    virtual void compositionDeleted(const Rosegarden::Composition *c) {
+	if (c == m_composition) m_composition = 0;
+    }
 
     bool hasTimeSigChanged() const { return m_timeSigChanged; }
     void reset() { m_timeSigChanged = false; }
@@ -166,11 +168,9 @@ void EditViewBase::setupActions(QString rcFileName, bool haveClipboard)
 
     // Actions all edit views will have
 
-    KStdAction::showToolbar(this, SLOT(slotToggleToolBar()),
-                                       actionCollection(), "options_show_toolbar");
-    
-    KStdAction::showStatusbar(this, SLOT(slotToggleStatusBar()),
-                                         actionCollection(), "options_show_statusbar");
+    KStdAction::showToolbar(this, SLOT(slotToggleToolBar()), actionCollection());
+    KStdAction::showStatusbar(this, SLOT(slotToggleStatusBar()), actionCollection());
+
 
     KStdAction::preferences(this,
                             SLOT(slotConfigure()),
@@ -209,38 +209,21 @@ void EditViewBase::setupActions(QString rcFileName, bool haveClipboard)
 
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
 
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/matrix.png");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/matrix.xpm"));
     new KAction(i18n("Open in Matri&x Editor"), icon, 0, this,
                 SLOT(slotOpenInMatrix()), actionCollection(),
                 "open_in_matrix");
 
-    pixmap.load(pixmapDir + "/toolbar/matrix-percussion.png");
-    icon = QIconSet(pixmap);
-    new KAction(i18n("Open in &Percussion Matrix Editor"), icon, 0, this,
-                SLOT(slotOpenInPercussionMatrix()), actionCollection(),
-                "open_in_percussion_matrix");
-    
-    pixmap.load(pixmapDir + "/toolbar/notation.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/notation.xpm"));
     new KAction(i18n("Open in &Notation Editor"), icon, 0, this,
                 SLOT(slotOpenInNotation()), actionCollection(),
                 "open_in_notation");
 
-    pixmap.load(pixmapDir + "/toolbar/eventlist.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/eventlist.xpm"));
     new KAction(i18n("Open in &Event List Editor"), icon, 0, this,
                 SLOT(slotOpenInEventList()), actionCollection(),
                 "open_in_event_list");
 
-    new KAction(i18n("Set Segment Start Time..."), 0, this,
-		SLOT(slotSetSegmentStartTime()), actionCollection(),
-		"set_segment_start");
-
-    new KAction(i18n("Set Segment Duration..."), 0, this,
-		SLOT(slotSetSegmentDuration()), actionCollection(),
-		"set_segment_duration");
-
     // add undo and redo to edit menu and toolbar
     getCommandHistory()->attachView(actionCollection());
     
@@ -281,7 +264,6 @@ void EditViewBase::slotUpdateToolbars()
 void
 EditViewBase::slotOpenInNotation()
 {
-
     emit openInNotation(m_segments);
 }
 
@@ -291,12 +273,6 @@ EditViewBase::slotOpenInMatrix()
     emit openInMatrix(m_segments);
 }
 
-void
-EditViewBase::slotOpenInPercussionMatrix()
-{
-    emit openInPercussionMatrix(m_segments);
-}
-
 void
 EditViewBase::slotOpenInEventList()
 {
@@ -592,7 +568,13 @@ void EditViewBase::toggleWidget(QWidget* widget,
         return;
     }
 
-    widget->setShown(toggleAction->isChecked());
+    // Qt 3.1 only :
+//     widget->setShown(toggleAction->isChecked());
+
+    if (toggleAction->isChecked())
+        widget->show();
+    else
+        widget->hide();
 }
 
     
@@ -620,110 +602,29 @@ EditViewBase::slotTestClipboard()
 void
 EditViewBase::slotToggleSolo()
 {
-    KToggleAction* toggleSoloAction = getToggleAction("toggle_solo");
-    if (!toggleSoloAction) return;
+    RG_DEBUG << "EditViewBase::slotToggleSolo()\n";
 
-    bool newSoloState = toggleSoloAction->isChecked();
+    if(getDocument()->getComposition().isSolo()) {
 
-    RG_DEBUG << "EditViewBase::slotToggleSolo() : solo  = " << newSoloState << endl;
-    emit toggleSolo(newSoloState);
+        getDocument()->getComposition().setSolo(false);
+
+    } else {
+
+        emit selectTrack(m_segments[0]->getTrack());
+        getDocument()->getComposition().setSolo(true);
 
-    if (newSoloState) {
-        emit selectTrack(getCurrentSegment()->getTrack());
     }
-
+    
 }
 
 void
 EditViewBase::slotStateChanged(const QString& s,
                                bool noReverse)
 {
-    RG_DEBUG << "EditViewBase::slotStateChanged " << s << ", " << noReverse << endl;
     stateChanged(s, noReverse ? KXMLGUIClient::StateNoReverse : KXMLGUIClient::StateReverse);
 }
 
 
-void
-EditViewBase::slotSetSegmentStartTime()
-{
-    Rosegarden::Segment *s = getCurrentSegment();
-    if (!s) return;
-
-    TimeDialog dialog(this, i18n("Segment Start Time"),
-		      &getDocument()->getComposition(),
-		      s->getStartTime());
-
-    if (dialog.exec() == QDialog::Accepted) {
-
-	SegmentReconfigureCommand *command =
-	    new SegmentReconfigureCommand(i18n("Set Segment Start Time"));
-	
-	command->addSegment
-	    (s, dialog.getTime(),
-	     s->getEndMarkerTime() - s->getStartTime() + dialog.getTime(),
-	     s->getTrack());
-
-        addCommandToHistory(command);
-    }
-}
-
-
-void
-EditViewBase::slotSetSegmentDuration()
-{
-    Rosegarden::Segment *s = getCurrentSegment();
-    if (!s) return;
-
-    TimeDialog dialog(this, i18n("Segment Duration"),
-		      &getDocument()->getComposition(),
-		      s->getStartTime(),
-		      s->getEndMarkerTime() - s->getStartTime());
-
-    if (dialog.exec() == QDialog::Accepted) {
-	
-	SegmentReconfigureCommand *command =
-	    new SegmentReconfigureCommand(i18n("Set Segment Duration"));
-	
-	command->addSegment
-	    (s, s->getStartTime(),
-	     s->getStartTime() + dialog.getTime(),
-	     s->getTrack());
-
-        addCommandToHistory(command);
-    }
-}
-
-void EditViewBase::slotCompositionStateUpdate()
-{
-    // update state of 'solo' toggle
-    //
-    KToggleAction* toggleSolo = getToggleAction("toggle_solo");
-    if (!toggleSolo) return;
-
-    if(getDocument()->getComposition().isSolo()) {
-        bool s = m_segments[0]->getTrack() == getDocument()->getComposition().getSelectedTrack();
-        RG_DEBUG << "EditViewBase::slotCompositionStateUpdate() : set solo to " << s << endl;
-        toggleSolo->setChecked(s);
-    } else {
-        toggleSolo->setChecked(false);
-        RG_DEBUG << "EditViewBase::slotCompositionStateUpdate() : set solo to false\n";
-    }
-
-    // update the window caption
-    //
-    updateViewCaption();
-}
-
-
-void
-EditViewBase::windowActivationChange(bool oldState)
-{
-    if (isActiveWindow()) {
-	emit windowActivated();
-    }
-}
-
-
 /*
  * Let tools know if their current element has gone
  */
@@ -733,4 +634,3 @@ EditViewBase::handleEventRemoved(Rosegarden::Event *event)
     if (m_tool) m_tool->handleEventRemoved(event);
 }
 
-#include "editviewbase.moc"
