@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -129,6 +129,12 @@ public:
      */
     EditToolBox* getToolBox() { return m_toolBox; }
 
+    /*
+     * Are these modifiers in use?
+     */
+    bool isShiftDown() { return m_shiftDown; }
+    bool isControlDown() { return m_controlDown; }
+
     /**
      * Let tools know if their current element has gone
      */
@@ -145,7 +151,6 @@ signals:
      */
     void openInNotation(std::vector<Rosegarden::Segment *>);
     void openInMatrix(std::vector<Rosegarden::Segment *>);
-    void openInPercussionMatrix(std::vector<Rosegarden::Segment *>);
     void openInEventList(std::vector<Rosegarden::Segment *>);
     
     /**
@@ -155,13 +160,6 @@ signals:
      */
     void selectTrack(int);
 
-    /**
-     * Tell the main view that the solo status has changed (the user clicked on the 'solo' toggle)
-     */
-    void toggleSolo(bool);
-
-    void windowActivated();
-
 public slots:
     /**
      * close window
@@ -218,37 +216,16 @@ public slots:
      */
     virtual void slotTestClipboard();
 
-    /**
-     * Connected to this view's toolbar 'solo' button
-     */
     virtual void slotToggleSolo();
 
     void slotStateChanged(const QString&, bool noReverse);
 
     virtual void slotOpenInMatrix();
-    virtual void slotOpenInPercussionMatrix();
     virtual void slotOpenInNotation();
     virtual void slotOpenInEventList();
     
-    /**
-     * Set the start time of the current segment
-     */
-    void slotSetSegmentStartTime();
-
-    /**
-     * Set the duration of the current segment
-     */
-    void slotSetSegmentDuration();
-
-    /**
-     * Global composition updates from the main view (track selection, solo, etc...)
-     */
-    virtual void slotCompositionStateUpdate();
-    
 protected:
 
-    virtual void windowActivationChange(bool);
-
     virtual void paintEvent(QPaintEvent* e);
 
     /**
@@ -288,17 +265,7 @@ protected:
      * setup status bar
      */
     virtual void initStatusBar() = 0;
-
-    /**
-     * Abstract method to get current segment
-     */
-    virtual Rosegarden::Segment *getCurrentSegment() = 0;
-
-    /**
-     * Set the caption of the view's window
-     */
-    virtual void updateViewCaption() = 0;
-
+    
 protected slots:
     /**
      * save general Options like all bar positions and status as well
@@ -321,9 +288,9 @@ protected:
 
     /**
      * Returns true if all of the segments contain
-     * only rests and clefs events
+     * only rests
      */
-    bool getSegmentsOnlyRestsAndClefs();
+    bool getSegmentsOnlyRests();
 
     /// Convenience function around actionCollection()->action()
     KToggleAction* getToggleAction(const QString& actionName);
@@ -377,6 +344,9 @@ protected:
 
     int          m_configDialogPageIndex;
 
+    bool         m_shiftDown;
+    bool         m_controlDown;
+
     bool         m_inCtor;
 
     EditViewTimeSigNotifier *m_timeSigNotifier;
