@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -46,15 +46,8 @@
 #include "BaseProperties.h"     // "
 #include "Event.h"              // "
 #include "rosedebug.h"          // debug stream
-#include "dialogs.h"            // PitchPickerDialog
 
 
-#define COMPILE_DEPRECATED      // will compile the useless 1.0 features
-                                // ifdeffing this stuff out will ease the
-				// transition into oblivion as I expunge
-				// these useless ideas and then implement new,
-				// useful ones beyond 1.0
-
 using Rosegarden::Note;
 
 const char* const EventFilterDialog::ConfigGroup = "EventFilter Dialog";
@@ -201,9 +194,7 @@ EventFilterDialog::initDialog()
 
     populateDurationCombos();
 
-#ifdef COMPILE_DEPRECATED
-// DEPRECATED
- 
+
     //----------[ Controller Filter Widgets ]---------------------
 
     // Frame
@@ -339,7 +330,6 @@ EventFilterDialog::initDialog()
     slotControllerCheckBoxToggle(0);
     slotWheelCheckBoxToggle(0);
 
-#endif // COMPILE_DEPRECATED
 
     //---------[ Buttons ]--------------------------------------
     QFrame* privateLayoutWidget = new QFrame(mainWidget);
@@ -369,10 +359,6 @@ EventFilterDialog::initDialog()
 // NOTE: these combos are calculated, rather than fixed, but the code that
 // picks a duration by index is dependant upon each index having a previously
 // expected value.  This could break easily at some point.
-//
-// NOTE: per the outstanding bug on this issue, it is impossible to select
-// dotted durations with this code.  In order for that to be possible, it will
-// probably be necessary to rework this code significantly.  (Post 1.0)
 void
 EventFilterDialog::populateDurationCombos()
 {
@@ -394,9 +380,9 @@ EventFilterDialog::populateDurationCombos()
 
     cfg->setGroup(EventFilterDialog::ConfigGroup);
     m_noteDurationFromComboBox->setCurrentItem(
-	    cfg->readUnsignedNumEntry("durationfrom", 0));
+	    cfg->readUnsignedNumEntry("durationfrom", (m_noteDurationToComboBox->count() - 1)));
     m_noteDurationToComboBox->setCurrentItem(
-	    cfg->readUnsignedNumEntry("durationto", (m_noteDurationToComboBox->count() - 1)));
+	    cfg->readUnsignedNumEntry("durationto", 0));
 }
 
 void
@@ -408,7 +394,7 @@ EventFilterDialog::slotToggleAll()
     m_velocityFromSpinBox        ->setValue(0);
     m_velocityToSpinBox          ->setValue(127);
     m_noteDurationFromComboBox   ->setCurrentItem(11); // hard coded; should be variable
-    m_noteDurationToComboBox     ->setCurrentItem(0);  // 0 = unlimited; 11 = 0
+    m_noteDurationToComboBox     ->setCurrentItem(0);
     m_controllerNumberFromSpinBox->setValue(0);
     m_controllerNumberToSpinBox  ->setValue(127);
     m_controllerValueFromSpinBox ->setValue(0);
@@ -455,7 +441,6 @@ EventFilterDialog::slotOk()
     cfg->writeEntry("durationto",      m_noteDurationToComboBox->currentItem());
     
 
-#ifdef COMPILE_DEPRECATED
     cfg->writeEntry("controllercheckbox", m_controllerCheckBox->isChecked());
     
     cfg->writeEntry("controllerinclude", m_controllerNumberIncludeComboBox->currentItem());
@@ -472,7 +457,6 @@ EventFilterDialog::slotOk()
     cfg->writeEntry("wheelinclude", m_wheelAmountIncludeComboBox->currentItem());
     cfg->writeEntry("wheelfrom",    m_wheelAmountFromSpinBox->value());
     cfg->writeEntry("wheelto",      m_wheelAmountToSpinBox->value());
-#endif // DEPRECATED
     
     accept();
 }
@@ -492,7 +476,6 @@ EventFilterDialog::slotNoteCheckBoxToggle(int)
     m_noteDurationFromComboBox   ->setEnabled(state);
 }
 
-#ifdef COMPILE_DEPRECATED
 void
 EventFilterDialog::slotControllerCheckBoxToggle(int)
 {
@@ -513,7 +496,6 @@ EventFilterDialog::slotWheelCheckBoxToggle(int)
     m_wheelAmountToSpinBox      ->setEnabled(state);
     m_wheelAmountFromSpinBox    ->setEnabled(state);
 }
-#endif //DEPRECATED
 
 void
 EventFilterDialog::slotPitchFromChanged(int pitch)
@@ -564,7 +546,6 @@ EventFilterDialog::slotControllerFromChanged(int controller)
 	m_controllerNumberToSpinBox->setValue(controller);
 }
 
-#ifdef COMPILE_DEPRECATED
 void
 EventFilterDialog::slotControllerToChanged(int controller)
 {
@@ -599,12 +580,11 @@ EventFilterDialog::slotWheelToChanged(int value)
     if (value < m_wheelAmountFromSpinBox->value())
 	m_wheelAmountFromSpinBox->setValue(value);
 }
-#endif // DEPRECATED
 
 void
 EventFilterDialog::slotPitchFromChooser()
 {
-    PitchPickerDialog dialog(this, m_pitchFromSpinBox->value(), i18n("Pitch from"));
+    PitchPickerDialog dialog(this, m_pitchFromSpinBox->value(), true);
 
     if (dialog.exec() == QDialog::Accepted)
     {
@@ -615,7 +595,7 @@ EventFilterDialog::slotPitchFromChooser()
 void
 EventFilterDialog::slotPitchToChooser()
 {
-    PitchPickerDialog dialog(this, m_pitchToSpinBox->value(), i18n("Pitch to"));
+    PitchPickerDialog dialog(this, m_pitchToSpinBox->value(), false);
 
     if (dialog.exec() == QDialog::Accepted)
     {
@@ -701,8 +681,6 @@ EventFilterDialog::getDuration()
     return foo;
 }
 
-#ifdef COMPILE_DEPRECATED
-// disappearing after 1.0
 EventFilterDialog::filterRange
 EventFilterDialog::getController()
 {
@@ -713,7 +691,6 @@ EventFilterDialog::getController()
     return foo;
 }
 
-
 EventFilterDialog::filterRange
 EventFilterDialog::getValue()
 {
@@ -733,18 +710,13 @@ EventFilterDialog::getWheel()
     if (!wheelIsInclusive()) invert(foo);
     return foo;
 }
-#endif // DEPRECATED
 
 bool
 EventFilterDialog::keepEvent(Rosegarden::Event* const &e)
 {
-    if ((*e).isa(Rosegarden::Note::EventType)      
-#ifdef COMPILE_DEPRECATED
-	||
-        (*e).isa(Rosegarden::Controller::EventType)||
-	(*e).isa(Rosegarden::PitchBend::EventType)
-#endif
-	)
+    if ((*e).isa(Rosegarden::Note::EventType)      ||
+	(*e).isa(Rosegarden::Controller::EventType)||
+	(*e).isa(Rosegarden::PitchBend::EventType))
     {
 	long property = 0;
 
@@ -765,7 +737,6 @@ EventFilterDialog::keepEvent(Rosegarden::Event* const &e)
 	    if (!EventFilterDialog::eventInRange(getDuration(), property)) return false; 
 	    property = 0; 
 	} 
-#ifdef COMPILE_DEPRECATED
 	else if ((*e).isa(Rosegarden::Controller::EventType) && filterController())
 	{
 	    // controller number
@@ -794,14 +765,11 @@ EventFilterDialog::keepEvent(Rosegarden::Event* const &e)
 	    
 	    if (!EventFilterDialog::eventInRange(getWheel(), property)) return false;
 	}
-#endif	
 	return true;
     }
     return false;
 }
 
-/*  MOVING TO DIALOGS.CPP
- *
 // PitchPickerDialog
 //
 // Constructs a dialog to contain a RosegardenPitchChooser widget to feed back
@@ -825,7 +793,4 @@ PitchPickerDialog::PitchPickerDialog(QWidget *parent, int initialPitch, bool isF
 PitchPickerDialog::~PitchPickerDialog()
 {
     // Nothing here...
-} */
-
-#include "eventfilter.moc"
-
+}
