@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -31,7 +31,6 @@
 #include <kstdaction.h> 
 #include <kaction.h>
 #include <kglobal.h>
-#include <klineeditdlg.h>
 #include <kstddirs.h>
 
 #include <qvbox.h>
@@ -42,7 +41,6 @@
 #include <qbuttongroup.h>
 #include <qpopupmenu.h>
 #include <qiconset.h>
-#include <qspinbox.h>
 
 #include <klistview.h>
 
@@ -56,9 +54,6 @@
 #include "matrixtool.h"
 #include "rosedebug.h"
 #include "eventcommands.h"
-#include "segmentcommands.h"
-#include "widgets.h"
-#include "midipitchlabel.h"
 
 #include "Segment.h"
 #include "SegmentPerformanceHelper.h"
@@ -70,6 +65,7 @@
 
 using Rosegarden::Int;
 using Rosegarden::String;
+using Rosegarden::BaseProperties;
 
 // EventView specialisation of a QListViewItem with the
 // addition of a segment pointer
@@ -161,12 +157,6 @@ EventViewItem::compare(QListViewItem *i, int col, bool ascending) const
 	} else {
 	    return key(col, ascending).compare(i->key(col, ascending));
 	}
-    } else if (col == 3) { // pitch
-	// numeric comparison for pitch used to work when we only
-	// showed the numeric pitch number, but then we added the MIDI
-	// pitch name as well and that broke plain numeric comparison
-	return key(col, ascending).section(' ', 0, 0).toInt() -
-	    i->key(col, ascending).section(' ', 0, 0).toInt();
     } else {               // numeric comparison
         return key(col, ascending).toInt() - i->key(col, ascending).toInt();
     }
@@ -187,17 +177,6 @@ EventView::EventView(RosegardenGUIDoc *doc,
 		  ProgramChange | PitchBend | Indication | Other),
     m_menu(0)
 {
-    m_isTriggerSegment = false;
-    m_triggerName = m_triggerPitch = m_triggerVelocity = 0;
-
-    if (!segments.empty()) {
-	Rosegarden::Segment *s = *segments.begin();
-	if (s->getComposition()) {
-	    int id = s->getComposition()->getTriggerSegmentId(s);
-	    if (id >= 0) m_isTriggerSegment = true;
-	}
-    }
-
     if (m_lastSetEventFilter < 0) m_lastSetEventFilter = m_eventFilter;
     else m_eventFilter = m_lastSetEventFilter;
 
@@ -232,80 +211,19 @@ EventView::EventView(RosegardenGUIDoc *doc,
 
     m_grid->addWidget(m_eventList, 2, 1);
 
-    if (m_isTriggerSegment) {
+    if (segments.size() == 1) {
 
-	int id = segments[0]->getComposition()->getTriggerSegmentId(segments[0]);
-	Rosegarden::TriggerSegmentRec *rec =
-	    segments[0]->getComposition()->getTriggerSegmentRec(id);
+        setCaption(QString("%1 - Segment Track #%2 - Event List")
+                   .arg(doc->getTitle())
+                   .arg(segments[0]->getTrack()));
 
-	QGroupBox *groupBox = new QGroupBox
-	    (1, Horizontal, i18n("Triggered Segment Properties"), getCentralWidget());
-	
-	QFrame *frame = new QFrame(groupBox);
-	QGridLayout *layout = new QGridLayout(frame, 5, 3, 5, 5);
+    } else {
 
-	layout->addWidget(new QLabel(i18n("Label:  "), frame), 0, 0);
-	QString label = strtoqstr(segments[0]->getLabel());
-	if (label == "") label = i18n("<no label>");
-	m_triggerName = new QLabel(label, frame);
-	layout->addWidget(m_triggerName, 0, 1);
-	QPushButton *editButton = new QPushButton(i18n("..."), frame);
-	layout->addWidget(editButton, 0, 2);
-	connect(editButton, SIGNAL(clicked()), this, SLOT(slotEditTriggerName()));
-
-	layout->addWidget(new QLabel(i18n("Base pitch:  "), frame), 1, 0);
-	m_triggerPitch = new QLabel(QString("%1").arg(rec->getBasePitch()), frame);
-	layout->addWidget(m_triggerPitch, 1, 1);
-	editButton = new QPushButton(i18n("..."), frame);
-	layout->addWidget(editButton, 1, 2);
-	connect(editButton, SIGNAL(clicked()), this, SLOT(slotEditTriggerPitch()));
-
-	layout->addWidget(new QLabel(i18n("Base velocity:  "), frame), 2, 0);
-	m_triggerVelocity = new QLabel(QString("%1").arg(rec->getBaseVelocity()), frame);
-	layout->addWidget(m_triggerVelocity, 2, 1);
-	editButton = new QPushButton(i18n("..."), frame);
-	layout->addWidget(editButton, 2, 2);
-	connect(editButton, SIGNAL(clicked()), this, SLOT(slotEditTriggerVelocity()));
-
-	/*!!! Comment out these two options, which are not yet used
-	  anywhere else -- intended for use with library ornaments, not
-	  yet implemented
-	
-	layout->addWidget(new QLabel(i18n("Default timing:  "), frame), 3, 0);
-
-	KComboBox *adjust = new KComboBox(frame);
-	layout->addMultiCellWidget(adjust, 3, 3, 1, 2);
-	adjust->insertItem(i18n("As stored"));
-	adjust->insertItem(i18n("Truncate if longer than note"));
-	adjust->insertItem(i18n("End at same time as note")); 
-	adjust->insertItem(i18n("Stretch or squash segment to note duration"));
-
-	std::string timing = rec->getDefaultTimeAdjust();
-	if (timing == Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_NONE) {
-	    adjust->setCurrentItem(0);
-	} else if (timing == Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SQUISH) {
-	    adjust->setCurrentItem(3);
-	} else if (timing == Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SYNC_START) {
-	    adjust->setCurrentItem(1);
-	} else if (timing == Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SYNC_END) {
-	    adjust->setCurrentItem(2);
-	}
-
-	connect(adjust, SIGNAL(activated(int)), this, SLOT(slotTriggerTimeAdjustChanged(int)));
-	    
-	QCheckBox *retune = new QCheckBox(i18n("Adjust pitch to trigger note by default"), frame);
-	retune->setChecked(rec->getDefaultRetune());
-	connect(retune, SIGNAL(clicked()), this, SLOT(slotTriggerRetuneChanged()));
-	layout->addMultiCellWidget(retune, 4, 4, 1, 2);
-
-	*/
-
-	m_grid->addWidget(groupBox, 2, 2);
-	
+        setCaption(QString("%1 - %2 Segments - Event List")
+                   .arg(doc->getTitle())
+                   .arg(segments.size()));
     }
 
-    updateViewCaption();
-
     for (unsigned int i = 0; i < m_segments.size(); ++i) {
 	m_segments[i]->addObserver(this);
     }
@@ -339,16 +257,14 @@ EventView::EventView(RosegardenGUIDoc *doc,
 
     makeInitialSelection(doc->getComposition().getPosition());
 
-    slotCompositionStateUpdate();
-
     setOutOfCtor();
 }
 
 EventView::~EventView()
 {
-    for (unsigned int i = 0; i < m_segments.size(); ++i) {
-        RG_DEBUG << "~EventView - removing this observer from " << m_segments[i] << endl;
-        m_segments[i]->removeObserver(this);
+    if (!getDocument()->isBeingDestroyed()) {
+	for (unsigned int i = 0; i < m_segments.size(); ++i)
+	    m_segments[i]->removeObserver(this);
     }
 }
 
@@ -358,19 +274,6 @@ EventView::eventRemoved(const Rosegarden::Segment *, Rosegarden::Event *e)
     m_deletedEvents.insert(e);
 }
 
-void
-EventView::segmentDeleted(const Rosegarden::Segment *s)
-{
-    std::vector<Rosegarden::Segment *>::iterator i = std::find(m_segments.begin(), m_segments.end(), s);
-
-    if (i != m_segments.end()) {
-        m_segments.erase(i);
-    } else {
-        RG_DEBUG << "%%% WARNING - EventView::segmentDeleted() called on non-registered segment - should not happen\n";
-    }
-    
-}
-
 bool
 EventView::applyLayout(int /*staffNo*/)
 {
@@ -457,17 +360,16 @@ EventView::applyLayout(int /*staffNo*/)
 
 	    // avoid debug stuff going to stderr if no properties found
 
-	    if ((*it)->has(Rosegarden::BaseProperties::PITCH)) {
-		int p = (*it)->get<Int>(Rosegarden::BaseProperties::PITCH);
-		pitchStr = QString("%1 %2  ")
-		    .arg(p).arg(Rosegarden::MidiPitchLabel(p).getQString());
+	    if ((*it)->has(BaseProperties::PITCH)) {
+		pitchStr = QString("%1  ").
+                    arg((*it)->get<Int>(BaseProperties::PITCH));
 	    } else if ((*it)->isa(Rosegarden::Note::EventType)) {
 		pitchStr = "<not set>";
 	    }
 
-	    if ((*it)->has(Rosegarden::BaseProperties::VELOCITY)) {
+	    if ((*it)->has(BaseProperties::VELOCITY)) {
 		velyStr = QString("%1  ").
-                    arg((*it)->get<Int>(Rosegarden::BaseProperties::VELOCITY));
+                    arg((*it)->get<Int>(BaseProperties::VELOCITY));
 	    } else if ((*it)->isa(Rosegarden::Note::EventType)) {
 		velyStr = "<not set>";
 	    }
@@ -496,10 +398,10 @@ EventView::applyLayout(int /*staffNo*/)
 	    } else if ((*it)->has(Rosegarden::PitchBend::MSB)) {
                 data1Str = QString("%1  ").
                     arg((*it)->get<Int>(Rosegarden::PitchBend::MSB));
-            } else if ((*it)->has(Rosegarden::BaseProperties::BEAMED_GROUP_TYPE)) {
+            } else if ((*it)->has(BaseProperties::BEAMED_GROUP_TYPE)) {
 		data1Str = QString("%1  ").
 		    arg(strtoqstr((*it)->get<String>
-				  (Rosegarden::BaseProperties::BEAMED_GROUP_TYPE)));
+				  (BaseProperties::BEAMED_GROUP_TYPE)));
 	    }
 
             if ((*it)->has(Rosegarden::Controller::VALUE)) {
@@ -519,14 +421,14 @@ EventView::applyLayout(int /*staffNo*/)
 	    } else if ((*it)->has(Rosegarden::PitchBend::LSB)) {
                 data2Str = QString("%1  ").
                     arg((*it)->get<Int>(Rosegarden::PitchBend::LSB));
-            } else if ((*it)->has(Rosegarden::BaseProperties::BEAMED_GROUP_ID)) {
+            } else if ((*it)->has(BaseProperties::BEAMED_GROUP_ID)) {
 		data2Str = i18n("(group %1)  ").
-		    arg((*it)->get<Int>(Rosegarden::BaseProperties::BEAMED_GROUP_ID));
+		    arg((*it)->get<Int>(BaseProperties::BEAMED_GROUP_ID));
 	    }
 
             if ((*it)->has(Rosegarden::ProgramChange::PROGRAM)) {
                 data1Str = QString("%1  ").
-                    arg((*it)->get<Int>(Rosegarden::ProgramChange::PROGRAM) + 1);
+                    arg((*it)->get<Int>(Rosegarden::ProgramChange::PROGRAM));
             }
 
             if ((*it)->has(Rosegarden::ChannelPressure::PRESSURE)) {
@@ -625,23 +527,6 @@ EventView::makeInitialSelection(Rosegarden::timeT time)
     EventViewItem *goodItem = 0;
     int goodItemNo = 0;
 
-    int i = 0;
-    
-    for (QListViewItem *child = m_eventList->firstChild(); 
-	 child;
-	 child = child->nextSibling()) {
-
-	EventViewItem *item = dynamic_cast<EventViewItem *>(child);
-
-	if (item) {
-	    if (item->getEvent()->getAbsoluteTime() > time) break;
-	    goodItem = item;
-	    goodItemNo = i;
-	}
-
-	++i;
-    }
-/*!!!
     for (int i = 0; m_eventList->itemAtIndex(i); ++i) {
 
 	EventViewItem *item = dynamic_cast<EventViewItem *>
@@ -653,7 +538,7 @@ EventView::makeInitialSelection(Rosegarden::timeT time)
 	    goodItemNo = i;
 	}
     }
-*/
+
     if (goodItem) {
 	m_listSelection.push_back(goodItemNo);
 	m_eventList->setSelected(goodItem, true);
@@ -688,8 +573,7 @@ EventView::makeTimeString(Rosegarden::timeT time, int timeMode)
     {
 	Rosegarden::RealTime rt =
 	    getDocument()->getComposition().getElapsedRealTime(time);
-//	return QString("%1  ").arg(rt.toString().c_str());
-	return QString("%1  ").arg(rt.toText().c_str());
+	return QString("%1  ").arg(rt.toString().c_str());
     }
 
     default:
@@ -725,8 +609,7 @@ EventView::makeDurationString(Rosegarden::timeT time,
 	Rosegarden::RealTime rt =
 	    getDocument()->getComposition().getRealTimeDifference
 	    (time, time + duration);
-//	return QString("%1  ").arg(rt.toString().c_str());
-	return QString("%1  ").arg(rt.toText().c_str());
+	return QString("%1  ").arg(rt.toString().c_str());
     }
 
     default:
@@ -749,120 +632,6 @@ EventView::updateView()
     m_eventList->update();
 }
 
-void
-EventView::slotEditTriggerName()
-{
-    bool ok = false;
-    QString newLabel = KLineEditDlg::getText(i18n("Segment label"), i18n("Label:"),
-					     strtoqstr(m_segments[0]->getLabel()),
-					     &ok, this);
-
-    if (ok) {
-	Rosegarden::SegmentSelection selection;
-	selection.insert(m_segments[0]);
-	SegmentLabelCommand *cmd = new SegmentLabelCommand(selection, newLabel);
-	addCommandToHistory(cmd);
-	m_triggerName->setText(newLabel);
-    }
-}
-
-void
-EventView::slotEditTriggerPitch()
-{
-    int id = m_segments[0]->getComposition()->getTriggerSegmentId(m_segments[0]);
-
-    Rosegarden::TriggerSegmentRec *rec =
-	m_segments[0]->getComposition()->getTriggerSegmentRec(id);
-
-    PitchDialog *dlg = new PitchDialog(this, i18n("Base pitch"), rec->getBasePitch());
-
-    if (dlg->exec() == QDialog::Accepted) {
-	addCommandToHistory(new SetTriggerSegmentBasePitchCommand
-			    (&getDocument()->getComposition(), id, dlg->getPitch()));
-	m_triggerPitch->setText(QString("%1").arg(dlg->getPitch()));
-    }
-}
-
-class TrivialVelocityDialog : public KDialogBase
-{
-public:
-    TrivialVelocityDialog(QWidget *parent, QString label, int deft) :
-	KDialogBase(parent, 0, true, label, Ok | Cancel)
-    {
-	QHBox *hbox = makeHBoxMainWidget();
-	new QLabel(label, hbox);
-	m_spin = new QSpinBox(0, 127, 1, hbox);
-	m_spin->setValue(deft);
-    }
-
-    int getVelocity() { return m_spin->value(); }
-
-protected:
-    QSpinBox *m_spin;
-};
-
-void
-EventView::slotEditTriggerVelocity()
-{
-    int id = m_segments[0]->getComposition()->getTriggerSegmentId(m_segments[0]);
-
-    Rosegarden::TriggerSegmentRec *rec =
-	m_segments[0]->getComposition()->getTriggerSegmentRec(id);
-
-    TrivialVelocityDialog *dlg = new TrivialVelocityDialog
-	(this, i18n("Base velocity"), rec->getBaseVelocity());
-
-    if (dlg->exec() == QDialog::Accepted) {
-	addCommandToHistory(new SetTriggerSegmentBaseVelocityCommand
-			    (&getDocument()->getComposition(), id, dlg->getVelocity()));
-	m_triggerVelocity->setText(QString("%1").arg(dlg->getVelocity()));
-    }
-}
-
-void
-EventView::slotTriggerTimeAdjustChanged(int option)
-{
-    std::string adjust = Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SQUISH;
-
-    switch(option) {
-
-    case  0:
-	adjust = Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_NONE;
-	break;
-    case  1:
-	adjust = Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SYNC_START;
-	break;
-    case  2:
-	adjust = Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SYNC_END;
-	break;
-    case  3:
-	adjust = Rosegarden::BaseProperties::TRIGGER_SEGMENT_ADJUST_SQUISH;
-	break;
-
-    default: break;
-    }
-    
-    int id = m_segments[0]->getComposition()->getTriggerSegmentId(m_segments[0]);
-
-    Rosegarden::TriggerSegmentRec *rec =
-	m_segments[0]->getComposition()->getTriggerSegmentRec(id);
-
-    addCommandToHistory(new SetTriggerSegmentDefaultTimeAdjustCommand
-			(&getDocument()->getComposition(), id, adjust));
-}
-
-void
-EventView::slotTriggerRetuneChanged()
-{
-    int id = m_segments[0]->getComposition()->getTriggerSegmentId(m_segments[0]);
-
-    Rosegarden::TriggerSegmentRec *rec =
-	m_segments[0]->getComposition()->getTriggerSegmentRec(id);
-
-    addCommandToHistory(new SetTriggerSegmentDefaultRetuneCommand
-			(&getDocument()->getComposition(), id, !rec->getDefaultRetune()));
-}
-
 void
 EventView::slotEditCut()
 {
@@ -1212,28 +981,25 @@ EventView::setupActions()
     EditViewBase::setupActions("eventlist.rc");
     
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QIconSet icon(QPixmap(pixmapDir + "/toolbar/event-insert.png"));
+    QIconSet icon(QPixmap(pixmapDir + "/toolbar/event-insert.xpm"));
     
     new KAction(i18n("&Insert Event"), icon, Key_I, this,
                 SLOT(slotEditInsert()), actionCollection(),
                 "insert");
 
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/event-delete.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-delete.xpm"));
     
     new KAction(i18n("&Delete Event"), icon, Key_Delete, this,
                 SLOT(slotEditDelete()), actionCollection(),
                 "delete");
     
-    pixmap.load(pixmapDir + "/toolbar/event-edit.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-edit.xpm"));
 
     new KAction(i18n("&Edit Event"), icon, Key_E, this,
                 SLOT(slotEditEvent()), actionCollection(),
                 "edit_simple");
     
-    pixmap.load(pixmapDir + "/toolbar/event-edit-advanced.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-edit-advanced.xpm"));
 
     new KAction(i18n("&Advanced Event Editor"), icon, Key_A, this,
                 SLOT(slotEditEventAdvanced()), actionCollection(),
@@ -1257,8 +1023,7 @@ EventView::setupActions()
 
     KRadioAction *action;
 
-    pixmap.load(pixmapDir + "/toolbar/time-musical.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-musical.xpm"));
 
     action = new KRadioAction(i18n("&Musical Times"), icon, 0, this,
 			      SLOT(slotMusicalTime()),
@@ -1266,8 +1031,7 @@ EventView::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 0) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-real.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-real.xpm"));
 
     action = new KRadioAction(i18n("&Real Times"), icon, 0, this,
 			      SLOT(slotRealTime()),
@@ -1275,8 +1039,7 @@ EventView::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 1) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-raw.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-raw.xpm"));
 
     action = new KRadioAction(i18n("Ra&w Times"), icon, 0, this,
 			      SLOT(slotRawTime()),
@@ -1284,13 +1047,6 @@ EventView::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 2) action->setChecked(true);
 
-    if (m_isTriggerSegment) {
-	KAction *action = actionCollection()->action("open_in_matrix");
-	if (action) delete action;
-	action = actionCollection()->action("open_in_notation");
-	if (action) delete action;
-    }
-
     createGUI(getRCFileName());
 }
 
@@ -1350,13 +1106,6 @@ EventView::slotSaveOptions()
     m_eventList->saveLayout(m_config, LayoutConfigGroupName);
 }
 
-Rosegarden::Segment *
-EventView::getCurrentSegment()
-{
-    if (m_segments.empty()) return 0;
-    else return *m_segments.begin();
-}
-
 void 
 EventView::slotModifyFilter(int button)
 {
@@ -1566,8 +1315,6 @@ EventView::slotPopupEventEditor(QListViewItem *item)
 {
     EventViewItem *eItem = dynamic_cast<EventViewItem*>(item);
 
-    //!!! trigger events
-
     if (eItem)
     {
 	Rosegarden::Event *event = eItem->getEvent();
@@ -1669,39 +1416,6 @@ EventView::slotMenuActivated(int value)
     return;
 }
 
-void
-EventView::updateViewCaption()
-{
-    if (m_isTriggerSegment) {
-
-	setCaption(i18n("%1 - Triggered Segment: %2")
-		   .arg(getDocument()->getTitle())
-		   .arg(strtoqstr(m_segments[0]->getLabel())));
-
-        
-    }  else if (m_segments.size() == 1) {
-
-	Rosegarden::TrackId trackId = m_segments[0]->getTrack();
-	Rosegarden::Track *track =
-	    m_segments[0]->getComposition()->getTrackById(trackId);
-
-	int trackPosition = -1;
-	if (track) trackPosition = track->getPosition();
-
-        setCaption(i18n("%1 - Segment Track #%2 - Event List")
-                   .arg(getDocument()->getTitle())
-                   .arg(trackPosition + 1));
-
-    } else {
-
-        setCaption(i18n("%1 - %2 Segments - Event List")
-                   .arg(getDocument()->getTitle())
-                   .arg(m_segments.size()));
-    }
-    
-}
-
 
 
 const char* const EventView::ConfigGroup = "EventList Options";
-#include "eventview.moc"
