@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -30,7 +30,7 @@
 #include "MappedCommon.h"
 #include "MidiProgram.h"
 
-#include "rosegardenparameterbox.h"
+#include "widgets.h"
 
 class QCheckBox;
 class QSlider;
@@ -42,8 +42,7 @@ class KComboBox;
 class RosegardenGUIDoc;
 class QWidgetStack;
 class AudioVUMeter;
-class AudioFaderBox;
-class RosegardenRotary;
+class AudioFaderWidget;
 
 namespace Rosegarden
 {
@@ -74,14 +73,16 @@ public:
     Rosegarden::Instrument* getSelectedInstrument()
         { return m_selectedInstrument; }
 
-    void setAudioMeter(float dBleft, float dBright,
-		       float recDBleft, float recDBright);
+    void setAudioMeter(float dBleft, float dBright);
+
+    // If currently showing this track's instrument then toggle
+    // the mute button on the display
+    //
+    void setMute(bool value);
+    void setSolo(bool value);
+    void setRecord(bool value);
 
     void setDocument(RosegardenGUIDoc* doc);
-    
-    virtual void showAdditionalControls(bool showThem);
-
-    virtual QString getPreviousBox(RosegardenParameterArea::Arrangement) const;
 
 public slots:
 
@@ -105,10 +106,11 @@ signals:
     void changeInstrumentLabel(Rosegarden::InstrumentId id, QString label);
 
     void selectPlugin(QWidget*, Rosegarden::InstrumentId id, int index);
-    void showPluginGUI(Rosegarden::InstrumentId id, int index);
+    void setMute(Rosegarden::InstrumentId, bool value);
+    void setSolo(Rosegarden::InstrumentId, bool value);
+    void setRecord(Rosegarden::InstrumentId, bool value);
 
     void instrumentParametersChanged(Rosegarden::InstrumentId);
-    void instrumentPercussionSetChanged(Rosegarden::Instrument *);
 
 protected:
 
@@ -123,7 +125,7 @@ protected:
     // So we can setModified()
     //
     RosegardenGUIDoc                *m_doc;
-    bool                            m_lastShowAdditionalControlsArg;
+
 };
 
 // Global references
@@ -144,8 +146,6 @@ public:
 
     void setDocument(RosegardenGUIDoc* doc);
 
-    void showAdditionalControls(bool showThem);
-
 signals:
     void updateAllBoxes();
         
@@ -168,16 +168,17 @@ public:
     // Set the audio meter to a given level for a maximum of
     // two channels.
     //
-    void setAudioMeter(float dBleft, float dBright,
-		       float recDBleft, float recDBright);
+    void setAudioMeter(float dBleft, float dBright);
 
     // Set the button colour
     //
     void setButtonColour(int pluginIndex, bool bypassState, 
                          const QColor &color);
 
+    void setMute(bool value);
+
 public slots:
-    // From AudioFaderBox
+    // From AudioFaderWidget
     //
     void slotSelectAudioLevel(float dB);
     void slotSelectAudioRecordLevel(float dB);
@@ -186,26 +187,34 @@ public slots:
     void slotSelectPlugin(int index);
 
     // From the parameter box clicks
+    void slotMute();
+    void slotSolo();
+    void slotRecord();
+
     void slotSetPan(float pan);
 
+    // External things set our button states here
+    //
+    void slotSetMute(bool value);
+    void slotSetSolo(bool value);
+    void slotSetRecord(bool value);
+
     // From Plugin dialog
     //
     void slotPluginSelected(Rosegarden::InstrumentId id, int index, int plugin);
     void slotPluginBypassed(Rosegarden::InstrumentId id, int pluginIndex, bool bp);
 
-    void slotSynthButtonClicked();
-    void slotSynthGUIButtonClicked();
-
 signals:
+    void muteButton(Rosegarden::InstrumentId, bool state);
+    void soloButton(Rosegarden::InstrumentId, bool state);
+    void recordButton(Rosegarden::InstrumentId, bool state);
     void selectPlugin(QWidget *, Rosegarden::InstrumentId, int index);
     void instrumentParametersChanged(Rosegarden::InstrumentId);
-    void showPluginGUI(Rosegarden::InstrumentId, int index);
-    void changeInstrumentLabel(Rosegarden::InstrumentId id, QString label);
 
 protected:
     //--------------- Data members ---------------------------------
 
-    AudioFaderBox   *m_audioFader;
+    AudioFaderWidget   *m_audioFader;
 
 private:
 
@@ -225,8 +234,6 @@ public:
 
     virtual void setupForInstrument(Rosegarden::Instrument*);
 
-    void showAdditionalControls(bool showThem);
-
 signals:
     void changeInstrumentLabel(Rosegarden::InstrumentId id, QString label);
     void instrumentParametersChanged(Rosegarden::InstrumentId);
@@ -236,7 +243,6 @@ public slots:
     void slotSelectBank(int index);
     void slotSelectVariation(int index);
     void slotSelectChannel(int index);
-    //void slotSelectInputChannel(int index);
 
     void slotControllerChanged(int index);
 
@@ -273,7 +279,6 @@ protected:
     KComboBox          *m_variationValue;
     KComboBox          *m_channelValue;
     KComboBox          *m_programValue;
-    //KComboBox          *m_channelInValue;
 
     QCheckBox          *m_percussionCheckBox;
     QCheckBox          *m_bankCheckBox;
@@ -282,7 +287,6 @@ protected:
 
     QLabel             *m_bankLabel;
     QLabel             *m_variationLabel;
-    QLabel             *m_programLabel;
 
     QGridLayout        *m_mainGrid;
     QFrame             *m_rotaryFrame;
@@ -290,9 +294,9 @@ protected:
     RotaryMap           m_rotaries;
     QSignalMapper      *m_rotaryMapper;
 
-    Rosegarden::BankList       m_banks;
-    Rosegarden::ProgramList    m_programs;
-    Rosegarden::MidiByteList   m_variations;
+    Rosegarden::BankList      m_banks;
+    Rosegarden::ProgramList   m_programs;
+    Rosegarden::MidiByteList  m_variations;
 };
 
 
