@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,6 +24,8 @@
 
 #include <unistd.h>
 
+#include "config.h"
+
 #include <qpainter.h>
 #include <qfontmetrics.h>
 
@@ -77,23 +79,18 @@ void KStartupLogo::paintEvent(QPaintEvent*)
 
     int y = m_pixmap.height() - 12;
 
-//    paint.setPen(QColor(206,214,163));
-//    paint.setBrush(QColor(206,214,163));
-    QColor bg(49,94,19);
-    paint.setPen(bg);
-    paint.setBrush(bg);
+    paint.setPen(QColor(206,214,163));
+    paint.setBrush(QColor(206,214,163));
     paint.drawRect(QRect(m_pixmap.width() - 220, m_pixmap.height() - 43,
 			 220, (y + 8) - (m_pixmap.height() - 43)));
 
-//    paint.setPen(Qt::black);
-//    paint.setBrush(Qt::black);
-    paint.setPen(Qt::white);
-    paint.setBrush(Qt::white);
+    paint.setPen(Qt::black);
+    paint.setBrush(Qt::black);
 
-    //QString version(VERSION);
-    //int sepIdx = version.find("-");
-    QString versionLabel(VERSION);
-	//QString("R%1 v%2").arg(version.left(sepIdx)).arg(version.mid(sepIdx + 1));
+    QString version(VERSION);
+    int sepIdx = version.find("-");
+    QString versionLabel =
+	QString("R%1 v%2").arg(version.left(sepIdx)).arg(version.mid(sepIdx + 1));
     int versionWidth = metrics.width(versionLabel);
 
     paint.drawText(m_pixmap.width() - versionWidth - 18,
@@ -147,4 +144,3 @@ void KStartupLogo::hideIfStillThere()
 
 KStartupLogo* KStartupLogo::m_instance = 0;
 bool KStartupLogo::m_wasClosed = false;
-#include "kstartuplogo.moc"
