@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -33,8 +33,6 @@
 #include <vector>
 #include "Event.h"
 #include "Segment.h"
-#include "Studio.h"
-#include "rosegardenguidoc.h"
 #include "progressreporter.h"
 
 /**
@@ -48,23 +46,20 @@ public:
     typedef std::multiset<Rosegarden::Event*, Rosegarden::Event::EventEndCmp> eventendlist;
 
 public:
-    LilypondExporter(QObject *parent, RosegardenGUIDoc *, std::string fileName);
+    LilypondExporter(QObject *parent, Rosegarden::Composition *,
+                     std::string fileName);
     ~LilypondExporter();
 
     bool write();
 
 protected:
-    RosegardenGUIDoc *m_doc;
     Rosegarden::Composition *m_composition;
-    Rosegarden::Studio *m_studio;
     std::string m_fileName;
-    bool m_pitchBorked;
 
-    void writeBar(Rosegarden::Segment *, int barNo, int barStart, int barEnd, int col,
+    void writeBar(Rosegarden::Segment *, int barNo, int col,
 		  Rosegarden::Key &key, std::string &lilyText, std::string &lilyLyrics,
 		  std::string &prevStyle, eventendlist &eventsInProgress,
-		  std::ofstream &str, bool &nextBarIsAlt1, bool &nextBarIsAlt2,
-		  bool &nextBarIsDouble, bool &nextBarIsEnd, bool &nextBarIsDot);
+		  std::ofstream &str, bool &note_ended_with_a_lyric);
     
     Rosegarden::timeT calculateDuration(Rosegarden::Segment *s,
 					const Rosegarden::Segment::iterator &i,
@@ -97,43 +92,15 @@ protected:
 		   bool useRests,
 		   std::ofstream &);
 
-    /*
-     * Handle Lilypond directive.  Returns true if the event was a directive,
-     * so subsequent code does not bother to process the event twice
-     */
-    bool handleDirective(const Rosegarden::Event *textEvent,
-	                 std::string &lilyText,
-		         bool &nextBarIsAlt1, bool &nextBarIsAlt2,
-			 bool &nextBarIsDouble, bool &nextBarIsEnd, bool &nextBarIsDot);
-
-    void handleText(const Rosegarden::Event *, std::string &lilyText, std::string &lilyLyrics);
+    void handleText(const Rosegarden::Event *, std::string &lilyText, std::string &lilyLyrics, int languageLevel);
     void writePitch(const Rosegarden::Event *note, const Rosegarden::Key &key, std::ofstream &);
-    void writeStyle(const Rosegarden::Event *note, std::string &prevStyle, int col, std::ofstream &, bool isInChord);
+    void writeStyle(const Rosegarden::Event *note, std::string &prevStyle, int col, std::ofstream &);
     void writeDuration(Rosegarden::timeT duration, std::ofstream &);
     void writeSlashes(const Rosegarden::Event *note, std::ofstream &);
        
 private:
     static const int MAX_DOTS = 4;
     static const Rosegarden::PropertyName SKIP_PROPERTY;
-    
-    unsigned int m_paperSize;
-    unsigned int m_fontSize;
-    bool m_exportLyrics;
-    bool m_exportHeaders;
-    bool m_exportMidi;
-    bool m_exportUnmuted;
-    bool m_exportPointAndClick;
-    bool m_exportBarChecks;
-    bool m_exportBeams;
-    bool m_exportStaffGroup;
-    bool m_exportStaffMerge;
-
-	// languagelevel meaning:
-	// 0 -> Lilypond 2.2
-	// 1 -> Lilypond 2.4
-	// 2 -> Lilypond 2.6
-	// 3 -> Lilypond 2.8
-    int m_languageLevel;
 };
 
 
