@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -25,7 +25,6 @@
 #include "colours.h"
 #include "Event.h"
 #include "rosestrings.h"
-#include "rosegardencanvasview.h"
 #include "rosedebug.h"
 #include "RulerScale.h"
 
@@ -43,13 +42,12 @@ LoopRuler::LoopRuler(RulerScale *rulerScale,
       m_invert(invert),
       m_currentXOffset(0),
       m_width(-1),
-      m_activeMousePress(false),
       m_rulerScale(rulerScale),
       m_grid(rulerScale),
-      m_loopingMode(false),
+      m_loop(false),
       m_startLoop(0), m_endLoop(0)
 {
-    setBackgroundColor(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::LoopRulerBackground));
+    setBackgroundColor(RosegardenGUIColours::LoopRulerBackground);
 
     // Only allow loops to be snapped to Beats on this grid
     //
@@ -129,7 +127,7 @@ void LoopRuler::drawBarSections(QPainter* paint)
 	firstBar = m_rulerScale->getFirstVisibleBar();
     }
 
-    paint->setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::LoopRulerForeground));
+    paint->setPen(RosegardenGUIColours::LoopRulerForeground);
 
     for (int i = firstBar; i <= lastBar; ++i) {
 
@@ -179,8 +177,8 @@ LoopRuler::drawLoopMarker(QPainter* paint)
     x2 += m_currentXOffset + m_xorigin;
 
     paint->save();
-    paint->setBrush(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::LoopHighlight));
-    paint->setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::LoopHighlight));
+    paint->setBrush(RosegardenGUIColours::LoopHighlight);
+    paint->setPen(RosegardenGUIColours::LoopHighlight);
     paint->drawRect(static_cast<int>(x1), 0, static_cast<int>(x2 - x1), m_height);
     paint->restore();
 
@@ -189,24 +187,14 @@ LoopRuler::drawLoopMarker(QPainter* paint)
 void
 LoopRuler::mousePressEvent(QMouseEvent *mE)
 {
-    RG_DEBUG << "LoopRuler::mousePressEvent: x = " << mE->x() << endl;
-
-    Qt::ButtonState bs = mE->state();
-    setLoopingMode((bs & Qt::ShiftButton) != 0);
-    
     if (mE->button() == LeftButton)
     {
-	double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset - m_xorigin;
+	double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset;
         
-        if (m_loopingMode)
+        if (m_loop)
             m_endLoop = m_startLoop = m_grid.snapX(x);
-        else {
-	    RG_DEBUG << "emitting setPointerPosition(" << m_rulerScale->getTimeForX(x) << ")" << endl;
+        else
 	    emit setPointerPosition(m_rulerScale->getTimeForX(x));
-	}
-
-	m_activeMousePress = true;
-        emit startMouseMove(RosegardenCanvasView::FollowHorizontal);
     }
 }
 
@@ -215,7 +203,7 @@ LoopRuler::mouseReleaseEvent(QMouseEvent *mE)
 {
     if (mE->button() == LeftButton)
     {
-        if (m_loopingMode)
+        if (m_loop)
         {
             // Cancel the loop if there was no drag
             //
@@ -235,42 +223,40 @@ LoopRuler::mouseReleaseEvent(QMouseEvent *mE)
             else
                 emit setLoop(m_startLoop, m_endLoop);
         }
-        emit stopMouseMove();
-	m_activeMousePress = false;
     }
 }
 
 void
 LoopRuler::mouseDoubleClickEvent(QMouseEvent *mE)
 {
-    double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset - m_xorigin;
+    double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset;
     if (x < 0) x = 0;
     
-    RG_DEBUG << "LoopRuler::mouseDoubleClickEvent: x = " << x << ", looping = " << m_loopingMode << endl;
-
-    if (mE->button() == LeftButton && !m_loopingMode)
+    if (mE->button() == LeftButton && !m_loop)
         emit setPlayPosition(m_rulerScale->getTimeForX(x));
 }
 
 void
 LoopRuler::mouseMoveEvent(QMouseEvent *mE)
 {
-    double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset - m_xorigin;
+    double x = mE->pos().x() / getHScaleFactor() - m_currentXOffset;
     if (x < 0) x = 0;
     
-    if (m_loopingMode)
+    if (m_loop)
     {
         if (m_grid.snapX(x) != m_endLoop)
         {
            m_endLoop = m_grid.snapX(x);
-           emit dragLoopToPosition(m_rulerScale->getTimeForX(x));
            update();
         }
     }
     else
-        emit dragPointerToPosition(m_rulerScale->getTimeForX(x));
+        emit setPointerPosition(m_rulerScale->getTimeForX(x));
+}
 
-    emit mouseMove();
+void LoopRuler::slotSetLoopingMode(bool value)
+{
+    m_loop = value;
 }
 
 void LoopRuler::slotSetLoopMarker(Rosegarden::timeT startLoop,
@@ -287,4 +273,3 @@ void LoopRuler::slotSetLoopMarker(Rosegarden::timeT startLoop,
     update();
 }
 
-#include "loopruler.moc"
