@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -27,7 +27,7 @@
 #include "SnapGrid.h"
 
 #include "rosegardenguidoc.h"
-#include "hzoomable.h"
+#include "widgets.h"
 
 namespace Rosegarden { class RulerScale; }
 
@@ -59,11 +59,8 @@ public:
 
     void setHorizScaleFactor(double dy) { m_hScaleFactor = dy; }
 
-    bool hasActiveMousePress() { return m_activeMousePress; }
-
-    bool getLoopingMode() { return m_loopingMode; }
-    
 public slots:
+    void slotSetLoopingMode(bool value);
     void slotSetLoopMarker(Rosegarden::timeT startLoop,
 			   Rosegarden::timeT endLoop);
 
@@ -76,33 +73,21 @@ protected:
 
     virtual void paintEvent(QPaintEvent*);
 
-    void setLoopingMode(bool value) { m_loopingMode = value; }
-    void drawBarSections(QPainter*);
-    void drawLoopMarker(QPainter*);  // between loop positions
-
 signals:
     // The three main functions that this class performs
     //
-    /// Set the pointer position on mouse single click
+    /// Set the pointer position on mouse single click or drag
     void setPointerPosition(Rosegarden::timeT);
 
-    /// Set the pointer position on mouse drag
-    void dragPointerToPosition(Rosegarden::timeT);
-
     /// Set pointer position and start playing on double click
     void setPlayPosition(Rosegarden::timeT);
 
     /// Set a playing loop
     void setLoop(Rosegarden::timeT, Rosegarden::timeT);
 
-    /// Set the loop end position on mouse drag
-    void dragLoopToPosition(Rosegarden::timeT);
-
-    void startMouseMove(int directionConstraint);
-    void stopMouseMove();
-    void mouseMove();
-
-protected:
+private:
+    void drawBarSections(QPainter*);
+    void drawLoopMarker(QPainter*);  // between loop positions
 
     //--------------- Data members ---------------------------------
     int  m_height;
@@ -110,12 +95,11 @@ protected:
     bool m_invert;
     int  m_currentXOffset;
     int  m_width;
-    bool m_activeMousePress;
 
     Rosegarden::RulerScale *m_rulerScale;
     Rosegarden::SnapGrid    m_grid;
     
-    bool m_loopingMode;
+    bool m_loop;
     Rosegarden::timeT m_startLoop;
     Rosegarden::timeT m_endLoop;
 };
