@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -342,10 +342,6 @@ static int _x_errhandler( Display *dpy, XErrorEvent *err )
 }
 #endif
 
-// NOTE: to get a dump of the stack trace from KDE during program execution:
-// std::cerr << kdBacktrace() << std::endl
-// (see kdebug.h)
-
 void testInstalledVersion()
 {
     QString versionLocation = locate("appdata", "version.txt");
@@ -369,18 +365,18 @@ void testInstalledVersion()
         KMessageBox::detailedError
             (0,
              i18n("Installation contains the wrong version of Rosegarden."),
-             i18n(" The wrong versions of Rosegarden's data files were\n"
+             QString(i18n(" The wrong versions of Rosegarden's data files were\n"
                   " found in the standard KDE installation directories.\n"
                   " (I am %1, but the installed files are for version %2.)\n\n"
                   " This may mean one of the following:\n\n"
                   " 1. This is a new upgrade of Rosegarden, and it has not yet been\n"
                   "     installed.  If you compiled it yourself, check that you have\n"
-                  "     run \"scons install\" and that the procedure completed\n"
+                  "     run \"make install\" and that the procedure completed\n"
                   "     successfully.\n\n"
                   " 2. The upgrade was installed in a non-standard directory,\n"
                   "     and an old version was found in a standard directory.  If so,\n"
                   "     you will need to add the correct directory to your KDEDIRS\n"
-                  "     environment variable before you can run it.").arg(VERSION).arg(installedVersion),
+                  "     environment variable before you can run it.")).arg(VERSION).arg(installedVersion),
              i18n("Installation problem"));
         
     } else {
@@ -392,7 +388,7 @@ void testInstalledVersion()
                   " found in the standard KDE installation directories.\n\n"
                   " This may mean one of the following:\n\n"
                   " 1. Rosegarden has not been correctly installed.  If you compiled\n"
-                  "     it yourself, check that you have run \"scons install\" and that\n"
+                  "     it yourself, check that you have run \"make install\" and that\n"
                   "     the procedure completed successfully.\n\n"
                   " 2. Rosegarden has been installed in a non-standard directory,\n"
                   "     and you need to add this directory to your KDEDIRS environment\n"
@@ -410,55 +406,31 @@ int main(int argc, char *argv[])
 {
     setsid(); // acquire shiny new process group
 
-    srandom((unsigned int)time(0) * (unsigned int)getpid());
-
     KAboutData aboutData( "rosegarden", I18N_NOOP("Rosegarden"),
                           VERSION, description, KAboutData::License_GPL,
-                          I18N_NOOP("Copyright 2000 - 2006 Guillaume Laurent, Chris Cannam, Richard Bown\nParts copyright 1994 - 2004 Chris Cannam, Andy Green, Richard Bown, Guillaume Laurent\nLilypond fonts copyright 1997 - 2005 Han-Wen Nienhuys and Jan Nieuwenhuizen"),
+                          I18N_NOOP("Copyright 2000 - 2004 Guillaume Laurent, Chris Cannam, Richard Bown\nParts copyright 1994 - 2004 Chris Cannam, Andy Green, Richard Bown, Guillaume Laurent\nLilypond fonts copyright 1997 - 2004 Han-Wen Nienhuys and Jan Nieuwenhuizen"),
                           0,
                           "http://www.rosegardenmusic.com/",
-                          "rosegarden-devel@lists.sourceforge.net");
+                          "rosegarden-devel@sf.net");
 
     aboutData.addAuthor("Guillaume Laurent", 0, "glaurent@telegraph-road.org", "http://telegraph-road.org");
     aboutData.addAuthor("Chris Cannam", 0, "cannam@all-day-breakfast.com", "http://all-day-breakfast.com");
     aboutData.addAuthor("Richard Bown", 0, "bownie@bownie.com", "http://bownie.com");
-    aboutData.addAuthor("D. Michael McIntyre (adjunct)", 0, "dmmcintyr@users.sourceforge.net", "http://www.geocities.com/Paris/Rue/5407");
 
     aboutData.addCredit("Randall Farmer", I18N_NOOP("Chord labelling code"), " rfarme@simons-rock.edu");
     aboutData.addCredit("Hans  Kieserman", I18N_NOOP("Lilypond output\nassorted other patches\ni18n-ization"), "hkieserman@mail.com");
+    aboutData.addCredit("Michael McIntyre", I18N_NOOP("notation selection event filter\nextra toolbars/pixmaps\nnotation/Lilypond patches\nauthor of \"Using Rosegarden\""), "dmmcintyr@users.sourceforge.net");
     aboutData.addCredit("Levi Burton", I18N_NOOP("UI improvements\nbug fixes"), "donburton@sbcglobal.net");
-    aboutData.addCredit("Mark Hymers", I18N_NOOP("Segment colours\nOther UI and bug fixes"),"<markh@linuxfromscratch.org>");
     aboutData.addCredit("Alexandre Prokoudine", I18N_NOOP("Russian translation\ni18n-ization"), "avp@altlinux.ru");
-    aboutData.addCredit("Pedro Lopez-Cabanillas", I18N_NOOP("ALSA hacking and bug fixes\nmulti-input MIDI recording\nformer Spanish translator"), "plcl@users.sourceforge.net");
+    aboutData.addCredit("Pedro Lopez-Cabanillas", I18N_NOOP("Spanish translatio\nALSA research"), "plcl@bigfoot.com");
     aboutData.addCredit("Jörg Schumann", I18N_NOOP("German translation"), "jrschumann@gmx.de");
-    aboutData.addCredit("Eckhard Jokisch", I18N_NOOP("German translation"), "e.jokisch@u-code.de");
     aboutData.addCredit("Kevin Donnelly", I18N_NOOP("Welsh translation"));
     aboutData.addCredit("Didier Burli", I18N_NOOP("French translation"), "didierburli@bluewin.ch");
     aboutData.addCredit("Daniele Medri", I18N_NOOP("Italian translation"), "madrid@linuxmeeting.net");
-    aboutData.addCredit("Alessandro Musesti", I18N_NOOP("Italian translation"), "a.musesti@dmf.unicatt.it");
     aboutData.addCredit("Stefan Asserhäll", I18N_NOOP("Swedish translation"), "stefan.asserhall@comhem.se");
-    aboutData.addCredit("Erik Magnus Johansson", I18N_NOOP("Swedish translation"), "erik.magnus.johansson@telia.com");
     aboutData.addCredit("Hasso Tepper", I18N_NOOP("Estonian translation"), "hasso@estpak.ee");
     aboutData.addCredit("Jelmer Vernooij", I18N_NOOP("Dutch translation"), "jelmer@samba.org");
-    aboutData.addCredit("Kevin Liang", I18N_NOOP("HSpinBox class"), "xkliang@rhpcs.mcmaster.ca");
-    aboutData.addCredit("Thorsten Wilms", I18N_NOOP("Original designs for rotary controllers"), "t_w_@freenet.de");
-    aboutData.addCredit("Oota Toshiya", I18N_NOOP("Japanese translation"), "ribbon@users.sourceforge.net");
-    aboutData.addCredit("William", I18N_NOOP("Auto-scroll deceleration\nRests outside staves and other bug fixes"), "rosegarden4p AT orthoset.com");
-    aboutData.addCredit("Liu Songhe", I18N_NOOP("Simplified Chinese translation"), "jackliu9999@msn.com");
-    aboutData.addCredit("Toni Arnold", I18N_NOOP("LIRC infrared remote-controller support"), "<toni__arnold@bluewin.ch>");
-    aboutData.addCredit("Vince Negri", I18N_NOOP("MTC slave timing implementation"), "vince.negri@gmail.com");
-    aboutData.addCredit("Jan Bína", I18N_NOOP("Czech translation"), "jbina@sky.cz");
-    aboutData.addCredit("Thomas Nagy", I18N_NOOP("SCons/bksys building system"), "tnagy256@yahoo.fr");
-    aboutData.addCredit("Vladimir Savic", I18N_NOOP("icons, icons, icons"), "vladimir@vladimirsavic.net");
-    aboutData.addCredit("Marcos Germán Guglielmetti", I18N_NOOP("Spanish translation"), "marcospcmusica@yahoo.com.ar");
-    aboutData.addCredit("Lisandro Damián Nicanor Pérez Meyer", I18N_NOOP("Spanish translation"), "perezmeyer@infovia.com.ar");
-    aboutData.addCredit("Javier Castrillo", I18N_NOOP("Spanish translation"), "riverplatense@gmail.com");
-    aboutData.addCredit("Lucas Godoy", I18N_NOOP("Spanish translation"), "godoy.lucas@gmail.com");
-    aboutData.addCredit("Feliu Ferrer", I18N_NOOP("Catalan translation"), "mverge2@pie.xtec.es");
-    aboutData.addCredit("Quim Perez i Noguer", I18N_NOOP("Catalan translation"), "noguer@osona.com");
-    aboutData.addCredit("Carolyn McIntyre", I18N_NOOP("new splash screen photo (of Michael's rose garden)"), "catma@adelphia.net");
-    aboutData.addCredit("Heikki Johannes Junes", I18N_NOOP("Finnish translation"), "hjunes@cc.hut.fi");
-//    aboutData.addCredit("Stephen Torri", I18N_NOOP("guitar chord editor"), "storri@torri.org");
+    aboutData.addCredit("Bernd Weber", I18N_NOOP("German translation (Arbeiten mit Rosegarden)"), "weber.freiburg@freenet.de");
 
     aboutData.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\nYour names") ,I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"));
     
@@ -513,13 +485,11 @@ int main(int argc, char *argv[])
     RosegardenGUIApp *rosegardengui = 0;
  
     if (app.isRestored()) {
-        RG_DEBUG << "Restoring from session\n";
 
         // RESTORE(RosegardenGUIApp);
         int n = 1;
         while (KMainWindow::canBeRestored(n)) {
             // memory leak if more than one can be restored?
-            RG_DEBUG << "Restoring from session - restoring app #" << n << endl;
             (rosegardengui = new RosegardenGUIApp)->restore(n);
             n++;
         }
@@ -549,7 +519,7 @@ int main(int argc, char *argv[])
         }
 
         if (args->count()) {
-            rosegardengui->openFile(QFile::decodeName(args->arg(0)), RosegardenGUIApp::ImportCheckType);
+            rosegardengui->openFile(args->arg(0), RosegardenGUIApp::ImportCheckType);
         } else {
             // rosegardengui->openDocumentFile();
         }
@@ -558,10 +528,6 @@ int main(int argc, char *argv[])
 
     }
 
-    QObject::connect(&app, SIGNAL(aboutToSaveState()),
-                     rosegardengui, SLOT(slotDeleteTransport()));
-
-
     // Now that we've started up, raise start logo
     //
     if (startLogo) {
