@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -33,7 +33,6 @@
 #include <qlabel.h>
 #include <qaccel.h>
 #include <qiconset.h>
-#include <qcanvas.h>
 
 #include "markereditor.h"
 #include "rosegardenguidoc.h"
@@ -213,7 +212,7 @@ MarkerEditorDialog::updatePosition()
 
     QString realTime, secsStr;
     if (hours) realTime += QString("%1h ").arg(hours);
-    if (mins) realTime += QString("%1m ").arg(mins);
+    if (mins) realTime += QString("%1m ").arg(hours);
     secsStr.sprintf("%ld.%03lds", secs, msecs);
     realTime += secsStr;
 
@@ -320,13 +319,9 @@ MarkerEditorDialog::slotDeleteAll()
 
     do
     {
-	MarkerEditorViewItem *ei = 
-	    dynamic_cast<MarkerEditorViewItem *>(item);
-	if (!ei) continue;
-
         RemoveMarkerCommand *rc = 
             new RemoveMarkerCommand(&m_doc->getComposition(),
-                                    ei->getRawTime(),
+                                    item->text(0).toInt(),
                                     qstrtostr(item->text(1)),
                                     qstrtostr(item->text(2)));
         command->addCommand(rc);
@@ -357,14 +352,11 @@ MarkerEditorDialog::slotDelete()
     RG_DEBUG << "MarkerEditorDialog::slotDelete" << endl;
     QListViewItem *item = m_listView->currentItem();
 
-    MarkerEditorViewItem *ei = 
-        dynamic_cast<MarkerEditorViewItem *>(item);
-
-    if (!ei) return;
+    if (!item) return;
 
     RemoveMarkerCommand *command =
         new RemoveMarkerCommand(&m_doc->getComposition(),
-                                ei->getRawTime(),
+                                item->text(0).toInt(),
                                 qstrtostr(item->text(1)),
                                 qstrtostr(item->text(2)));
 
@@ -407,13 +399,11 @@ MarkerEditorDialog::setupActions()
                             KStdAction::stdName(KStdAction::Redo));
 
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    kapp->config()->setGroup(MarkerEditorConfigGroup);
     int timeMode = kapp->config()->readNumEntry("timemode", 0);
 
     KRadioAction *action;
 
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/time-musical.png");
-    QIconSet icon(pixmap);
+    QIconSet icon(QCanvasPixmap(pixmapDir + "/toolbar/time-musical.xpm"));
 
     action = new KRadioAction(i18n("&Musical Times"), icon, 0, this,
                               SLOT(slotMusicalTime()),
@@ -421,8 +411,7 @@ MarkerEditorDialog::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 0) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-real.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-real.xpm"));
 
     action = new KRadioAction(i18n("&Real Times"), icon, 0, this,
                               SLOT(slotRealTime()),
@@ -430,8 +419,7 @@ MarkerEditorDialog::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 1) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-raw.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-raw.xpm"));
 
     action = new KRadioAction(i18n("Ra&w Times"), icon, 0, this,
                               SLOT(slotRawTime()),
@@ -484,12 +472,6 @@ MarkerEditorDialog::slotEdit(QListViewItem *i)
 {
     RG_DEBUG << "MarkerEditorDialog::slotEdit" << endl;
 
-    if (m_listView->selectionMode() == QListView::NoSelection) {
-	// The marker list is empty, so we shouldn't allow editing the
-	// <none> placeholder
-	return;
-    }
-
     // Need to get the raw time from the ListViewItem
     //
     MarkerEditorViewItem *item = 
@@ -583,15 +565,13 @@ void
 MarkerEditorDialog::slotItemClicked(QListViewItem *item)
 {
     RG_DEBUG << "MarkerEditorDialog::slotItemClicked" << endl;
-    MarkerEditorViewItem *ei = 
-        dynamic_cast<MarkerEditorViewItem *>(item);
 
-    if (ei)
+    if (item)
     {
         RG_DEBUG << "MarkerEditorDialog::slotItemClicked - "
-                 << "jump to marker at " << ei->getRawTime() << endl;
+                 << "jump to marker at " << item->text(0).toInt() << endl;
 
-        emit jumpToMarker(Rosegarden::timeT(ei->getRawTime()));
+        emit jumpToMarker(Rosegarden::timeT(item->text(0).toInt()));
     }
 }
 
@@ -622,8 +602,7 @@ MarkerEditorDialog::makeTimeString(Rosegarden::timeT time, int timeMode)
     {
         Rosegarden::RealTime rt =
             m_doc->getComposition().getElapsedRealTime(time);
-//        return QString("%1   ").arg(rt.toString().c_str());
-        return QString("%1   ").arg(rt.toText().c_str());
+        return QString("%1   ").arg(rt.toString().c_str());
     }
 
     default:
@@ -658,4 +637,3 @@ MarkerEditorDialog::slotRawTime()
 
 
 const char* const MarkerEditorDialog::MarkerEditorConfigGroup = "Marker Editor";
-#include "markereditor.moc"
