@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -37,7 +37,6 @@ class MatrixCanvasView : public RosegardenCanvasView
 public:
     MatrixCanvasView(MatrixStaff&,
 		     Rosegarden::SnapGrid *,
-		     bool drumMode,
                      QCanvas *viewing,
                      QWidget *parent=0, const char *name=0, WFlags f=0);
 
@@ -60,8 +59,7 @@ signals:
      * Emitted when the mouse cursor moves to a different height
      * on the staff.  Returns the new pitch.
      */
-    void hoveredOverNoteChanged(int evPitch, bool haveEvent,
-				Rosegarden::timeT evTime);
+    void hoveredOverNoteChanged(int evPitch);
 
     /**
      * Emitted when the mouse cursor moves to a note which is at a
@@ -110,7 +108,7 @@ protected:
      * Update the value of snap grid according to the button's state
      *
      * If the button was pressed with the 'smooth' modifier, set the
-     * grid so it won't snap time.
+     * grid so it won't snap time. Snap to beat otherwise.
      *
      * @see #setSmoothModifier
      * @see #getSmoothModifier
@@ -121,7 +119,6 @@ protected:
 
     MatrixStaff          &m_staff;
     Rosegarden::SnapGrid *m_snapGrid;
-    bool                  m_drumMode;
 
     Rosegarden::timeT     m_previousEvTime;
     int                   m_previousEvPitch;
@@ -131,7 +128,7 @@ protected:
 
     Qt::ButtonState       m_smoothModifier;
     Rosegarden::timeT     m_lastSnap;
-    bool                  m_isSnapTemporary;
+
 };
 
 
