@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,8 +23,6 @@
 #include <klocale.h>
 #include <kaction.h>
 #include <kstddirs.h>
-#include <qapplication.h>
-#include <qtimer.h>
 
 #include "BaseProperties.h"
 #include "SegmentMatrixHelper.h"
@@ -34,9 +32,7 @@
 #include "matrixview.h"
 #include "matrixstaff.h"
 #include "matrixcommands.h"
-#include "notationcommands.h"
 #include "velocitycolour.h"
-#include "zoomslider.h"
 
 #include "rosestrings.h"
 #include "rosedebug.h"
@@ -167,8 +163,7 @@ MatrixPainter::MatrixPainter(MatrixView* parent)
       m_currentStaff(0)
 {
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/select.xpm");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/select.xpm"));
 
     new KAction(i18n("Switch to Select Tool"), icon, 0, this,
                 SLOT(slotSelectSelected()), actionCollection(),
@@ -182,8 +177,7 @@ MatrixPainter::MatrixPainter(MatrixView* parent)
                 SLOT(slotMoveSelected()), actionCollection(),
                 "move");
 
-    pixmap.load(pixmapDir + "/toolbar/resize.xpm");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/resize.xpm"));
     new KAction(i18n("Switch to Resize Tool"), icon, 0, this,
                 SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
@@ -241,7 +235,7 @@ void MatrixPainter::handleLeftButtonPress(Rosegarden::timeT time,
     ev->set<Rosegarden::Int>(Rosegarden::BaseProperties::PITCH, pitch);
     ev->set<Rosegarden::Int>(Rosegarden::BaseProperties::VELOCITY, 100);
 
-    m_currentElement = new MatrixElement(ev, m_mParentView->isDrumMode());
+    m_currentElement = new MatrixElement(ev);
 
     int y = m_currentStaff->getLayoutYForHeight(pitch) -
             m_currentStaff->getElementHeight() / 2;
@@ -265,7 +259,7 @@ int MatrixPainter::handleMouseMove(Rosegarden::timeT time,
                                    QMouseEvent *)
 {
     // sanity check
-    if (!m_currentElement) return RosegardenCanvasView::NoFollow;
+    if (!m_currentElement) return NoFollow;
 
     MATRIX_DEBUG << "MatrixPainter::handleMouseMove : pitch = "
                          << pitch << ", time : " << time << endl;
@@ -283,8 +277,7 @@ int MatrixPainter::handleMouseMove(Rosegarden::timeT time,
 
     m_currentElement->setWidth(int(width));
     
-    if (m_currentElement->event()->has(PITCH) &&
-	pitch != m_currentElement->event()->get<Rosegarden::Int>(PITCH)) {
+    if (pitch != m_currentElement->event()->get<Rosegarden::Int>(PITCH)) {
 	m_currentElement->event()->set<Rosegarden::Int>(PITCH, pitch);
 	int y = m_currentStaff->getLayoutYForHeight(pitch) -
 	    m_currentStaff->getElementHeight() / 2;
@@ -296,7 +289,7 @@ int MatrixPainter::handleMouseMove(Rosegarden::timeT time,
     }
     m_mParentView->update();
 
-    return RosegardenCanvasView::FollowHorizontal | RosegardenCanvasView::FollowVertical;
+    return FollowHorizontal;
 }
 
 void MatrixPainter::handleMouseRelease(Rosegarden::timeT endTime,
@@ -308,101 +301,38 @@ void MatrixPainter::handleMouseRelease(Rosegarden::timeT endTime,
     // got the mouse down
     if (!m_currentElement) return;
 
+    // Insert element if it has a non null duration,
+    // discard it otherwise
+    //
     timeT time = m_currentElement->getViewAbsoluteTime();
-    timeT segmentEndTime = m_currentStaff->getSegment().getEndMarkerTime();
 
-    if (m_mParentView->isDrumMode()) {
+    if (time > endTime) std::swap(time, endTime);
 
-	if (time > segmentEndTime) time = segmentEndTime;
+    if (endTime == time) endTime = time + m_currentElement->getViewDuration();
 
-	MatrixPercussionInsertionCommand *command =
-	    new MatrixPercussionInsertionCommand(m_currentStaff->getSegment(),
-						 time,
-						 m_currentElement->event());
-	m_mParentView->addCommandToHistory(command);
+    Rosegarden::SegmentMatrixHelper helper(m_currentStaff->getSegment());
+    MATRIX_DEBUG << "MatrixPainter::handleMouseRelease() : helper.insertNote()\n";
 
-	Event* ev = m_currentElement->event();
-	delete m_currentElement;
-	delete ev;
+    MatrixInsertionCommand* command = 
+	new MatrixInsertionCommand(m_currentStaff->getSegment(),
+				   time,
+                                   endTime,
+				   m_currentElement->event());
+    
+    m_mParentView->addCommandToHistory(command);
 
-	ev = command->getLastInsertedEvent();
-	if (ev) m_mParentView->setSingleSelectedEvent(m_currentStaff->getSegment(),
+    Event* ev = m_currentElement->event();
+    delete m_currentElement;
+    delete ev;
+
+    ev = command->getLastInsertedEvent();
+    if (ev) m_mParentView->setSingleSelectedEvent(m_currentStaff->getSegment(),
 						  ev);
-    } else {
-
-	// Insert element if it has a non null duration,
-	// discard it otherwise
-	//
-	if (time > endTime) std::swap(time, endTime);
-	
-	if (endTime == time) endTime = time + m_currentElement->getViewDuration();
-
-	if (time < segmentEndTime) {
-	
-	    if (endTime > segmentEndTime) endTime = segmentEndTime;
-
-	    Rosegarden::SegmentMatrixHelper helper(m_currentStaff->getSegment());
-	    MATRIX_DEBUG << "MatrixPainter::handleMouseRelease() : helper.insertNote()\n";
-	
-	    MatrixInsertionCommand* command = 
-		new MatrixInsertionCommand(m_currentStaff->getSegment(),
-					   time,
-					   endTime,
-					   m_currentElement->event());
-	
-	    m_mParentView->addCommandToHistory(command);
-
-	    Event* ev = m_currentElement->event();
-	    delete m_currentElement;
-	    delete ev;
-
-	    ev = command->getLastInsertedEvent();
-	    if (ev) m_mParentView->setSingleSelectedEvent(m_currentStaff->getSegment(),
-							  ev);
-	} else {
-
-	    Event* ev = m_currentElement->event();
-	    delete m_currentElement;
-	    delete ev;
-	}
-    }
 
     m_mParentView->update();
     m_currentElement = 0;
 }
 
-void MatrixPainter::ready()
-{
-    connect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixPainter::stow()
-{
-    disconnect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-               this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixPainter::slotMatrixScrolled(int newX, int newY) 
-{
-    if (!m_currentElement) return;
-
-    QPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
-                                    m_parentView->getCanvasView()->contentsY());
-
-    QPoint offset = newP1 - oldP1;
-
-    offset = m_mParentView->inverseMapPoint(offset);
-
-    QPoint p(m_currentElement->getCanvasX() + m_currentElement->getWidth(), m_currentElement->getCanvasY());
-    p += offset;
-    
-    timeT newTime = m_mParentView->getSnapGrid().snapX(p.x());
-    int newPitch = m_currentStaff->getHeightAtCanvasCoords(p.x(), p.y());
-
-    handleMouseMove(newTime, newPitch, 0);
-}
-
 //------------------------------
 
 MatrixEraser::MatrixEraser(MatrixView* parent)
@@ -410,8 +340,7 @@ MatrixEraser::MatrixEraser(MatrixView* parent)
       m_currentStaff(0)
 {
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/select.xpm");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/select.xpm"));
 
     new KAction(i18n("Switch to Select Tool"), icon, 0, this,
                 SLOT(slotSelectSelected()), actionCollection(),
@@ -425,8 +354,7 @@ MatrixEraser::MatrixEraser(MatrixView* parent)
                 SLOT(slotMoveSelected()), actionCollection(),
                 "move");
 
-    pixmap.load(pixmapDir + "/toolbar/resize.xpm");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/resize.xpm"));
     new KAction(i18n("Switch to Resize Tool"), icon, 0, this,
                 SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
@@ -472,8 +400,6 @@ MatrixSelector::MatrixSelector(MatrixView* view)
       m_currentStaff(0),
       m_clickedElement(0),
       m_dispatchTool(0),
-      m_justSelectedBar(false),
-      m_matrixView(view),
       m_selectionToMerge(0)
 {
     connect(m_parentView, SIGNAL(usedSelection()),
@@ -492,8 +418,7 @@ MatrixSelector::MatrixSelector(MatrixView* view)
                 "move");
 
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/resize.xpm");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/resize.xpm"));
 
     new KAction(i18n("Switch to Resize Tool"), icon, 0, this,
                 SLOT(slotResizeSelected()), actionCollection(),
@@ -518,11 +443,6 @@ void MatrixSelector::handleEventRemoved(Rosegarden::Event *event)
     }
 }
 
-void MatrixSelector::slotClickTimeout()
-{
-    m_justSelectedBar = false;
-}
-
 void MatrixSelector::handleLeftButtonPress(Rosegarden::timeT time,
                                            int height,
                                            int staffNo,
@@ -531,12 +451,6 @@ void MatrixSelector::handleLeftButtonPress(Rosegarden::timeT time,
 {
     MATRIX_DEBUG << "MatrixSelector::handleMousePress" << endl;
 
-    if (m_justSelectedBar) {
-	handleMouseTripleClick(time, height, staffNo, e, element);
-	m_justSelectedBar = false;
-	return;
-    }
-
     QPoint p = m_mParentView->inverseMapPoint(e->pos());
 
     m_currentStaff = m_mParentView->getStaff(staffNo);
@@ -585,31 +499,8 @@ void MatrixSelector::handleLeftButtonPress(Rosegarden::timeT time,
     }
     else
     {
-	// Workaround for #930420 Positional error in sweep-selection box
-	// boundary
-	int zoomValue = (int)m_matrixView->m_hZoomSlider->getCurrentSize();
-	MatrixStaff *staff = m_mParentView->getStaff(staffNo);
-	int pitch = m_currentStaff->getHeightAtCanvasCoords(p.x(), p.y());
-	int pitchCentreHeight = staff->getTotalHeight() -
-				pitch * staff->getLineSpacing() - 2; // 2 or ?
-	int pitchLineHeight = pitchCentreHeight + staff->getLineSpacing()/2;
-	int drawHeight = p.y();
-	if (drawHeight <= pitchLineHeight + 1 &&
-	    drawHeight >= pitchLineHeight - 1) {
-	    if (drawHeight == pitchLineHeight)
-		drawHeight += 2;
-	    else
-		drawHeight += 2 * (drawHeight - pitchLineHeight);
-	}
-	MATRIX_DEBUG << "#### MatrixSelector::handleLeftButtonPress() : zoom "
-		<< zoomValue
-		<< " pitch " << pitch
-		<< " pitchCentreHeight " << pitchCentreHeight
-		<< " pitchLineHeight " << pitchLineHeight
-		<< " lineSpacing " << staff->getLineSpacing()
-		<< " drawHeight " << drawHeight << endl;
-        m_selectionRect->setX(int(p.x()/4)*4); // more workaround for #930420
-        m_selectionRect->setY(drawHeight);
+        m_selectionRect->setX(p.x());
+        m_selectionRect->setY(p.y());
         m_selectionRect->setSize(0,0);
 
         m_selectionRect->show();
@@ -649,7 +540,7 @@ void MatrixSelector::handleMidButtonPress(Rosegarden::timeT time,
 void MatrixSelector::handleMouseDoubleClick(Rosegarden::timeT ,
 					    int ,
 					    int staffNo,
-					    QMouseEvent *ev,
+					    QMouseEvent* ,
 					    Rosegarden::ViewElement *element)
 {
 /*
@@ -666,97 +557,20 @@ void MatrixSelector::handleMouseDoubleClick(Rosegarden::timeT ,
 
     if (m_clickedElement) {
 
-	if (m_clickedElement->event()->isa(Rosegarden::Note::EventType) &&
-	    m_clickedElement->event()->has(Rosegarden::BaseProperties::TRIGGER_SEGMENT_ID)) {
-	    
-	    int id = m_clickedElement->event()->get<Rosegarden::Int>
-		(Rosegarden::BaseProperties::TRIGGER_SEGMENT_ID);
-	    emit editTriggerSegment(id);
-	    return;
+	EventEditDialog dialog(m_mParentView, *m_clickedElement->event(), true);
+
+	if (dialog.exec() == QDialog::Accepted &&
+	    dialog.isModified()) {
+
+	    EventEditCommand *command = new EventEditCommand
+		(staff->getSegment(),
+		 m_clickedElement->event(),
+		 dialog.getEvent());
+
+	    m_mParentView->addCommandToHistory(command);
 	}
-
-	if (ev->state() & ShiftButton) { // advanced edit
-
-	    EventEditDialog dialog(m_mParentView, *m_clickedElement->event(), true);
-
-	    if (dialog.exec() == QDialog::Accepted &&
-		dialog.isModified()) {
-		
-		EventEditCommand *command = new EventEditCommand
-		    (staff->getSegment(),
-		     m_clickedElement->event(),
-		     dialog.getEvent());
-		
-		m_mParentView->addCommandToHistory(command);
-	    }
-	} else {
-
-	    SimpleEventEditDialog dialog(m_mParentView, m_mParentView->getDocument(),
-					 *m_clickedElement->event(), false);
-
-	    if (dialog.exec() == QDialog::Accepted &&
-		dialog.isModified()) {
-		
-		EventEditCommand *command = new EventEditCommand
-		    (staff->getSegment(),
-		     m_clickedElement->event(),
-		     dialog.getEvent());
-		
-		m_mParentView->addCommandToHistory(command);
-	    }
-	}	    
-
-    } /*  
-	  
-      #988167: Matrix:Multiclick select methods don't work in matrix editor
-      Postponing this, as it falls foul of world-matrix transformation
-      etiquette and other such niceties
-
-	  else {
-
-	QRect rect = staff->getBarExtents(ev->x(), ev->y());
-
-	m_selectionRect->setX(rect.x() + 2);
-	m_selectionRect->setY(rect.y());
-	m_selectionRect->setSize(rect.width() - 4, rect.height());
-
-	m_selectionRect->show();
-	m_updateRect = false;
-	
-	m_justSelectedBar = true;
-	QTimer::singleShot(QApplication::doubleClickInterval(), this,
-			   SLOT(slotClickTimeout()));
-    } */
-}
-
-void MatrixSelector::handleMouseTripleClick(Rosegarden::timeT t,
-					    int height,
-					    int staffNo,
-					    QMouseEvent *ev,
-					    Rosegarden::ViewElement *element)
-{
-    if (!m_justSelectedBar) return;
-    m_justSelectedBar = false;
-
-    MatrixStaff *staff = m_mParentView->getStaff(staffNo);
-    if (!staff) return;
-
-    if (m_clickedElement) {
-
-	// should be safe, as we've already set m_justSelectedBar false
-	handleLeftButtonPress(t, height, staffNo, ev, element);
-	return;
-
-    } else {
-
-	m_selectionRect->setX(staff->getX());
-	m_selectionRect->setY(staff->getY());
-	m_selectionRect->setSize(int(staff->getTotalWidth()) - 1,
-				 staff->getTotalHeight() - 1);
-
-	m_selectionRect->show();
-	m_updateRect = false;
     }
+
 }
 
 int MatrixSelector::handleMouseMove(timeT time, int height,
@@ -769,7 +583,7 @@ int MatrixSelector::handleMouseMove(timeT time, int height,
         return m_dispatchTool->handleMouseMove(time, height, e);
     }
 
-    if (!m_updateRect) return RosegardenCanvasView::NoFollow;
+    if (!m_updateRect) return NoFollow;
 
     int w = int(p.x() - m_selectionRect->x());
     int h = int(p.y() - m_selectionRect->y());
@@ -778,18 +592,11 @@ int MatrixSelector::handleMouseMove(timeT time, int height,
     if (w > 0) ++w; else --w;
     if (h > 0) ++h; else --h;
 
-    // Workaround for #930420 Positional error in sweep-selection box boundary
-    int wFix = (w > 0) ? 3 : 0;
-    int hFix = (h > 0) ? 3 : 0;
-    int xFix = (w < 0) ? 3 : 0;
-    m_selectionRect->setSize(w-wFix,h-hFix);
-    m_selectionRect->setX(m_selectionRect->x()+xFix);
-    setViewCurrentSelection();
     m_selectionRect->setSize(w,h);
-    m_selectionRect->setX(m_selectionRect->x()-xFix);
+    setViewCurrentSelection();
     m_mParentView->canvas()->update();
 
-    return RosegardenCanvasView::FollowHorizontal | RosegardenCanvasView::FollowVertical;
+    return FollowHorizontal | FollowVertical;
 }
 
 void MatrixSelector::handleMouseRelease(timeT time, int height, QMouseEvent *e)
@@ -834,15 +641,11 @@ void MatrixSelector::ready()
     {
         m_selectionRect = new QCanvasRectangle(m_mParentView->canvas());
         m_selectionRect->hide();
-        m_selectionRect->setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::SelectionRectangle));
+        m_selectionRect->setPen(RosegardenGUIColours::SelectionRectangle);
 
         m_mParentView->setCanvasCursor(Qt::arrowCursor);
         //m_mParentView->setPositionTracking(false);
     }
-
-    connect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotMatrixScrolled(int, int)));
-
 }
 
 void MatrixSelector::stow()
@@ -853,10 +656,6 @@ void MatrixSelector::stow()
         m_selectionRect = 0;
         m_mParentView->canvas()->update();
     }
-
-    disconnect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-               this, SLOT(slotMatrixScrolled(int, int)));
-
 }
 
 
@@ -868,26 +667,6 @@ void MatrixSelector::slotHideSelection()
     m_mParentView->canvas()->update();
 }
 
-void MatrixSelector::slotMatrixScrolled(int newX, int newY)
-{
-    if (m_updateRect) {
-        int offsetX = newX - m_parentView->getCanvasView()->contentsX();
-        int offsetY = newY - m_parentView->getCanvasView()->contentsY();
-
-        int w = int(m_selectionRect->width() + offsetX);
-        int h = int(m_selectionRect->height() + offsetY);
-
-        // Qt rectangle dimensions appear to be 1-based
-        if (w > 0) ++w; else --w;
-        if (h > 0) ++h; else --h;
-
-        m_selectionRect->setSize(w,h);
-        setViewCurrentSelection();
-        m_mParentView->canvas()->update();
-    }
-}
-
-
 void MatrixSelector::setViewCurrentSelection()
 {
     EventSelection* selection = getSelection();
@@ -946,8 +725,7 @@ MatrixMover::MatrixMover(MatrixView* parent)
       m_oldY(0)
 {
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/select.xpm");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/select.xpm"));
 
     new KAction(i18n("Switch to Select Tool"), icon, 0, this,
                 SLOT(slotSelectSelected()), actionCollection(),
@@ -961,8 +739,7 @@ MatrixMover::MatrixMover(MatrixView* parent)
                 SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
-    pixmap.load(pixmapDir + "/toolbar/resize.xpm");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/resize.xpm"));
     new KAction(i18n("Switch to Resize Tool"), icon, 0, this,
                 SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
@@ -1043,7 +820,7 @@ int MatrixMover::handleMouseMove(Rosegarden::timeT newTime,
     MATRIX_DEBUG << "MatrixMover::handleMouseMove() time = "
                          << newTime << endl;
 
-    if (!m_currentElement || !m_currentStaff) return RosegardenCanvasView::NoFollow;
+    if (!m_currentElement || !m_currentStaff) return NoFollow;
 
     /*
     using Rosegarden::BaseProperties::PITCH;
@@ -1144,7 +921,7 @@ int MatrixMover::handleMouseMove(Rosegarden::timeT newTime,
     }
 
     m_mParentView->canvas()->update();
-    return RosegardenCanvasView::FollowHorizontal | RosegardenCanvasView::FollowVertical;
+    return FollowHorizontal | FollowVertical;
 }
 
 void MatrixMover::handleMouseRelease(Rosegarden::timeT newTime,
@@ -1186,11 +963,8 @@ void MatrixMover::handleMouseRelease(Rosegarden::timeT newTime,
 
     using Rosegarden::BaseProperties::PITCH;
     timeT diffTime = newTime - m_currentElement->getViewAbsoluteTime();
-    int diffPitch = 0;
-    if (m_currentElement->event()->has(PITCH)) {
-	diffPitch = newPitch -
-	    m_currentElement->event()->get<Rosegarden::Int>(PITCH);
-    }
+    int diffPitch = newPitch -
+        m_currentElement->event()->get<Rosegarden::Int>(PITCH);
 
     if (diffTime == 0 && diffPitch == 0) { // don't generate command or refresh
 	m_mParentView->canvas()->update();
@@ -1220,10 +994,7 @@ void MatrixMover::handleMouseRelease(Rosegarden::timeT newTime,
         for (; it != selection->getSegmentEvents().end(); it++)
         {
             timeT newTime = (*it)->getAbsoluteTime() + diffTime;
-            int newPitch = 60;
-	    if ((*it)->has(PITCH)) {
-		newPitch = (*it)->get<Rosegarden::Int>(PITCH) + diffPitch;
-	    }
+            int newPitch = (*it)->get<Rosegarden::Int>(PITCH) + diffPitch;
             
             Rosegarden::Event *newEvent = new Rosegarden::Event(**it, newTime);
             newEvent->set<Rosegarden::Int>
@@ -1233,13 +1004,10 @@ void MatrixMover::handleMouseRelease(Rosegarden::timeT newTime,
                     new MatrixModifyCommand(m_currentStaff->getSegment(),
                                             (*it),
                                             newEvent,
-                                            true,
-					    false));
+                                            true));
             newSelection->addEvent(newEvent);
         }
 
-	macro->addCommand(new AdjustMenuNormalizeRestsCommand(*newSelection));
-
         m_mParentView->setCurrentSelection(0, false, false);
         m_mParentView->addCommandToHistory(macro);
         m_mParentView->setCurrentSelection(newSelection, false, false);
@@ -1250,39 +1018,6 @@ void MatrixMover::handleMouseRelease(Rosegarden::timeT newTime,
     m_currentElement = 0;
 }
 
-void MatrixMover::ready()
-{
-    connect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixMover::stow()
-{
-    disconnect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-               this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixMover::slotMatrixScrolled(int newX, int newY) 
-{
-    if (!m_currentElement) return;
-
-    QPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
-                                    m_parentView->getCanvasView()->contentsY());
-
-    QPoint offset = newP1 - oldP1;
-
-    offset = m_mParentView->inverseMapPoint(offset);
-
-    QPoint p(m_currentElement->getCanvasX(), m_currentElement->getCanvasY());
-    p += offset;
-    
-    timeT newTime = m_mParentView->getSnapGrid().snapX(p.x());
-    int newPitch = m_currentStaff->getHeightAtCanvasCoords(p.x(), p.y());
-
-    handleMouseMove(newTime, newPitch, 0);
-}
-
-
 //------------------------------
 MatrixResizer::MatrixResizer(MatrixView* parent)
     : MatrixTool("MatrixResizer", parent),
@@ -1290,8 +1025,7 @@ MatrixResizer::MatrixResizer(MatrixView* parent)
       m_currentStaff(0)
 {
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/select.xpm");
-    QIconSet icon = QIconSet(pixmap);
+    QIconSet icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/select.xpm"));
 
     new KAction(i18n("Switch to Select Tool"), icon, 0, this,
                 SLOT(slotSelectSelected()), actionCollection(),
@@ -1375,7 +1109,7 @@ int MatrixResizer::handleMouseMove(Rosegarden::timeT newTime,
                                    int,
                                    QMouseEvent *)
 {
-    if (!m_currentElement || !m_currentStaff) return RosegardenCanvasView::NoFollow;
+    if (!m_currentElement || !m_currentStaff) return NoFollow;
     timeT newDuration = newTime - m_currentElement->getViewAbsoluteTime();
 
     int initialWidth = m_currentElement->getWidth();
@@ -1411,7 +1145,7 @@ int MatrixResizer::handleMouseMove(Rosegarden::timeT newTime,
     }
 
     m_mParentView->canvas()->update();
-    return RosegardenCanvasView::FollowHorizontal;
+    return FollowHorizontal;
 }
 
 void MatrixResizer::handleMouseRelease(Rosegarden::timeT newTime,
@@ -1474,14 +1208,11 @@ void MatrixResizer::handleMouseRelease(Rosegarden::timeT newTime,
                     new MatrixModifyCommand(m_currentStaff->getSegment(),
                                             *it,
                                             newEvent,
-                                            false,
-					    false));
+                                            false));
 
             newSelection->addEvent(newEvent);
         }
 
-	macro->addCommand(new AdjustMenuNormalizeRestsCommand(*newSelection));
-
         m_mParentView->setCurrentSelection(0, false, false);
         m_mParentView->addCommandToHistory(macro);
         m_mParentView->setCurrentSelection(newSelection, false, false);
@@ -1491,34 +1222,6 @@ void MatrixResizer::handleMouseRelease(Rosegarden::timeT newTime,
     m_currentElement = 0;
 }
 
-void MatrixResizer::ready()
-{
-    connect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-            this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixResizer::stow()
-{
-    disconnect(m_parentView->getCanvasView(), SIGNAL(contentsMoving (int, int)),
-               this, SLOT(slotMatrixScrolled(int, int)));
-}
-
-void MatrixResizer::slotMatrixScrolled(int newX, int newY) 
-{
-    QPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
-                                    m_parentView->getCanvasView()->contentsY());
-
-    QPoint p(newX, newY);
-    
-    if (newP1.x() > oldP1.x()) {
-        p.setX(newX + m_parentView->getCanvasView()->visibleWidth());
-    }
-
-    p = m_mParentView->inverseMapPoint(p);
-    int newTime = m_mParentView->getSnapGrid().snapX(p.x());
-    handleMouseMove(newTime, 0, 0);
-}
-
 //------------------------------
 
 const QString MatrixPainter::ToolName   = "painter";
@@ -1527,4 +1230,3 @@ const QString MatrixSelector::ToolName  = "selector";
 const QString MatrixMover::ToolName     = "mover";
 const QString MatrixResizer::ToolName   = "resizer";
 
-#include "matrixtool.moc"
