@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -25,7 +25,6 @@
 #include <kmainwindow.h>
 #include "studiowidgets.h"
 #include "Instrument.h"
-#include "MappedEvent.h"
 
 class RosegardenGUIDoc;
 namespace Rosegarden { class Studio; }
@@ -42,16 +41,12 @@ public:
 
 signals:
     void closing();
-    void windowActivated();
 
 protected slots:
     void slotClose();
 
 protected:
     virtual void closeEvent(QCloseEvent *);
-    virtual void windowActivationChange(bool);
-
-    virtual void sendControllerRefresh() = 0;
 
     RosegardenGUIDoc *m_document;
     Rosegarden::Studio *m_studio;
@@ -70,11 +65,7 @@ public:
     ~AudioMixerWindow();
 
     void updateMeters(SequencerMapper *mapper);
-    void updateMonitorMeters(SequencerMapper *mapper);
-
-public slots:
-    void slotControllerDeviceEventReceived(Rosegarden::MappedEvent *,
-					   const void *);
+    void updateMonitorMeter(SequencerMapper *mapper);
 
 signals:
     void selectPlugin(QWidget *, Rosegarden::InstrumentId id, int index);
@@ -86,7 +77,6 @@ signals:
     void fastForwardPlaybackToEnd();
     void rewindPlaybackToBeginning();
     void record();
-    void panic();
 
     // to be redirected to the instrument parameter box if necessary
     void instrumentParametersChanged(Rosegarden::InstrumentId);
@@ -114,19 +104,10 @@ protected slots:
     void slotSetInputCountFromAction();
     void slotSetSubmasterCountFromAction();
 
-    void slotToggleFaders();
-    void slotToggleSynthFaders();
-    void slotToggleSubmasters();
-    void slotTogglePluginButtons();
-    void slotToggleUnassignedFaders();
-
-    void slotUpdateFaderVisibility();
-    void slotUpdateSynthFaderVisibility();
-    void slotUpdateSubmasterVisibility();
-    void slotUpdatePluginButtonVisibility();
-
-protected:
-    virtual void sendControllerRefresh();
+    void slotShowFaders();
+    void slotShowSubmasters();
+    void slotShowPluginButtons();
+    void slotShowUnassignedFaders();
 
 private:
 
@@ -233,11 +214,6 @@ public:
 public slots:
     void slotSynchronise(); // synchronise with updated studio
 
-    void slotControllerDeviceEventReceived(Rosegarden::MappedEvent *,
-					   const void *);
-
-    void slotCurrentTabChanged(QWidget *);
-
 signals:
     void play();
     void stop();
@@ -246,7 +222,6 @@ signals:
     void fastForwardPlaybackToEnd();
     void rewindPlaybackToBeginning();
     void record();
-    void panic();
 
     // to be redirected to the instrument parameter box if necessary
     void instrumentParametersChanged(Rosegarden::InstrumentId);
@@ -261,8 +236,6 @@ protected slots:
 protected:
     void addTab(QWidget *tab, const QString &title);
 
-    virtual void sendControllerRefresh();
-
     QTabWidget                        *m_tabWidget;
 
     struct FaderStruct {
