@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -27,8 +27,6 @@
 
 #include <qdir.h>
 #include <kstddirs.h>
-#include <kconfig.h>
-#include <algorithm>
 
 #include "mmapper.h"
 
@@ -38,16 +36,11 @@
 #include "ControlBlock.h"
 #include "MappedEvent.h"
 #include "SegmentPerformanceHelper.h"
-#include "BaseProperties.h"
-#include "Midi.h"
 
 #include "rosestrings.h"
 #include "rosegardenguidoc.h"
 #include "rosedebug.h"
 #include "rgapplication.h"
-#include "constants.h"
-
-#include <stdint.h>
 
 // Seems not to be properly defined under some gcc 2.95 setups
 #ifndef MREMAP_MAYMOVE
@@ -60,9 +53,6 @@ using Rosegarden::Segment;
 using Rosegarden::Composition;
 using Rosegarden::MappedEvent;
 using Rosegarden::timeT;
-using Rosegarden::Int;
-using Rosegarden::Bool;
-using namespace Rosegarden::BaseProperties;
 
 ControlBlockMmapper::ControlBlockMmapper(RosegardenGUIDoc* doc)
     : m_doc(doc),
@@ -122,11 +112,6 @@ void ControlBlockMmapper::updateTrackData(Track *t)
     m_controlBlock->updateTrackData(t);
 }
 
-void ControlBlockMmapper::setTrackDeleted(Rosegarden::TrackId t)
-{
-    m_controlBlock->setTrackDeleted(t, true);
-}
-
 void ControlBlockMmapper::updateMidiFilters(Rosegarden::MidiFilter thruFilter,
 					    Rosegarden::MidiFilter recordFilter)
 {
@@ -155,25 +140,11 @@ void ControlBlockMmapper::updateMetronomeForRecord()
     m_controlBlock->setMetronomeMuted(muted);
 }
 
-bool ControlBlockMmapper::updateSoloData(bool solo,
+void ControlBlockMmapper::updateSoloData(bool solo,
                                          Rosegarden::TrackId selectedTrack)
 {
-    bool changed = false;
-
-    if (solo != m_controlBlock->isSolo()) {
-
-	changed = true;
-
-    } else if (solo &&
-	       (selectedTrack != m_controlBlock->getSelectedTrack())) {
-
-	changed = true;
-    }
-
     m_controlBlock->setSolo(solo);
     m_controlBlock->setSelectedTrack(selectedTrack);
-
-    return changed;
 }
 
 void ControlBlockMmapper::setDocument(RosegardenGUIDoc* doc)
@@ -189,7 +160,7 @@ void ControlBlockMmapper::initControlBlock()
 {
     SEQMAN_DEBUG << "ControlBlockMmapper::initControlBlock()\n";
 
-    m_controlBlock = new (m_mmappedBuffer) ControlBlock(m_doc->getComposition().getMaxTrackId());
+    m_controlBlock = new (m_mmappedBuffer) ControlBlock(m_doc->getComposition().getNbTracks());
 
     Composition& comp = m_doc->getComposition();
     
@@ -234,12 +205,6 @@ void ControlBlockMmapper::setFileSize(size_t size)
     
 }
 
-void 
-ControlBlockMmapper::enableMIDIThruRouting(bool state)
-{
-    m_controlBlock->setMidiRoutingEnabled(state);
-}
-
 //----------------------------------------
 
 SegmentMmapper::SegmentMmapper(RosegardenGUIDoc* doc,
@@ -259,29 +224,23 @@ SegmentMmapper::SegmentMmapper(RosegardenGUIDoc* doc,
     m_fd = ::open(m_fileName.latin1(), O_RDWR|O_CREAT|O_TRUNC,
                   S_IRUSR|S_IWUSR);
     if (m_fd < 0) {
-	perror("SegmentMmapper::SegmentMmapper: Failed to open mmap file for writing");
         SEQMAN_DEBUG << "SegmentMmapper : Couldn't open " << m_fileName
                      << endl;
         throw Rosegarden::Exception("Couldn't open " + qstrtostr(m_fileName));
     }
 
-//    SEQMAN_DEBUG << "SegmentMmapper : mmap size = " << m_mmappedSize
-//                 << endl;
+    SEQMAN_DEBUG << "SegmentMmapper : mmap size = " << m_mmappedSize
+                 << endl;
 }
 
 void SegmentMmapper::init()
 {
     m_mmappedSize = computeMmappedSize() + sizeof(size_t);
-    
+
     if (m_mmappedSize > 0) {
         setFileSize(m_mmappedSize);
         doMmap();
         dump();
-        if (m_segment != 0) {
-            SEQMAN_DEBUG << "SegmentMmapper::init : mmap size = " << m_mmappedSize
-                         << " for segment " << m_segment->getLabel() << endl;
-        }
-        
     } else {
         SEQMAN_DEBUG << "SegmentMmapper::init : mmap size = 0 - skipping mmapping for now\n";
     }
@@ -298,13 +257,6 @@ size_t SegmentMmapper::computeMmappedSize()
 }
 
 
-size_t SegmentMmapper::addMmappedSize(Segment *s)
-{
-    int repeatCount = getSegmentRepeatCount();
-    return m_mmappedSize + (repeatCount + 1) * s->size() * sizeof(MappedEvent);
-}
-
-
 SegmentMmapper::~SegmentMmapper()
 {
     SEQMAN_DEBUG << "~SegmentMmapper : " << this
@@ -480,6 +432,8 @@ void SegmentMmapper::dump()
     Rosegarden::RealTime duration;
     Rosegarden::Track* track = comp.getTrackById(m_segment->getTrack());
     
+    Rosegarden::SegmentPerformanceHelper helper(*m_segment);
+
     timeT segmentStartTime = m_segment->getStartTime();
     timeT segmentEndTime = m_segment->getEndMarkerTime();
     timeT segmentDuration = segmentEndTime - segmentStartTime;
@@ -493,130 +447,57 @@ void SegmentMmapper::dump()
 
     for (int repeatNo = 0; repeatNo <= repeatCount; ++repeatNo) {
 
-	Segment *triggered = 0;
-	Segment::iterator *i = 0;
-
         for (Segment::iterator j = m_segment->begin();
-	     m_segment->isBeforeEndMarker(j) || (i && *i != triggered->end()); ) {
+             j != m_segment->end(); ++j) {
 
-	    bool usingi = false;
-	    Segment::iterator *k = &j;
+            // Skip rests
+            //
+            if ((*j)->isa(Rosegarden::Note::EventRestType)) continue;
 
-	    if (i && *i != triggered->end() &&
-		(!m_segment->isBeforeEndMarker(j) ||
-		 (**i)->getAbsoluteTime() < (*j)->getAbsoluteTime())) {
-		k = i;
-		usingi = true;
-	    }
+            timeT playTime =
+                helper.getSoundingAbsoluteTime(j) + repeatNo * segmentDuration;
+            if (playTime >= repeatEndTime) break;
 
-	    if (!usingi) { // don't permit nested triggered segments
+	    timeT playDuration = helper.getSoundingDuration(j);
 
-		long triggerId = -1;
-		(**k)->get<Int>(TRIGGER_SEGMENT_ID, triggerId);
-
-		if (triggerId >= 0) {
-
-		    Rosegarden::TriggerSegmentRec *rec =
-			comp.getTriggerSegmentRec(triggerId);
-
-		    if (rec && rec->getSegment()) {
-			Rosegarden::timeT performanceDuration =
-			    Rosegarden::SegmentPerformanceHelper(*m_segment).
-			    getSoundingDuration(j);
-			if (performanceDuration > 0) {
-			    mergeTriggerSegment(&triggered, *j,
-						performanceDuration, rec);
-			    size_t sz = addMmappedSize(rec->getSegment());
-			    size_t offset = bufPos - m_mmappedEventBuffer;
-			    setFileSize(sz);
-			    remap(sz);
-			    bufPos = m_mmappedEventBuffer + offset;
-			}
-		    }
-
-		    if (triggered) {
-			if (i) delete i;
-			i = new Segment::iterator
-			    (triggered->findTime((*j)->getAbsoluteTime()));
-		    }
-
-		    // Use the next triggered event (presumably the
-		    // first of the current triggered segment) instead
-		    // of the one that triggered it
-
-		    ++j; // whatever happens, we don't want to write this one
-
-		    if (i && *i != triggered->end() &&
-			(!m_segment->isBeforeEndMarker(j) ||
-			 ((**i)->getAbsoluteTime() < (*j)->getAbsoluteTime()))) {
-			k = i;
-			usingi = true;
-		    } else {
-			// no joy at all
-			continue; 
-		    }
-		}
-	    }
-
-	    // Ignore rests
-	    //
-            if (!(**k)->isa(Rosegarden::Note::EventRestType)) {
-
-		Rosegarden::SegmentPerformanceHelper helper
-		    (usingi ? *triggered : *m_segment);
-
-		timeT playTime =
-		    helper.getSoundingAbsoluteTime(*k) + repeatNo * segmentDuration;
-		if (playTime >= repeatEndTime) break;
-
-		timeT playDuration = helper.getSoundingDuration(*k);
-
-		// Ignore notes without duration -- they're probably in a tied
-		// series but not as first note
-		//
-		if (playDuration > 0 || !(**k)->isa(Rosegarden::Note::EventType)) {
+            // No duration and we're a note?  Probably in a tied
+            // series, but not as first note
+            //
+            if (playDuration == 0 && (*j)->isa(Rosegarden::Note::EventType))
+                continue;
                 
-		    if (playTime + playDuration > repeatEndTime)
-			playDuration = repeatEndTime - playTime;
+	    if (playTime + playDuration > repeatEndTime)
+		playDuration = repeatEndTime - playTime;
 
-		    playTime = playTime + m_segment->getDelay();
-		    eventTime = comp.getElapsedRealTime(playTime);
+	    playTime = playTime + m_segment->getDelay();
+            eventTime = comp.getElapsedRealTime(playTime);
 
-		    // slightly quicker than calling helper.getRealSoundingDuration()
-		    duration =
-			comp.getElapsedRealTime(playTime + playDuration) - eventTime;
+	    // slightly quicker than calling helper.getRealSoundingDuration()
+	    duration =
+		comp.getElapsedRealTime(playTime + playDuration) - eventTime;
 
-		    eventTime = eventTime + m_segment->getRealTimeDelay();
+	    eventTime = eventTime + m_segment->getRealTimeDelay();
 
-		    try {
-			// Create mapped event in mmapped buffer.  The
-			// instrument will be extracted from the ControlBlock
-			// by the sequencer, so we set it to zero here.
-			MappedEvent *mE = new (bufPos)
-			    MappedEvent(0,
-					***k, // three stars! what an accolade
-					eventTime,
-					duration);
-			mE->setTrackId(track->getId());
+            try {
+                // Create mapped event in mmapped buffer
+                MappedEvent *mE = new (bufPos) MappedEvent(0, // the instrument will be extracted from the ControlBlock by the sequencer
+                                                           **j,
+                                                           eventTime,
+                                                           duration);
+                mE->setTrackId(track->getId());
 
-			if (m_segment->getTranspose() != 0 &&
-			    (**k)->isa(Rosegarden::Note::EventType)) {
-			    mE->setPitch(mE->getPitch() + m_segment->getTranspose());
-			}
-
-			++bufPos;
-
-		    } catch(...) {
-			SEQMAN_DEBUG << "SegmentMmapper::dump - caught exception while trying to create MappedEvent\n";
-		    }
+		if (m_segment->getTranspose() != 0 &&
+		    (*j)->isa(Rosegarden::Note::EventType)) {
+		    mE->setPitch(mE->getPitch() + m_segment->getTranspose());
 		}
-	    }
-	
-	    ++*k; // increment either i or j, whichever one we just used
-        }
 
-	delete i;
-	delete triggered;
+                ++bufPos;
+
+            } catch(...) {
+                SEQMAN_DEBUG << "SegmentMmapper::dump - caught exception while trying to create MappedEvent\n";
+            }
+        }
+        
     }
 
     // Store the number of events at the start of the shared memory region
@@ -645,95 +526,6 @@ unsigned int SegmentMmapper::getSegmentRepeatCount()
     return repeatCount;
 }
 
-void
-SegmentMmapper::mergeTriggerSegment(Rosegarden::Segment **target,
-				    Rosegarden::Event *trigger,
-				    Rosegarden::timeT evDuration,
-				    Rosegarden::TriggerSegmentRec *rec)
-{
-    if (!rec || !rec->getSegment() || rec->getSegment()->empty()) return;
-    if (!*target) *target = new Rosegarden::Segment;
-
-    Rosegarden::timeT evTime = trigger->getAbsoluteTime();
-    Rosegarden::timeT trStart = rec->getSegment()->getStartTime();
-    Rosegarden::timeT trEnd = rec->getSegment()->getEndMarkerTime();
-    Rosegarden::timeT trDuration = trEnd - trStart;
-    if (trDuration == 0) return;
-
-    bool retune = false;
-    std::string timeAdjust = TRIGGER_SEGMENT_ADJUST_NONE;
-
-    trigger->get<Bool>
-	(TRIGGER_SEGMENT_RETUNE, retune);
-    
-    trigger->get<Rosegarden::String>
-	(TRIGGER_SEGMENT_ADJUST_TIMES, timeAdjust);
-
-    long evPitch = rec->getBasePitch();
-    (void)trigger->get<Int>(PITCH, evPitch);
-    int pitchDiff = evPitch - rec->getBasePitch();
-
-    long evVelocity = rec->getBaseVelocity();
-    (void)trigger->get<Int>(VELOCITY, evVelocity);
-    int velocityDiff = evVelocity - rec->getBaseVelocity();
-
-    Rosegarden::timeT offset = 0;
-    if (timeAdjust == TRIGGER_SEGMENT_ADJUST_SYNC_END) {
-	offset = evDuration - trDuration;
-    }
-
-    for (Segment::iterator i = rec->getSegment()->begin();
-	 rec->getSegment()->isBeforeEndMarker(i); ++i) {
-	
-	Rosegarden::timeT t = (*i)->getAbsoluteTime() - trStart;
-	Rosegarden::timeT d = (*i)->getDuration();
-
-	if (evDuration != trDuration &&
-	    timeAdjust == TRIGGER_SEGMENT_ADJUST_SQUISH) {
-	    t = Rosegarden::timeT(double(t * evDuration) / double(trDuration));
-	    d = Rosegarden::timeT(double(d * evDuration) / double(trDuration));
-	}
-
-	t += evTime + offset;
-
-	if (t < evTime) {
-	    if (t + d <= evTime) continue;
-	    else {
-		d -= (evTime - t);
-		t = evTime;
-	    }
-	}
-	
-	if (timeAdjust == TRIGGER_SEGMENT_ADJUST_SYNC_START) {
-	    if (t + d > evTime + evDuration) {
-		if (t >= evTime + evDuration) continue;
-		else {
-		    d = evTime + evDuration - t;
-		}
-	    }
-	}
-
-	Rosegarden::Event *newEvent = new Rosegarden::Event(**i, t, d);
-
-	if (retune && newEvent->has(PITCH)) {
-	    int pitch = newEvent->get<Int>(PITCH) + pitchDiff;
-	    if (pitch > 127) pitch = 127;
-	    if (pitch < 0) pitch = 0;
-	    newEvent->set<Int>(PITCH, pitch);
-	}
-
-	if (newEvent->has(VELOCITY)) {
-	    int velocity = newEvent->get<Int>(VELOCITY) + velocityDiff;
-	    if (velocity > 127) velocity = 127;
-	    if (velocity < 0) velocity = 0;
-	    newEvent->set<Int>(VELOCITY, velocity);
-	}
-
-	(*target)->insert(newEvent);
-    }
-}
-    
-
 //----------------------------------------
 
 AudioSegmentMmapper::AudioSegmentMmapper(RosegardenGUIDoc* doc, Rosegarden::Segment* s,
@@ -760,13 +552,6 @@ void AudioSegmentMmapper::dump()
     Rosegarden::RealTime eventTime;
     Rosegarden::Track* track = comp.getTrackById(m_segment->getTrack());
     
-    // Can't write out if no track
-    if (!track) {
-	std::cerr << "AudioSegmentMmapper::dump: ERROR: No track for segment!"
-		  << std::endl;
-	return;
-    }
-
     timeT segmentStartTime = m_segment->getStartTime();
     timeT segmentEndTime = m_segment->getEndMarkerTime();
     timeT segmentDuration = segmentEndTime - segmentStartTime;
@@ -803,26 +588,6 @@ void AudioSegmentMmapper::dump()
                                                  audioStart);
         mE->setTrackId(track->getId());
         mE->setRuntimeSegmentId(m_segment->getRuntimeId());
-
-        // Send the autofade if required
-        //
-        if (m_segment->isAutoFading())
-        {
-            mE->setAutoFade(true);
-            mE->setFadeInTime(m_segment->getFadeInTime());
-            mE->setFadeOutTime(m_segment->getFadeOutTime());
-            std::cout << "AudioSegmentMmapper::dump - "
-                      << "SETTING AUTOFADE "
-                      << "in = " << m_segment->getFadeInTime()
-                      << ", out = " << m_segment->getFadeOutTime()
-                      << std::endl;
-        }
-        else
-        {
-//            std::cout << "AudioSegmentMmapper::dump - "
-//                      << "NO AUTOFADE SET ON SEGMENT" << std::endl;
-        }
-
         ++bufPos;
     }
 
@@ -891,10 +656,6 @@ bool CompositionMmapper::segmentModified(Segment* segment)
 {
     SegmentMmapper* mmapper = m_segmentMmappers[segment];
 
-    if (!mmapper)
-        return false; // this can happen with the SegmentSplitCommand, where the new segment's transpose is set
-    // even though it's not mapped yet
-
     SEQMAN_DEBUG << "CompositionMmapper::segmentModified(" << segment << ") - mmapper = "
                  << mmapper << endl;
 
@@ -936,7 +697,7 @@ QString CompositionMmapper::makeFileName(Segment* segment)
 
     return QString("%1/segment_%2")
         .arg(tmpDirs.last())
-        .arg((uintptr_t)segment, 0, 16);
+        .arg((unsigned int)segment, 0, 16);
 }
 
 QString CompositionMmapper::getSegmentFileName(Segment* s)
@@ -964,6 +725,7 @@ size_t CompositionMmapper::getSegmentFileSize(Segment* s)
 
 MetronomeMmapper::MetronomeMmapper(RosegardenGUIDoc* doc)
     : SegmentMmapper(doc, 0, createFileName()),
+      m_deleteMetronome(false),
       m_metronome(0), // no metronome to begin with
       m_tickDuration(0, 100000000)
 {
@@ -991,55 +753,27 @@ MetronomeMmapper::MetronomeMmapper(RosegardenGUIDoc* doc)
     Rosegarden::timeT t = c.getBarStart(-20); // somewhat arbitrary
     int depth = m_metronome->getDepth();
 
-    if (depth > 0) {
-	while (t < c.getEndMarker()) {
+    while (t < c.getEndMarker()) {
 
-	    Rosegarden::TimeSignature sig = c.getTimeSignatureAt(t);
-	    Rosegarden::timeT barDuration = sig.getBarDuration();
-	    std::vector<int> divisions;
-	    if (depth > 0) sig.getDivisions(depth - 1, divisions);
-	    int ticks = 1;
-	    
-	    for (int i = -1; i < (int)divisions.size(); ++i) {
-		if (i >= 0) ticks *= divisions[i];
-		
-		for (int tick = 0; tick < ticks; ++tick) {
-		    if (i >= 0 && (tick % divisions[i] == 0)) continue;
-		    Rosegarden::timeT tickTime = t + (tick * barDuration) / ticks;
-		    m_ticks.push_back(Tick(tickTime, i+1));
-		}
-	    }
-	    
-	    t = c.getBarEndForTime(t);
-	}
+        Rosegarden::TimeSignature sig = c.getTimeSignatureAt(t);
+	Rosegarden::timeT barDuration = sig.getBarDuration();
+        std::vector<int> divisions;
+        if (depth > 0) sig.getDivisions(depth - 1, divisions);
+        int ticks = 1;
+        
+        for (int i = -1; i < (int)divisions.size(); ++i) {
+            if (i >= 0) ticks *= divisions[i];
+        
+            for (int tick = 0; tick < ticks; ++tick) {
+                if (i >= 0 && (tick % divisions[i] == 0)) continue;
+                Rosegarden::timeT tickTime = t + (tick * barDuration) / ticks;
+                m_ticks.push_back(Tick(tickTime, i+1));
+            }
+        }
+        
+        t = c.getBarEndForTime(t);
     }
     
-    KConfig *config = kapp->config();
-    config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
-    int midiClock = config->readNumEntry("midiclock", 0);
-    int mtcMode = config->readNumEntry("mtcmode", 0);
-
-    if (midiClock == 1)
-    {
-        using Rosegarden::Note;
-        Rosegarden::timeT quarterNote = Note(Note::Crotchet).getDuration();
-
-        // Insert 24 clocks per quarter note
-        //
-        for (Rosegarden::timeT insertTime = c.getStartMarker();
-             insertTime < c.getEndMarker(); 
-             insertTime += quarterNote / 24)
-        {
-            m_ticks.push_back(Tick(insertTime, 3));
-        }
-    }
-
-
-    if (mtcMode > 0)
-    {
-        // do something
-    }
-
     sortTicks();
 
     if (m_ticks.size() == 0) {
@@ -1059,7 +793,7 @@ MetronomeMmapper::MetronomeMmapper(RosegardenGUIDoc* doc)
 MetronomeMmapper::~MetronomeMmapper()
 {
     SEQMAN_DEBUG << "~MetronomeMmapper " << this << endl;
-    delete m_metronome;
+    if (m_deleteMetronome) delete m_metronome;
 }
 
 Rosegarden::InstrumentId MetronomeMmapper::getMetronomeInstrument()
@@ -1079,38 +813,7 @@ unsigned int MetronomeMmapper::getSegmentRepeatCount()
 
 size_t MetronomeMmapper::computeMmappedSize()
 {
-    KConfig *config = kapp->config();
-    config->setGroup(Rosegarden::SequencerOptionsConfigGroup);
-    int midiClock = config->readNumEntry("midiclock", 0);
-    int mtcMode = config->readNumEntry("mtcmode", 0);
-
-    // base size for Metronome ticks
-    size_t size = m_ticks.size() * sizeof(MappedEvent);
-    Composition& comp = m_doc->getComposition();
-
-    if (midiClock == 1)
-    {
-        using Rosegarden::Note;
-
-        // Allow room for MIDI clocks
-        int clocks = ( 24 * ( comp.getEndMarker() - comp.getStartMarker() ) ) / 
-            Note(Note::Crotchet).getDuration();
-
-        /*
-        SEQMAN_DEBUG << "MetronomeMmapper::computeMmappedSize - " 
-                     << "Number of clock events catered for = " << clocks
-                     << endl;
-        */
-
-        size += clocks * sizeof(MappedEvent);
-    }
-
-    if (mtcMode > 0)
-    {
-        // Allow room for MTC timing messages (how?)
-    }
-
-    return size;
+    return m_ticks.size() * sizeof(MappedEvent);
 }
 
 void MetronomeMmapper::dump()
@@ -1120,10 +823,17 @@ void MetronomeMmapper::dump()
 
     SEQMAN_DEBUG << "MetronomeMmapper::dump: instrument is " << m_metronome->getInstrument() << endl;
 
-    MappedEvent* bufPos = m_mmappedEventBuffer, *mE;
+    MappedEvent* bufPos = m_mmappedEventBuffer;
 
     for (TickContainer::iterator i = m_ticks.begin(); i != m_ticks.end(); ++i) {
 
+        Rosegarden::MidiByte velocity;
+	switch (i->second) {
+	case 0:  velocity = m_metronome->getBarVelocity(); break;
+	case 1:  velocity = m_metronome->getBeatVelocity(); break;
+	default: velocity = m_metronome->getSubBeatVelocity(); break;
+	}
+
         /*
         SEQMAN_DEBUG << "MetronomeMmapper::dump: velocity = "
                      << int(velocity) << endl;
@@ -1131,49 +841,16 @@ void MetronomeMmapper::dump()
 
         eventTime = comp.getElapsedRealTime(i->first);
 
-        if (i->second == 3) // MIDI Clock
-        {
-            mE = new (bufPos) MappedEvent(0, MappedEvent::MidiSystemMessage);
-            mE->setData1(Rosegarden::MIDI_TIMING_CLOCK);
-            mE->setEventTime(eventTime);
-        }
-        else
-        {
-            Rosegarden::MidiByte velocity;
-            Rosegarden::MidiByte pitch;
-	    switch (i->second) {
-	    case 0:  
-	    	velocity = m_metronome->getBarVelocity(); 
-	    	pitch = m_metronome->getBarPitch();
-	    	break;
-	    case 1:  
-	    	velocity = m_metronome->getBeatVelocity(); 
-	    	pitch = m_metronome->getBeatPitch();
-	    	break;
-	    default: 
-	    	velocity = m_metronome->getSubBeatVelocity(); 
-	    	pitch = m_metronome->getSubBeatPitch();
-	    	break;
-            }
-
-            new (bufPos) MappedEvent(m_metronome->getInstrument(),
-				     MappedEvent::MidiNoteOneShot,
-                                     pitch,
-                                     velocity,
-                                     eventTime,
-                                     m_tickDuration,
-				     Rosegarden::RealTime::zeroTime);
-        }
-
+        new (bufPos) MappedEvent(m_metronome->getInstrument(),
+                                 m_metronome->getPitch(),
+                                 velocity,
+                                 eventTime,
+                                 m_tickDuration);
         ++bufPos;
     }
 
     // Store the number of events at the start of the shared memory region
     *(size_t *)m_mmappedRegion = (bufPos - m_mmappedEventBuffer);
-
-    SEQMAN_DEBUG << "MetronomeMmapper::dump: - "
-                 << "Total events written = " << *(size_t *)m_mmappedRegion
-                 << endl;
 }
 
 
@@ -1224,19 +901,13 @@ void TempoSegmentMmapper::dump()
 
     for (int i = 0; i < comp.getTempoChangeCount(); ++i) {
 
-        std::pair<timeT, Rosegarden::tempoT> tempoChange = comp.getTempoChange(i);
+        std::pair<timeT, long> tempoChange = comp.getRawTempoChange(i);
 
         eventTime = comp.getElapsedRealTime(tempoChange.first);
         MappedEvent* mappedEvent = new (bufPos) MappedEvent();
         mappedEvent->setType(MappedEvent::Tempo);
         mappedEvent->setEventTime(eventTime);
-
-	// Nasty hack -- we use the instrument ID to pass through the
-	// raw tempo value, as it has the appropriate range (unlike
-	// e.g. tempo1 + tempo2).  These events are not actually used
-	// on the sequencer side yet, so this may change to something
-	// nicer at some point.
-        mappedEvent->setInstrument(tempoChange.second);
+        mappedEvent->setData1(tempoChange.second);
         
         ++bufPos;
     }
