@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -58,15 +58,13 @@ public:
     
     QString getFileName() { return m_fileName; }
     void updateTrackData(Rosegarden::Track*);
-    void setTrackDeleted(Rosegarden::TrackId);
     void updateMetronomeData(Rosegarden::InstrumentId instId);
     void updateMetronomeForPlayback();
     void updateMetronomeForRecord();
-    bool updateSoloData(bool solo, Rosegarden::TrackId selectedTrack);
+    void updateSoloData(bool solo, Rosegarden::TrackId selectedTrack);
     void updateMidiFilters(Rosegarden::MidiFilter thruFilter,
 			   Rosegarden::MidiFilter recordFilter);
     void setDocument(RosegardenGUIDoc*);
-    void enableMIDIThruRouting(bool state);
 
 protected:
     void initControlBlock();
@@ -110,8 +108,6 @@ protected:
                    const QString& fileName);
 
     virtual size_t computeMmappedSize();
-    
-    virtual size_t addMmappedSize(Rosegarden::Segment *);
 
     /// actual setup, must be called after ctor, calls virtual methods
     virtual void init();
@@ -128,11 +124,6 @@ protected:
     /// dump all segment data in the file
     virtual void dump();
 
-    void mergeTriggerSegment(Rosegarden::Segment **target,
-			     Rosegarden::Event *trigger,
-			     Rosegarden::timeT performanceDuration,
-			     Rosegarden::TriggerSegmentRec *rec);
-
     //--------------- Data members ---------------------------------
     RosegardenGUIDoc* m_doc;
     Rosegarden::Segment* m_segment;
