@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -120,7 +120,7 @@ MultiViewCommandHistory::addCommand(KCommand *command, bool execute)
 {
     if (!command) return;
 
-    RG_DEBUG << "MultiViewCommandHistory::addCommand: " << command->name() << endl;
+    RG_DEBUG << "MultiViewCommandHistory::addCommand: " << command << endl;
 
     // We can't redo after adding a command
     clearStack(m_redoStack);
@@ -305,7 +305,6 @@ MultiViewCommandHistory::updateButton(bool undo,
 	    action->setEnabled(true);
 	    QString commandName = stack.top()->name();
 	    commandName.replace(QRegExp("&"), "");
-	    commandName.replace(QRegExp("\\.\\.\\.$"), "");
 	    if (undo) text = i18n("Und&o %1").arg(commandName);
 	    else      text = i18n("Re&do %1").arg(commandName);
 	    action->setText(text);
@@ -343,7 +342,6 @@ MultiViewCommandHistory::updateMenu(bool undo,
 
 	    QString commandName = command->name();
 	    commandName.replace(QRegExp("&"), "");
-	    commandName.replace(QRegExp("\\.\\.\\.$"), "");
 
 	    QString text;
 	    if (undo) text = i18n("Und&o %1").arg(commandName);
@@ -358,4 +356,3 @@ MultiViewCommandHistory::updateMenu(bool undo,
     }
 }
 
-#include "multiviewcommandhistory.moc"
