@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -52,6 +52,7 @@ using Rosegarden::Text;
 using Rosegarden::Accidental;
 using namespace Rosegarden::Accidentals;
 using Rosegarden::Mark;
+using Rosegarden::Marks;
 using Rosegarden::Indication;
 using Rosegarden::EventSelection;
 
@@ -352,15 +353,12 @@ TextChangeCommand::modifySegment()
 KeyInsertionCommand::KeyInsertionCommand(Segment &segment, timeT time,
 					 Rosegarden::Key key,
 					 bool convert,
-					 bool transpose,
-					 bool transposeKey) :
+					 bool transpose) :
     BasicCommand(getGlobalName(&key), segment, time, segment.getEndTime()),
     m_key(key),
     m_lastInsertedEvent(0),
     m_convert(convert),
-    m_transpose(transpose),
-    m_transposeKey(transposeKey)
-
+    m_transpose(transpose)
 {
     // nothing
 }
@@ -392,135 +390,6 @@ KeyInsertionCommand::modifySegment()
 	++i;
     }
 
-    // transpose if desired, according to new dialog option
-    if (m_transposeKey) {
-	// we don't really care about major/minor for this, so pass it through
-	// from the original key
-	bool keyIsMinor = m_key.isMinor();
-
-	// get whether the original key is flat or sharp, so we know what to
-	// prefer for the new key
-	bool keyIsSharp = m_key.isSharp();
-
-	// get the tonic pitch of the user-specified key, reported as a 0-11 int, then
-	// add an extra octave to it to avoid winding up with negative numbers
-	// (the octave will be stripped back off)
-	int specifiedKeyTonic = m_key.getTonicPitch() + 12;
-
-	// get the transpose factor for the segment we're working on
-	int segTranspose = getSegment().getTranspose();	
-
-	// subtract the transpose factor from the tonic pitch of the
-	// user-specified key, because we want to move in the opposite
-	// direction for notation (eg. notation is in C major concert, at Bb
-	// transposition, we have -2 from the segment, and want to go +2 for
-	// the key, from tonic pitch 0 (C) to tonic pitch 2 (D) for the key as
-	// written for a Bb instrument
-	//
-	// sanity check: 0 == C; 0 + 12 == 12; (12 - -2) % 12 == 2; 2 == D
-	int transposedKeyTonic = (specifiedKeyTonic - segTranspose) % 12;
-
-	// create a new key with the new tonic pitch, and major/minor from the
-	// original key
-	std::string newKeyName = "";
-
-	switch (transposedKeyTonic) {
-	// 0 C | 1 C# | 2 D | 3 D# | 4 E | 5 F | 6 F# | 7 G | 8 G# | 9 A | 10 A# | 11 B
-	    case 0 : // C
-		     newKeyName = "C";
-		     break;
-	    case 2 : // D
-		     newKeyName = "D";
-		     break;
-	    case 4 : // E
-		     newKeyName = "E";
-		     break;
-	    case 5 : // F
-		     newKeyName = "F";
-		     break;
-	    case 7 : // G
-		     newKeyName = "G";
-		     break;
-	    case 9 : // A
-		     newKeyName = "A";
-		     break;
-	    case 11: // B
-		     newKeyName = "B";
-		     break;
-	    // the glorious, glorious black keys need special treatment
-	    // again, so we pick flat or sharp spellings based on the
-	    // condition of the original, user-specified key we're
-	    // transposing
-	    case 1 : // C#/Db
-		     newKeyName = (keyIsSharp ? "C#" : "Db");
-		     break;
-	    case 3 : // D#/Eb
-		     newKeyName = (keyIsSharp ? "D#" : "Eb");
-		     break;
-	    case 6 : // F#/Gb
-		     newKeyName = (keyIsSharp ? "F#" : "Gb");
-		     break;
-	    case 8 : // G#/Ab
-		     newKeyName = (keyIsSharp ? "G#" : "Ab");
-		     break;
-	    case 10:  // A#/Bb
-		     newKeyName = (keyIsSharp ? "A#" : "Bb");
-		     break;
-	    default:
-		     // if this fails, we won't have a valid key name, and
-		     // there will be some crashing exception I don't know how
-		     // to intercept and avoid, so I'm doing this lame failsafe
-		     // instead, which should never, ever actually run under
-		     // any conceivable cirumstance anyway
-		     RG_DEBUG << "KeyInsertionCommand: by the pricking of my thumbs, something wicked this way comes.  :("
-			      << endl;
-		     return;
-	}
-
-	newKeyName += (keyIsMinor ? " minor" : " major");
-
-	//for f in C# D# E# F# G# A# B# Cb Db Eb Fb Gb Ab Bb;do grep "$f
-	//major" NotationTypes.C > /dev/null||echo "invalid key: $f
-	//major";grep "$f minor" NotationTypes.C > /dev/null||echo "invalid
-	//key: $f minor";done|sort
-	//invalid key: A# major
-	//invalid key: B# major
-	//invalid key: B# minor
-	//invalid key: Cb minor
-	//invalid key: Db minor
-	//invalid key: D# major
-	//invalid key: E# major
-	//invalid key: E# minor
-	//invalid key: Fb major
-	//invalid key: Fb minor
-	//invalid key: Gb minor
-	//invalid key: G# major
-	
-	// some kludgery to avoid creating invalid key names with some if/then
-	// swapping to manually respell things generated incorrectly by the
-	// above, rather than adding all kinds of nonsense to avoid this
-	// necessity
-	if (newKeyName == "A# major") newKeyName = "Bb major";
-	else if (newKeyName == "B# major") newKeyName = "C major";
-	else if (newKeyName == "Cb minor") newKeyName = "B minor";
-	else if (newKeyName == "Db minor") newKeyName = "C# minor";
-	else if (newKeyName == "D# major") newKeyName = "Eb major";
-	else if (newKeyName == "E# major") newKeyName = "F major";
-	else if (newKeyName == "E# minor") newKeyName = "F minor";
-	else if (newKeyName == "Fb major") newKeyName = "E major";
-	else if (newKeyName == "Fb minor") newKeyName = "E minor";
-	else if (newKeyName == "Gb minor") newKeyName = "F# minor";
-	else if (newKeyName == "G# major") newKeyName = "Ab major";
-
-	// create a new key with the newly derived name, and swap it for the
-	// user-specified version
-	Rosegarden::Key k(newKeyName);
-	RG_DEBUG << "KeyInsertCommand: inserting transposed key" << endl
-	         << "        user key was: " << m_key.getName() << endl
-		 << "    tranposed key is: " << k.getName() << endl;
-	m_key = k;
-    } // if (m_transposeKey)
-
     i = helper.insertKey(getStartTime(), m_key);
 
     if (i != helper.segment().end()) {
@@ -554,20 +423,11 @@ MultiKeyInsertionCommand::MultiKeyInsertionCommand(Rosegarden::Composition &c,
 						   timeT time,
 						   Rosegarden::Key key,
 						   bool convert,
-						   bool transpose,
-						   bool transposeKey) :
+						   bool transpose) :
     KMacroCommand(getGlobalName(&key))
 {
     for (Rosegarden::Composition::iterator i = c.begin(); i != c.end(); ++i) {
-	Rosegarden::Segment *segment = *i;
-
-	// no harm in using getEndTime instead of getEndMarkerTime here:
-	if (segment->getStartTime() <= time && segment->getEndTime() > time) {
-	    addCommand(new KeyInsertionCommand(*segment, time, key, convert, transpose, transposeKey));
-	} else if (segment->getStartTime() > time) {
-	    addCommand(new KeyInsertionCommand(*segment, segment->getStartTime(),
-					       key, convert, transpose, transposeKey));
-	}
+       addCommand(new KeyInsertionCommand(**i, time, key, convert, transpose));
     }
 }
 
@@ -576,34 +436,6 @@ MultiKeyInsertionCommand::~MultiKeyInsertionCommand()
     // nothing
 }
 
-
-SustainInsertionCommand::SustainInsertionCommand(Segment &segment, timeT time,
-						 bool down,
-						 int controllerNumber) :
-    BasicCommand(getGlobalName(down), segment, time, time),
-    m_down(down),
-    m_controllerNumber(controllerNumber),
-    m_lastInsertedEvent(0)
-{
-    // nothing
-}
-
-SustainInsertionCommand::~SustainInsertionCommand()
-{
-    // nothing
-}
-
-void
-SustainInsertionCommand::modifySegment()
-{
-    Event *e = new Event(Rosegarden::Controller::EventType, getStartTime(), 0,
-			 Rosegarden::Controller::EventSubOrdering);
-    e->set<Int>(Rosegarden::Controller::NUMBER, m_controllerNumber);
-    e->set<Int>(Rosegarden::Controller::VALUE, m_down ? 127 : 0);
-    m_lastInsertedEvent = *getSegment().insert(e);
-}
-
-
 EraseEventCommand::EraseEventCommand(Segment &segment,
 				     Event *event,
 				     bool collapseRest) :
@@ -673,7 +505,7 @@ EraseEventCommand::modifySegment()
 
 
 void
-NotesMenuBeamCommand::modifySegment()
+GroupMenuBeamCommand::modifySegment()
 {
     int id = getSegment().getNextId();
 
@@ -689,14 +521,14 @@ NotesMenuBeamCommand::modifySegment()
 }
 
 void
-NotesMenuAutoBeamCommand::modifySegment()
+GroupMenuAutoBeamCommand::modifySegment()
 {
     SegmentNotationHelper helper(getSegment());
     helper.autoBeam(getStartTime(), getEndTime(), GROUP_TYPE_BEAMED);
 }
 
 void
-NotesMenuBreakCommand::modifySegment()
+GroupMenuBreakCommand::modifySegment()
 {
     for (EventSelection::eventcontainer::iterator i =
 	     m_selection->getSegmentEvents().begin();
@@ -709,7 +541,7 @@ NotesMenuBreakCommand::modifySegment()
     }
 }
 
-AdjustMenuGraceCommand::AdjustMenuGraceCommand(Rosegarden::EventSelection &selection) :
+GroupMenuGraceCommand::GroupMenuGraceCommand(Rosegarden::EventSelection &selection) :
     BasicCommand(getGlobalName(),
 		 selection.getSegment(),
 		 selection.getStartTime(),
@@ -720,7 +552,7 @@ AdjustMenuGraceCommand::AdjustMenuGraceCommand(Rosegarden::EventSelection &selec
 }
 
 timeT
-AdjustMenuGraceCommand::getEffectiveEndTime(Rosegarden::EventSelection &
+GroupMenuGraceCommand::getEffectiveEndTime(Rosegarden::EventSelection &
 					   selection)
 {
     EventSelection::eventcontainer::iterator i =
@@ -736,7 +568,7 @@ AdjustMenuGraceCommand::getEffectiveEndTime(Rosegarden::EventSelection &
 }
 
 void
-AdjustMenuGraceCommand::modifySegment()
+GroupMenuGraceCommand::modifySegment()
 {
     Segment &s(getSegment());
     timeT startTime = getStartTime();
@@ -778,59 +610,35 @@ AdjustMenuGraceCommand::modifySegment()
 }
 
 void
-AdjustMenuUnGraceCommand::modifySegment()
+GroupMenuUnGraceCommand::modifySegment()
 {
     //!!!
 }
 
 
-AdjustMenuTupletCommand::AdjustMenuTupletCommand(Rosegarden::Segment &segment,
+GroupMenuTupletCommand::GroupMenuTupletCommand(Rosegarden::Segment &segment,
 					       timeT startTime,
 					       timeT unit,
-					       int untupled, int tupled,
-					       bool hasTimingAlready) :
+					       int untupled, int tupled) :
     BasicCommand(getGlobalName((untupled == 3) && (tupled == 2)),
 		 segment, startTime, startTime + (unit * untupled)),
     m_unit(unit),
     m_untupled(untupled),
-    m_tupled(tupled),
-    m_hasTimingAlready(hasTimingAlready)
+    m_tupled(tupled)
 {
     // nothing else
 }
 
 void
-AdjustMenuTupletCommand::modifySegment()
+GroupMenuTupletCommand::modifySegment()
 {
-    if (m_hasTimingAlready) {
-
-	int groupId = getSegment().getNextId();
-
-	for (Segment::iterator i = getSegment().findTime(getStartTime());
-	     getSegment().isBeforeEndMarker(i); ++i) {
-
-	    if ((*i)->getNotationAbsoluteTime() >=
-	        getStartTime() + (m_unit * m_tupled)) break;
-
-	    Event *e = *i;
-
-	    e->set<Int>(BEAMED_GROUP_ID, groupId);
-	    e->set<String>(BEAMED_GROUP_TYPE, GROUP_TYPE_TUPLED);
-	    
-	    e->set<Int>(BEAMED_GROUP_TUPLET_BASE, m_unit);
-	    e->set<Int>(BEAMED_GROUP_TUPLED_COUNT, m_tupled);
-	    e->set<Int>(BEAMED_GROUP_UNTUPLED_COUNT, m_untupled);
-	}
-
-    } else {
-	SegmentNotationHelper helper(getSegment());
-	helper.makeTupletGroup(getStartTime(), m_untupled, m_tupled, m_unit);
-    }
+    SegmentNotationHelper helper(getSegment());
+    helper.makeTupletGroup(getStartTime(), m_untupled, m_tupled, m_unit);
 }
 
 
 void
-AdjustMenuUnTupletCommand::modifySegment()
+GroupMenuUnTupletCommand::modifySegment()
 {
     for (EventSelection::eventcontainer::iterator i =
 	     m_selection->getSegmentEvents().begin();
@@ -841,12 +649,13 @@ AdjustMenuUnTupletCommand::modifySegment()
 	(*i)->unset(BEAMED_GROUP_TUPLET_BASE);
 	(*i)->unset(BEAMED_GROUP_TUPLED_COUNT);
 	(*i)->unset(BEAMED_GROUP_UNTUPLED_COUNT);
+//!!!	(*i)->unset(TUPLET_NOMINAL_DURATION);
     }
 }
 
 
 
-NotesMenuAddIndicationCommand::NotesMenuAddIndicationCommand(std::string indicationType, 
+GroupMenuAddIndicationCommand::GroupMenuAddIndicationCommand(std::string indicationType, 
 							     EventSelection &selection) :
     BasicCommand(getGlobalName(indicationType),
 		 selection.getSegment(),
@@ -859,13 +668,13 @@ NotesMenuAddIndicationCommand::NotesMenuAddIndicationCommand(std::string indicat
     // nothing else
 }
 
-NotesMenuAddIndicationCommand::~NotesMenuAddIndicationCommand()
+GroupMenuAddIndicationCommand::~GroupMenuAddIndicationCommand()
 {
     // empty
 }
 
 bool
-NotesMenuAddIndicationCommand::canExecute()
+GroupMenuAddIndicationCommand::canExecute()
 {
     Segment &s(getSegment());
     
@@ -921,7 +730,7 @@ NotesMenuAddIndicationCommand::canExecute()
 }
 
 void
-NotesMenuAddIndicationCommand::modifySegment()
+GroupMenuAddIndicationCommand::modifySegment()
 {
     SegmentNotationHelper helper(getSegment());
 
@@ -943,12 +752,10 @@ NotesMenuAddIndicationCommand::modifySegment()
 }
 
 QString
-NotesMenuAddIndicationCommand::getGlobalName(std::string indicationType)
+GroupMenuAddIndicationCommand::getGlobalName(std::string indicationType)
 {
     if (indicationType == Rosegarden::Indication::Slur) {
 	return i18n("Add S&lur");
-    } else if (indicationType == Rosegarden::Indication::PhrasingSlur) {
-	return i18n("Add &Phrasing Slur");
     } else if (indicationType == Rosegarden::Indication::QuindicesimaUp) {
 	return i18n("Add Double-Octave Up");
     } else if (indicationType == Rosegarden::Indication::OttavaUp) {
@@ -957,15 +764,6 @@ NotesMenuAddIndicationCommand::getGlobalName(std::string indicationType)
 	return i18n("Add Octave &Down");
     } else if (indicationType == Rosegarden::Indication::QuindicesimaDown) {
 	return i18n("Add Double Octave Down");
-
-    // We used to generate these ones from the internal names plus
-    // caps, but that makes them untranslateable:
-    } else if (indicationType == Rosegarden::Indication::Crescendo) {
-	return i18n("Add &Crescendo");
-    } else if (indicationType == Rosegarden::Indication::Decrescendo) {
-	return i18n("Add &Decrescendo");
-    } else if (indicationType == Rosegarden::Indication::Glissando) {
-	return i18n("Add &Glissando");
     }
 
     QString n = i18n("Add &%1%2").arg((char)toupper(indicationType[0])).arg(strtoqstr(indicationType.substr(1)));
@@ -974,7 +772,7 @@ NotesMenuAddIndicationCommand::getGlobalName(std::string indicationType)
 
 
 void
-AdjustMenuMakeChordCommand::modifySegment()
+GroupMenuMakeChordCommand::modifySegment()
 {
     // find all the notes in the selection, and bring them back to align
     // with the start of the selection, giving them the same duration as
@@ -1009,7 +807,7 @@ AdjustMenuMakeChordCommand::modifySegment()
 }	 
 
 
-AdjustMenuNormalizeRestsCommand::AdjustMenuNormalizeRestsCommand
+TransformsMenuNormalizeRestsCommand::TransformsMenuNormalizeRestsCommand
 (Rosegarden::EventSelection &selection) :
     BasicCommand(getGlobalName(),
 		 selection.getSegment(),
@@ -1019,12 +817,12 @@ AdjustMenuNormalizeRestsCommand::AdjustMenuNormalizeRestsCommand
     // nothing else
 }
 
-void AdjustMenuNormalizeRestsCommand::modifySegment()
+void TransformsMenuNormalizeRestsCommand::modifySegment()
 {
     getSegment().normalizeRests(getStartTime(), getEndTime());
 }
 
-AdjustMenuCollapseRestsCommand::AdjustMenuCollapseRestsCommand
+TransformsMenuCollapseRestsCommand::TransformsMenuCollapseRestsCommand
 (Rosegarden::EventSelection &selection) :
     BasicCommand(getGlobalName(),
 		 selection.getSegment(),
@@ -1034,14 +832,54 @@ AdjustMenuCollapseRestsCommand::AdjustMenuCollapseRestsCommand
     // nothing else
 }
 
-void AdjustMenuCollapseRestsCommand::modifySegment()
+void TransformsMenuCollapseRestsCommand::modifySegment()
 {
     SegmentNotationHelper helper(getSegment());
     helper.collapseRestsAggressively(getStartTime(), getEndTime());
 }
 
 void
-NotesMenuTieNotesCommand::modifySegment()
+TransformsMenuCollapseNotesCommand::modifySegment()
+{
+    SegmentNotationHelper helper(getSegment());
+    timeT endTime = getEndTime();
+
+    // This is really nasty stuff.  We can't go in forward direction
+    // using the j-iterator trick because collapseNoteAggressively may
+    // erase the following iterator as well as the preceding one.  We
+    // can't go backward naively, because collapseNoteAggressively
+    // erases i from the EventSelection now that it's a
+    // SegmentObserver.  We need the fancy hybrid j-iterator-backward
+    // technique applied to selections instead of segments.
+    
+    EventSelection::eventcontainer::iterator i =
+	m_selection->getSegmentEvents().end();
+    EventSelection::eventcontainer::iterator j = i;
+    bool thisOne = false;
+
+    while (i != m_selection->getSegmentEvents().begin()) {
+	
+	--j;
+	
+	if (thisOne) {
+	    helper.collapseNoteAggressively(*i, endTime);
+	}
+	
+	// rather than "true" one could perform a test to see
+	// whether j pointed to a candidate for collapsing:
+	thisOne = true;
+	
+	i = j;
+    }
+    
+    if (thisOne) {
+	helper.collapseNoteAggressively(*i, endTime);
+    }
+}
+
+
+void
+TransformsMenuTieNotesCommand::modifySegment()
 {
     Segment &segment(getSegment());
     SegmentNotationHelper helper(segment);
@@ -1072,7 +910,7 @@ NotesMenuTieNotesCommand::modifySegment()
 
 
 void
-AdjustMenuUntieNotesCommand::modifySegment()
+TransformsMenuUntieNotesCommand::modifySegment()
 {
     for (EventSelection::eventcontainer::iterator i =
 	     m_selection->getSegmentEvents().begin();
@@ -1085,7 +923,7 @@ AdjustMenuUntieNotesCommand::modifySegment()
 
 
 void
-AdjustMenuMakeNotesViableCommand::modifySegment()
+TransformsMenuMakeNotesViableCommand::modifySegment()
 {
     Segment &segment(getSegment());
     SegmentNotationHelper helper(segment);
@@ -1104,7 +942,7 @@ AdjustMenuMakeNotesViableCommand::modifySegment()
 }
 
 void
-AdjustMenuMakeRegionViableCommand::modifySegment()
+TransformsMenuMakeRegionViableCommand::modifySegment()
 {
     Segment &segment(getSegment());
     SegmentNotationHelper helper(segment);
@@ -1114,7 +952,7 @@ AdjustMenuMakeRegionViableCommand::modifySegment()
 }
 
 void
-AdjustMenuDeCounterpointCommand::modifySegment()
+TransformsMenuDeCounterpointCommand::modifySegment()
 {
     Segment &segment(getSegment());
     SegmentNotationHelper helper(segment);
@@ -1134,7 +972,7 @@ AdjustMenuDeCounterpointCommand::modifySegment()
 
 
 void
-AdjustMenuChangeStemsCommand::modifySegment()
+TransformsMenuChangeStemsCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1149,7 +987,7 @@ AdjustMenuChangeStemsCommand::modifySegment()
 
 
 void
-AdjustMenuRestoreStemsCommand::modifySegment()
+TransformsMenuRestoreStemsCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1162,56 +1000,15 @@ AdjustMenuRestoreStemsCommand::modifySegment()
     }
 }
 
-
-void
-AdjustMenuChangeSlurPositionCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if ((*i)->isa(Indication::EventType)) {
-	    std::string indicationType;
-	    if ((*i)->get<String>(Indication::IndicationTypePropertyName, indicationType)
-		&& (indicationType == Indication::Slur ||
-		    indicationType == Indication::PhrasingSlur)) {
-		(*i)->set<Rosegarden::Bool>(NotationProperties::SLUR_ABOVE, m_above);
-	    }
-	}
-    }
-}
-
-
-void
-AdjustMenuRestoreSlursCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if ((*i)->isa(Indication::EventType)) {
-	    std::string indicationType;
-	    if ((*i)->get<String>(Indication::IndicationTypePropertyName, indicationType)
-		&& (indicationType == Indication::Slur ||
-		    indicationType == Indication::PhrasingSlur)) {
-		(*i)->unset(NotationProperties::SLUR_ABOVE);
-	    }
-	}
-    }
-}
-
-
 QString
-AdjustMenuChangeStyleCommand::getGlobalName(NoteStyleName style)
+TransformsMenuChangeStyleCommand::getGlobalName(NoteStyleName style)
 {
     return strtoqstr(style);
 }
 
 
 void
-AdjustMenuChangeStyleCommand::modifySegment()
+TransformsMenuChangeStyleCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1248,7 +1045,7 @@ NotesMenuAddSlashesCommand::modifySegment()
 
 
 QString
-NotesMenuAddMarkCommand::getGlobalName(Rosegarden::Mark markType)
+MarksMenuAddMarkCommand::getGlobalName(Rosegarden::Mark markType)
 {
     QString m = strtoqstr(markType);
 
@@ -1258,8 +1055,6 @@ NotesMenuAddMarkCommand::getGlobalName(Rosegarden::Mark markType)
     else if (markType == Rosegarden::Marks::Rinforzando) m = i18n("R&inforzando");
     else if (markType == Rosegarden::Marks::Tenuto) m = i18n("T&enuto");
     else if (markType == Rosegarden::Marks::Trill) m = i18n("Tri&ll");
-    else if (markType == Rosegarden::Marks::LongTrill) m = i18n("Trill &with Line");
-    else if (markType == Rosegarden::Marks::TrillLine) m = i18n("Trill Line");
     else if (markType == Rosegarden::Marks::Turn) m = i18n("&Turn");
     else if (markType == Rosegarden::Marks::Accent) m = i18n("&Accent");
     else if (markType == Rosegarden::Marks::Staccatissimo) m = i18n("&Staccatissimo");
@@ -1267,14 +1062,6 @@ NotesMenuAddMarkCommand::getGlobalName(Rosegarden::Mark markType)
     else if (markType == Rosegarden::Marks::Pause) m = i18n("&Pause");
     else if (markType == Rosegarden::Marks::UpBow) m = i18n("&Up-Bow");
     else if (markType == Rosegarden::Marks::DownBow) m = i18n("&Down-Bow");
-    else if (markType == Rosegarden::Marks::Mordent)
-	m = i18n("Mo&rdent");
-    else if (markType == Rosegarden::Marks::MordentInverted)
-	m = i18n("Inverted Mordent");
-    else if (markType == Rosegarden::Marks::MordentLong)
-	m = i18n("Long Mordent");
-    else if (markType == Rosegarden::Marks::MordentLongInverted)
-	m = i18n("Lon&g Inverted Mordent");
     else m = i18n("&%1%2").arg(m[0].upper()).arg(m.right(m.length()-1));
     // FIXME: That last i18n has very little chance of working, unless
     // by some miracle the exact same string was translated elsewhere already
@@ -1285,7 +1072,7 @@ NotesMenuAddMarkCommand::getGlobalName(Rosegarden::Mark markType)
 }
 
 void
-NotesMenuAddMarkCommand::modifySegment()
+MarksMenuAddMarkCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1301,7 +1088,7 @@ NotesMenuAddMarkCommand::modifySegment()
 }
 
 void
-NotesMenuAddTextMarkCommand::modifySegment()
+MarksMenuAddTextMarkCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1317,7 +1104,7 @@ NotesMenuAddTextMarkCommand::modifySegment()
 }
 
 QString
-NotesMenuAddFingeringMarkCommand::getGlobalName(QString fingering)
+MarksMenuAddFingeringMarkCommand::getGlobalName(QString fingering)
 {
     if (fingering == "") return i18n("Add Other &Fingering...");
     else if (fingering == "0") return i18n("Add Fingering &0 (Thumb)");
@@ -1325,7 +1112,7 @@ NotesMenuAddFingeringMarkCommand::getGlobalName(QString fingering)
 }
 
 void
-NotesMenuAddFingeringMarkCommand::modifySegment()
+MarksMenuAddFingeringMarkCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
     Segment &segment(m_selection->getSegment());
@@ -1387,7 +1174,7 @@ NotesMenuAddFingeringMarkCommand::modifySegment()
 }
 
 void
-NotesMenuRemoveMarksCommand::modifySegment()
+MarksMenuRemoveMarksCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1405,7 +1192,7 @@ NotesMenuRemoveMarksCommand::modifySegment()
 }
 
 void
-NotesMenuRemoveFingeringMarksCommand::modifySegment()
+MarksMenuRemoveFingeringMarksCommand::modifySegment()
 {
     EventSelection::eventcontainer::iterator i;
 
@@ -1423,7 +1210,7 @@ NotesMenuRemoveFingeringMarksCommand::modifySegment()
 }
 
 void
-AdjustMenuFixNotationQuantizeCommand::modifySegment()
+TransformsMenuFixNotationQuantizeCommand::modifySegment()
 {
     std::vector<Event *> toErase;
     std::vector<Event *> toInsert;
@@ -1469,48 +1256,16 @@ AdjustMenuFixNotationQuantizeCommand::modifySegment()
     //!!! normalizeRests?
 }
 
-void
-AdjustMenuRemoveNotationQuantizeCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
 
-    std::vector<Event *> toInsert;
-    std::vector<Event *> toErase;
+const int TransformsMenuInterpretCommand::NoInterpretation      = 0;
+const int TransformsMenuInterpretCommand::GuessDirections	= (1<<0);
+const int TransformsMenuInterpretCommand::ApplyTextDynamics	= (1<<1);
+const int TransformsMenuInterpretCommand::ApplyHairpins		= (1<<2);
+const int TransformsMenuInterpretCommand::StressBeats		= (1<<3);
+const int TransformsMenuInterpretCommand::Articulate		= (1<<4);
+const int TransformsMenuInterpretCommand::AllInterpretations	= (1<<5) - 1;
 
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	toInsert.push_back(new Event(**i,
-				     (*i)->getAbsoluteTime(),
-				     (*i)->getDuration(),
-				     (*i)->getSubOrdering(),
-				     (*i)->getAbsoluteTime(),
-				     (*i)->getDuration()));
-
-	toErase.push_back(*i);
-    }
-
-    for (std::vector<Event *>::iterator i = toErase.begin(); i != toErase.end();
-	 ++i) {
-	m_selection->getSegment().eraseSingle(*i);
-    }
-
-    for (std::vector<Event *>::iterator i = toInsert.begin(); i != toInsert.end();
-	 ++i) {
-	m_selection->getSegment().insert(*i);
-    }
-}
-
-
-const int AdjustMenuInterpretCommand::NoInterpretation      = 0;
-const int AdjustMenuInterpretCommand::GuessDirections	= (1<<0);
-const int AdjustMenuInterpretCommand::ApplyTextDynamics	= (1<<1);
-const int AdjustMenuInterpretCommand::ApplyHairpins		= (1<<2);
-const int AdjustMenuInterpretCommand::StressBeats		= (1<<3);
-const int AdjustMenuInterpretCommand::Articulate		= (1<<4);
-const int AdjustMenuInterpretCommand::AllInterpretations	= (1<<5) - 1;
-
-AdjustMenuInterpretCommand::~AdjustMenuInterpretCommand()
+TransformsMenuInterpretCommand::~TransformsMenuInterpretCommand()
 {
     for (IndicationMap::iterator i = m_indications.begin();
 	 i != m_indications.end(); ++i) {
@@ -1519,7 +1274,7 @@ AdjustMenuInterpretCommand::~AdjustMenuInterpretCommand()
 }
 
 void
-AdjustMenuInterpretCommand::modifySegment()
+TransformsMenuInterpretCommand::modifySegment()
 {
     // Of all the interpretations, Articulate is the only one that
     // changes event times or durations.  This means we must apply it
@@ -1572,13 +1327,13 @@ AdjustMenuInterpretCommand::modifySegment()
 }
 
 void
-AdjustMenuInterpretCommand::guessDirections()
+TransformsMenuInterpretCommand::guessDirections()
 {
     //...
 }
 
 void
-AdjustMenuInterpretCommand::applyTextDynamics()
+TransformsMenuInterpretCommand::applyTextDynamics()
 {
     // laborious
 
@@ -1611,7 +1366,7 @@ AdjustMenuInterpretCommand::applyTextDynamics()
 }
 
 int
-AdjustMenuInterpretCommand::getVelocityForDynamic(std::string text)
+TransformsMenuInterpretCommand::getVelocityForDynamic(std::string text)
 {
     int velocity = 100;
 		    
@@ -1631,13 +1386,13 @@ AdjustMenuInterpretCommand::getVelocityForDynamic(std::string text)
     else if (text == "ffff")  velocity = 120;
     else if (text == "fffff") velocity = 125;
 
-    NOTATION_DEBUG << "AdjustMenuInterpretCommand::getVelocityForDynamic: unrecognised dynamic " << text << endl;
+    NOTATION_DEBUG << "TransformsMenuInterpretCommand::getVelocityForDynamic: unrecognised dynamic " << text << endl;
 
     return velocity;
 }
 
 void
-AdjustMenuInterpretCommand::applyHairpins()
+TransformsMenuInterpretCommand::applyHairpins()
 {
     Segment &segment(getSegment());
     int velocityToApply = -1;
@@ -1688,9 +1443,9 @@ AdjustMenuInterpretCommand::applyHairpins()
 	    --itr;
 	}
 
-	long startingVelocity = 100;
+	int startingVelocity = 100;
 	if (itr != segment.end()) {
-	    (*itr)->get<Int>(VELOCITY, startingVelocity);
+	    startingVelocity = (*itr)->get<Int>(VELOCITY);
 	}
 	
 	// The ending velocity is harder.  If there's a dynamic change
@@ -1700,7 +1455,7 @@ AdjustMenuInterpretCommand::applyHairpins()
 	// we should probably make the degree of change caused by the
 	// hairpin depend on its total duration.
 
-	long endingVelocity = startingVelocity;
+	int endingVelocity = startingVelocity;
 	timeT hairpinEndTime = inditr->first +
                                inditr->second->getIndicationDuration();
 	itr = segment.findTime(hairpinEndTime);
@@ -1739,7 +1494,7 @@ AdjustMenuInterpretCommand::applyHairpins()
 	    int((endingVelocity - startingVelocity) * proportion +
 		startingVelocity);
 
-	NOTATION_DEBUG << "AdjustMenuInterpretCommand::applyHairpins: velocity of note at " << e->getAbsoluteTime() << " is " << velocity << " (" << proportion << " through hairpin from " << startingVelocity << " to " << endingVelocity <<")" << endl;
+	NOTATION_DEBUG << "TransformsMenuInterpretCommand::applyHairpins: velocity of note at " << e->getAbsoluteTime() << " is " << velocity << " (" << proportion << " through hairpin from " << startingVelocity << " to " << endingVelocity <<")" << endl;
 	if (velocity < 10) velocity = 10;
 	if (velocity > 127) velocity = 127;
 	e->set<Int>(VELOCITY, velocity);
@@ -1748,7 +1503,7 @@ AdjustMenuInterpretCommand::applyHairpins()
 }
 
 void
-AdjustMenuInterpretCommand::stressBeats()
+TransformsMenuInterpretCommand::stressBeats()
 {
     Rosegarden::Composition *c = getSegment().getComposition();
 
@@ -1780,7 +1535,7 @@ AdjustMenuInterpretCommand::stressBeats()
 }
 
 void
-AdjustMenuInterpretCommand::articulate()
+TransformsMenuInterpretCommand::articulate()
 {
     // Basic articulations:
     //
@@ -1840,26 +1595,26 @@ AdjustMenuInterpretCommand::articulate()
 	for (std::vector<Mark>::iterator i = marks.begin();
 	     i != marks.end(); ++i) {
 
-	    if (*i == Rosegarden::Marks::Accent) {
+	    if (*i == Marks::Accent) {
 		velocityChange += 30;
-	    } else if (*i == Rosegarden::Marks::Tenuto) {
+	    } else if (*i == Marks::Tenuto) {
 		tenuto = true;
-	    } else if (*i == Rosegarden::Marks::Staccato) {
+	    } else if (*i == Marks::Staccato) {
 		staccato = true;
-	    } else if (*i == Rosegarden::Marks::Staccatissimo) {
+	    } else if (*i == Marks::Staccatissimo) {
 		staccatissimo = true;
 		velocityChange -= 5;
-	    } else if (*i == Rosegarden::Marks::Marcato) {
+	    } else if (*i == Marks::Marcato) {
 		marcato = true;
 		velocityChange += 15;
-	    } else if (*i == Rosegarden::Marks::Sforzando) {
+	    } else if (*i == Marks::Sforzando) {
 		velocityChange += 35;
-	    } else if (*i == Rosegarden::Marks::Rinforzando) {
+	    } else if (*i == Marks::Rinforzando) {
 		rinforzando = true;
 		velocityChange += 15;
-	    } else if (*i == Rosegarden::Marks::DownBow) {
+	    } else if (*i == Marks::DownBow) {
 		velocityChange += 5;
-	    } else if (*i == Rosegarden::Marks::UpBow) {
+	    } else if (*i == Marks::UpBow) {
 		velocityChange -= 5;
 	    }
 	}
@@ -1903,14 +1658,14 @@ AdjustMenuInterpretCommand::articulate()
 	    else durationChange = -10;
 	}
 
-	NOTATION_DEBUG << "AdjustMenuInterpretCommand::modifySegment: chord has " << chord.size() << " notes in it" << endl;
+	NOTATION_DEBUG << "TransformsMenuInterpretCommand::modifySegment: chord has " << chord.size() << " notes in it" << endl;
 
 	for (Rosegarden::Chord::iterator ci = chord.begin();
 	     ci != chord.end(); ++ci) {
 
 	    e = **ci;
 
-	NOTATION_DEBUG << "AdjustMenuInterpretCommand::modifySegment: For note at " << e->getAbsoluteTime() << ", velocityChange is " << velocityChange << " and durationChange is " << durationChange << endl;
+	NOTATION_DEBUG << "TransformsMenuInterpretCommand::modifySegment: For note at " << e->getAbsoluteTime() << ", velocityChange is " << velocityChange << " and durationChange is " << durationChange << endl;
 
 	    // do this even if velocityChange == 0, in case the event
 	    // has no velocity yet
@@ -1942,12 +1697,8 @@ AdjustMenuInterpretCommand::articulate()
 		
 		    //!!! deal with tuplets
 		    
-		    Event *newEvent = new Event(*e,
-						e->getAbsoluteTime(),
-						newDuration,
-						e->getSubOrdering(),
-						e->getNotationAbsoluteTime(),
-						duration);
+		    Event *newEvent = new Event(*e, e->getAbsoluteTime(), newDuration);
+		    newEvent->setNotationDuration(duration);
 		    toInsert.insert(newEvent);
 		    toErase.insert(e);
 		}
@@ -1973,8 +1724,8 @@ AdjustMenuInterpretCommand::articulate()
     }
 }
 
-AdjustMenuInterpretCommand::IndicationMap::iterator
-AdjustMenuInterpretCommand::findEnclosingIndication(Event *e,
+TransformsMenuInterpretCommand::IndicationMap::iterator
+TransformsMenuInterpretCommand::findEnclosingIndication(Event *e,
 							std::string type)
 {
     // a bit slow, but let's wait and see whether it's a bottleneck
@@ -2074,19 +1825,7 @@ RespellCommand::modifySegment()
 
 	    } else if (m_type == Set) {
 		
-		// trap respelling black key notes as natural; which is
-		// impossible, and makes rawPitchToDisplayPitch() do crazy
-		// things as a consequence (fixes #1349782)
-		// 1 = C#, 3 = D#, 6 = F#, 8 = G#, 10 = A#
-		long pitch;
-		(*i)->get<Int>(PITCH, pitch);
-		pitch %= 12;
-		if ((pitch == 1 || pitch == 3 || pitch == 6 || pitch == 8 || pitch == 10 )
-			&& m_accidental == Natural) {
-		    // fail silently; is there anything to do here?
-		} else {
-                    (*i)->set<String>(ACCIDENTAL, m_accidental);
-		}
+		(*i)->set<String>(ACCIDENTAL, m_accidental);
 
 	    } else {
 
@@ -2124,76 +1863,4 @@ MakeAccidentalsCautionaryCommand::modifySegment()
 }
 
 
-void
-IncrementDisplacementsCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	long prevX = 0, prevY = 0;
-	(*i)->get<Int>(DISPLACED_X, prevX);
-	(*i)->get<Int>(DISPLACED_Y, prevY);
-	(*i)->setMaybe<Int>(DISPLACED_X, prevX + long(m_dx));
-	(*i)->setMaybe<Int>(DISPLACED_Y, prevY + long(m_dy));
-    }
-}
-
-
-void
-ResetDisplacementsCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	(*i)->unset(DISPLACED_X);
-	(*i)->unset(DISPLACED_Y);
-    }
-}
-
-
-void
-SetVisibilityCommand::modifySegment()
-{
-    EventSelection::eventcontainer::iterator i;
-
-    for (i  = m_selection->getSegmentEvents().begin();
-	 i != m_selection->getSegmentEvents().end(); ++i) {
-
-	if (m_visible) {
-	    (*i)->unset(INVISIBLE);
-	} else {
-	    (*i)->set<Bool>(INVISIBLE, true);
-	}
-    }
-}
-
-
-FretboardInsertionCommand::FretboardInsertionCommand(Segment &segment,
-        Rosegarden::timeT time,
-        Guitar::Fingering chord) :
-        BasicCommand(i18n("Insert Fretboard"), segment, time, time + 1, true),
-        m_chord(chord)
-{
-    // nothing
-}
-
-FretboardInsertionCommand::~FretboardInsertionCommand()
-{}
-
-void
-FretboardInsertionCommand::modifySegment()
-{
-    Segment::iterator i = getSegment().insert(m_chord.getAsEvent(getStartTime()));
-    if (i != getSegment().end())
-    {
-        m_lastInsertedEvent = *i;
-    }
-}
-
-
-
 		
