@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -26,7 +26,6 @@
 #include "rosestrings.h"
 #include "basiccommand.h"
 #include "notestyle.h"
-#include "guitar/fingering.h"
 #include <klocale.h>
 
 
@@ -134,10 +133,6 @@ protected:
     Rosegarden::Text m_text;
 };
 
-/*
- * Inserts a key change into a single segment, taking segment transpose into
- * account (fixes #1520716) if desired.
- */
 class KeyInsertionCommand : public BasicCommand
 {
 public:
@@ -145,8 +140,7 @@ public:
 			Rosegarden::timeT time,
 			Rosegarden::Key key,
 			bool shouldConvert,
-			bool shouldTranspose,
-			bool shouldTransposeKey);
+			bool shouldTranspose);
     virtual ~KeyInsertionCommand();
 
     static QString getGlobalName(Rosegarden::Key *key = 0) {
@@ -166,23 +160,16 @@ protected:
     Rosegarden::Event *m_lastInsertedEvent;
     bool m_convert;
     bool m_transpose;
-    bool m_transposeKey;
 };
 
-/*
- * Inserts a key change into multiple segments at the same time, taking
- * individual segment transpose into account (fixes #1520716) if desired.
- */
 class MultiKeyInsertionCommand : public KMacroCommand
 {
 public:
-    
     MultiKeyInsertionCommand(Rosegarden::Composition &composition,
 			     Rosegarden::timeT time,
 			     Rosegarden::Key key,
 			     bool shouldConvert,
-			     bool shouldTranspose,
-			     bool shouldTransposeKey); 
+			     bool shouldTranspose);
     virtual ~MultiKeyInsertionCommand();
 
     static QString getGlobalName(Rosegarden::Key *key = 0) {
@@ -194,33 +181,6 @@ public:
     }
 };
 
-class SustainInsertionCommand : public BasicCommand
-{
-public:
-    SustainInsertionCommand(Rosegarden::Segment &segment,
-			    Rosegarden::timeT time,
-			    bool down,
-			    int controllerNumber);
-    virtual ~SustainInsertionCommand();
-
-    static QString getGlobalName(bool down) {
-	if (down) {
-	    return i18n("Add Pedal &Press");
-	} else {
-	    return i18n("Add Pedal &Release");
-	}
-    }
-
-    Rosegarden::Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
-
-protected:
-    virtual void modifySegment();
-
-    bool m_down;
-    int m_controllerNumber;
-    Rosegarden::Event *m_lastInsertedEvent;
-};
-
 
 class EraseEventCommand : public BasicCommand
 {
@@ -247,10 +207,10 @@ protected:
 // Group menu commands
 
 
-class NotesMenuBeamCommand : public BasicSelectionCommand
+class GroupMenuBeamCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuBeamCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuBeamCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -262,13 +222,13 @@ protected:
 };
 
 
-class NotesMenuAutoBeamCommand : public BasicSelectionCommand
+class GroupMenuAutoBeamCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuAutoBeamCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuAutoBeamCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection) { }
 
-    NotesMenuAutoBeamCommand(Rosegarden::Segment &segment) :
+    GroupMenuAutoBeamCommand(Rosegarden::Segment &segment) :
 	BasicSelectionCommand(getGlobalName(), segment) { }
 
     static QString getGlobalName() { return i18n("&Auto-Beam"); }
@@ -278,10 +238,10 @@ protected:
 };
 
 
-class NotesMenuBreakCommand : public BasicSelectionCommand
+class GroupMenuBreakCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuBreakCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuBreakCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -293,18 +253,17 @@ protected:
 };
 
 
-class AdjustMenuTupletCommand : public BasicCommand
+class GroupMenuTupletCommand : public BasicCommand
 {
 public:
-    AdjustMenuTupletCommand(Rosegarden::Segment &segment,
+    GroupMenuTupletCommand(Rosegarden::Segment &segment,
 			   Rosegarden::timeT startTime,
 			   Rosegarden::timeT unit,
-			   int untupled = 3, int tupled = 2,
-			   bool groupHasTimingAlready = false);
+			   int untupled = 3, int tupled = 2);
 
     static QString getGlobalName(bool simple = true) {
-	if (simple) return i18n("&Triplet");
-	else return i18n("Tu&plet...");
+	if (simple) return i18n("&Simple Tuplet");
+	else return i18n("&Tuplet...");
     }
 
 protected:
@@ -314,14 +273,13 @@ private:
     Rosegarden::timeT m_unit;
     int m_untupled;
     int m_tupled;
-    bool m_hasTimingAlready;
 };
 
 
-class AdjustMenuUnTupletCommand : public BasicSelectionCommand
+class GroupMenuUnTupletCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuUnTupletCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuUnTupletCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -335,10 +293,10 @@ protected:
 };
 
 
-class AdjustMenuGraceCommand : public BasicCommand
+class GroupMenuGraceCommand : public BasicCommand
 {
 public:
-    AdjustMenuGraceCommand(Rosegarden::EventSelection &selection);
+    GroupMenuGraceCommand(Rosegarden::EventSelection &selection);
 
     static QString getGlobalName() { return i18n("Make &Grace Notes"); }
 
@@ -348,10 +306,10 @@ protected:
     Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
 };
 
-class AdjustMenuUnGraceCommand : public BasicSelectionCommand
+class GroupMenuUnGraceCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuUnGraceCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuUnGraceCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection) { }
 
     static QString getGlobalName() { return i18n("Ung&race"); }
@@ -361,12 +319,12 @@ protected:
 };
 
 
-class NotesMenuAddIndicationCommand : public BasicCommand
+class GroupMenuAddIndicationCommand : public BasicCommand
 {
 public:
-    NotesMenuAddIndicationCommand(std::string indicationType,
+    GroupMenuAddIndicationCommand(std::string indicationType,
 				  Rosegarden::EventSelection &selection);
-    virtual ~NotesMenuAddIndicationCommand();
+    virtual ~GroupMenuAddIndicationCommand();
 
     // tests whether the indication can be added without overlapping
     // another one of the same type
@@ -390,10 +348,10 @@ protected:
 };
     
 
-class AdjustMenuMakeChordCommand : public BasicSelectionCommand
+class GroupMenuMakeChordCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuMakeChordCommand(Rosegarden::EventSelection &selection) :
+    GroupMenuMakeChordCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -410,15 +368,15 @@ private:
 // Transforms menu commands
 
 
-class AdjustMenuNormalizeRestsCommand : public BasicCommand
+class TransformsMenuNormalizeRestsCommand : public BasicCommand
 {
 public:
-    AdjustMenuNormalizeRestsCommand(Rosegarden::Segment &s,
+    TransformsMenuNormalizeRestsCommand(Rosegarden::Segment &s,
 					Rosegarden::timeT startTime,
 					Rosegarden::timeT endTime) :
 	BasicCommand(getGlobalName(), s, startTime, endTime) { }
 
-    AdjustMenuNormalizeRestsCommand(Rosegarden::EventSelection &selection);
+    TransformsMenuNormalizeRestsCommand(Rosegarden::EventSelection &selection);
 
     static QString getGlobalName() { return i18n("&Normalize Rests"); }
 
@@ -427,15 +385,15 @@ protected:
 };
 
 
-class AdjustMenuCollapseRestsCommand : public BasicCommand
+class TransformsMenuCollapseRestsCommand : public BasicCommand
 {
 public:
-    AdjustMenuCollapseRestsCommand(Rosegarden::Segment &s,
+    TransformsMenuCollapseRestsCommand(Rosegarden::Segment &s,
 				       Rosegarden::timeT startTime,
 				       Rosegarden::timeT endTime) :
 	BasicCommand(getGlobalName(), s, startTime, endTime) { }
 
-    AdjustMenuCollapseRestsCommand(Rosegarden::EventSelection &selection);
+    TransformsMenuCollapseRestsCommand(Rosegarden::EventSelection &selection);
 
     static QString getGlobalName() { return i18n("&Collapse Rests"); }
 
@@ -443,14 +401,32 @@ protected:
     virtual void modifySegment();
 };
 
-class NotesMenuTieNotesCommand : public BasicSelectionCommand
+
+class TransformsMenuCollapseNotesCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuTieNotesCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuCollapseNotesCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
-    static QString getGlobalName() { return i18n("&Tie"); }
+    static QString getGlobalName() { return i18n("Collapse &Equal-Pitch Notes"); }
+
+protected:
+    virtual void modifySegment();
+
+private:
+    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
+};
+    
+
+class TransformsMenuTieNotesCommand : public BasicSelectionCommand
+{
+public:
+    TransformsMenuTieNotesCommand(Rosegarden::EventSelection &selection) :
+	BasicSelectionCommand(getGlobalName(), selection, true),
+	m_selection(&selection) { }
+
+    static QString getGlobalName() { return i18n("&Tie Equal-Pitch Notes"); }
 
 protected:
     virtual void modifySegment();
@@ -460,14 +436,14 @@ private:
 };
      
 
-class AdjustMenuUntieNotesCommand : public BasicSelectionCommand
+class TransformsMenuUntieNotesCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuUntieNotesCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuUntieNotesCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
-    static QString getGlobalName() { return i18n("&Untie"); }
+    static QString getGlobalName() { return i18n("&Untie Notes"); }
 
 protected:
     virtual void modifySegment();
@@ -478,14 +454,14 @@ private:
     
 
 /// MakeNotesViable works on a selection or entire segment
-class AdjustMenuMakeNotesViableCommand : public BasicSelectionCommand
+class TransformsMenuMakeNotesViableCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuMakeNotesViableCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuMakeNotesViableCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
-    AdjustMenuMakeNotesViableCommand(Rosegarden::Segment &segment) :
+    TransformsMenuMakeNotesViableCommand(Rosegarden::Segment &segment) :
 	BasicSelectionCommand(getGlobalName(), segment, true),
 	m_selection(0) { }
 
@@ -499,10 +475,10 @@ private:
 };
  
 /// MakeRegionViable works on part of a segment
-class AdjustMenuMakeRegionViableCommand : public BasicCommand
+class TransformsMenuMakeRegionViableCommand : public BasicCommand
 {
 public:
-    AdjustMenuMakeRegionViableCommand(Rosegarden::Segment &segment,
+    TransformsMenuMakeRegionViableCommand(Rosegarden::Segment &segment,
 					  Rosegarden::timeT startTime,
 					  Rosegarden::timeT endTime) :
 	BasicCommand(getGlobalName(), segment, startTime, endTime) { }
@@ -514,14 +490,14 @@ protected:
 };
     
 
-class AdjustMenuDeCounterpointCommand : public BasicSelectionCommand
+class TransformsMenuDeCounterpointCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuDeCounterpointCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuDeCounterpointCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
-    AdjustMenuDeCounterpointCommand(Rosegarden::Segment &segment) :
+    TransformsMenuDeCounterpointCommand(Rosegarden::Segment &segment) :
 	BasicSelectionCommand(getGlobalName(), segment, true),
 	m_selection(0) { }
 
@@ -535,10 +511,10 @@ private:
 };
   
 
-class AdjustMenuChangeStemsCommand : public BasicSelectionCommand
+class TransformsMenuChangeStemsCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuChangeStemsCommand(bool up, Rosegarden::EventSelection &selection) :
+    TransformsMenuChangeStemsCommand(bool up, Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(up), selection, true),
 	m_selection(&selection), m_up(up) { }
 
@@ -555,10 +531,10 @@ private:
 };
 
 
-class AdjustMenuRestoreStemsCommand : public BasicSelectionCommand
+class TransformsMenuRestoreStemsCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuRestoreStemsCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuRestoreStemsCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -572,47 +548,10 @@ private:
 };
 
 
-class AdjustMenuChangeSlurPositionCommand : public BasicSelectionCommand
+class TransformsMenuChangeStyleCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuChangeSlurPositionCommand(bool above, Rosegarden::EventSelection &selection) :
-	BasicSelectionCommand(getGlobalName(above), selection, true),
-	m_selection(&selection), m_above(above) { }
-
-    static QString getGlobalName(bool above) {
-	return above ? i18n("Slur &Above") : i18n("Slur &Below");
-    }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    bool m_above;
-};
-
-
-class AdjustMenuRestoreSlursCommand : public BasicSelectionCommand
-{
-public:
-    AdjustMenuRestoreSlursCommand(Rosegarden::EventSelection &selection) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection) { }
-
-    static QString getGlobalName() { return i18n("&Restore Computed Slur Position"); }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
-
-
-class AdjustMenuChangeStyleCommand : public BasicSelectionCommand
-{
-public:
-    AdjustMenuChangeStyleCommand(NoteStyleName style,
+    TransformsMenuChangeStyleCommand(NoteStyleName style,
 				     Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(style), selection, true),
 	m_selection(&selection), m_style(style) { }
@@ -648,10 +587,10 @@ private:
     int m_number;
 };    
 
-class NotesMenuAddMarkCommand : public BasicSelectionCommand
+class MarksMenuAddMarkCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuAddMarkCommand(Rosegarden::Mark mark,
+    MarksMenuAddMarkCommand(Rosegarden::Mark mark,
 			    Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(mark), selection, true),
 	m_selection(&selection), m_mark(mark) { }
@@ -667,10 +606,10 @@ private:
 };
 
 
-class NotesMenuAddTextMarkCommand : public BasicSelectionCommand
+class MarksMenuAddTextMarkCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuAddTextMarkCommand(std::string text,
+    MarksMenuAddTextMarkCommand(std::string text,
 				Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection), m_text(text) { }
@@ -686,10 +625,10 @@ private:
 };
 
 
-class NotesMenuAddFingeringMarkCommand : public BasicSelectionCommand
+class MarksMenuAddFingeringMarkCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuAddFingeringMarkCommand(std::string text,
+    MarksMenuAddFingeringMarkCommand(std::string text,
 				     Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection), m_text(text) { }
@@ -705,10 +644,10 @@ private:
 };
 
 
-class NotesMenuRemoveMarksCommand : public BasicSelectionCommand
+class MarksMenuRemoveMarksCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuRemoveMarksCommand(Rosegarden::EventSelection &selection) :
+    MarksMenuRemoveMarksCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -721,10 +660,10 @@ private:
     Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
 };
 
-class NotesMenuRemoveFingeringMarksCommand : public BasicSelectionCommand
+class MarksMenuRemoveFingeringMarksCommand : public BasicSelectionCommand
 {
 public:
-    NotesMenuRemoveFingeringMarksCommand(Rosegarden::EventSelection &selection) :
+    MarksMenuRemoveFingeringMarksCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
 
@@ -737,10 +676,10 @@ private:
     Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
 };
 
-class AdjustMenuFixNotationQuantizeCommand : public BasicSelectionCommand
+class TransformsMenuFixNotationQuantizeCommand : public BasicSelectionCommand
 {
 public:
-    AdjustMenuFixNotationQuantizeCommand(Rosegarden::EventSelection &selection) :
+    TransformsMenuFixNotationQuantizeCommand(Rosegarden::EventSelection &selection) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
 	m_selection(&selection) { }
     
@@ -753,23 +692,7 @@ private:
     Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
 };
 
-class AdjustMenuRemoveNotationQuantizeCommand : public BasicSelectionCommand
-{
-public:
-    AdjustMenuRemoveNotationQuantizeCommand(Rosegarden::EventSelection &selection) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection) { }
-    
-    static QString getGlobalName() { return i18n("Remo&ve Notation Quantization"); }
-    
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
-
-class AdjustMenuInterpretCommand : public BasicSelectionCommand
+class TransformsMenuInterpretCommand : public BasicSelectionCommand
 {
 public:
     // bit masks: pass an OR of these to the constructor
@@ -781,7 +704,7 @@ public:
     static const int Articulate;         // slurs, marks, legato etc
     static const int AllInterpretations; // all of the above
 
-    AdjustMenuInterpretCommand(Rosegarden::EventSelection &selection,
+    TransformsMenuInterpretCommand(Rosegarden::EventSelection &selection,
 				   const Rosegarden::Quantizer *quantizer,
 				   int interpretations) :
 	BasicSelectionCommand(getGlobalName(), selection, true),
@@ -789,7 +712,7 @@ public:
 	m_quantizer(quantizer),
 	m_interpretations(interpretations) { }
 
-    virtual ~AdjustMenuInterpretCommand();
+    virtual ~TransformsMenuInterpretCommand();
 
     static QString getGlobalName() { return i18n("&Interpret..."); }
     
@@ -865,76 +788,4 @@ private:
     bool m_cautionary;
 };
 
-class IncrementDisplacementsCommand : public BasicSelectionCommand
-{
-public:
-    IncrementDisplacementsCommand(Rosegarden::EventSelection &selection,
-				  long dx, long dy) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection),
-	m_dx(dx),
-	m_dy(dy) { }
-
-    static QString getGlobalName() { return i18n("Fine Reposition"); }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    long m_dx;
-    long m_dy;
-};
-
-class ResetDisplacementsCommand : public BasicSelectionCommand
-{
-public:
-    ResetDisplacementsCommand(Rosegarden::EventSelection &selection) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection) { }
-
-    static QString getGlobalName() { return i18n("Restore Computed Positions"); }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-};
-
-class SetVisibilityCommand : public BasicSelectionCommand
-{
-public:
-    SetVisibilityCommand(Rosegarden::EventSelection &selection, bool visible) :
-	BasicSelectionCommand(getGlobalName(), selection, true),
-	m_selection(&selection),
-	m_visible(visible) { }
-
-    static QString getGlobalName() { return i18n("Set Visibility"); }
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
-    bool m_visible;
-};
-
-class FretboardInsertionCommand : public BasicCommand
-{
-public:
-    FretboardInsertionCommand(Rosegarden::Segment &segment,
-                              Rosegarden::timeT time,
-                              Guitar::Fingering chord);
-    virtual ~FretboardInsertionCommand();
-
-    Rosegarden::Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
-
-protected:
-    virtual void modifySegment();
-
-    Guitar::Fingering m_chord;
-    Rosegarden::Event *m_lastInsertedEvent;
-};
-
 #endif
