@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -36,7 +36,6 @@
 #include "Profiler.h"
 #include "Composition.h"
 #include "SegmentNotationHelper.h"
-#include "guitar/fingering.h"
 
 #include <cmath> // for fabs()
 #include <set>
@@ -85,10 +84,6 @@ NotationHLayout::NotationHLayout(Composition *c, NotePixmapFactory *npf,
     m_staffCount(0)
 {
 //    NOTATION_DEBUG << "NotationHLayout::NotationHLayout()" << endl;
-
-    KConfig *config = kapp->config();
-    config->setGroup("Notation Options");
-    m_keySigCancelMode = config->readNumEntry("keysigcancelmode", 1);
 }
 
 NotationHLayout::~NotationHLayout()
@@ -145,7 +140,7 @@ NotationHLayout::getBarData(Staff &staff) const
 
 
 NotationElementList::iterator
-NotationHLayout::getStartOfQuantizedSlice(NotationElementList *notes,
+NotationHLayout::getStartOfQuantizedSlice(const NotationElementList *notes,
 					  timeT t)
     const
 {
@@ -246,30 +241,16 @@ NotationHLayout::scanStaff(Staff &staff, timeT startTime, timeT endTime)
 
     NOTATION_DEBUG << "ottava shift at start:" << ottavaShift << ", ottavaEnd " << ottavaEnd << endl;
 
-    KConfig *config = kapp->config();
-    config->setGroup("Notation Options");
-
-    int accOctaveMode = config->readNumEntry("accidentaloctavemode", 1);
+    //!!! problematic: if we're scanning from the middle, we won't
+    //have recorded any accidentals in the previous bar for the
+    //desirable BarResetCautionary/BarResetNaturals accidental table
+    //modes
+    
     Rosegarden::AccidentalTable::OctaveType octaveType = 
-	(accOctaveMode == 0 ? Rosegarden::AccidentalTable::OctavesIndependent :
-	 accOctaveMode == 1 ? Rosegarden::AccidentalTable::OctavesCautionary :
-	 Rosegarden::AccidentalTable::OctavesEquivalent);
+	Rosegarden::AccidentalTable::OctavesCautionary;
 
-    int accBarMode = config->readNumEntry("accidentalbarmode", 0);
     Rosegarden::AccidentalTable::BarResetType barResetType =
-	(accBarMode == 0 ? Rosegarden::AccidentalTable::BarResetNone :
-	 accBarMode == 1 ? Rosegarden::AccidentalTable::BarResetCautionary :
-	 Rosegarden::AccidentalTable::BarResetExplicit);
-
-    bool showInvisibles = config->readBoolEntry("showinvisibles", true);
-
-    if (barResetType != Rosegarden::AccidentalTable::BarResetNone) {
-	//!!! very crude and expensive way of making sure we see the
-	// accidentals from previous bar:
-	if (startBarNo > segment.getComposition()->getBarNumber(segment.getStartTime())) {
-	    --startBarNo;
-	}
-    }
+	Rosegarden::AccidentalTable::BarResetCautionary;
 
     Rosegarden::AccidentalTable accTable(key, clef, octaveType, barResetType);
 
@@ -343,11 +324,6 @@ NotationHLayout::scanStaff(Staff &staff, timeT startTime, timeT endTime)
 		}
 	    }
 
-	    bool invisible = false;
-	    if (el->event()->get<Bool>(INVISIBLE, invisible) && invisible) {
-		if (!showInvisibles) continue;
-	    }
-
 	    if (el->event()->has(BEAMED_GROUP_ID)) {
 		NOTATION_DEBUG << "element is beamed" << endl;
 		long groupId = el->event()->get<Int>(BEAMED_GROUP_ID);
@@ -515,7 +491,6 @@ NotationHLayout::setBarSizeData(Staff &staff,
     i->second.sizeData.actualDuration = actualDuration;
     i->second.sizeData.idealWidth = 0.0;
     i->second.sizeData.reconciledWidth = 0.0;
-    i->second.sizeData.clefKeyWidth = 0;
     i->second.sizeData.fixedWidth = fixedWidth;
 }
 
@@ -794,13 +769,7 @@ NotationHLayout::preSquishBar(int barNo)
 	if (bdli != bdl.end()) {
 
 	    bdli->second.sizeData.idealWidth =
-		bdli->second.sizeData.fixedWidth + x;
-
-	    if (!bdli->second.basicData.timeSignature.hasHiddenBars()) {
-		bdli->second.sizeData.idealWidth += getBarMargin();
-	    } else if (bdli->second.basicData.newTimeSig) {
-		bdli->second.sizeData.idealWidth += getPostBarMargin();
-	    }
+		bdli->second.sizeData.fixedWidth + x + getBarMargin();
 
 	    bdli->second.sizeData.reconciledWidth =
 		bdli->second.sizeData.idealWidth;
@@ -840,40 +809,6 @@ NotationHLayout::getStaffWithWidestBar(int barNo)
     return widest;
 }
 
-int
-NotationHLayout::getMaxRepeatedClefAndKeyWidth(int barNo)
-{
-    int max = 0;
-
-    timeT barStart = 0;
-
-    for (BarDataMap::iterator mi = m_barData.begin();
-	 mi != m_barData.end(); ++mi) {
-
-	Staff *staff = mi->first;
-	if (mi == m_barData.begin()) {
-	    barStart = staff->getSegment().getComposition()->getBarStart(barNo);
-	}
-
-	timeT t;
-	int w = 0;
-
-	Clef clef = staff->getSegment().getClefAtTime(barStart, t);
-	if (t < barStart) w += m_npf->getClefWidth(clef);
-
-	Rosegarden::Key key = staff->getSegment().getKeyAtTime(barStart, t);
-	if (t < barStart) w += m_npf->getKeyWidth(key);
-
-	if (w > max) max = w;
-    }
-
-    NOTATION_DEBUG << "getMaxRepeatedClefAndKeyWidth(" << barNo << "): " << max
-		   << endl;
-
-    if (max > 0) return max + getFixedItemSpacing() * 2;
-    else return 0;
-}
-
 void
 NotationHLayout::reconcileBarsLinear()
 {
@@ -1047,24 +982,8 @@ NotationHLayout::reconcileBarsPage()
 	    rowData.push_back(std::pair<int, double>(barNoThisRow,
 						     pageWidthSoFar));
 	    barNoThisRow = 1;
-
-	    // When we start a new row, we always need to allow for the
-	    // repeated clef and key at the start of it.
-	    int maxClefKeyWidth = getMaxRepeatedClefAndKeyWidth(barNo);
-
-	    for (BarDataMap::iterator i = m_barData.begin();
-		 i != m_barData.end(); ++i) {
-		
-		BarDataList &list = i->second;
-		BarDataList::iterator bdli = list.find(barNo);
-		
-		if (bdli != list.end()) {
-		    bdli->second.sizeData.clefKeyWidth = maxClefKeyWidth;
-		}
-	    }
-
-	    pageWidthSoFar = maxWidth + maxClefKeyWidth;
-	    stretchFactor = m_pageWidth / pageWidthSoFar;
+	    pageWidthSoFar = maxWidth;
+	    stretchFactor = m_pageWidth / maxWidth;
 	} else {
 	    ++barNoThisRow;
 	    pageWidthSoFar = nextPageWidth;
@@ -1104,17 +1023,16 @@ NotationHLayout::reconcileBarsPage()
 		if (barNo >= getLastVisibleBar()) break; // yes
 		else maxWidth = stretchFactor * (m_spacing / 3);
 	    } else {
-		BarData &bd = m_barData[widest].find(barNo)->second;
-		maxWidth = (stretchFactor * bd.sizeData.idealWidth) +
-		    bd.sizeData.clefKeyWidth;
-		NOTATION_DEBUG << "setting maxWidth to " << (stretchFactor * bd.sizeData.idealWidth) << " + " << bd.sizeData.clefKeyWidth << " = " << maxWidth << endl;
+		maxWidth =
+		    (stretchFactor *
+		     m_barData[widest].find(barNo)->
+		     second.sizeData.idealWidth);
 	    }
 
 	    if (barNoThisRow == finalBarThisRow) {
 		if (!finalRow ||
 		    (maxWidth > (m_pageWidth - pageWidthSoFar))) {
 		    maxWidth = m_pageWidth - pageWidthSoFar;
-		    NOTATION_DEBUG << "reset maxWidth to " << m_pageWidth << " - " << pageWidthSoFar << " = " << maxWidth << endl;
 		}
 	    }
 
@@ -1210,16 +1128,12 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 	(isFullLayout && (notes->begin() != notes->end())) ?
 	(*notes->begin())->getViewAbsoluteTime() : startTime;
 
-    Rosegarden::Key key = notationStaff.getSegment().getKeyAtTime(lastIncrement);
+    Rosegarden::Key key = notationStaff.getSegment().getKeyAtTime(lastIncrement);;
     Clef clef = notationStaff.getSegment().getClefAtTime(lastIncrement);
     TimeSignature timeSignature;
 
     int startBar = getComposition()->getBarNumber(startTime);
 
-    KConfig *config = kapp->config();
-    config->setGroup("Notation Options");
-    bool showInvisibles = config->readBoolEntry("showinvisibles", true);
-
     for (BarPositionList::iterator bpi = m_barPositions.begin();
 	 bpi != m_barPositions.end(); ++bpi) {
 
@@ -1289,45 +1203,26 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 	    timeSignature = bdi->second.basicData.timeSignature;
 	    timeSigToPlace = !bdi->second.basicData.timeSignature.isHidden();
 	}
+
         if (timeSigToPlace) {
 	    NOTATION_DEBUG << "NotationHLayout::layout(): there's a time sig in this bar" << endl;
 	}
 
-	bool repeatClefAndKey = false;
-	if (bdi->second.sizeData.clefKeyWidth > 0) {
-	    repeatClefAndKey = true;
-	}
-	if (repeatClefAndKey) {
-	    NOTATION_DEBUG << "NotationHLayout::layout(): need to repeat clef & key in this bar" << endl;
-	}
-
-	double barInset = notationStaff.getBarInset(barNo, repeatClefAndKey);
-
 	NotationElement *lastDynamicText = 0;
 	int count = 0;
 
-	double offset = 0.0;
-	double reconciledWidth = bdi->second.sizeData.reconciledWidth;
-
-	if (repeatClefAndKey) {
-	    offset = bdi->second.sizeData.clefKeyWidth;
-	    reconciledWidth -= offset;
-	}
-
-	if (bdi->second.basicData.newTimeSig ||
-	    !bdi->second.basicData.timeSignature.hasHiddenBars()) {
-	    offset += getPostBarMargin();
-	}
-
 	ChunkList &chunks = bdi->second.chunks;
 	ChunkList::iterator chunkitr = chunks.begin();
 	double reconcileRatio = 1.0;
 	if (bdi->second.sizeData.idealWidth > 0.0) {
-	    reconcileRatio = reconciledWidth / bdi->second.sizeData.idealWidth;
+	    reconcileRatio =
+		bdi->second.sizeData.reconciledWidth /
+		bdi->second.sizeData.idealWidth;
 	}
 
 	NOTATION_DEBUG << "have " << chunks.size() << " chunks, reconciledWidth " << bdi->second.sizeData.reconciledWidth << ", idealWidth " << bdi->second.sizeData.idealWidth << ", ratio " << reconcileRatio << endl;
 
+	double offset = getPostBarMargin();
 	double delta = 0;
 
         for (NotationElementList::iterator it = from; it != to; ++it) {
@@ -1336,18 +1231,7 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 	    delta = 0;
 	    float fixed = 0;
 
-	    if (el->event()->isa(Note::EventType)) {
-		long pitch = 0;
-		el->event()->get<Int>(PITCH, pitch);
-		NOTATION_DEBUG << "element is a " << el->event()->getType() << " (pitch " << pitch << ")" << endl;
-	    } else {
-		NOTATION_DEBUG << "element is a " << el->event()->getType() << endl;
-	    }
-
-	    bool invisible = false;
-	    if (el->event()->get<Bool>(INVISIBLE, invisible) && invisible) {
-		if (!showInvisibles) continue;
-	    }
+	    NOTATION_DEBUG << "element is a " << el->event()->getType() << endl;
 
 	    if (chunkitr != chunks.end()) {
 		NOTATION_DEBUG << "new chunk: addr " << &(*chunkitr) << " duration=" << (*chunkitr).duration << " subordering=" << (*chunkitr).subordering << " fixed=" << (*chunkitr).fixed << " stretchy=" << (*chunkitr).stretchy << " x=" << (*chunkitr).x << endl;
@@ -1358,13 +1242,13 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 		if (++chunkscooter != chunks.end()) {
 		    delta = (*chunkscooter).x - (*chunkitr).x;
 		} else {
-		    delta = reconciledWidth -
+		    delta = bdi->second.sizeData.reconciledWidth -
 			bdi->second.sizeData.fixedWidth - (*chunkitr).x;
 		}
 		delta *= reconcileRatio;
 		++chunkitr;
 	    } else {
-		x = barX + reconciledWidth - getPreBarMargin();
+		x = barX + bdi->second.sizeData.reconciledWidth - getPreBarMargin();
 		delta = 0;
 	    }
 
@@ -1381,37 +1265,15 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 		timeSigToPlace = false;
 	    }
 
-	    if (barInset >= 1.0) {
-		if (el->event()->isa(Rosegarden::Clef::EventType) ||
-		    el->event()->isa(Rosegarden::Key::EventType)) {
-		    NOTATION_DEBUG << "Pulling clef/key back by " << getPreBarMargin() << endl;
-		    x -= getPostBarMargin() * 2 / 3;
-		} else {
-		    barInset = 0.0;
-		}
-	    }
-
             NOTATION_DEBUG << "NotationHLayout::layout(): setting element's x to " << x << " (was " << el->getLayoutX() << ")" << endl;
 
-	    double displacedX = 0.0;
-	    long dxRaw = 0;
-	    el->event()->get<Int>(DISPLACED_X, dxRaw);
-	    displacedX = double(dxRaw * m_npf->getNoteBodyWidth()) / 1000.0;
-
-	    el->setLayoutX(x + displacedX);
+	    el->setLayoutX(x);
 	    el->setLayoutAirspace(x, int(delta));
 
-	    // #704958 (multiple tuplet spanners created when entering
-	    // triplet chord) -- only do this here for non-notes,
-	    // notes get it from positionChord
-	    if (!el->isNote()) {
-		sampleGroupElement(staff, clef, key, it);
-	    }
-
 	    if (el->isNote()) {
 
 		// This modifies "it" and "tieMap"
-		positionChord(staff, it, clef, key, tieMap, to);
+		positionChord(staff, it, bdi, timeSignature, clef, key, tieMap, to);
 
 	    } else if (el->isRest()) {
 
@@ -1460,19 +1322,39 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 			m_npf->getNoteBodyWidth() / 4;
 		}
 
-		el->setLayoutX(ix + displacedX);
+		el->setLayoutX(ix);
 		el->setLayoutAirspace(ix, delta - (ix - x));
 
-            } else if (el->event()->isa(Guitar::Fingering::EventType)) {
-
-                int fretboardWidth = m_npf->getLineSpacing() * 6;
-                el->setLayoutX(x - (fretboardWidth / 2));
-
 	    } else {    
 
 		// nothing else
 	    }
 
+	    if (it != to && el->event()->has(BEAMED_GROUP_ID)) {
+
+		//!!! Gosh.  We need some clever logic to establish
+		// whether one group is happening while another has
+		// not yet ended -- perhaps we decide one has ended
+		// if we see another, and then re-open the case of
+		// the first if we meet another note that claims to
+		// be in it.  Then we need to hint to both of the
+		// groups that they should choose appropriate stem
+		// directions -- we could just use HEIGHT_ON_STAFF
+		// of their first notes to determine this, as if that
+		// doesn't work, nothing will
+
+		long groupId = el->event()->get<Int>(BEAMED_GROUP_ID);
+//		NOTATION_DEBUG << "group id: " << groupId << endl;
+		if (m_groupsExtant.find(groupId) == m_groupsExtant.end()) {
+//		    NOTATION_DEBUG << "(new group)" << endl;
+		    m_groupsExtant[groupId] =
+			new NotationGroup(*staff.getViewElementList(),
+					  m_notationQuantizer,
+					  m_properties, clef, key);
+		}
+		m_groupsExtant[groupId]->sample(it, true);
+	    }
+
 	    if (m_timePerProgressIncrement > 0 && (++count == 100)) {
 		count = 0;
 		timeT sinceIncrement = el->getViewAbsoluteTime() - lastIncrement;
@@ -1489,7 +1371,7 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 
 	if (timeSigToPlace) {
 	    // no other events in this bar, so we never managed to place it
-	    x = barX + offset;
+	    x = x + delta - m_npf->getTimeSigWidth(bdi->second.basicData.timeSignature);
 	    NOTATION_DEBUG << "Placing timesig reluctantly at " << x << endl;
 	    bdi->second.layoutData.timeSigX = (int)(x);
 	    timeSigToPlace = false;
@@ -1507,37 +1389,6 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
     }
 }
 
-void
-NotationHLayout::sampleGroupElement(Staff &staff,
-				    const Clef &clef,
-				    const Rosegarden::Key &key,
-				    const NotationElementList::iterator &itr)
-{
-    NotationElement *el = static_cast<NotationElement *>(*itr);
-
-    if (el->event()->has(BEAMED_GROUP_ID)) {
-
-	//!!! Gosh.  We need some clever logic to establish whether
-	// one group is happening while another has not yet ended --
-	// perhaps we decide one has ended if we see another, and then
-	// re-open the case of the first if we meet another note that
-	// claims to be in it.  Then we need to hint to both of the
-	// groups that they should choose appropriate stem directions
-	// -- we could just use HEIGHT_ON_STAFF of their first notes
-	// to determine this, as if that doesn't work, nothing will
-
-	long groupId = el->event()->get<Int>(BEAMED_GROUP_ID);
-	NOTATION_DEBUG << "group id: " << groupId << endl;
-	if (m_groupsExtant.find(groupId) == m_groupsExtant.end()) {
-	    NOTATION_DEBUG << "(new group)" << endl;
-	    m_groupsExtant[groupId] =
-		new NotationGroup(*staff.getViewElementList(),
-				  m_notationQuantizer,
-				  m_properties, clef, key);
-	}
-	m_groupsExtant[groupId]->sample(itr, true);
-    }
-}
 
 timeT
 NotationHLayout::getSpacingDuration(Staff &staff,
@@ -1579,6 +1430,8 @@ NotationHLayout::getSpacingDuration(Staff &staff,
 void
 NotationHLayout::positionChord(Staff &staff,
                                NotationElementList::iterator &itr,
+				const BarDataList::iterator &, //!!!unreqd?
+				const TimeSignature &, //!!! unreqd?
 			       const Clef &clef, const Rosegarden::Key &key,
 			       TieMap &tieMap, 
 			       NotationElementList::iterator &to)
@@ -1603,25 +1456,14 @@ NotationHLayout::positionChord(Staff &staff,
 	
 	if (citr == to) barEndsInChord = true;
 
-	// #704958 (multiple tuplet spanners created when entering
-	// triplet chord) -- layout() updates the beamed group data
-	// for non-notes, but we have to do it for notes so as to
-	// ensure every note in the chord is accounted for
-	sampleGroupElement(staff, clef, key, citr);
+	NotationElement *elt = static_cast<NotationElement*>(*citr);//!!!
 
-	NotationElement *elt = static_cast<NotationElement*>(*citr);
-
-	double displacedX = 0.0;
-	long dxRaw = 0;
-	elt->event()->get<Int>(DISPLACED_X, dxRaw);
-	displacedX = double(dxRaw * m_npf->getNoteBodyWidth()) / 1000.0;
-
-	elt->setLayoutX(baseX + displacedX);
+	elt->setLayoutX(baseX);
 	elt->setLayoutAirspace(baseX, delta);
 
 	NOTATION_DEBUG << "NotationHLayout::positionChord: assigned x to elt at " << elt->getViewAbsoluteTime() << endl;
 
-	if (citr == chord.getFinalElement()) break;
+	if (citr == chord.getFinalElement()) break;//!!!
     }
 
     // Check for any ties going back, and if so work out how long they
@@ -1630,9 +1472,9 @@ NotationHLayout::positionChord(Staff &staff,
     for (NotationElementList::iterator citr = chord.getInitialElement();
 	 citr != staff.getViewElementList()->end(); ++citr) {
 	
-	NotationElement *note = static_cast<NotationElement*>(*citr);
+	NotationElement *note = static_cast<NotationElement*>(*citr);//!!!
 	if (!note->isNote()) {
-	    if (citr == chord.getFinalElement()) break;
+	    if (citr == chord.getFinalElement()) break; //!!!
 	    continue;
 	}
 
@@ -1642,7 +1484,6 @@ NotationHLayout::positionChord(Staff &staff,
 	note->event()->get<Bool>(TIED_FORWARD,  tiedForwards);
 	note->event()->get<Bool>(TIED_BACKWARD, tiedBack);
 
-	if (!note->event()->has(PITCH)) continue;
 	int pitch = note->event()->get<Int>(PITCH);
 
 	if (tiedBack) {
@@ -1690,7 +1531,7 @@ NotationHLayout::getLayoutWidth(Rosegarden::ViewElement &ve,
 {
     NotationElement& e = static_cast<NotationElement&>(ve);
 
-    if ((e.isNote() || e.isRest()) && e.event()->has(NOTE_TYPE)) {
+    if (e.isNote() || e.isRest()) {
 
         long noteType = e.event()->get<Int>(NOTE_TYPE);
 	long dots = 0;
@@ -1730,31 +1571,20 @@ NotationHLayout::getLayoutWidth(Rosegarden::ViewElement &ve,
 
 	    Rosegarden::Key key(*e.event());
 
-	    Rosegarden::Key cancelKey = previousKey;
-
-	    if (m_keySigCancelMode == 0) { // only when entering C maj / A min
-
-		if (key.getAccidentalCount() != 0) cancelKey = Rosegarden::Key();
-
-	    } else if (m_keySigCancelMode == 1) { // only when reducing acc count
-
-		if (!(key.isSharp() == cancelKey.isSharp() &&
-		      key.getAccidentalCount() < cancelKey.getAccidentalCount())) {
-		    cancelKey = Rosegarden::Key();
-		}
+	    if (key.getAccidentalCount() == 0) {
+		w += m_npf->getKeyWidth(previousKey, true);
+	    } else {
+		w += m_npf->getKeyWidth(key);
 	    }
 
-	    w += m_npf->getKeyWidth(key, cancelKey);
-
 	} else if (e.event()->isa(Indication::EventType) ||
 		   e.event()->isa(Text::EventType)) {
 
 	    w = 0;
 
 	} else {
-//	    NOTATION_DEBUG << "NotationHLayout::getLayoutWidth(): no case for event type " << e.event()->getType() << endl;
-//	    w += 24;
-	    w = 0;
+	    NOTATION_DEBUG << "NotationHLayout::getLayoutWidth(): no case for event type " << e.event()->getType() << endl;
+	    w += 24;
 	}
 
 	return w;
@@ -1805,11 +1635,11 @@ NotationHLayout::resetStaff(Staff &staff, timeT startTime, timeT endTime)
 }
 
 int
-NotationHLayout::getFirstVisibleBar() const
+NotationHLayout::getFirstVisibleBar()
 {
     int bar = 0;
     bool haveBar = false;
-    for (BarDataMap::const_iterator i = m_barData.begin(); i != m_barData.end(); ++i) {
+    for (BarDataMap::iterator i(m_barData.begin()); i != m_barData.end(); ++i) {
 	if (i->second.begin() == i->second.end()) continue;
 	int barHere = i->second.begin()->first;
 	if (barHere < bar || !haveBar) {
@@ -1837,11 +1667,11 @@ NotationHLayout::getFirstVisibleBarOnStaff(Staff &staff)
 }
 
 int
-NotationHLayout::getLastVisibleBar() const
+NotationHLayout::getLastVisibleBar()
 {
     int bar = 0;
     bool haveBar = false;
-    for (BarDataMap::const_iterator i = m_barData.begin();
+    for (BarDataMap::iterator i = m_barData.begin();
 	 i != m_barData.end(); ++i) {
 	if (i->second.begin() == i->second.end()) continue;
 	int barHere = getLastVisibleBarOnStaff(*i->first);
@@ -1857,13 +1687,13 @@ NotationHLayout::getLastVisibleBar() const
 }
 
 int
-NotationHLayout::getLastVisibleBarOnStaff(Staff &staff) const
+NotationHLayout::getLastVisibleBarOnStaff(Staff &staff)
 {
-    const BarDataList &bdl(getBarData(staff));
+    BarDataList &bdl(getBarData(staff));
     int bar = 0;
 
     if (bdl.begin() != bdl.end()) {
-	BarDataList::const_iterator i = bdl.end();
+	BarDataList::iterator i(bdl.end());
 	bar = ((--i)->first) + 1; // last visible bar_line_
     }
 
@@ -1873,11 +1703,11 @@ NotationHLayout::getLastVisibleBarOnStaff(Staff &staff) const
 }
 
 double
-NotationHLayout::getBarPosition(int bar) const
+NotationHLayout::getBarPosition(int bar)
 {
     double position = 0.0;
 
-    BarPositionList::const_iterator i = m_barPositions.find(bar);
+    BarPositionList::iterator i = m_barPositions.find(bar);
 
     if (i != m_barPositions.end()) {
 
@@ -1928,23 +1758,23 @@ bool NotationHLayout::getTimeSignaturePosition(Staff &staff,
 }
 
 Rosegarden::timeT
-NotationHLayout::getTimeForX(double x) const
+NotationHLayout::getTimeForX(double x)
 {
     return RulerScale::getTimeForX(x);
 }
 
 double
-NotationHLayout::getXForTime(Rosegarden::timeT t) const
+NotationHLayout::getXForTime(Rosegarden::timeT t)
 {
     return RulerScale::getXForTime(t);
 }
 
 double
-NotationHLayout::getXForTimeByEvent(Rosegarden::timeT time) const
+NotationHLayout::getXForTimeByEvent(Rosegarden::timeT time)
 {
 //    NOTATION_DEBUG << "NotationHLayout::getXForTime(" << time << ")" << endl;
 
-    for (BarDataMap::const_iterator i = m_barData.begin(); i != m_barData.end(); ++i) {
+    for (BarDataMap::iterator i(m_barData.begin()); i != m_barData.end(); ++i) {
 
 	Rosegarden::Staff *staff = i->first;
 
@@ -1962,6 +1792,7 @@ NotationHLayout::getXForTimeByEvent(Rosegarden::timeT time) const
 		if (vli == staff->getViewElementList()->end()) break;
 		NotationElement *element = static_cast<NotationElement *>(*vli);
 		if (element->getCanvasItem()) {
+//!!!		    && (element->isNote() || element->isRest())) {
 		    x = element->getLayoutX();
 		    double temp;
 		    element->getLayoutAirspace(temp, dx);
