@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -39,7 +39,6 @@
 #include "widgets.h"
 #include "notefont.h"
 #include "pixmapfunctions.h"
-#include "rosegardenguidoc.h" // for studio stuff that determines whether a controller is sustain or not
 
 #include "Event.h"
 #include "Segment.h"
@@ -51,8 +50,6 @@
 #include "Composition.h"
 #include "BaseProperties.h"
 #include "Profiler.h"
-#include "Studio.h" // for studio stuff that determines whether a controller is sustain or not
-#include "guitar/fingering.h"
 
 using Rosegarden::timeT;
 using Rosegarden::Segment;
@@ -95,19 +92,14 @@ NotationStaff::NotationStaff(QCanvas *canvas, Segment *segment,
     m_barNumbersEvery(0),
     m_colourQuantize(true),
     m_showUnknowns(true),
-    m_showRanges(true),
     m_printPainter(0),
     m_ready(false)
 {
     KConfig *config = kapp->config();
     config->setGroup(NotationView::ConfigGroup);
     m_colourQuantize = config->readBoolEntry("colourquantize", false);
-
-    // Shouldn't change these  during the lifetime of the staff, really:
+    // Shouldn't change this one during the lifetime of the staff, really:
     m_showUnknowns = config->readBoolEntry("showunknowns", false);
-    m_showRanges = config->readBoolEntry("showranges", true);
-    m_keySigCancelMode = config->readNumEntry("keysigcancelmode", 1);
-
     changeFont(fontName, resolution);
 }
 
@@ -170,97 +162,6 @@ NotationStaff::deleteTimeSignatures()
     m_timeSigs.clear();
 }
 
-void
-NotationStaff::insertRepeatedClefAndKey(double layoutX, int barNo)
-{
-    bool needClef = false, needKey = false;
-    timeT t;
-    
-    timeT barStart = getSegment().getComposition()->getBarStart(barNo);
-
-    Rosegarden::Clef clef = getSegment().getClefAtTime(barStart, t);
-    if (t < barStart) needClef = true;
-
-    Rosegarden::Key key = getSegment().getKeyAtTime(barStart, t);
-    if (t < barStart) needKey = true;
-
-    double dx = m_notePixmapFactory->getBarMargin() / 2;
-
-    if (!m_notationView->isInPrintMode()) m_notePixmapFactory->setShaded(true);
-
-    if (needClef) {
-
-	int layoutY = getLayoutYForHeight(clef.getAxisHeight());
-
-	LinedStaffCoords coords =
-	    getCanvasCoordsForLayoutCoords(layoutX + dx, layoutY);
-    
-	QCanvasPixmap *pixmap = m_notePixmapFactory->makeClefPixmap(clef);
-
-	QCanvasNonElementSprite *sprite = 
-	    new QCanvasNonElementSprite(pixmap, m_canvas);
-
-	sprite->move(coords.first, coords.second);
-	sprite->show();
-	m_repeatedClefsAndKeys.insert(sprite);
-
-	dx += pixmap->width() + m_notePixmapFactory->getNoteBodyWidth() * 2 / 3;
-    }
-
-    if (needKey) {
-
-	int layoutY = getLayoutYForHeight(12);
-
-	LinedStaffCoords coords =
-	    getCanvasCoordsForLayoutCoords(layoutX + dx, layoutY);
-    
-	QCanvasPixmap *pixmap = m_notePixmapFactory->makeKeyPixmap(key, clef);
-
-	QCanvasNonElementSprite *sprite = 
-	    new QCanvasNonElementSprite(pixmap, m_canvas);
-
-	sprite->move(coords.first, coords.second);
-	sprite->show();
-	m_repeatedClefsAndKeys.insert(sprite);
-
-	dx += pixmap->width();
-    }
-
-/* attempt to blot out things like slurs & ties that overrun this area: doesn't work
-
-    if (m_notationView->isInPrintMode() && (needClef || needKey)) {
-
-	int layoutY = getLayoutYForHeight(14);
-	int h = getLayoutYForHeight(-8) - layoutY;
-
-	LinedStaffCoords coords =
-	    getCanvasCoordsForLayoutCoords(layoutX, layoutY);
-    
-	QCanvasRectangle *rect = new QCanvasRectangle(coords.first, coords.second,
-						      dx, h, m_canvas);
-	rect->setPen(Qt::black);
-	rect->setBrush(Qt::white);
-	rect->setZ(1);
-	rect->show();
-
-	m_repeatedClefsAndKeys.insert(rect);
-    }
-*/
-
-    m_notePixmapFactory->setShaded(false);
-}	
-
-void
-NotationStaff::deleteRepeatedClefsAndKeys()
-{
-    for (ItemSet::iterator i = m_repeatedClefsAndKeys.begin();
-	 i != m_repeatedClefsAndKeys.end(); ++i) {
-	delete *i;
-    }
-
-    m_repeatedClefsAndKeys.clear();
-}
-
 void
 NotationStaff::drawStaffName()
 {
@@ -310,7 +211,21 @@ NotationStaff::getClefAndKeyAtCanvasCoords(double cx, int cy,
     }
 }
 
-Rosegarden::ViewElementList::iterator
+NotationElementList::iterator
+NotationStaff::getClosestElementToCanvasCoords(double cx, int cy,
+					       Rosegarden::Event *&clef,
+					       Rosegarden::Event *&key,
+					       bool notesAndRestsOnly,
+					       int proximityThreshold)
+{
+    LinedStaffCoords layoutCoords = getLayoutCoordsForCanvasCoords(cx, cy);
+
+    return getClosestElementToLayoutX
+	(layoutCoords.first, clef, key, notesAndRestsOnly, proximityThreshold);
+}
+
+
+NotationElementList::iterator
 NotationStaff::getClosestElementToLayoutX(double x,
 					  Rosegarden::Event *&clef,
 					  Rosegarden::Event *&key,
@@ -368,7 +283,17 @@ NotationStaff::getClosestElementToLayoutX(double x,
     return result;
 }
 
-Rosegarden::ViewElementList::iterator
+
+NotationElementList::iterator
+NotationStaff::getElementUnderCanvasCoords(double cx, int cy,
+					   Rosegarden::Event *&clef,
+					   Rosegarden::Event *&key)
+{
+    LinedStaffCoords layoutCoords = getLayoutCoordsForCanvasCoords(cx, cy);
+    return getElementUnderLayoutX(layoutCoords.first, clef, key);
+}
+
+NotationElementList::iterator
 NotationStaff::getElementUnderLayoutX(double x,
 				      Rosegarden::Event *&clef,
 				      Rosegarden::Event *&key)
@@ -538,12 +463,6 @@ NotationStaff::renderPrintable(timeT from, timeT to)
 //			 << elementCount << " elements rendered" << endl;
 }	
 
-const NotationProperties &
-NotationStaff::getProperties() const
-{
-    return m_notationView->getProperties();
-}
-
 void
 NotationStaff::positionElements(timeT from, timeT to)
 {
@@ -555,7 +474,7 @@ NotationStaff::positionElements(timeT from, timeT to)
     emit setProgress(0);
     throwIfCancelled();
 
-    const NotationProperties &properties(getProperties());
+    const NotationProperties &properties(m_notationView->getProperties());
 
     int elementsPositioned = 0;
     int elementsRendered = 0; // diagnostic
@@ -869,20 +788,11 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 				   const Rosegarden::Key &currentKey,
 				   bool selected)
 {
-    const NotationProperties &properties(getProperties());
+    const NotationProperties &properties(m_notationView->getProperties());
     static NotePixmapParameters restParams(Note::Crotchet, 0);
 
     NotationElement* elt = static_cast<NotationElement*>(*vli);
     
-    bool invisible = false;
-    if (elt->event()->get<Bool>(INVISIBLE, invisible) && invisible) {
-	if (m_printPainter) return;
-	KConfig *config = kapp->config();
-	config->setGroup("Notation Options");
-	bool showInvisibles = config->readBoolEntry("showinvisibles", true);
-	if (!showInvisibles) return;
-    }
-
     try {
 	m_notePixmapFactory->setNoteStyle
 	    (NoteStyleFactory::getStyleForEvent(elt->event()));
@@ -904,7 +814,6 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 	QCanvasPixmap *pixmap = 0;
 
 	m_notePixmapFactory->setSelected(selected);
-	m_notePixmapFactory->setShaded(invisible);
 	int z = selected ? 3 : 0;
 
 	// these are actually only used for the printer stuff
@@ -935,17 +844,6 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 		restParams.setDots(dots);
 		setTuplingParameters(elt, restParams);
 		restParams.setQuantized(false);
-		bool restOutside = false;
-		elt->event()->get<Bool>(properties.REST_OUTSIDE_STAVE,
-					restOutside);
-    		restParams.setRestOutside(restOutside);
-    		if (restOutside) {
-		   NOTATION_DEBUG << "NotationStaff::renderSingleElement() : rest outside staff" << endl;
-		   if (note == Note::DoubleWholeNote) {
-		      NOTATION_DEBUG << "NotationStaff::renderSingleElement() : breve rest needs leger lines" << endl;
-		      restParams.setLegerLines(5);
-		   }
-		}
 
 		if (m_printPainter) {
 		    m_notePixmapFactory->drawRest
@@ -964,23 +862,15 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 	} else if (elt->event()->isa(Rosegarden::Key::EventType)) {
 
 	    Rosegarden::Key key(*elt->event());
-	    Rosegarden::Key cancelKey = currentKey;
 
-	    if (m_keySigCancelMode == 0) { // only when entering C maj / A min
-
-		if (key.getAccidentalCount() != 0) cancelKey = Rosegarden::Key();
-
-	    } else if (m_keySigCancelMode == 1) { // only when reducing acc count
-
-		if (!(key.isSharp() == cancelKey.isSharp() &&
-		      key.getAccidentalCount() < cancelKey.getAccidentalCount())) {
-		    cancelKey = Rosegarden::Key();
-		}
+	    if (key.getAccidentalCount() == 0) { // need cancellation
+		pixmap = m_notePixmapFactory->makeKeyPixmap
+		    (currentKey, currentClef, true);
+	    } else {
+		pixmap = m_notePixmapFactory->makeKeyPixmap
+		    (key, currentClef);
 	    }
 
-	    pixmap = m_notePixmapFactory->makeKeyPixmap
-		(key, currentClef, cancelKey);
- 
 	} else if (elt->event()->isa(Rosegarden::Text::EventType)) {
 
 	    policy = MoveBackToFit;
@@ -992,14 +882,6 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 		!m_notationView->areAnnotationsVisible()) {
 
 		// nothing I guess
-		 
-            } else if (elt->event()->has(Rosegarden::Text::TextTypePropertyName) &&
-		       elt->event()->get<String>
-		       (Rosegarden::Text::TextTypePropertyName) ==
-		       Rosegarden::Text::LilypondDirective &&
-		       !m_notationView->areLilyPondDirectivesVisible()) {
-
-		// nothing here either
 
 	    } else {
 
@@ -1044,14 +926,12 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 
 		int length, y1;
 
-		if ((indicationType == Indication::Slur ||
-		     indicationType == Indication::PhrasingSlur) &&
+		if (indicationType == Indication::Slur &&
 		    indicationEnd != getViewElementList()->begin()) {
 		    --indicationEnd;
 		}
 
-		if ((indicationType != Indication::Slur &&
-		     indicationType != Indication::PhrasingSlur) &&
+		if (indicationType != Indication::Slur &&
 		    indicationEnd != getViewElementList()->begin() &&
 		    (indicationEnd == getViewElementList()->end() ||
 		     indicationEndTime ==
@@ -1103,8 +983,7 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 			    (length, indicationType == Indication::Crescendo);
 		    }
 		    
-		} else if (indicationType == Indication::Slur ||
-			   indicationType == Indication::PhrasingSlur) {
+		} else if (indicationType == Indication::Slur) {
 		    
 		    bool above = true;
 		    long dy = 0;
@@ -1123,14 +1002,11 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 						   policy);
 			    m_notePixmapFactory->drawSlur
 				(length, dy, above,
-				 indicationType == Indication::PhrasingSlur,
 				 *m_printPainter, int(coords.first), coords.second);
 			    m_printPainter->restore();
 			}
 		    } else {
-			pixmap = m_notePixmapFactory->makeSlurPixmap
-			    (length, dy, above,
-			     indicationType == Indication::PhrasingSlur);
+			pixmap = m_notePixmapFactory->makeSlurPixmap(length, dy, above);
 		    }
 		    
 		} else {
@@ -1167,92 +1043,6 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 		NOTATION_DEBUG << "Bad indication!" << endl;
 	    }
 
-	} else if (elt->event()->isa(Rosegarden::Controller::EventType)) {
-
-	    bool isSustain = false;
-
-	    long controlNumber = 0;
-	    elt->event()->get<Int>(Rosegarden::Controller::NUMBER, controlNumber);
-
-	    Rosegarden::Studio *studio = &m_notationView->getDocument()->getStudio();
-	    Rosegarden::Track *track = getSegment().getComposition()->getTrackById
-		(getSegment().getTrack());
-
-	    if (track) {
-
-		Rosegarden::Instrument *instrument = studio->getInstrumentById
-		    (track->getInstrument());
-		if (instrument) {
-		    Rosegarden::MidiDevice *device = dynamic_cast<Rosegarden::MidiDevice *>
-			(instrument->getDevice());
-		    if (device) {
-			for (Rosegarden::ControlList::const_iterator i =
-				 device->getControlParameters().begin();
-			     i != device->getControlParameters().end(); ++i) {
-			    if (i->getType() == Rosegarden::Controller::EventType &&
-				i->getControllerValue() == controlNumber) {
-				if (i->getName() == "Sustain" ||
-				    strtoqstr(i->getName()) == i18n("Sustain")) {
-				    isSustain = true;
-				}
-				break;
-			    }
-			}
-		    } else if (instrument->getDevice() &&
-			       instrument->getDevice()->getType() == Rosegarden::Device::SoftSynth) {
-			if (controlNumber == 64) {
-			    isSustain = true;
-			}
-		    }
-		}
-	    }
-
-	    if (isSustain) {
-		long value = 0;
-		elt->event()->get<Int>(Rosegarden::Controller::VALUE, value);
-		if (value > 0) {
-		    pixmap = m_notePixmapFactory->makePedalDownPixmap();
-		} else {
-		    pixmap = m_notePixmapFactory->makePedalUpPixmap();
-		}
-
-	    } else {
-
-		if (m_showUnknowns) {
-		    pixmap = m_notePixmapFactory->makeUnknownPixmap();
-		}
-	    }		
-	} else if (elt->event()->isa(Guitar::Fingering::EventType)) {
-		// Create a fretboard pixmap
-		try {
-
-		    Guitar::Fingering arrangement (*elt->event());
-
-/* UNUSED - for printing, just use a large pixmap as below
-		    if (m_printPainter) {
-
-			int length = m_notePixmapFactory->getTextWidth(text);
-			for (double w = -1, inc = 0; w != 0; inc += w) {
-			    w = setPainterClipping(m_printPainter,
-						   elt->getLayoutX(),
-						   int(elt->getLayoutY()),
-						   int(inc), length, coords,
-						   policy);
-			    m_notePixmapFactory->drawText
-				(text, *m_printPainter, int(coords.first), coords.second);
-			    m_printPainter->restore();
-			}
-		    } else {
-			*/
-
-		    pixmap = m_notePixmapFactory->makeFretboardPixmap (arrangement,
-			     int(coords.first),
-                             coords.second);
-//		    }
-		} catch (Rosegarden::Exception e) { // Text ctor failed
-		    NOTATION_DEBUG << "Bad fretboard event" << endl;
-		}
-    
 	} else {
 
 	    if (m_showUnknowns) {
@@ -1281,9 +1071,6 @@ NotationStaff::renderSingleElement(Rosegarden::ViewElementList::iterator &vli,
 		  << std::endl;
 	elt->event()->dump(std::cerr);
     }
-
-    m_notePixmapFactory->setSelected(false);
-    m_notePixmapFactory->setShaded(false);
 }
 
 double
@@ -1430,7 +1217,7 @@ NotationStaff::renderNote(Rosegarden::ViewElementList::iterator &vli)
 {
     NotationElement* elt = static_cast<NotationElement*>(*vli);
 
-    const NotationProperties &properties(getProperties());
+    const NotationProperties &properties(m_notationView->getProperties());
     static NotePixmapParameters params(Note::Crotchet, 0);
 
     Note::Type note = elt->event()->get<Int>(NOTE_TYPE);
@@ -1485,22 +1272,6 @@ NotationStaff::renderNote(Rosegarden::ViewElementList::iterator &vli)
     }
     params.setQuantized(quantized);
 
-    bool trigger = false;
-    if (elt->event()->has(TRIGGER_SEGMENT_ID)) trigger = true;
-    params.setTrigger(trigger);
-
-    bool inRange = true;
-    Rosegarden::Pitch p(*elt->event()); 
-    Rosegarden::Segment *segment = &getSegment();
-    if (m_showRanges) {
-	int pitch = p.getPerformancePitch();
-	if (pitch > segment->getHighestPlayable() ||
-	    pitch < segment->getLowestPlayable()) {
-	    inRange = false;
-	}
-    }
-    params.setInRange(inRange);
-
     params.setNoteType(note);
     params.setDots(dots);
     params.setAccidental(accidental);
@@ -1557,10 +1328,6 @@ NotationStaff::renderNote(Rosegarden::ViewElementList::iterator &vli)
     params.setAccidentalShift(accidentalShift);
     params.setAccExtraShift(accidentalExtra);
 
-    double airX, airWidth;
-    elt->getLayoutAirspace(airX, airWidth);
-    params.setWidth(int(airWidth));
-
     if (beamed) {
 
         if (elt->event()->get<Bool>(properties.CHORD_PRIMARY_NOTE, primary)
@@ -1612,7 +1379,6 @@ NotationStaff::renderNote(Rosegarden::ViewElementList::iterator &vli)
     if (elt->isGrace()) {
 	params.setLegerLines(0);
 	m_graceNotePixmapFactory->setSelected(m_notePixmapFactory->isSelected());
-	m_graceNotePixmapFactory->setShaded(m_notePixmapFactory->isShaded());
 	factory = m_graceNotePixmapFactory;
     }
 
@@ -1661,7 +1427,7 @@ void
 NotationStaff::setTuplingParameters(NotationElement *elt,
 				    NotePixmapParameters &params)
 {
-    const NotationProperties &properties(getProperties());
+    const NotationProperties &properties(m_notationView->getProperties());
 
     params.setTupletCount(0);
     long tuplingLineY = 0;
@@ -1675,8 +1441,8 @@ NotationStaff::setTuplingParameters(NotationElement *elt,
 	}
 
 	long tuplingLineGradient = 0;
-	if (!(elt->event()->get<Int>(properties.TUPLING_LINE_GRADIENT,
-	      tuplingLineGradient))) {
+	if (!(elt->event()->get<Int>(properties.TUPLING_LINE_GRADIENT),
+	      tuplingLineGradient)) {
 	    std::cerr << "WARNING: Tupled event at " << elt->event()->getAbsoluteTime() << " has no tupling line gradient" << std::endl;
 	}
 
@@ -1750,8 +1516,6 @@ NotationStaff::wrapEvent(Rosegarden::Event *e)
 {
     bool wrap = true;
 
-/*!!! always wrap unknowns, just don't necessarily render them?
-
     if (!m_showUnknowns) {
 	std::string etype = e->getType();
 	if (etype != Rosegarden::Note::EventType &&
@@ -1763,7 +1527,6 @@ NotationStaff::wrapEvent(Rosegarden::Event *e)
 	    wrap = false;
 	}
     }
-*/
 
     if (wrap) wrap = Rosegarden::Staff::wrapEvent(e);
 
@@ -1953,141 +1716,3 @@ NotationStaff::doRenderWork(timeT from, timeT to)
 
     return false;
 }
-
-LinedStaff::BarStyle
-NotationStaff::getBarStyle(int barNo) const
-{
-    const Rosegarden::Segment *s = &getSegment();
-    Rosegarden::Composition *c = s->getComposition();
-
-    int firstBar = c->getBarNumber(s->getStartTime());
-    int lastNonEmptyBar = c->getBarNumber(s->getEndMarkerTime() - 1);
-
-    // Currently only the first and last bar in a segment have any
-    // possibility of getting special treatment:
-    if (barNo > firstBar && barNo <= lastNonEmptyBar) return PlainBar;
-
-    // First and last bar in a repeating segment get repeat bars.
-    
-    if (s->isRepeating()) {
-	if (barNo == firstBar) return RepeatStartBar;
-	else if (barNo == lastNonEmptyBar + 1) return RepeatEndBar;
-    }
-
-    if (barNo <= lastNonEmptyBar) return PlainBar;
-
-    // Last bar on a given track gets heavy double bars.  Exploit the
-    // fact that Composition's iterator returns segments in track
-    // order.
-
-    Rosegarden::Segment *lastSegmentOnTrack = 0;
-    
-    for (Rosegarden::Composition::iterator i = c->begin(); i != c->end(); ++i) {
-	if ((*i)->getTrack() == s->getTrack()) {
-	    lastSegmentOnTrack = *i;
-	} else if (lastSegmentOnTrack != 0) {
-	    break;
-	}
-    }
-
-    if (&getSegment() == lastSegmentOnTrack) return HeavyDoubleBar;
-    else return PlainBar;
-}
-
-double
-NotationStaff::getBarInset(int barNo, bool isFirstBarInRow) const
-{
-    LinedStaff::BarStyle style = getBarStyle(barNo);
-
-    NOTATION_DEBUG << "getBarInset(" << barNo << "," << isFirstBarInRow << ")" << endl;
-
-    if (!(style == RepeatStartBar || style == RepeatBothBar)) return 0.0;
-
-    const Rosegarden::Segment &s = getSegment();
-    Rosegarden::Composition *composition = s.getComposition();
-    timeT barStart = composition->getBarStart(barNo);
-
-    double inset = 0.0;
-
-    NOTATION_DEBUG << "ready" << endl;
-
-    bool haveKey = false, haveClef = false;
-    
-    Rosegarden::Key key;
-    Rosegarden::Key cancelKey;
-    Rosegarden::Clef clef;
-
-    for (Rosegarden::Segment::iterator i = s.findTime(barStart);
-	 s.isBeforeEndMarker(i) && ((*i)->getNotationAbsoluteTime() == barStart);
-	 ++i) {
-
-	NOTATION_DEBUG << "type " << (*i)->getType() << " at " << (*i)->getNotationAbsoluteTime() << endl;
-
-	if ((*i)->isa(Rosegarden::Key::EventType)) {
-
-	    try {
-		key = Rosegarden::Key(**i);
-
-		if (barNo > composition->getBarNumber(s.getStartTime())) {
-		    cancelKey = s.getKeyAtTime(barStart - 1);
-		}
-		
-		if (m_keySigCancelMode == 0) { // only when entering C maj / A min
-		    
-		    if (key.getAccidentalCount() != 0) cancelKey = Rosegarden::Key();
-		    
-		} else if (m_keySigCancelMode == 1) { // only when reducing acc count
-		    
-		    if (!(key.isSharp() == cancelKey.isSharp() &&
-			  key.getAccidentalCount() < cancelKey.getAccidentalCount())) {
-			cancelKey = Rosegarden::Key();
-		    }
-		}
-		
-		haveKey = true;
-
-	    } catch (...) {
-		NOTATION_DEBUG << "getBarInset: Bad key in event" << endl;
-	    }
-
-	} else if ((*i)->isa(Rosegarden::Clef::EventType)) {
-
-	    try {
-		clef = Rosegarden::Clef(**i);
-		haveClef = true;
-	    } catch (...) {
-		NOTATION_DEBUG << "getBarInset: Bad clef in event" << endl;
-	    }
-	}
-    }
-
-    if (isFirstBarInRow) {
-	if (!haveKey) {
-	    key = s.getKeyAtTime(barStart);
-	    haveKey = true;
-	}
-	if (!haveClef) {
-	    clef = s.getClefAtTime(barStart);
-	    haveClef = true;
-	}
-    }
-
-    if (haveKey) {
-	inset += m_notePixmapFactory->getKeyWidth(key, cancelKey);
-    }
-    if (haveClef) {
-	inset += m_notePixmapFactory->getClefWidth(clef);
-    }
-    if (haveClef || haveKey) {
-	inset += m_notePixmapFactory->getBarMargin() / 3;
-    }
-    if (haveClef && haveKey) {
-	inset += m_notePixmapFactory->getNoteBodyWidth() / 2;
-    }
-
-    NOTATION_DEBUG << "getBarInset(" << barNo << "," << isFirstBarInRow << "): inset " << inset << endl;
-
-
-    return inset;
-}
-
