@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,7 +23,6 @@
 #define NOTATION_STAFF_H
 
 #include <string>
-#include <map>
 
 #include "notepixmapfactory.h"
 #include "notationelement.h"
@@ -204,16 +203,6 @@ public:
      * Delete all time signatures
      */
     virtual void deleteTimeSignatures();
-    
-    /**
-     * Insert repeated clef and key at start of new line, at x-coordinate \a x.
-     */
-    virtual void insertRepeatedClefAndKey(double layoutX, int barNo);
-
-    /**
-     * Delete all repeated clefs and keys.
-     */
-    virtual void deleteRepeatedClefsAndKeys();
 
     /**
      * (Re)draw the staff name from the track's current name
@@ -243,6 +232,25 @@ public:
      Rosegarden::Accidental accidental =
      Rosegarden::Accidentals::NoAccidental) const;
 
+    /**
+     * Find the NotationElement whose canvas coords are closest to
+     * (x,y).
+     *
+     * If notesAndRestsOnly is true, will return the closest note
+     * or rest but will never return any other kind of element.
+     * 
+     * If the closest event is further than \a proximityThreshold
+     * horizontally away from (x,y), in pixels, end() is returned.
+     * (If proximityThreshold is negative, there will be no limit
+     * to the distances that will be considered.)
+     *
+     * Also returns the clef and key in force at the given coordinates.
+     */
+    virtual NotationElementList::iterator getClosestElementToCanvasCoords
+    (double x, int y, Rosegarden::Event *&clef, Rosegarden::Event *&key,
+     bool notesAndRestsOnly = false,
+     int proximityThreshold = 10);
+
     /**
      * Find the NotationElement whose layout x-coord is closest to x,
      * without regard to its y-coord.
@@ -257,18 +265,26 @@ public:
      *
      * Also returns the clef and key in force at the given coordinate.
      */
-    virtual Rosegarden::ViewElementList::iterator getClosestElementToLayoutX
+    virtual NotationElementList::iterator getClosestElementToLayoutX
     (double x, Rosegarden::Event *&clef, Rosegarden::Event *&key,
      bool notesAndRestsOnly = false,
      int proximityThreshold = 10);
 
+    /**
+     * Find the NotationElement "under" the canvas coords (x,y).
+     *
+     * Also returns the clef and key in force at the given coordinates.
+     */
+    virtual NotationElementList::iterator getElementUnderCanvasCoords
+    (double x, int y, Rosegarden::Event *&clef, Rosegarden::Event *&key);
+
     /**
      * Find the NotationElement "under" the given layout x-coord,
      * without regard to its y-coord.
      *
      * Also returns the clef and key in force at the given coordinates.
      */
-    virtual Rosegarden::ViewElementList::iterator getElementUnderLayoutX
+    virtual NotationElementList::iterator getElementUnderLayoutX
     (double x, Rosegarden::Event *&clef, Rosegarden::Event *&key);
 
     /**
@@ -296,13 +312,6 @@ public:
      */
     virtual void eventRemoved(const Rosegarden::Segment *, Rosegarden::Event *);
 
-    /**
-     * Return the view-local PropertyName definitions for this staff's view
-     */
-    const NotationProperties &getProperties() const;
-
-    virtual double getBarInset(int barNo, bool isFirstBarInRow) const;
-
 protected:
 
     virtual Rosegarden::ViewElement* makeViewElement(Rosegarden::Event*);
@@ -314,8 +323,6 @@ protected:
     virtual int getHeightPerLine() const     { return 2; }
     virtual int showBarNumbersEvery() const  { return m_barNumbersEvery; }
 
-    virtual BarStyle getBarStyle(int barNo) const;
-
     /** 
      * Assign a suitable sprite to the given element (the clef is
      * needed in case it's a key event, in which case we need to judge
@@ -409,9 +416,6 @@ protected:
     typedef std::set<QCanvasSimpleSprite *> SpriteSet;
     SpriteSet m_timeSigs;
 
-    typedef std::set<QCanvasItem *> ItemSet;
-    ItemSet m_repeatedClefsAndKeys;
-
     typedef std::pair<int, Rosegarden::Clef> ClefChange;
     FastVector<ClefChange> m_clefChanges;
 
@@ -430,13 +434,11 @@ protected:
     int m_barNumbersEvery;
     bool m_colourQuantize;
     bool m_showUnknowns;
-    bool m_showRanges;
-    int m_keySigCancelMode;
 
     QPainter *m_printPainter;
 
     enum BarStatus { UnRendered = 0, Rendered, Positioned };
-    typedef std::map<int, BarStatus> BarStatusMap;
+    typedef __HASH_NS::hash_map<int, BarStatus> BarStatusMap;
     BarStatusMap m_status;
     std::pair<int, int> m_lastRenderCheck;
     bool m_ready;
