@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -53,6 +53,7 @@
 #include "colours.h"
 
 using Rosegarden::Accidental;
+using Rosegarden::Accidentals;
 using Rosegarden::Event;
 using Rosegarden::EventSelection;
 using Rosegarden::Clef;
@@ -109,14 +110,6 @@ EditTool* NotationToolBox::createTool(const QString& toolName)
 
         tool = new TextInserter(m_nParentView);
 
-    else if (toolNamelc == FretboardInserter::ToolName)
-
-        tool = new FretboardInserter(m_nParentView);
-
-/*    else if (toolNamelc == LilypondDirectiveInserter::ToolName)
-
-        tool = new LilypondDirectiveInserter(m_nParentView);*/
-
     else if (toolNamelc == NotationEraser::ToolName)
 
         tool = new NotationEraser(m_nParentView);
@@ -171,9 +164,7 @@ NoteInserter::NoteInserter(NotationView* view)
       m_noteType(Rosegarden::Note::Quaver),
       m_noteDots(0),
       m_autoBeam(true),
-      m_accidental(Rosegarden::Accidentals::NoAccidental),
-      m_lastAccidental(Rosegarden::Accidentals::NoAccidental),
-      m_followAccidental(false)
+      m_accidental(Accidentals::NoAccidental)
 {
     QIconSet icon;
 
@@ -229,8 +220,8 @@ NoteInserter::NoteInserter(NotationView* view)
 
     createMenu("noteinserter.rc");
 
-    connect(m_parentView, SIGNAL(changeAccidental(Rosegarden::Accidental, bool)),
-            this,         SLOT(slotSetAccidental(Rosegarden::Accidental, bool)));
+    connect(m_parentView, SIGNAL(changeAccidental(Rosegarden::Accidental)),
+            this,         SLOT(slotSetAccidental(Rosegarden::Accidental)));
 }
 
 NoteInserter::NoteInserter(const QString& menuName, NotationView* view)
@@ -239,12 +230,10 @@ NoteInserter::NoteInserter(const QString& menuName, NotationView* view)
       m_noteDots(0),
       m_autoBeam(false),
       m_clickHappened(false),
-      m_accidental(Rosegarden::Accidentals::NoAccidental),
-      m_lastAccidental(Rosegarden::Accidentals::NoAccidental),
-      m_followAccidental(false)
+      m_accidental(Accidentals::NoAccidental)
 {
-    connect(m_parentView, SIGNAL(changeAccidental(Rosegarden::Accidental, bool)),
-            this,         SLOT(slotSetAccidental(Rosegarden::Accidental, bool)));
+    connect(m_parentView, SIGNAL(changeAccidental(Rosegarden::Accidental)),
+            this,         SLOT(slotSetAccidental(Rosegarden::Accidental)));
 }
 
 NoteInserter::~NoteInserter()
@@ -277,11 +266,9 @@ NoteInserter::handleMouseMove(Rosegarden::timeT,
 			      int,
 			      QMouseEvent *e)
 {
-    if (m_clickHappened) {
-        computeLocationAndPreview(e);
-    }
-    
-    return RosegardenCanvasView::NoFollow;
+    if (!m_clickHappened) return NoFollow;
+    computeLocationAndPreview(e);
+    return NoFollow;
 }
 
 
@@ -309,10 +296,7 @@ NoteInserter::handleMouseRelease(Rosegarden::timeT,
     }
 
     Event *lastInsertedEvent = doAddCommand
-	(segment, m_clickTime, endTime, note, m_clickPitch,
-	 (m_accidental == Rosegarden::Accidentals::NoAccidental &&
-	  m_followAccidental) ?
-	    m_lastAccidental : m_accidental);
+	(segment, m_clickTime, endTime, note, m_clickPitch, m_accidental);
 
     if (lastInsertedEvent) {
 
@@ -376,7 +360,8 @@ NoteInserter::computeLocationAndPreview(QMouseEvent *e)
     double x = e->x();
     int y = (int)e->y();
 
-    LinedStaff *staff = m_nParentView->getStaffForCanvasCoords(e->x(), y);
+    NotationStaff *staff = dynamic_cast<NotationStaff *>
+	(m_nParentView->getStaffForCanvasCoords(e->x(), y));
     if (!staff) {
 	clearPreview();
 	return false;
@@ -416,35 +401,6 @@ NoteInserter::computeLocationAndPreview(QMouseEvent *e)
     Rosegarden::Pitch p(height, clef, key, m_accidental);
     int pitch = p.getPerformancePitch();
 
-    // [RFE 987960] When inserting via mouse, if no accidental is
-    // selected, we use the same accidental (and thus the same pitch)
-    // as of the previous note found at this height -- iff such a note
-    // is found more recently than the last key signature.
-
-    if (m_accidental == Rosegarden::Accidentals::NoAccidental &&
-	m_followAccidental) {
-	Rosegarden::Segment &segment = staff->getSegment();
-	m_lastAccidental = m_accidental;
-	Segment::iterator i = segment.findNearestTime(time);
-	while (i != segment.end()) {
-	    if ((*i)->isa(Rosegarden::Key::EventType)) break;
-	    if ((*i)->isa(Rosegarden::Note::EventType)) {
-		if ((*i)->has(NotationProperties::HEIGHT_ON_STAFF) &&
-		    (*i)->has(Rosegarden::BaseProperties::PITCH)) {
-		    int h = (*i)->get<Int>(NotationProperties::HEIGHT_ON_STAFF);
-		    if (h == height) {
-			pitch = (*i)->get<Int>(Rosegarden::BaseProperties::PITCH);
-			(*i)->get<String>(Rosegarden::BaseProperties::ACCIDENTAL,
-					  m_lastAccidental);
-			break;
-		    }
-		}
-	    }
-	    if (i == segment.begin()) break;
-	    --i;
-	}
-    }
-
     bool changed = false;
 
     if (m_clickHappened) {
@@ -499,9 +455,8 @@ NoteInserter::getOffsetWithinRest(int staffNo,
     // do that, we just haven't yet
     if (m_nParentView->isInTripletMode()) return 0;
 
-    Rosegarden::Staff *staff = m_nParentView->getStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     NotationElement* el = static_cast<NotationElement*>(*i);
-    if (!el->getCanvasItem()) return 0;
     double offset = canvasX - el->getCanvasX();
 
     if (offset < 0) return 0;
@@ -576,16 +531,9 @@ Event *
 NoteInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
 			   const Note &note, int pitch, Accidental accidental)
 {
-    timeT noteEnd = time + note.getDuration();
-
-    // #1046934: make it possible to insert triplet at end of segment!
-    if (m_nParentView->isInTripletMode()) {
-	noteEnd = time + (note.getDuration() * 2 / 3);
-    }
-
     if (time < segment.getStartTime() ||
 	endTime > segment.getEndMarkerTime() ||
-	noteEnd > segment.getEndMarkerTime()) {
+	time + note.getDuration() > segment.getEndMarkerTime()) {
 	return 0;
     }
 
@@ -606,24 +554,8 @@ NoteInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
 	    !(*i)->has(BEAMED_GROUP_TUPLET_BASE)) {
 
 	    KMacroCommand *command = new KMacroCommand(insertionCommand->name());
-
-	    //## Attempted fix to bug reported on rg-user by SlowPic
-	    //## <slowpic@web.de> 28/02/2005 22:32:56 UTC: Triplet input error
-	    //# HJJ: Comment out this attempt. It breaks the splitting of 
-	    //#      the first bars into rests.
-	    //## if ((*i)->isa(Rosegarden::Note::EventRestType) &&
-		//## (*i)->getNotationDuration() > (note.getDuration() * 3)) {
-	    // split the rest
-	    command->addCommand(new RestInsertionCommand
-				(segment, time,
-				time + note.getDuration() * 2,
-				Note::getNearestNote(note.getDuration() * 2)));
-	    //## }
-	    //# These comments should probably be deleted.
-
-	    command->addCommand(new AdjustMenuTupletCommand
-				(segment, time, note.getDuration(),
-				 3, 2, true)); // #1046934: "has timing already"
+	    command->addCommand(new GroupMenuTupletCommand
+				(segment, time, note.getDuration()));
 	    command->addCommand(insertionCommand);
 	    activeCommand = command;
 	}
@@ -651,13 +583,34 @@ void NoteInserter::slotSetDots(unsigned int dots)
     if (dotsAction) dotsAction->setChecked(dots > 0);
 }
 
-void NoteInserter::slotSetAccidental(Rosegarden::Accidental accidental,
-				     bool follow)
+void NoteInserter::slotSetAccidental(Rosegarden::Accidental accidental)
 {
     NOTATION_DEBUG << "NoteInserter::setAccidental: accidental is "
 			 << accidental << endl;
     m_accidental = accidental;
-    m_followAccidental = follow;
+}
+
+void NoteInserter::slotSetAccidentalSync(Rosegarden::Accidental accidental)
+{
+    NOTATION_DEBUG << "NoteInserter::setAccidentalSync: accidental is "
+			 << accidental << endl;
+    slotSetAccidental(accidental);
+
+    int i;
+    for (i = 0; i < 6; ++i) {
+	if (accidental == m_actionsAccidental[i][4]) break;
+    }
+    if (i == 6) return;
+
+    // Get the parent view toolbar in sync - check the corresponding action
+    KAction* action = actionCollection()->action(m_actionsAccidental[i][2]);
+
+    KToggleAction* tAction = 0;
+    
+    if ((tAction = dynamic_cast<KToggleAction*>(action)))
+        tAction->setChecked(true);
+    else
+        KMessageBox::error(0, "NoteInserter::setAccidentalSync : couldn't find action");
 }
 
 void NoteInserter::slotNoAccidental()
@@ -665,11 +618,6 @@ void NoteInserter::slotNoAccidental()
     m_parentView->actionCollection()->action("no_accidental")->activate();
 }
 
-void NoteInserter::slotFollowAccidental()
-{
-    m_parentView->actionCollection()->action("follow_accidental")->activate();
-}
-
 void NoteInserter::slotSharp()
 {
     m_parentView->actionCollection()->action("sharp_accidental")->activate();
@@ -737,22 +685,20 @@ void NoteInserter::slotRestsSelected()
     }
 }
 
-const char* NoteInserter::m_actionsAccidental[][4] = 
+const char* NoteInserter::m_actionsAccidental[][5] = 
     {
         { "No accidental",  "1slotNoAccidental()",  "no_accidental",
-          "accidental-none" },
-        { "Follow accidental",  "1slotFollowAccidental()",  "follow_accidental",
-          "accidental-follow" },
+          "accidental-none", Accidentals::NoAccidental.c_str() },
         { "Sharp",          "1slotSharp()",         "sharp_accidental",
-          "accidental-sharp" },
+          "accidental-sharp", Accidentals::Sharp.c_str() },
         { "Flat",           "1slotFlat()",          "flat_accidental",
-          "accidental-flat" },
+          "accidental-flat", Accidentals::Flat.c_str() },
         { "Natural",        "1slotNatural()",       "natural_accidental",
-          "accidental-natural" },
+          "accidental-natural", Accidentals::Natural.c_str() },
         { "Double sharp",   "1slotDoubleSharp()",   "double_sharp_accidental",
-          "accidental-doublesharp" },
+          "accidental-doublesharp", Accidentals::DoubleSharp.c_str() },
         { "Double flat",    "1slotDoubleFlat()",    "double_flat_accidental",
-          "accidental-doubleflat" }
+          "accidental-doubleflat", Accidentals::DoubleFlat.c_str() }
     };
 
 //------------------------------
@@ -816,7 +762,7 @@ RestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
 	    !(*i)->has(BEAMED_GROUP_TUPLET_BASE)) {
 
 	    KMacroCommand *command = new KMacroCommand(insertionCommand->name());
-	    command->addCommand(new AdjustMenuTupletCommand
+	    command->addCommand(new GroupMenuTupletCommand
 				(segment, time, note.getDuration()));
 	    command->addCommand(insertionCommand);
 	    activeCommand = command;
@@ -912,7 +858,7 @@ void ClefInserter::handleLeftButtonPress(Rosegarden::timeT,
     if (staffNo < 0) return;
     Event *clef = 0, *key = 0;
 
-    LinedStaff *staff = m_nParentView->getLinedStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     
     NotationElementList::iterator closestElement =
 	staff->getClosestElementToCanvasCoords(e->x(), (int)e->y(),
@@ -986,7 +932,7 @@ void TextInserter::handleLeftButtonPress(Rosegarden::timeT,
 					 ViewElement *element)
 {
     if (staffNo < 0) return;
-    LinedStaff *staff = m_nParentView->getLinedStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     
     Rosegarden::Text defaultText(m_text);
     timeT insertionTime;
@@ -1145,45 +1091,6 @@ NotationSelector::NotationSelector(NotationView* view)
                 SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
-// (this crashed, and it might be superfluous with ^N anyway, so I'm
-// commenting it out, but leaving it here in case I change my mind about
-// fooling with it.)  (DMM)
-//    new KAction(i18n("Normalize Rests"), 0, 0, this,
-//		SLOT(slotCollapseRests()), actionCollection(),
-//		"collapse_rests"); 
-
-    new KAction(i18n("Collapse Rests"), 0, 0, this,
-		SLOT(slotCollapseRestsHard()), actionCollection(),
-		"collapse_rests_aggressively"); 
-
-    new KAction(i18n("Respell as Flat"), 0, 0, this,
-		SLOT(slotRespellFlat()), actionCollection(),
-		"respell_flat"); 
-
-    new KAction(i18n("Respell as Sharp"), 0, 0, this,
-		SLOT(slotRespellSharp()), actionCollection(),
-		"respell_sharp"); 
-
-    new KAction(i18n("Respell as Natural"), 0, 0, this,
-		SLOT(slotRespellNatural()), actionCollection(),
-		"respell_natural"); 
-
-    new KAction(i18n("Collapse Notes"), 0, 0, this,
-		SLOT(slotCollapseNotes()), actionCollection(),
-		"collapse_notes"); 
-
-    new KAction(i18n("Interpret"), 0, 0, this,
-		SLOT(slotInterpret()), actionCollection(),
-		"interpret"); 
-
-    new KAction(i18n("Make Invisible"), 0, 0, this,
-		SLOT(slotMakeInvisible()), actionCollection(),
-		"make_invisible"); 
-
-    new KAction(i18n("Make Visible"), 0, 0, this,
-		SLOT(slotMakeVisible()), actionCollection(),
-		"make_visible"); 
-
     createMenu("notationselector.rc");
 }
 
@@ -1211,10 +1118,7 @@ void NotationSelector::handleLeftButtonPress(Rosegarden::timeT t,
     delete m_selectionToMerge;
     const EventSelection *selectionToMerge = 0;
     if (e->state() & ShiftButton) {
-	m_clickedShift = true;
 	selectionToMerge = m_nParentView->getCurrentSelection();
-    } else {
-	m_clickedShift = false;
     }
     m_selectionToMerge =
 	(selectionToMerge ? new EventSelection(*selectionToMerge) : 0);
@@ -1234,7 +1138,6 @@ void NotationSelector::handleLeftButtonPress(Rosegarden::timeT t,
 
     m_selectionRect->show();
     m_updateRect = true;
-    m_startedFineDrag = false;
 
     //m_parentView->setCursorPosition(p.x());
 }
@@ -1253,7 +1156,7 @@ void NotationSelector::handleMouseDoubleClick(Rosegarden::timeT,
     NOTATION_DEBUG << "NotationSelector::handleMouseDoubleClick" << endl;
     m_clickedElement = dynamic_cast<NotationElement*>(element);
     
-    NotationStaff *staff = m_nParentView->getNotationStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     if (!staff) return;
     m_selectedStaff = staff;
 
@@ -1281,8 +1184,6 @@ void NotationSelector::handleMouseDoubleClick(Rosegarden::timeT,
 
     return;
 }
-
-
 void NotationSelector::handleMouseTripleClick(Rosegarden::timeT t,
 					      int height,
 					      int staffNo,
@@ -1295,7 +1196,7 @@ void NotationSelector::handleMouseTripleClick(Rosegarden::timeT t,
     NOTATION_DEBUG << "NotationSelector::handleMouseTripleClick" << endl;
     m_clickedElement = dynamic_cast<NotationElement*>(element);
     
-    NotationStaff *staff = m_nParentView->getNotationStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     if (!staff) return;
     m_selectedStaff = staff;
 
@@ -1324,20 +1225,14 @@ void NotationSelector::handleMouseTripleClick(Rosegarden::timeT t,
 int NotationSelector::handleMouseMove(timeT, int,
 				      QMouseEvent* e)
 {
-    if (!m_updateRect) return RosegardenCanvasView::NoFollow;
+    if (!m_updateRect) return NoFollow;
 
     int w = int(e->x() - m_selectionRect->x());
     int h = int(e->y() - m_selectionRect->y());
 
-    if (m_clickedElement /* && !m_clickedElement->isRest() */) {
+    if (m_clickedElement && !m_clickedElement->isRest()) {
 
-	if (m_startedFineDrag) {
-	    dragFine(e->x(), e->y(), false);
-	} else if (m_clickedShift) {
-	    if (w > 2 || w < -2 || h > 2 || h < -2) {
-		dragFine(e->x(), e->y(), false);
-	    }
-	} else if (w > 3 || w < -3 || h > 3 || h < -3) {
+	if (w > 3 || w < -3 || h > 3 || h < -3) {
 	    drag(e->x(), e->y(), false);
 	}
 
@@ -1352,7 +1247,7 @@ int NotationSelector::handleMouseMove(timeT, int,
 	m_nParentView->canvas()->update();
     }
 
-    return RosegardenCanvasView::FollowHorizontal | RosegardenCanvasView::FollowVertical;
+    return FollowHorizontal | FollowVertical;
 }
 
 void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
@@ -1367,11 +1262,10 @@ void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
     // how big the rectangle is (if we were dragging an event, the
     // rectangle size will still be zero).
     
-    if (((e->x() - m_selectionRect->x()) > -3 &&
-	 (e->x() - m_selectionRect->x()) <  3 &&
-	 (e->y() - m_selectionRect->y()) > -3 &&
-	 (e->y() - m_selectionRect->y()) <  3) &&
-	!m_startedFineDrag) {
+    if ((e->x() - m_selectionRect->x()) > -3 &&
+        (e->x() - m_selectionRect->x()) <  3 &&
+        (e->y() - m_selectionRect->y()) > -3 &&
+        (e->y() - m_selectionRect->y()) <  3) {
 
 	if (m_clickedElement != 0 && m_selectedStaff) {
 		
@@ -1411,9 +1305,7 @@ void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
 
     } else {
 
-	if (m_startedFineDrag) {
-	    dragFine(e->x(), e->y(), true);
-	} else if (m_clickedElement /* && !m_clickedElement->isRest() */) {
+	if (m_clickedElement && !m_clickedElement->isRest()) {
 	    drag(e->x(), e->y(), true);
 	} else {
 	    setViewCurrentSelection(false);
@@ -1433,29 +1325,25 @@ void NotationSelector::drag(int x, int y, bool final)
     if (!m_clickedElement || !m_selectedStaff) return;
 
     EventSelection *selection = m_nParentView->getCurrentSelection();
-    if (!selection || !selection->contains(m_clickedElement->event())) {
-	selection = new EventSelection(m_selectedStaff->getSegment());
-	selection->addEvent(m_clickedElement->event());
-    }
+    if (!selection) selection = new EventSelection(m_selectedStaff->getSegment());
+    if (!selection->contains(m_clickedElement->event()))
+	 selection->addEvent(m_clickedElement->event());
     m_nParentView->setCurrentSelection(selection);
 
-    LinedStaff *targetStaff = m_nParentView->getStaffForCanvasCoords(x, y);
+    NotationStaff *targetStaff = dynamic_cast<NotationStaff *>
+	(m_nParentView->getStaffForCanvasCoords(x, y));
     if (!targetStaff) targetStaff = m_selectedStaff;
 
     // Calculate time and height
     
     timeT clickedTime = m_clickedElement->event()->getNotationAbsoluteTime();
 
-    Accidental clickedAccidental = Rosegarden::Accidentals::NoAccidental;
+    Accidental clickedAccidental = Accidentals::NoAccidental;
     (void)m_clickedElement->event()->get<String>(ACCIDENTAL, clickedAccidental);
 
     long clickedPitch = 0;
     (void)m_clickedElement->event()->get<Rosegarden::Int>(PITCH, clickedPitch);
 
-    long clickedHeight = 0;
-    (void)m_clickedElement->event()->get<Rosegarden::Int>
-	(NotationProperties::HEIGHT_ON_STAFF, clickedHeight);
-
     Event *clefEvt = 0, *keyEvt = 0;
     Rosegarden::Clef clef;
     Rosegarden::Key key;
@@ -1467,13 +1355,13 @@ void NotationSelector::drag(int x, int y, bool final)
     NotationElementList::iterator itr =
 	targetStaff->getElementUnderCanvasCoords(x, y, clefEvt, keyEvt);
 
-    if (itr != targetStaff->getViewElementList()->end()) {
+    if (itr != targetStaff /* m_selectedStaff */ ->getViewElementList()->end()) {
 
 	NotationElement *elt = dynamic_cast<NotationElement *>(*itr);
 	dragTime = elt->getViewAbsoluteTime();
 	layoutX  = elt->getLayoutX();
 
-	if (elt->isRest() && duration > 0 && elt->getCanvasItem()) {
+	if (elt->isRest() && duration > 0) {
 
 	    double restX = 0, restWidth = 0;
 	    elt->getCanvasAirspace(restX, restWidth);
@@ -1500,12 +1388,8 @@ void NotationSelector::drag(int x, int y, bool final)
     if (keyEvt) key = Rosegarden::Key(*keyEvt);
     
     int height = targetStaff->getHeightAtCanvasCoords(x, y);
-    int pitch = clickedPitch;
-
-    if (height != clickedHeight)
-	pitch = 
-	    Rosegarden::Pitch
-	    (height, clef, key, clickedAccidental).getPerformancePitch();
+    int pitch = Rosegarden::Pitch
+	(height, clef, key, clickedAccidental).getPerformancePitch();
 
     if (pitch < clickedPitch) {
 	if (height < -10) {
@@ -1601,104 +1485,12 @@ void NotationSelector::drag(int x, int y, bool final)
     }
 }
 
-void NotationSelector::dragFine(int x, int y, bool final)
-{
-    NOTATION_DEBUG << "NotationSelector::drag " << x << ", " << y << endl;
-
-    if (!m_clickedElement || !m_selectedStaff) return;
-
-    EventSelection *selection = m_nParentView->getCurrentSelection();
-    if (!selection) selection = new EventSelection(m_selectedStaff->getSegment());
-    if (!selection->contains(m_clickedElement->event()))
-	 selection->addEvent(m_clickedElement->event());
-    m_nParentView->setCurrentSelection(selection);
-
-    // Fine drag modifies the DISPLACED_X and DISPLACED_Y properties on
-    // each event.  The modifications have to be relative to the previous
-    // values of these properties, not to zero, so for each event we need
-    // to store the previous value at the time the drag starts.
-
-    static Rosegarden::PropertyName xProperty("temporary-displaced-x");
-    static Rosegarden::PropertyName yProperty("temporary-displaced-y");
-
-    if (!m_startedFineDrag) {
-	// back up original properties
-
-	for (EventSelection::eventcontainer::iterator i =
-		selection->getSegmentEvents().begin();
-	     i != selection->getSegmentEvents().end(); ++i) {
-	    long prevX = 0, prevY = 0;
-	    (*i)->get<Int>(DISPLACED_X, prevX);
-	    (*i)->get<Int>(DISPLACED_Y, prevY);
-	    (*i)->setMaybe<Int>(xProperty, prevX);
-	    (*i)->setMaybe<Int>(yProperty, prevY);
-	}
-
-	m_startedFineDrag = true;
-    }
-
-    // We want the displacements in 1/1000ths of a staff space
-
-    double dx = x - m_selectionRect->x();
-    double dy = y - m_selectionRect->y();
-
-    double noteBodyWidth = m_nParentView->getNotePixmapFactory()->getNoteBodyWidth();
-    double lineSpacing = m_nParentView->getNotePixmapFactory()->getLineSpacing();
-    dx = (1000.0 * dx) / noteBodyWidth;
-    dy = (1000.0 * dy) / lineSpacing;
-
-    if (final) {
-
-	// reset original values (and remove backup values) before
-	// applying command
-
-	for (EventSelection::eventcontainer::iterator i =
-		 selection->getSegmentEvents().begin();
-	     i != selection->getSegmentEvents().end(); ++i) {
-	    long prevX = 0, prevY = 0;
-	    (*i)->get<Int>(xProperty, prevX);
-	    (*i)->get<Int>(yProperty, prevY);
-	    (*i)->setMaybe<Int>(DISPLACED_X, prevX);
-	    (*i)->setMaybe<Int>(DISPLACED_Y, prevY);
-	    (*i)->unset(xProperty);
-	    (*i)->unset(yProperty);
-	}
-
-	IncrementDisplacementsCommand *command = new IncrementDisplacementsCommand
-	    (*selection, long(dx), long(dy));
-	m_nParentView->addCommandToHistory(command);
-
-    } else {
-
-	Rosegarden::timeT startTime = 0, endTime = 0;
-
-	for (EventSelection::eventcontainer::iterator i =
-		 selection->getSegmentEvents().begin();
-	     i != selection->getSegmentEvents().end(); ++i) {
-	    long prevX = 0, prevY = 0;
-	    (*i)->get<Int>(xProperty, prevX);
-	    (*i)->get<Int>(yProperty, prevY);
-	    (*i)->setMaybe<Int>(DISPLACED_X, prevX + long(dx));
-	    (*i)->setMaybe<Int>(DISPLACED_Y, prevY + long(dy));
-	    if (i == selection->getSegmentEvents().begin()) {
-		startTime = (*i)->getAbsoluteTime();
-	    }
-	    endTime = (*i)->getAbsoluteTime() + (*i)->getDuration();
-	}
-	
-	if (startTime == endTime) ++endTime;
-	selection->getSegment().updateRefreshStatuses(startTime, endTime);
-	m_nParentView->update();
-    }
-}
-
-
 void NotationSelector::ready()
 {
     m_selectionRect = new QCanvasRectangle(m_nParentView->canvas());
     
     m_selectionRect->hide();
-    m_selectionRect->setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::SelectionRectangle));
+    m_selectionRect->setPen(RosegardenGUIColours::SelectionRectangle);
 
     m_nParentView->setCanvasCursor(Qt::arrowCursor);
     m_nParentView->setHeightTracking(false);
@@ -1730,52 +1522,6 @@ void NotationSelector::slotEraseSelected()
     m_parentView->actionCollection()->action("erase")->activate();
 }
 
-//void NotationSelector::slotCollapseRests()
-//{
-//    m_parentView->actionCollection()->action("collapse_rests")->activate();
-//}
-
-void NotationSelector::slotCollapseRestsHard()
-{
-    m_parentView->actionCollection()->action("collapse_rests_aggressively")->activate();
-}
-
-void NotationSelector::slotRespellFlat()
-{
-    m_parentView->actionCollection()->action("respell_flat")->activate();
-}
-
-void NotationSelector::slotRespellSharp()
-{
-    m_parentView->actionCollection()->action("respell_sharp")->activate();
-}
-
-void NotationSelector::slotRespellNatural()
-{
-    m_parentView->actionCollection()->action("respell_natural")->activate();
-}
-
-void NotationSelector::slotCollapseNotes()
-{
-    m_parentView->actionCollection()->action("collapse_notes")->activate();
-}
-
-void NotationSelector::slotInterpret()
-{
-    m_parentView->actionCollection()->action("interpret")->activate();
-}
-
-void NotationSelector::slotMakeInvisible()
-{
-    m_parentView->actionCollection()->action("make_invisible")->activate();
-}
-
-void NotationSelector::slotMakeVisible()
-{
-    m_parentView->actionCollection()->action("make_visible")->activate();
-}
-
-
 EventSelection* NotationSelector::getSelection()
 {
     // If selection rect is not visible or too small,
@@ -1791,7 +1537,7 @@ EventSelection* NotationSelector::getSelection()
         m_selectionRect->height() > -3 &&
         m_selectionRect->height() <  3) return 0;
 
-    QCanvasItemList itemList = m_selectionRect->collisions(false);
+    QCanvasItemList itemList = m_selectionRect->collisions(true);
     QCanvasItemList::Iterator it;
 
     QRect rect = m_selectionRect->rect().normalize();
@@ -1799,44 +1545,21 @@ EventSelection* NotationSelector::getSelection()
 
     if (!m_selectedStaff) {
 
-        // Scan the list of collisions, looking for a valid notation
+	// Scan the list of collisions, looking for a valid notation
 	// element; if we find one, initialise m_selectedStaff from it.
 	// If we don't find one, we have no selection.  This is a little
 	// inefficient but we only do it for the first event in the
 	// selection.
-
+	
 	for (it = itemList.begin(); it != itemList.end(); ++it) {
         
 	    if ((sprite = dynamic_cast<QCanvasNotationSprite*>(*it))) {
 
-		NotationElement &el = sprite->getNotationElement();
-
-		NotationStaff *staff = getStaffForElement(&el);
-		if (!staff) continue;
-	    
-		int x = (int)(*it)->x();
-		bool shifted = false;
-		int nbw = staff->getNotePixmapFactory(false).getNoteBodyWidth();
-
-		
-		// #957364 (Notation: Hard to select upper note in
-		// chords of seconds) -- adjust x-coord for shifted
-		// note head
-		if (el.event()->get<Rosegarden::Bool>
-		    (staff->getProperties().NOTE_HEAD_SHIFTED, shifted) && shifted) {
-		    x += nbw;
-		}
-
-		if (!rect.contains(x, int((*it)->y()), true)) {
-		    // #988217 (Notation: Special column of pixels
-		    // prevents sweep selection) -- for notes, test
-		    // again with centred x-coord
-		    if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
-			continue;
-		    }
-		}
+		if (!rect.contains(int((*it)->x()), int((*it)->y()), true)) 
+		    continue;
             
-		m_selectedStaff = staff;
+		NotationElement &el = sprite->getNotationElement();
+		m_selectedStaff = getStaffForElement(&el);
 		break;
 	    }
 	}
@@ -1865,31 +1588,14 @@ EventSelection* NotationSelector::getSelection()
 
         if ((sprite = dynamic_cast<QCanvasNotationSprite*>(*it))) {
 
-	    NotationElement &el = sprite->getNotationElement();
-	    
-	    int x = (int)(*it)->x();
-	    bool shifted = false;
-	    int nbw = m_selectedStaff->getNotePixmapFactory(false).getNoteBodyWidth();
-
-	    // #957364 (Notation: Hard to select upper note in chords
-	    // of seconds) -- adjust x-coord for shifted note head
-	    if (el.event()->get<Rosegarden::Bool>
-		(m_selectedStaff->getProperties().NOTE_HEAD_SHIFTED, shifted) && shifted) {
-		x += nbw;
-	    }
-
             // check if the element's rect
             // is actually included in the selection rect.
             //
-            if (!rect.contains(x, int((*it)->y()), true))  {
-		// #988217 (Notation: Special column of pixels
-		// prevents sweep selection) -- for notes, test again
-		// with centred x-coord
-		if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
-		    continue;
-		}
-	    }
+            if (!rect.contains(int((*it)->x()), int((*it)->y()), true)) 
+		continue;
             
+            NotationElement &el = sprite->getNotationElement();
+
 	    // must be in the same segment as we first started on,
 	    // we can't select events across multiple segments
 	    if (selection->getSegment().findSingle(el.event()) !=
@@ -1927,153 +1633,13 @@ NotationStaff *
 NotationSelector::getStaffForElement(NotationElement *elt)
 {
     for (int i = 0; i < m_nParentView->getStaffCount(); ++i) {
-	NotationStaff *staff = m_nParentView->getNotationStaff(i);
+	NotationStaff *staff = m_nParentView->getStaff(i);
 	if (staff->getSegment().findSingle(elt->event()) !=
 	    staff->getSegment().end()) return staff;
     }
     return 0;
 }
 
-//------------------------------
-
-FretboardInserter::FretboardInserter(NotationView* view)
-        : NotationTool("FretboardInserter", view),
-	m_guitarChord_ref (m_nParentView)
-{
-    QIconSet icon = QIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::
-                             makeToolbarPixmap("select")));
-
-    new KAction(i18n("Switch to Select Tool"), icon, 0, this,
-                SLOT(slotSelectSelected()), actionCollection(),
-                "select");
-
-    new KAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
-                SLOT(slotEraseSelected()), actionCollection(),
-                "erase");
-
-    icon = QIconSet
-           (NotePixmapFactory::toQPixmap(NotePixmapFactory::
-                                         makeToolbarPixmap("crotchet")));
-
-    new KAction(i18n("Switch to Inserting Notes"), icon, 0, this,
-                SLOT(slotNoteSelected()), actionCollection(),
-                "notes");
-
-    m_guitarChord_ref.init();
-    createMenu("fretboardinserter.rc");
-}
-
-void FretboardInserter::slotFretboardSelected()
-{
-    // Switch to last selected Fretboard
-    // m_nParentView->slotLastFretboardAction();
-}
-
-void FretboardInserter::slotEraseSelected()
-{
-    m_parentView->actionCollection()->action("erase")->activate();
-}
-
-void FretboardInserter::slotSelectSelected()
-{
-    m_parentView->actionCollection()->action("select")->activate();
-}
-
-void FretboardInserter::handleLeftButtonPress(Rosegarden::timeT,
-        int,
-        int staffNo,
-        QMouseEvent* e,
-        ViewElement *element)
-{
-    std::cout << "FretboardInserter::handleLeftButtonPress" << std::endl;
-
-    if (staffNo < 0)
-    {
-        return;
-    }
-
-    Rosegarden::Staff *staff = m_nParentView->getStaff(staffNo);
-
-    if (element && element->event()->isa(Guitar::Fingering::EventType))
-    {
-        handleSelectedFretboard (element, staff);
-    }
-    else
-    {
-        createNewFretboard (element, staff, e);
-    }
-}
-
-bool FretboardInserter::processDialog( Rosegarden::Staff* staff,
-                                       Rosegarden::timeT& insertionTime)
-{
-    bool result = false;
-
-    if (m_guitarChord_ref.exec() == QDialog::Accepted)
-    {
-        Guitar::Fingering m_chord = m_guitarChord_ref.getArrangement();
-
-        FretboardInsertionCommand *command =
-            new FretboardInsertionCommand
-            (staff->getSegment(), insertionTime, m_chord);
-
-        m_nParentView->addCommandToHistory(command);
-        result = true;
-    }
-
-    return result;
-}
-
-void FretboardInserter::handleSelectedFretboard (ViewElement* element, Rosegarden::Staff *staff)
-{
-    std::cout << "FretboardInserter::handleSelectedFretboard" << std::endl;
-
-
-    // Get time of where fretboard is inserted
-    timeT insertionTime = element->event()->getAbsoluteTime(); // not getViewAbsoluteTime()
-
-    // edit an existing fretboard, if that's what we clicked on
-    try
-    {
-        Guitar::Fingering existingFret (*element->event());
-
-        m_guitarChord_ref.setArrangement( &existingFret );
-        if ( processDialog( staff, insertionTime ) )
-        {
-            // Erase old fretboard
-            EraseEventCommand *command =
-                new EraseEventCommand(staff->getSegment(),
-                                      element->event(),
-                                      false);
-
-            m_nParentView->addCommandToHistory(command);
-        }
-    }
-    catch (Rosegarden::Exception e)
-    {}
-}
-
-void FretboardInserter::createNewFretboard (ViewElement* element, Rosegarden::Staff *staff, QMouseEvent* e)
-{
-    std::cout << "FretboardInserter::createNewFretboard" << std::endl;
-    Event *clef = 0, *key = 0;
-
-    LinedStaff *s = dynamic_cast<LinedStaff *>(staff);
-
-    NotationElementList::iterator closestElement =
-        s->getClosestElementToCanvasCoords(e->x(), (int)e->y(),
-					   clef, key, false, -1);
-
-    if (closestElement == staff->getViewElementList()->end())
-    {
-        return;
-    }
-
-    timeT insertionTime = (*closestElement)->event()->getAbsoluteTime(); // not getViewAbsoluteTime()
-
-    processDialog( staff, insertionTime );
-}
-
 
 //------------------------------
 
@@ -2083,7 +1649,6 @@ const QString ClefInserter::ToolName     = "clefinserter";
 const QString TextInserter::ToolName     = "textinserter";
 const QString NotationEraser::ToolName   = "notationeraser";
 const QString NotationSelector::ToolName = "notationselector";
-const QString FretboardInserter::ToolName = "fretboardinserter";
 
 
 //----------------------------------------------------------------------
@@ -2111,7 +1676,7 @@ void NotationSelectionPaster::handleLeftButtonPress(Rosegarden::timeT,
     if (staffNo < 0) return;
     Event *clef = 0, *key = 0;
 
-    LinedStaff *staff = m_nParentView->getLinedStaff(staffNo);
+    NotationStaff *staff = m_nParentView->getStaff(staffNo);
     
     NotationElementList::iterator closestElement =
 	staff->getClosestElementToCanvasCoords(e->x(), (int)e->y(),
@@ -2134,4 +1699,3 @@ void NotationSelectionPaster::handleLeftButtonPress(Rosegarden::timeT,
     }
 }
 
-#include "notationtool.moc"
