@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -29,7 +29,6 @@
 #include "notationelement.h"
 #include "notestyle.h"
 #include "notationstaff.h"
-#include "guitar/guitartabselector.h"
 
 class QCanvasRectangle;
 
@@ -162,7 +161,13 @@ public slots:
     void slotSetDots(unsigned int dots);
  
     /// Set the accidental for the notes which will be inserted
-    void slotSetAccidental(Rosegarden::Accidental, bool follow);
+    void slotSetAccidental(Rosegarden::Accidental);
+
+    /**
+     * Set the accidental for the notes which will be inserted
+     * and put the parent view toolbar in sync
+     */
+    void slotSetAccidentalSync(Rosegarden::Accidental);
 
 protected:
     NoteInserter(NotationView*);
@@ -189,7 +194,6 @@ protected:
 protected slots:
     // RMB menu slots
     void slotNoAccidental();
-    void slotFollowAccidental();
     void slotSharp();
     void slotFlat();
     void slotNatural();
@@ -219,10 +223,8 @@ protected:
     double m_clickInsertX;
 
     Rosegarden::Accidental m_accidental;
-    Rosegarden::Accidental m_lastAccidental;
-    bool m_followAccidental;
 
-    static const char* m_actionsAccidental[][4];
+    static const char* m_actionsAccidental[][5];
 };
 
 /**
@@ -439,15 +441,6 @@ public slots:
     
     void slotInsertSelected();
     void slotEraseSelected();
-//    void slotCollapseRests();
-    void slotCollapseRestsHard();
-    void slotRespellFlat();
-    void slotRespellSharp();
-    void slotRespellNatural();
-    void slotCollapseNotes();
-    void slotInterpret();
-    void slotMakeInvisible();
-    void slotMakeVisible();
 
     void slotClickTimeout();
 
@@ -465,7 +458,6 @@ protected:
     NotationStaff *getStaffForElement(NotationElement *elt);
 
     void drag(int x, int y, bool final);
-    void dragFine(int x, int y, bool final);
 
     //--------------- Data members ---------------------------------
 
@@ -474,8 +466,6 @@ protected:
 
     NotationStaff *m_selectedStaff;
     NotationElement *m_clickedElement;
-    bool m_clickedShift;
-    bool m_startedFineDrag;
 
     Rosegarden::EventSelection *m_selectionToMerge;
 
@@ -511,53 +501,4 @@ protected:
 
 };
 
-
-/**
- * This tool will insert fretboard on mouse click events
-*/
-class FretboardInserter : public NotationTool
-{
-    Q_OBJECT
-
-    friend class NotationToolBox;
-
-public:
-
-    virtual void handleLeftButtonPress(Rosegarden::timeT t,
-                                       int height,
-                                       int staffNo,
-                                       QMouseEvent* e,
-                                       Rosegarden::ViewElement *element);
-
-/*
-    virtual void handleMouseDoubleClick(Rosegarden::timeT,
-                                        int height, int staffNo,
-                                        QMouseEvent*,
-                                        Rosegarden::ViewElement* el);
-*/
-
-    static const QString ToolName;
-
-protected slots:
-    void slotFretboardSelected();
-    void slotEraseSelected();
-    void slotSelectSelected();
-
-    GuitarTabSelectorDialog m_guitarChord_ref;
-
-protected:
-    FretboardInserter(NotationView*);
-
-private:
-    void handleSelectedFretboard (Rosegarden::ViewElement* element,
-                                  Rosegarden::Staff *staff);
-
-    void createNewFretboard (Rosegarden::ViewElement* element,
-                             Rosegarden::Staff *staff,
-                             QMouseEvent* e);
-
-    bool processDialog (Rosegarden::Staff *staff,
-                        Rosegarden::timeT& insertionTime);
-};
-
 #endif
