@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -45,7 +45,6 @@ class NotationToolBox;
 class PositionCursor;
 class ActiveItem;
 class NoteActionData;
-class NoteChangeActionData;
 class MarkActionData;
 class ChordNameRuler;
 class RawNoteRuler;
@@ -116,29 +115,13 @@ public:
     int getStaffCount() { return m_staffs.size(); }
 
     /// Return a pointer to the staff at the specified index
-    Rosegarden::Staff *getStaff(int i) {
-	return getLinedStaff(i);
-    }
-
-    /// Return a pointer to the staff corresponding to the given segment
-    Rosegarden::Staff *getStaff(const Rosegarden::Segment &segment) {
-	return getLinedStaff(segment);
-    }
-
-    /// Return a pointer to the staff at the specified index
-    LinedStaff *getLinedStaff(int i);
-
-    /// Return a pointer to the staff corresponding to the given segment
-    LinedStaff *getLinedStaff(const Rosegarden::Segment &segment);
-
-    /// Return a pointer to the staff at the specified index
-    NotationStaff *getNotationStaff(int i) {
+    NotationStaff *getStaff(int i) {
         if (i >= 0 && unsigned(i) < m_staffs.size()) return m_staffs[i];
         else return 0;
     }
 
     /// Return a pointer to the staff corresponding to the given segment
-    NotationStaff *getNotationStaff(const Rosegarden::Segment &segment);
+    NotationStaff *getStaff(const Rosegarden::Segment &segment);
 
     QCanvas* canvas() { return getCanvasView()->canvas(); }
     
@@ -183,11 +166,6 @@ public:
      */
     bool areAnnotationsVisible() { return m_annotationsVisible; }
 
-    /**
-     * Discover whether LilyPond directives are being displayed or not
-     */
-    bool areLilyPondDirectivesVisible() { return m_lilypondDirectivesVisible; }
-
     /**
      * Set the current event selection.
      *
@@ -390,7 +368,6 @@ public slots:
 
     /// accidental switch slots
     void slotNoAccidental();
-    void slotFollowAccidental();
     void slotSharp();
     void slotFlat();
     void slotNatural();
@@ -406,9 +383,6 @@ public slots:
     /// text tool
     void slotText();
 
-    /// fretboard tool
-    void slotFretboard();
-
     /// editing tools
     void slotEraseSelected();
     void slotSelectSelected();
@@ -418,7 +392,6 @@ public slots:
     /// status stuff
     void slotUpdateInsertModeStatus();
     void slotUpdateAnnotationsStatus();
-    void slotUpdateLilyPondDirectivesStatus();
 
     /// edit menu
     void slotPreviewSelection();
@@ -437,7 +410,6 @@ public slots:
     void slotToggleRawNoteRuler();
     void slotToggleTempoRuler();
     void slotToggleAnnotations();
-    void slotToggleLilyPondDirectives();
     void slotEditLyrics();
 
     /// group slots
@@ -451,7 +423,6 @@ public slots:
     void slotGroupGrace();
     void slotGroupUnGrace();
     void slotGroupSlur();
-    void slotGroupPhrasingSlur();
     void slotGroupGlissando();
     void slotGroupCrescendo();
     void slotGroupDecrescendo();
@@ -473,12 +444,8 @@ public slots:
     void slotTransformsStemsUp();
     void slotTransformsStemsDown();
     void slotTransformsRestoreStems();
-    void slotTransformsSlursAbove();
-    void slotTransformsSlursBelow();
-    void slotTransformsRestoreSlurs();
     void slotTransformsQuantize();
     void slotTransformsFixQuantization();
-    void slotTransformsRemoveQuantization();
     void slotTransformsInterpret();
 
     void slotRespellDoubleFlat();
@@ -497,7 +464,6 @@ public slots:
     void slotInsertRest();
     void slotSwitchFromRestToNote();
     void slotSwitchFromNoteToRest();
-    void slotToggleDot();
 
     void slotAddMark();
     void slotMarksAddTextMark();
@@ -505,33 +471,13 @@ public slots:
     void slotMarksAddFingeringMarkFromAction();
     void slotMarksRemoveMarks();
     void slotMarksRemoveFingeringMarks();
-    void slotMakeOrnament();
-    void slotUseOrnament();
-    void slotRemoveOrnament();
-
-    void slotNoteChangeAction();
-    void slotSetNoteDurations(Rosegarden::Note::Type, bool notationOnly);
-    void slotAddDot();
-    void slotAddDotNotationOnly();
 
     void slotAddSlashes();
 
     void slotEditAddClef();
     void slotEditAddKeySignature();
-    void slotEditAddSustainDown();
-    void slotEditAddSustainUp();
-    void slotEditAddSustain(bool down);
     void slotEditElement(NotationStaff *, NotationElement *, bool advanced);
 
-    void slotFinePositionLeft();
-    void slotFinePositionRight();
-    void slotFinePositionUp();
-    void slotFinePositionDown();
-    void slotFinePositionRestore();
-
-    void slotMakeVisible();
-    void slotMakeInvisible();
-
     void slotDebugDump();
 
     /// Canvas actions slots
@@ -670,12 +616,6 @@ public slots:
     /// Changes the font size of the staffs on the view to the nth size in the available size list
     void slotChangeFontSizeFromStringValue(const QString&);
 
-    /// Changes to the next font size up
-    void slotZoomIn();
-
-    /// Changes to the next font size down
-    void slotZoomOut();
-
     /// Changes the hlayout spacing of the staffs on the view
     void slotChangeSpacing(int newSpacing);
 
@@ -720,9 +660,6 @@ public slots:
     // Update notation view based on track/staff name change
     void slotUpdateStaffName();
 
-    // Lilypond Directive slots
-    void slotBeginLilypondRepeat();
-
 signals:
     /**
      * Emitted when the note selected in the palette changes
@@ -732,7 +669,7 @@ signals:
     /**
      * Emitted when a new accidental has been choosen by the user
      */
-    void changeAccidental(Rosegarden::Accidental, bool follow);
+    void changeAccidental(Rosegarden::Accidental);
 
     /**
      * Emitted when the selection has been cut or copied
@@ -748,7 +685,6 @@ signals:
     void fastForwardPlaybackToEnd();
     void rewindPlaybackToBeginning();
     void jumpPlaybackTo(Rosegarden::timeT);
-    void panic();
 
     /// progress Report
     void setProgress(int);
@@ -763,8 +699,6 @@ signals:
 
     void editMetadata(QString);
 
-    void editTriggerSegment(int);
-
     void staffLabelChanged(Rosegarden::TrackId id, QString label);
 
 protected:
@@ -881,9 +815,7 @@ protected:
     virtual NotationCanvasView* getCanvasView();
 
     virtual Rosegarden::Segment *getCurrentSegment();
-    virtual Rosegarden::Staff *getCurrentStaff() { return getCurrentLinedStaff(); }
-    virtual LinedStaff *getCurrentLinedStaff();
-	
+    virtual Rosegarden::Staff *getCurrentStaff();
 
     /**
      * Return the time at which the insert cursor may be found.
@@ -911,8 +843,6 @@ protected:
      */
     bool canPreviewAnotherNote();
 
-    virtual void updateViewCaption();
-
     //--------------- Data members ---------------------------------
 
     NotationProperties m_properties;
@@ -926,9 +856,6 @@ protected:
     /// Displayed in the status bar, shows when annotations are hidden
     QLabel *m_annotationsLabel;
 
-    /// Displayed in the status bar, shows when LilyPond directives are hidden
-    QLabel *m_lilypondDirectivesLabel;
-
     /// Displayed in the status bar, shows progress of current operation
     RosegardenProgressBar *m_progressBar;
 
@@ -962,6 +889,7 @@ protected:
     DeferredCursorMoveType m_deferredCursorMove;
     double m_deferredCursorScrollToX;
 
+    Rosegarden::Accidental m_currentAccidental;
     QString m_lastNoteAction;
 
     std::string m_fontName;
@@ -978,16 +906,12 @@ protected:
     QWidget *m_tempoRuler;
     RawNoteRuler *m_rawNoteRuler;
     bool m_annotationsVisible;
-    bool m_lilypondDirectivesVisible;
     
     KAction* m_selectDefaultNote;
 
     typedef QMap<QString, NoteActionData> NoteActionDataMap;
     static NoteActionDataMap* m_noteActionDataMap;
 
-    typedef QMap<QString, NoteChangeActionData> NoteChangeActionDataMap;
-    static NoteChangeActionDataMap* m_noteChangeActionDataMap;
-
     typedef QMap<QString, MarkActionData> MarkActionDataMap;
     static MarkActionDataMap *m_markActionDataMap;
 
