@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -28,16 +28,11 @@
 #include <qpainter.h>
 #include <qregexp.h>
 #include <qfontdatabase.h>
-#include <qstringlist.h>
-
-#include <algorithm>
 
 #include <kglobal.h>
 #include <kstddirs.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kapplication.h>
-#include <kconfig.h>
 
 #include <iostream>
 
@@ -45,7 +40,7 @@
 #include "rosestrings.h"
 #include "rosedebug.h"
 #include "pixmapfunctions.h"
-#include "constants.h"
+#include "config.h"
 
 using std::string;
 using std::map;
@@ -69,7 +64,6 @@ NoteFontMap::NoteFontMap(string name) :
     m_srcDirectory(name),
     m_characterDestination(0),
     m_hotspotCharName(""),
-    m_errorString(i18n("unknown error")),
     m_ok(true)
 {
     m_fontDirectory = KGlobal::dirs()->findResource("appdata", "fonts/");
@@ -255,29 +249,29 @@ NoteFontMap::startElement(const QString &, const QString &,
 	QString s;
 
         s = attributes.value("font-height");
-	if (s) fontHeight = qstrtodouble(s);
+	if (s) fontHeight = s.toDouble();
 	else {
 	    m_errorString = "font-height is a required attribute of font-scale";
 	    return false;
 	}
 
         s = attributes.value("staff-line-thickness");
-	if (s) staffLineThickness = qstrtodouble(s);
+	if (s) staffLineThickness = s.toDouble();
 
         s = attributes.value("leger-line-thickness");
-	if (s) legerLineThickness = qstrtodouble(s);
+	if (s) legerLineThickness = s.toDouble();
 
         s = attributes.value("stem-thickness");
-	if (s) stemThickness = qstrtodouble(s);
+	if (s) stemThickness = s.toDouble();
 
         s = attributes.value("beam-thickness");
-	if (s) beamThickness = qstrtodouble(s);
+	if (s) beamThickness = s.toDouble();
 
         s = attributes.value("stem-length");
-	if (s) stemLength = qstrtodouble(s);
+	if (s) stemLength = s.toDouble();
 
         s = attributes.value("flag-spacing");
-	if (s) flagSpacing = qstrtodouble(s);
+	if (s) flagSpacing = s.toDouble();
 
 	int fontId = 0;
 	s = attributes.value("font-id");
@@ -477,14 +471,14 @@ NoteFontMap::startElement(const QString &, const QString &,
 
 	QString s = attributes.value("x");
 	double x = -1.0;
-	if (s) x = qstrtodouble(s);
+	if (s) x = s.toDouble();
 
 	s = attributes.value("y");
 	if (!s) {
 	    m_errorString = "y is a required attribute of scaled";
 	    return false;
 	}
-	double y = qstrtodouble(s);
+	double y = s.toDouble();
 	
         HotspotDataMap::iterator i = m_hotspots.find(m_hotspotCharName);
         if (i == m_hotspots.end()) {
@@ -643,22 +637,20 @@ NoteFontMap::startElement(const QString &, const QString &,
 bool
 NoteFontMap::error(const QXmlParseException& exception)
 {
-    m_errorString = QString("%1 at line %2, column %3: %4")
+    m_errorString = QString("%1 at line %2, column %3")
 	.arg(exception.message())
 	.arg(exception.lineNumber())
-	.arg(exception.columnNumber())
-	.arg(m_errorString);
+	.arg(exception.columnNumber());
     return QXmlDefaultHandler::error(exception);
 }
 
 bool
 NoteFontMap::fatalError(const QXmlParseException& exception)
 {
-    m_errorString = QString("%1 at line %2, column %3: %4")
+    m_errorString = QString("%1 at line %2, column %3")
 	.arg(exception.message())
 	.arg(exception.lineNumber())
-	.arg(exception.columnNumber())
-	.arg(m_errorString);
+	.arg(exception.columnNumber());
     return QXmlDefaultHandler::fatalError(exception);
 }
 
@@ -1500,51 +1492,12 @@ NoteFont::getColouredPixmap(CharName baseCharName, QPixmap &pixmap,
     return ok;
 }
 
-bool
-NoteFont::getShadedPixmap(CharName baseCharName, QPixmap &pixmap,
-			  bool inverted) const
-{
-    CharName charName(getNameShaded(baseCharName));
-
-    QPixmap *found = 0;
-    bool ok = lookup(charName, inverted, found);
-    if (ok) {
-	if (found) {
-	    pixmap = *found;
-	    return true;
-	} else {
-	    pixmap = *m_blankPixmap;
-	    return false;
-	}
-    }
-
-    QPixmap basePixmap;
-    ok = getPixmap(baseCharName, basePixmap, inverted);
-
-    if (!ok) {
-	add(charName, inverted, 0);
-	pixmap = *m_blankPixmap;
-	return false;
-    }
-
-    found = new QPixmap(PixmapFunctions::shadePixmap(basePixmap));
-    add(charName, inverted, found);
-    pixmap = *found;
-    return ok;
-}
-
 CharName
 NoteFont::getNameWithColour(CharName base, int hue) const
 {
     return qstrtostr(QString("%1__%2").arg(hue).arg(strtoqstr(base)));
 }
 
-CharName
-NoteFont::getNameShaded(CharName base) const
-{
-    return qstrtostr(QString("shaded__%1").arg(strtoqstr(base)));
-}
-
 bool
 NoteFont::getDimensions(CharName charName, int &x, int &y, bool inverted) const
 {
@@ -1689,77 +1642,11 @@ NoteFont::getCharacterColoured(CharName charName,
     return character;
 }
 
-bool
-NoteFont::getCharacterShaded(CharName charName,
-			     NoteCharacter &character,
-			     CharacterType type,
-			     bool inverted)
-{
-    QPixmap pixmap;
-    if (!getShadedPixmap(charName, pixmap, inverted)) {
-	return false;
-    }
-
-    if (type == Screen) {
-
-	character = NoteCharacter(pixmap,
-				  getHotspot(charName, inverted),
-				  0);
-
-    } else {
-
-	// Get the pointer direct from cache (depends on earlier call
-	// to getPixmap to put it in the cache if available)
-
-	QPixmap *pmapptr = 0;
-	CharName cCharName(getNameShaded(charName));
-	bool found = lookup(cCharName, inverted, pmapptr);
-
-	NoteCharacterDrawRep *rep = 0;
-	if (found && pmapptr) rep = lookupDrawRep(pmapptr);
-
-	character = NoteCharacter(pixmap,
-				  getHotspot(charName, inverted),
-				  rep);
-    }
-
-    return true;
-}
-
-NoteCharacter
-NoteFont::getCharacterShaded(CharName charName,
-			     CharacterType type,
-			     bool inverted)
-{
-    NoteCharacter character;
-    getCharacterShaded(charName, character, type, inverted);
-    return character;
-}
-
 
 std::set<std::string>
-NoteFontFactory::getFontNames(bool forceRescan)
+NoteFontFactory::getFontNames()
 {
-    NOTATION_DEBUG << "NoteFontFactory::getFontNames: forceRescan = " << forceRescan << endl;
-
-    if (forceRescan) m_fontNames.clear();
-    if (!m_fontNames.empty()) return m_fontNames;
-    
-    KConfig *config = kapp->config();
-    config->setGroup(Rosegarden::NotationViewConfigGroup);
-
-    QString fontNameList = "";
-    if (!forceRescan) {
-	fontNameList = config->readEntry("notefontlist");
-    }	
-
-    NOTATION_DEBUG << "NoteFontFactory::getFontNames: read from cache: " << fontNameList << endl;
-
-    QStringList names = QStringList::split(",", fontNameList);
-
-    if (names.empty()) {
-
-	NOTATION_DEBUG << "NoteFontFactory::getFontNames: No names available, rescanning..." << endl;
+    if (m_fontNames.empty()) {
 
 	QString mappingDir = 
 	    KGlobal::dirs()->findResource("appdata", "fonts/mappings/");
@@ -1780,7 +1667,7 @@ NoteFontFactory::getFontNames(bool forceRescan)
 
 		try {
 		    NoteFontMap map(name);
-		    if (map.ok()) names.append(strtoqstr(map.getName()));
+		    if (map.ok()) m_fontNames.insert(map.getName());
 		} catch (Rosegarden::Exception e) {
 		    KStartupLogo::hideIfStillThere();
 		    KMessageBox::error(0, strtoqstr(e.getMessage()));
@@ -1788,17 +1675,7 @@ NoteFontFactory::getFontNames(bool forceRescan)
 		}
 	    }
 	}
-    }
-
-    QString savedNames = "";
-
-    for (QStringList::Iterator i = names.begin(); i != names.end(); ++i) {
-	m_fontNames.insert(qstrtostr(*i));
-	if (i != names.begin()) savedNames += ",";
-	savedNames += *i;
-    }
-
-    config->writeEntry("notefontlist", savedNames);
+    } 
 
     return m_fontNames;
 }
@@ -1858,26 +1735,16 @@ NoteFontFactory::getFont(std::string fontName, int size)
 std::string
 NoteFontFactory::getDefaultFontName()
 {
-    static std::string defaultFont = "";
-    if (defaultFont != "") return defaultFont;
-
     std::set<std::string> fontNames = getFontNames();
-
-    if (fontNames.find("Feta") != fontNames.end()) defaultFont = "Feta";
-    else {
-	fontNames = getFontNames(true);
-	if (fontNames.find("Feta") != fontNames.end()) defaultFont = "Feta";
-	else if (fontNames.find("Feta Pixmaps") != fontNames.end()) defaultFont = "Feta Pixmaps";
-	else if (fontNames.size() > 0) defaultFont = *fontNames.begin();
-	else {
-	    QString message = i18n("Can't obtain a default font -- no fonts found");
-	    KStartupLogo::hideIfStillThere();
-	    KMessageBox::error(0, message);
-	    throw NoFontsAvailable(qstrtostr(message));
-	}
+    if (fontNames.find("Feta") != fontNames.end()) return "Feta";
+    else if (fontNames.find("Feta Pixmaps") != fontNames.end()) return "Feta Pixmaps";
+    else if (fontNames.size() == 0) {
+	QString message = i18n("Can't obtain a default font -- no fonts found");
+	KStartupLogo::hideIfStillThere();
+	KMessageBox::error(0, message);
+	throw NoFontsAvailable(qstrtostr(message));
     }
-
-    return defaultFont;
+    else return *fontNames.begin();
 }
 
 int
