@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,21 +24,16 @@
 
 #include <vector>
 #include <set>
-#include <map>
 
 #include <qcanvas.h>
 #include <qpainter.h>
 
 #include "NotationTypes.h"
-#include "notefont.h"
 
+class NoteFont;
 class NoteStyle;
 class NotePixmapCache;
 
-namespace Guitar {
-    class Fingering;
-}
-
 class NotePixmapParameters
 {
 public:
@@ -64,12 +59,10 @@ public:
     void setStemLength(int length)        { m_stemLength       = length;    }
     void setLegerLines(int lines)         { m_legerLines       = lines;     }
     void setSlashes(int slashes)          { m_slashes          = slashes;   }
-    void setRestOutside(bool os)          { m_restOutsideStave = os;        }
 
     void setSelected(bool selected)       { m_selected         = selected;  }
     void setHighlighted(bool highlighted) { m_highlighted      = highlighted;}
     void setQuantized(bool quantized)     { m_quantized        = quantized; }
-    void setTrigger(bool trigger)         { m_trigger          = trigger;   }
     void setIsOnLine(bool isOnLine)       { m_onLine           = isOnLine;  }
     void setSafeVertDistance(int safe)    { m_safeVertDistance = safe;      }
 
@@ -91,8 +84,6 @@ public:
 
     void setMarks(const std::vector<Rosegarden::Mark> &marks);
     void removeMarks();
-
-    void setInRange(bool inRange)         { m_inRange          = inRange;    }
     
     std::vector<Rosegarden::Mark> getNormalMarks() const;
     std::vector<Rosegarden::Mark> getAboveMarks() const; // bowings, pause etc
@@ -121,10 +112,8 @@ private:
     bool    m_selected;
     bool    m_highlighted;
     bool    m_quantized;
-    bool    m_trigger;
     bool    m_onLine;
     int     m_safeVertDistance;
-    bool    m_restOutsideStave;
 
     bool    m_beamed;
     int     m_nextBeamCount;
@@ -141,8 +130,6 @@ private:
 
     bool    m_tied;
     int     m_tieLength;
-
-    bool    m_inRange;
     
     std::vector<Rosegarden::Mark> m_marks;
 };    
@@ -168,9 +155,6 @@ public:
     void setSelected(bool selected) { m_selected = selected; }
     bool isSelected() const { return m_selected; }
 
-    void setShaded(bool shaded) { m_shaded = shaded; }
-    bool isShaded() const { return m_shaded; }
-
     void setNoteStyle(NoteStyle *style) { m_style = style; }
     const NoteStyle *getNoteStyle() const { return m_style; } 
 
@@ -181,18 +165,13 @@ public:
     QCanvasPixmap* makeClefPixmap(const Rosegarden::Clef &clef);
     QCanvasPixmap* makeKeyPixmap(const Rosegarden::Key &key,
 				 const Rosegarden::Clef &clef,
-				 Rosegarden::Key previousKey =
-				 Rosegarden::Key::DefaultKey);
+				 bool cancellation = false);
     QCanvasPixmap* makeTimeSigPixmap(const Rosegarden::TimeSignature& sig);
     QCanvasPixmap* makeHairpinPixmap(int length, bool isCrescendo);
-    QCanvasPixmap* makeSlurPixmap(int length, int dy, bool above, bool phrasing);
+    QCanvasPixmap* makeSlurPixmap(int length, int dy, bool above);
     QCanvasPixmap* makeOttavaPixmap(int length, int octavesUp);
-    QCanvasPixmap* makePedalDownPixmap();
-    QCanvasPixmap* makePedalUpPixmap();
     QCanvasPixmap* makeUnknownPixmap();
     QCanvasPixmap* makeTextPixmap(const Rosegarden::Text &text);
-    QCanvasPixmap* makeFretboardPixmap(const Guitar::Fingering &arrangement,
-				       int x, int y);
 
     // Printing methods -- draw direct to a paint device:
 
@@ -202,7 +181,7 @@ public:
 		  QPainter &painter, int x, int y);
     void drawHairpin(int length, bool isCrescendo,
 		     QPainter &painter, int x, int y);
-    void drawSlur(int length, int dy, bool above, bool phrasing,
+    void drawSlur(int length, int dy, bool above,
 		  QPainter &painter, int x, int y);
     void drawOttava(int length, int octavesUp,
 		    QPainter &painter, int x, int y);
@@ -211,10 +190,9 @@ public:
 
     // Other support methods for producing pixmaps for other contexts:
 
-    static QCanvasPixmap *makeToolbarPixmap(const char *name);
-    static QCanvasPixmap *makeNoteMenuPixmap(Rosegarden::timeT duration,
+    static QCanvasPixmap* makeToolbarPixmap(const char *name);
+    static QCanvasPixmap* makeNoteMenuPixmap(Rosegarden::timeT duration,
 					     Rosegarden::timeT &errorReturn);
-    static QCanvasPixmap *makeMarkMenuPixmap(Rosegarden::Mark);
 
     QCanvasPixmap* makePitchDisplayPixmap(int pitch,
 					  const Rosegarden::Clef &clef,
@@ -246,8 +224,7 @@ public:
     int getClefWidth(const Rosegarden::Clef &clef) const;
     int getTimeSigWidth(const Rosegarden::TimeSignature &timesig) const;
     int getRestWidth(const Rosegarden::Note &restType) const;
-    int getKeyWidth(const Rosegarden::Key &key,
-		    Rosegarden::Key previousKey = Rosegarden::Key::DefaultKey) const;
+    int getKeyWidth(const Rosegarden::Key &key, bool cancellation = false) const;
     int getTextWidth(const Rosegarden::Text &text) const;
 
     /**
@@ -262,11 +239,6 @@ public:
     static QPixmap toQPixmap(QCanvasPixmap*);
     static void dumpStats(std::ostream &);
 
-
-    static const char* const defaultSerifFontFamily;
-    static const char* const defaultTimeSigFontFamily;
-    
-
 protected:
     void init(std::string fontName, int size);
     void initMaybe() { if (!m_font) init("", -1); }
@@ -277,7 +249,7 @@ protected:
 		     QPainter *painter, int x, int y);
     void drawHairpinAux(int length, bool isCrescendo,
 			QPainter *painter, int x, int y);
-    void drawSlurAux(int length, int dy, bool above, bool smooth, bool tie, bool phrasing,
+    void drawSlurAux(int length, int dy, bool above, bool smooth, bool flat,
 		     QPoint &hotspot,
 		     QPainter *painter, int x, int y);
     void drawOttavaAux(int length, int octavesUp,
@@ -302,8 +274,7 @@ protected:
     void drawFlags(int flagCount, const NotePixmapParameters &params,
 		   const QPoint &startPoint, const QPoint &endPoint);
     void drawStem(const NotePixmapParameters &params,
-		  const QPoint &startPoint, const QPoint &endPoint,
-		  int shortening);
+		  const QPoint &startPoint, const QPoint &endPoint);
 
     void makeRoomForBeams(const NotePixmapParameters &params);
     void drawBeams(const QPoint &, const NotePixmapParameters &params,
@@ -324,33 +295,17 @@ protected:
     QFont getTextFont(const Rosegarden::Text &text) const;
 
     QCanvasPixmap* makeAnnotationPixmap(const Rosegarden::Text &text);
-    QCanvasPixmap* makeAnnotationPixmap(const Rosegarden::Text &text, const bool isLilypondDirective);
 
     void createPixmapAndMask(int width, int height,
 			     int maskWidth = -1,
 			     int maskHeight = -1);
     QCanvasPixmap* makeCanvasPixmap(QPoint hotspot, bool generateMask = false);
 
-    enum ColourType {
-	PlainColour,
-	QuantizedColour,
-	HighlightedColour,
-	TriggerColour,
-	OutRangeColour
-    };
-
-    /// draws selected/shaded status from m_selected/m_shaded:
-    NoteCharacter getCharacter(CharName name, ColourType type, bool inverted);
-
-    /// draws selected/shaded status from m_selected/m_shaded:
-    bool getCharacter(CharName name, NoteCharacter &ch, ColourType type, bool inverted);
-
     //--------------- Data members ---------------------------------
 
     NoteFont *m_font;
     NoteStyle *m_style;
     bool m_selected;
-    bool m_shaded;
 
     int m_noteBodyWidth, m_noteBodyHeight;
     int m_left, m_right, m_above, m_below;
@@ -385,7 +340,7 @@ protected:
 
     mutable NotePixmapCache *m_dottedRestCache;
 
-    typedef std::map<const char *, QFont> TextFontCache;
+    typedef Rosegarden::hash_char<QFont> TextFontCache;
     mutable TextFontCache m_textFontCache;
 
     static QPoint m_pointZero;
