@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -129,12 +129,11 @@ bool RG21Loader::parseMetronome()
     int count = (*i).toInt(&isNumeric);
     if (!count || !isNumeric) return false;
 
-    // we need to take into account the fact that "duration" might not
-    // be a crotchet
-    
-    double qpm = (count * duration) / Note(Note::Crotchet).getDuration();
-    m_composition->addTempoAtTime(m_currentSegmentTime,
-				  m_composition->getTempoForQpm(qpm));
+    // RG4 raw tempos are in crotchets-per-hour, and we need to take
+    // into account the fact that "duration" might not be a crotchet
+
+    int raw = (count * duration * 60) / Note(Note::Crotchet).getDuration();
+    m_composition->addRawTempo(m_currentSegmentTime, raw);
     return true;
 }
 
@@ -536,8 +535,7 @@ bool RG21Loader::parseStaveType()
 
     int programNo = m_tokens[8].toInt();
 
-    if (staffNo >= (int)m_composition->getMinTrackId() &&
-	staffNo <= (int)m_composition->getMaxTrackId()) {
+    if (staffNo < (int)m_composition->getNbTracks()) {
 
 	Rosegarden::Track *track = m_composition->getTrackById(staffNo);
 
