@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -24,15 +24,12 @@
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
-#include <kstatusbar.h>
-#include <klocale.h>
 
 #include "constants.h"
 #include "rgapplication.h"
 #include "rosegardengui.h"
 #include "rosegardenguidoc.h"
 #include "rosedebug.h"
-#include "ktmpstatusmsg.h"
 
 int RosegardenApplication::newInstance()
 {
@@ -84,24 +81,13 @@ void RosegardenApplication::sfxLoadExited(KProcess *proc)
         config()->setGroup(configGroup);
         
         KMessageBox::error(mainWidget(),
-                           i18n("Failed to load soundfont %1").arg(soundFontPath));
+                           QString(i18n("Failed to load soundfont %1")).arg(soundFontPath));
     } else {
         RG_DEBUG << "RosegardenApplication::sfxLoadExited() : sfxload exited normally\n";
     }
     
 }
 
-void RosegardenApplication::slotSetStatusMessage(QString msg)
-{
-    KMainWindow* mainWindow = dynamic_cast<KMainWindow*>(mainWidget());
-    if (mainWindow) {
-        if (msg.isEmpty())
-            msg = KTmpStatusMsg::getDefaultMsg();
-        mainWindow->statusBar()->changeItem(QString("  %1").arg(msg), KTmpStatusMsg::getDefaultId());
-    }
-    
-}
-
 void
 RosegardenApplication::refreshGUI(int maxTime)
 {
@@ -110,12 +96,6 @@ RosegardenApplication::refreshGUI(int maxTime)
 			       maxTime);
 }
 
-void RosegardenApplication::saveState(QSessionManager& sm)
-{
-    emit aboutToSaveState();
-    KUniqueApplication::saveState(sm);
-}
-
 RosegardenApplication* RosegardenApplication::rgApp()
 {
     return dynamic_cast<RosegardenApplication*>(kApplication());
@@ -124,4 +104,3 @@ RosegardenApplication* RosegardenApplication::rgApp()
 
 QByteArray RosegardenApplication::Empty;
 
-#include "rgapplication.moc"
