@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -26,8 +26,7 @@
 
 #include <qcanvas.h>
 #include <qwmatrix.h>
-#include <qdatetime.h>
-#include <qtimer.h>
+
 
 class QScrollBar;
 class QGridLayout;
@@ -46,16 +45,6 @@ public:
     RosegardenCanvasView(QCanvas*,
                          QWidget* parent=0, const char* name=0, WFlags f=0);
 
-    /**
-     * EditTool::handleMouseMove() returns a OR-ed combination of these
-     * to indicate which direction to scroll to
-     */
-    enum {
-        NoFollow = 0x0,
-        FollowHorizontal = 0x1,
-        FollowVertical = 0x2
-    };
-
     /**
      * Sets the canvas width to be exactly the width needed to show
      * all the items
@@ -73,16 +62,6 @@ public:
     /// Map a point with the inverse world matrix
     QPoint inverseMapPoint(const QPoint& p) { return inverseWorldMatrix().map(p); }
 
-    void setSmoothScroll(bool s) { m_smoothScroll = s; }
-
-    bool isTimeForSmoothScroll();
-
-    void setScrollDirectionConstraint(int d) { m_scrollDirectionConstraint = d; }
-
-    bool isAutoScrolling() const { return m_autoScrolling; }
-
-    virtual void wheelEvent(QWheelEvent *);
-
 public slots:
     /// Update the RosegardenCanvasView after a change of content
     virtual void slotUpdate();
@@ -119,69 +98,20 @@ public slots:
      */
     void slotSetScrollPos(const QPoint &);
 
-    void startAutoScroll();
-    void startAutoScroll(int directionConstraint);
-    void stopAutoScroll();
-    void doAutoScroll();
-
 signals:
     void bottomWidgetHeightChanged(int);
 
-    void zoomIn();
-    void zoomOut();
-
 protected:
     
     virtual void resizeEvent(QResizeEvent*);
     virtual void setHBarGeometry(QScrollBar &hbar, int x, int y, int w, int h);
-
-    virtual QScrollBar* getMainHorizontalScrollBar() { return horizontalScrollBar(); }
-
-    //--------------- Data members ---------------------------------
-    enum ScrollDirection { None, Top, Bottom, Left, Right };
     
-        
+    //--------------- Data members ---------------------------------
+
     QWidget* m_bottomWidget;
     int m_currentBottomWidgetHeight;
-
-    bool m_smoothScroll;
-    int m_smoothScrollTimeInterval;
-    float m_minDeltaScroll;
-    QTime m_scrollTimer;
-    QTime m_scrollAccelerationTimer;
-
-    QTimer m_autoScrollTimer;
-    int m_autoScrollTime;
-    int m_autoScrollAccel;
-    QPoint m_autoScrollStartPoint;
-    int m_autoScrollXMargin;
-    int m_autoScrollYMargin;
-    ScrollDirection m_currentScrollDirection;
-    int m_scrollDirectionConstraint;
-    bool m_autoScrolling;
-
-    static const int DefaultSmoothScrollTimeInterval;
-    static const int DefaultMinDeltaScroll;
-
-    static const int AutoscrollMargin;
-    static const int InitialScrollTime;
-    static const int InitialScrollAccel;
-    static const int MaxScrollDelta;
-    static const double ScrollAccelValue;
-
 };
 
-class CanvasCursor : public QCanvasRectangle
-{
-public:
-    CanvasCursor(QCanvas*, int width);
-    void updateHeight();
-//     virtual QRect boundingRect() const;
-protected:
-    int m_width;
-};
-
-
 
 /**
  * A pseudo GC in which CanvasItems whose ownership isn't clear cut
