@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -32,7 +32,6 @@
 #include <qslider.h>
 #include <qlineedit.h>
 
-#include <kdeversion.h>
 #include <klocale.h>
 #include <kcolordialog.h>
 #include <kcolorbutton.h>
@@ -41,20 +40,20 @@
 
 #include "ColourMap.h"
 #include "Device.h"
+#include "config.h"
 #include "widgets.h"
 #include "colourwidgets.h"
 
+class RosegardenGUIDoc;
 class QTabWidget;
 class QLineEdit;
 class QPushButton;
 class QRadioButton;
 class QLabel;
 class QCheckBox;
-class QTable;
-class KListView;
-class KFontRequester;
-class RosegardenGUIDoc;
 class RosegardenQuantizeParameters;
+class KListView;
+class QTable;
 
 namespace Rosegarden
 {
@@ -188,7 +187,6 @@ public:
 
 signals:
     void updateAutoSaveInterval(unsigned int);
-    void updateSidebarStyle(unsigned int);
 
 protected slots:
     void slotFileDialog();
@@ -208,8 +206,6 @@ protected:
     QCheckBox *m_autosave;
     QSpinBox*  m_autosaveInterval;
     QComboBox* m_nameStyle;
-    QComboBox* m_previewStyle;
-    QComboBox* m_sidebarStyle;
 
 };
 
@@ -218,7 +214,7 @@ protected:
  */
 class NotationConfigurationPage : public TabbedConfigurationPage
 {
-    Q_OBJECT
+    Q_OBJECT;
 
 public:
     NotationConfigurationPage(KConfig *cfg,
@@ -228,12 +224,10 @@ public:
 
     static QString iconLabel() { return i18n("Notation"); }
     static QString title()     { return i18n("Notation"); }
-    static QString iconName()  { return "music_eightnote"; }
+    static QString iconName()  { return "fonts"; }
 
 protected slots:
     void slotFontComboChanged(int);
-    void slotRescanFonts();
-    void slotPopulateFontCombo(bool rescan);
     void slotViewButtonPressed();
 
 protected:
@@ -244,8 +238,6 @@ protected:
     QComboBox *m_singleStaffSize;
     QComboBox *m_multiStaffSize;
     QComboBox *m_printingSize;
-    KFontRequester* m_textFont;
-    KFontRequester* m_timeSigFont;
     QPushButton *m_viewButton;
     QLabel *m_fontOriginLabel;
     QLabel *m_fontCopyrightLabel;
@@ -256,16 +248,11 @@ protected:
     QComboBox *m_proportion;
     QCheckBox *m_colourQuantize;
     QCheckBox *m_showUnknowns;
-    QCheckBox *m_showInvisibles;
-    QCheckBox *m_showRanges;
     QComboBox *m_noteStyle;
     QComboBox *m_insertType;
     QCheckBox *m_autoBeam;
     QCheckBox *m_collapseRests;
     QComboBox *m_pasteType;
-    QComboBox *m_accOctavePolicy;
-    QComboBox *m_accBarPolicy;
-    QComboBox *m_keySigCancelMode;
     RosegardenQuantizeParameters *m_quantizeFrame;
     QStringList m_untranslatedFont;
     QStringList m_untranslatedNoteStyle;
@@ -278,7 +265,7 @@ protected:
  */
 class MatrixConfigurationPage : public TabbedConfigurationPage
 {
-    Q_OBJECT
+    Q_OBJECT;
 
 public:
     MatrixConfigurationPage(KConfig *cfg,
@@ -361,7 +348,6 @@ protected:
 
     //--------------- Data members ---------------------------------
 
-    KListView *m_fixed;
     KListView *m_metadata;
 };
 
@@ -391,11 +377,6 @@ protected slots:
     //
     void calculateStats();
 
-    void slotFoundMountPoint(const QString&,
-                             unsigned long kBSize,
-                             unsigned long kBUsed,
-                             unsigned long kBAvail);
-    
 protected:
 
     //--------------- Data members ---------------------------------
@@ -503,16 +484,11 @@ protected:
     QLineEdit *m_jackPath;
 #endif // HAVE_LIBJACK
 
-    // Sync and timing
-    //
-    //QCheckBox *m_midiClockEnabled;
-    QComboBox *m_midiSync;
-    QString    m_origTimer;
+    // Latency
+    QCheckBox *m_midiClockEnabled;
     QComboBox *m_timer;
     QComboBox *m_jackTransport;
     QComboBox *m_mmcTransport;
-    QComboBox *m_mtcTransport;
-    QCheckBox *m_midiSyncAuto;
 
     int      m_sampleRate;
     QSlider* m_readAhead;
@@ -534,17 +510,11 @@ protected:
     QCheckBox    *m_createFaderOuts;
     QCheckBox    *m_createSubmasterOuts;
 
-    QComboBox    *m_audioRecFormat;
-
-    KComboBox    *m_lowLatencyMode;
-
 #endif // HAVE_LIBJACK
 
     // How many minutes of audio recording should we allow?
     //
-/*  #1045380 ("minutes of audio recording" just insanely confusing) -- remove
     QSpinBox     *m_audioRecordMinutes;
-*/
 
 };
  
