@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -38,7 +38,6 @@ class ConfigureDialogBase : public KDialogBase
     Q_OBJECT
 public:
     ConfigureDialogBase(QWidget *parent=0,
-			QString label = 0,
                         const char *name=0);
     virtual ~ConfigureDialogBase();
 
@@ -66,7 +65,6 @@ public:
                     const char *name=0);
 signals:
     void updateAutoSaveInterval(unsigned int);
-    void updateSidebarStyle(unsigned int);
 };
 
 class DocumentConfigureDialog : public ConfigureDialogBase
@@ -76,8 +74,6 @@ public:
                             QWidget *parent=0,
                             const char *name=0);
 
-    void showAudioPage();
-
     void selectMetadata(QString name);
 };
 
