@@ -3,7 +3,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -38,10 +38,12 @@ typedef enum
 {
      STOPPED,
      PLAYING,
-     RECORDING,
+     RECORDING_MIDI,
+     RECORDING_AUDIO,
      STOPPING,
      STARTING_TO_PLAY,
-     STARTING_TO_RECORD,
+     STARTING_TO_RECORD_MIDI,
+     STARTING_TO_RECORD_AUDIO,
      RECORDING_ARMED,                   // gui only state
      QUIT
 } TransportStatus;
