@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -22,6 +22,10 @@
 #ifndef ROSEGARDENGUIDOC_H
 #define ROSEGARDENGUIDOC_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif 
+
 // include files for QT
 #include <qobject.h>
 #include <qstring.h>
@@ -30,7 +34,6 @@
 
 #include "rosegardendcop.h"
 #include "rosegardengui.h"
-#include "audiopreviewthread.h"
 
 #include "Composition.h"
 #include "MappedComposition.h"
@@ -93,10 +96,6 @@ private:
     RosegardenGUIDoc& operator=(const RosegardenGUIDoc &doc);
 
 public:
-    static int FILE_FORMAT_VERSION_MAJOR;
-    static int FILE_FORMAT_VERSION_MINOR;
-    static int FILE_FORMAT_VERSION_POINT;
-
     /**
      * Destructor for the fileclass of the application
      */
@@ -157,7 +156,7 @@ public:
      * "save modified" - asks the user for saving if the document is
      * modified
      */
-    bool saveIfModified();
+    bool saveIfModified();	
 
     /**
      * get the autosave interval in seconds
@@ -182,10 +181,8 @@ public:
 
     /**
      * saves the document under filename and format.
-     *
-     * errMsg will be set to a user-readable error message if save fails
      */	
-    bool saveDocument(const QString &filename, QString& errMsg,
+    bool saveDocument(const QString &filename, const char *format=0,
 		      bool autosave = false);
 
     /**
@@ -246,15 +243,6 @@ public:
 
     const Rosegarden::Studio& getStudio() const { return m_studio;}
 
-    /*
-     * return the AudioPreviewThread
-     */
-    AudioPreviewThread& getAudioPreviewThread()
-        { return m_audioPreviewThread; }
-
-    const AudioPreviewThread& getAudioPreviewThread() const
-        { return m_audioPreviewThread; }
-
     /*
      * return the AudioFileManager
      */
@@ -285,18 +273,14 @@ public:
     /**
      * insert some recorded MIDI events into our recording Segment
      */
-    void insertRecordedMidi(const Rosegarden::MappedComposition &mc);
+    void insertRecordedMidi(const Rosegarden::MappedComposition &mc,
+                            TransportStatus status);
 
-    /**
-     * Update the recording progress -- called regularly from
-     * RosegardenGUIApp::slotUpdatePlaybackPosition() while recording
+    /*
+     *  insert a recording SegmentItem for Audio with a given audio level
      */
-    void updateRecordingMIDISegment();
-
-    /**
-     * Update the recording progress for audio
-     */
-    void updateRecordingAudioSegments();
+    void insertRecordedAudio(const Rosegarden::RealTime &time,
+                             TransportStatus status);
 
     /**
      * Tidy up the recording SegmentItems and other post record jobs
@@ -304,11 +288,23 @@ public:
     void stopRecordingMidi();
     void stopRecordingAudio();
 
+    /**
+     * Update the recording progress -- called regularly from
+     * RosegardenGUIApp::slotUpdatePlaybackPosition() while recording
+     */
+    void updateRecordingSegment();
+
     /**
      * Register audio samples at the sequencer
      */
     void prepareAudio();
 
+    /**
+     * Cause the pointerPositionChanged signal to be emitted and any
+     * associated internal work in the document to happen
+     */
+    void setPointerPosition(Rosegarden::timeT);
+
     /**
      * Cause the playPositionChanged signal to be emitted and any
      * associated internal work in the document to happen
@@ -321,12 +317,6 @@ public:
      */
     void setLoop(Rosegarden::timeT, Rosegarden::timeT);
 
-    /**
-     * Cause the document to use the given time as the origin
-     * when inserting any subsequent recorded data
-     */
-    void setRecordStartTime(Rosegarden::timeT t) { m_recordStartTime = t; }
-
     /*
     * Sync device information with sequencer
     */
@@ -338,8 +328,11 @@ public:
      */
     void getMappedDevice(Rosegarden::DeviceId id);
 
-    void addRecordMIDISegment(Rosegarden::TrackId);
-    void addRecordAudioSegment(Rosegarden::InstrumentId, Rosegarden::AudioFileId);
+    /*
+     * Create a new audio file and return the path to it so that
+     * the sequencer can use it to write to.
+     */
+    std::string createNewAudioFile();
 
     // Audio play and record latencies direct from the sequencer
     //
@@ -356,21 +349,7 @@ public:
     // access the file until lead-out information has been written by the 
     // sequencer.
     //
-    // Note that the sequencer doesn't know the audio file id (yet),
-    // only the instrument it was recorded to.  (It does know the
-    // filename, but the instrument id is enough for us.)
-    //
-    void finalizeAudioFile(Rosegarden::InstrumentId instrument);
-
-    // Tell the document that an audio file has been orphaned.  An
-    // orphaned audio file is a file that was created by recording in
-    // Rosegarden during the current session, but that has been
-    // unloaded from the audio file manager.  It's therefore likely
-    // that no other application will be using it, and that that user
-    // doesn't want to keep it.  We can offer to delete these files
-    // permanently when the document is saved.
-    //
-    void addOrphanedAudioFile(QString fileName);
+    void finalizeAudioFile(Rosegarden::AudioFileId id);
 
     /*
     void setAudioRecordLatency(const Rosegarden::RealTime &latency)
@@ -406,8 +385,7 @@ public:
         { return (dynamic_cast<RosegardenGUIApp*>(parent()))
                                          ->getSequenceManager(); }
 
-    //Obsolete: multitrack MIDI recording. plcl 06/2006.
-    //Rosegarden::Segment *getRecordMIDISegment() { return m_recordMIDISegment; }
+    Rosegarden::Segment *getRecordSegment() { return m_recordSegment; }
 
     QStringList getTimers();
     QString getCurrentTimer();
@@ -422,6 +400,10 @@ public:
 
     static const unsigned int MinNbOfTracks; // 64
 
+    // Turn on and off audio monitoring for a particular instrument
+    //
+    void setAudioMonitoringState(bool value, Rosegarden::InstrumentId id);
+
 public slots:
     /**
      * calls repaint() on all views connected to the document object
@@ -445,11 +427,15 @@ public slots:
      */
     void slotAutoSave();
 
-    void slotSetPointerPosition(Rosegarden::timeT);
-    void slotDragPointerToPosition(Rosegarden::timeT);
+    void slotSetPointerPosition(Rosegarden::timeT t) { setPointerPosition(t); }
     void slotSetPlayPosition(Rosegarden::timeT t) { setPlayPosition(t); }
     void slotSetLoop(Rosegarden::timeT s, Rosegarden::timeT e) {setLoop(s,e);}
 
+    // Record button has changed - tell the sequencer if it's to
+    // an audio track.
+    //
+    void slotNewRecordButton();
+
     void slotDocColoursChanged();
 
     // Cancelling an audio preview
@@ -463,21 +449,10 @@ signals:
     void documentModified(bool);
 
     /**
-     * Emitted during playback, to suggest that views should track along,
-     * as well as when pointer is moved via a click on the loop ruler.
+     * Emitted during playback, to suggest that views should track along
      */
     void pointerPositionChanged(Rosegarden::timeT);
 
-    /**
-     * Emitted when pointer is dragged on the loop ruler
-     */
-    void pointerDraggedToPosition(Rosegarden::timeT);
-
-    /**
-     * Emitted when pointer is dragged on the loop ruler
-     */
-    void loopDraggedToPosition(Rosegarden::timeT);
-
     /**
      * Emitted during recording, to indicate that some new notes (it's
      * only emitted for notes) have appeared in the recording segment
@@ -485,22 +460,8 @@ signals:
      * start of the new region, which is presumed to extend up to the
      * end of the segment.
      */
-    void recordMIDISegmentUpdated(Rosegarden::Segment *recordSegment,
-				  Rosegarden::timeT updatedFrom);
-
-    /**
-     * Emitted when a new MIDI recording segment is set
-     */
-    void newMIDIRecordingSegment(Rosegarden::Segment*);
-
-    /**
-     * Emitted when a new audio recording segment is set
-     */
-    void newAudioRecordingSegment(Rosegarden::Segment*);
-
-    void stoppedAudioRecording();
-    void stoppedMIDIRecording();
-    void audioFileFinalized(Rosegarden::Segment*);
+    void recordingSegmentUpdated(Rosegarden::Segment *recordSegment,
+				 Rosegarden::timeT updatedFrom);
 
     void playPositionChanged(Rosegarden::timeT);
     void loopChanged(Rosegarden::timeT, Rosegarden::timeT);
@@ -527,7 +488,7 @@ protected:
      * @return false if parsing failed
      * @see RoseXmlHandler
      */
-    bool xmlParse(QString fileContents, QString &errMsg,
+    bool xmlParse(QIODevice* file, QString &errMsg,
                   RosegardenProgressDialog *progress,
                   unsigned int elementCount,
 		  bool permanent,
@@ -553,44 +514,7 @@ protected:
     /**
      * Save one segment to the given text stream
      */
-    void saveSegment(QTextStream&, Rosegarden::Segment*, KProgress*,
-                     long totalNbOfEvents, long &count,
-                     QString extraAttributes = QString::null);
-
-    bool deleteOrphanedAudioFiles(bool documentWillNotBeSaved);
-
-
-    /**
-     * A struct formed by a Segment pointer and an iterator to the same 
-     * Segment, used in NoteOn calculations when recording MIDI.
-     */
-    struct NoteOnRec {
-        Rosegarden::Segment *m_segment;
-        Rosegarden::Segment::iterator m_segmentIterator;
-    };
-
-    /**
-     * A vector of NoteOnRec elements, necessary in multitrack MIDI 
-     * recording for NoteOn calculations
-     */
-    typedef std::vector<NoteOnRec>  NoteOnRecSet;
-
-    /**
-     * Store a single NoteOnRec element in the m_noteOnEvents map
-     */
-    void storeNoteOnEvent( Rosegarden::Segment *s, Rosegarden::Segment::iterator it, 
-                           int device, int channel );
-
-    /**
-     * Replace recorded Note events in one or several segments, returning the
-     * resulting NoteOnRecSet
-     */
-    NoteOnRecSet* replaceRecordedEvent(NoteOnRecSet &rec_vec, Rosegarden::Event *fresh);
-    
-    /**
-     * Insert a recorded event in one or several segments
-     */
-    void insertRecordedEvent(Rosegarden::Event *ev, int device, int channel, bool isNoteOn);
+    void saveSegment(QTextStream&, Rosegarden::Segment*, KProgress* = 0, int totalNbOfEvents = 0);
 
     //--------------- Data members ---------------------------------
 
@@ -635,37 +559,11 @@ protected:
     Rosegarden::AudioFileManager m_audioFileManager;
 
     /**
-     * calculates AudioFile previews
+     * a Segment onto which we can record events
      */
-    AudioPreviewThread m_audioPreviewThread;
+    Rosegarden::Segment *m_recordSegment;
 
-    typedef std::map<Rosegarden::InstrumentId, Rosegarden::Segment *> RecordingSegmentMap;
-
-    /** 
-     * Segments onto which we can record MIDI events
-     */
-    //Rosegarden::Segment *m_recordMIDISegment;
-    RecordingSegmentMap m_recordMIDISegments;
-
-    /**
-     * Segments for recording audio (per instrument)
-     */
-    RecordingSegmentMap m_recordAudioSegments;
-    
-    /**
-     * a map[Pitch] of NoteOnRecSet elements, for NoteOn calculations
-     */
-    typedef std::map<int, NoteOnRecSet>                         PitchMap;
-    
-    /**
-     * a map[Channel] of PitchMap
-     */
-    typedef std::map<int, PitchMap>				ChanMap;
-    
-    /**
-     * a map[Port] of ChanMap
-     */
-    typedef std::map<int, ChanMap>				NoteOnMap;
+    typedef std::map<int, Rosegarden::Segment::iterator> NoteOnMap;
 
     /**
      * During recording, we collect note-ons that haven't yet had a note-off
@@ -693,10 +591,6 @@ protected:
 
     Rosegarden::RealTime m_audioRecordLatency;
 
-    Rosegarden::timeT m_recordStartTime;
-
-    std::vector<QString> m_orphanedAudioFiles;
-
     // Autosave period for this document in seconds
     //
     int m_autoSavePeriod;
