@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -28,19 +28,15 @@
 #include <qlineedit.h>
 #include <qtimer.h>
 #include <qlayout.h>
-#include <qobjectlist.h>
 
 #include <kglobal.h>
 #include <kstddirs.h>
 #include <klocale.h>
-#include <kconfig.h>
 
 #include "midipitchlabel.h"
 #include "rosestrings.h"
 #include "widgets.h"
 #include "rosedebug.h"
-#include "rgapplication.h"
-#include "constants.h"
 
 namespace Rosegarden
 {
@@ -70,10 +66,7 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     m_denominator(0),
     m_framesPerSecond(24),
     m_bitsPerFrame(80),
-    m_isExpanded(false),
-    m_haveOriginalBackground(false),
-    m_isBackgroundSet(false),
-    m_sampleRate(0)
+    m_isExpanded(false)
 {
 //     QHBox *b = new QHBox(this);
     m_transport = new RosegardenTransport(this);
@@ -110,17 +103,6 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     m_transport->PlayButton->setToggleButton(true);
     m_transport->RecordButton->setToggleButton(true);
 
-    // Disable the loop button if JACK transport enabled, because this
-    // causes a nasty race condition, and it just seems our loops are not JACK compatible
-    // #1240039 - DMM
-//    KConfig* config = rgapp->config();
-//    config->setGroup(SequencerOptionsConfigGroup);
-//    if (config->readBoolEntry("jacktransport", false))
-//    {
-//        m_transport->LoopButton->setEnabled(false);
-//    }
-
-
     // read only tempo
     //
 //    TempoLineEdit->setReadOnly(true);
@@ -135,7 +117,6 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     // Create Midi label timers
     m_midiInTimer = new QTimer(this);
     m_midiOutTimer = new QTimer(this);
-    m_clearMetronomeTimer = new QTimer(this);
 
     connect(m_midiInTimer, SIGNAL(timeout()),
             SLOT(slotClearMidiInLabel()));
@@ -143,9 +124,6 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     connect(m_midiOutTimer, SIGNAL(timeout()),
             SLOT(slotClearMidiOutLabel()));
 
-    connect(m_clearMetronomeTimer, SIGNAL(timeout()),
-	    SLOT(slotResetBackground()));
-
     m_transport->TimeDisplayLabel->hide();
     m_transport->ToEndLabel->hide();
 
@@ -169,10 +147,6 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     m_panelOpen = *m_transport->PanelOpenButton->pixmap();
     m_panelClosed = *m_transport->PanelCloseButton->pixmap();
 
-
-    connect(m_transport->SetStartLPButton, SIGNAL(clicked()), SLOT(slotSetStartLoopingPointAtMarkerPos()));
-    connect(m_transport->SetStopLPButton, SIGNAL(clicked()), SLOT(slotSetStopLoopingPointAtMarkerPos()));
-
     // clear labels
     //
     slotClearMidiInLabel();
@@ -197,6 +171,7 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     // if the rest of the Transport ever changes then this code
     // will have to as well.
     //
+    //
     QPalette pal;
     pal.setColor(QColorGroup::Foreground, QColor(192, 216, 255));
 
@@ -227,8 +202,6 @@ RosegardenTransportDialog::RosegardenTransportDialog(QWidget *parent,
     // accelerator object
     //
     m_accelerators = new QAccel(this);
-
-
 }
 
 RosegardenTransportDialog::~RosegardenTransportDialog()
@@ -305,67 +278,22 @@ RosegardenTransportDialog::getSMPTEResolution(int &framesPerSecond,
 void
 RosegardenTransportDialog::slotChangeTimeDisplay()
 {
-    if (m_sampleRate == 0) {
-
-	QCString replyType;
-	QByteArray replyData;
-	m_sampleRate = 0;
-
-	if (rgapp->sequencerCall("getSampleRate()", replyType, replyData)) {
-	    QDataStream streamIn(replyData, IO_ReadOnly);
-	    unsigned int result;
-	    streamIn >> result;
-	    m_sampleRate = result;
-	} else {
-	    m_sampleRate = -1;
-	}
-    }
-
     switch (m_currentMode) {
-
     case RealMode:
-	if (m_sampleRate > 0) m_currentMode = FrameMode;
-	else m_currentMode = BarMode;
-	break;
-
-    case FrameMode: m_currentMode = BarMode; break;
-
-    case SMPTEMode: m_currentMode = BarMode; break;
-
-    case BarMode: m_currentMode = BarMetronomeMode; break;
-
-    case BarMetronomeMode: m_currentMode = RealMode; break;
-    }
-
-    switch (m_currentMode) {
-
-    case RealMode:
-	m_clearMetronomeTimer->stop();
-	m_transport->TimeDisplayLabel->hide();
+	m_transport->TimeDisplayLabel->setText("SMPTE");
+	m_transport->TimeDisplayLabel->show();
+	m_currentMode = SMPTEMode;
 	break;
 
     case SMPTEMode:
-	m_clearMetronomeTimer->stop();
-	m_transport->TimeDisplayLabel->setText("SMPTE"); // DO NOT i18n
+	m_transport->TimeDisplayLabel->setText("BAR");
 	m_transport->TimeDisplayLabel->show();
+	m_currentMode = BarMode;
 	break;
 
     case BarMode:
-	m_clearMetronomeTimer->stop();
-	m_transport->TimeDisplayLabel->setText("BAR"); // DO NOT i18n
-	m_transport->TimeDisplayLabel->show();
-	break;
-
-    case BarMetronomeMode:
-	m_clearMetronomeTimer->start(1700, FALSE);
-	m_transport->TimeDisplayLabel->setText("MET"); // DO NOT i18n
-	m_transport->TimeDisplayLabel->show();
-	break;
-
-    case FrameMode:
-	m_clearMetronomeTimer->stop();
-	m_transport->TimeDisplayLabel->setText(QString("%1").arg(m_sampleRate));
-	m_transport->TimeDisplayLabel->show();
+	m_transport->TimeDisplayLabel->hide();
+	m_currentMode = RealMode;
 	break;
     }
 }
@@ -391,11 +319,8 @@ RosegardenTransportDialog::displayRealTime(const Rosegarden::RealTime &rt)
 {
     Rosegarden::RealTime st = rt;
 
-    slotResetBackground();
-
     if (m_lastMode != RealMode) {
 	m_transport->HourColonPixmap->show();
-	m_transport->MinuteColonPixmap->show();
 	m_transport->SecondColonPixmap->hide();
 	m_transport->HundredthColonPixmap->hide();
 	m_lastMode = RealMode;
@@ -436,65 +361,13 @@ RosegardenTransportDialog::displayRealTime(const Rosegarden::RealTime &rt)
     updateTimeDisplay();
 }
 
-void
-RosegardenTransportDialog::displayFrameTime(const Rosegarden::RealTime &rt)
-{
-    Rosegarden::RealTime st = rt;
-
-    slotResetBackground();
-
-    if (m_lastMode != FrameMode) {
-	m_transport->HourColonPixmap->hide();
-	m_transport->MinuteColonPixmap->hide();
-	m_transport->SecondColonPixmap->hide();
-	m_transport->HundredthColonPixmap->hide();
-	m_lastMode = FrameMode;
-    }
-
-    // If time is negative then reverse the time and set the minus flag
-    //
-    if (st < Rosegarden::RealTime::zeroTime)
-    {
-        st = Rosegarden::RealTime::zeroTime - st;
-        if (!m_lastNegative) {
-	    m_transport->NegativePixmap->setPixmap(m_lcdNegative);
-	    m_lastNegative = true;
-	}
-    }
-    else // don't show the flag
-    {
-	if (m_lastNegative) {
-	    m_transport->NegativePixmap->clear();
-	    m_lastNegative = false;
-	}
-    }
-         
-    long frame = Rosegarden::RealTime::realTime2Frame(st, m_sampleRate);
-
-    m_tenThousandths = frame % 10; frame /= 10;
-    m_thousandths = frame % 10; frame /= 10;
-    m_hundreths = frame % 10; frame /= 10;
-    m_tenths = frame % 10; frame /= 10;
-    m_unitSeconds = frame % 10; frame /= 10;
-    m_tenSeconds = frame % 10; frame /= 10;
-    m_unitMinutes = frame % 10; frame /= 10;
-    m_tenMinutes = frame % 10; frame /= 10;
-    m_unitHours = frame % 10; frame /= 10;
-    m_tenHours = frame % 10; frame /= 10;
-    
-    updateTimeDisplay();
-}
-
 void
 RosegardenTransportDialog::displaySMPTETime(const Rosegarden::RealTime &rt)
 {
     Rosegarden::RealTime st = rt;
 
-    slotResetBackground();
-
     if (m_lastMode != SMPTEMode) {
 	m_transport->HourColonPixmap->show();
-	m_transport->MinuteColonPixmap->show();
 	m_transport->SecondColonPixmap->show();
 	m_transport->HundredthColonPixmap->show();
 	m_lastMode = SMPTEMode;
@@ -545,7 +418,6 @@ RosegardenTransportDialog::displayBarTime(int bar, int beat, int unit)
 {
     if (m_lastMode != BarMode) {
 	m_transport->HourColonPixmap->hide();
-	m_transport->MinuteColonPixmap->show();
 	m_transport->SecondColonPixmap->hide();
 	m_transport->HundredthColonPixmap->hide();
 	m_lastMode = BarMode;
@@ -569,16 +441,6 @@ RosegardenTransportDialog::displayBarTime(int bar, int beat, int unit)
 	}
     }
 
-    if (m_currentMode == BarMetronomeMode && unit < 2) {
-	if (beat == 1) {
-	    slotSetBackground(Qt::red);
-	} else {
-	    slotSetBackground(Qt::cyan);
-	}
-    } else {
-	slotResetBackground();
-    }
-
     m_tenThousandths = ( unit ) % 10;
     m_thousandths = ( unit / 10 ) % 10;
     m_hundreths = ( unit / 100 ) % 10;
@@ -695,7 +557,7 @@ RosegardenTransportDialog::updateTimeDisplay()
 }
 
 void
-RosegardenTransportDialog::setTempo(const Rosegarden::tempoT &tempo)
+RosegardenTransportDialog::setTempo(const double &tempo)
 {
     if (m_tempo == tempo) return;
     m_tempo = tempo;
@@ -705,7 +567,7 @@ RosegardenTransportDialog::setTempo(const Rosegarden::tempoT &tempo)
     // where the tempo should always be consistent.  Quarter Note
     // Length is sent (MIDI CLOCK) at 24ppqn.
     //
-    double qnD = 60.0 / Rosegarden::Composition::getTempoQpm(tempo);
+    double qnD = 60.0/tempo;
     Rosegarden::RealTime qnTime =
         Rosegarden::RealTime(long(qnD),
                              long((qnD - double(long(qnD))) * 1000000000.0));
@@ -713,7 +575,7 @@ RosegardenTransportDialog::setTempo(const Rosegarden::tempoT &tempo)
     StudioControl::sendQuarterNoteLength(qnTime);
 
     QString tempoString;
-    tempoString.sprintf("%4.3f", Rosegarden::Composition::getTempoQpm(tempo));
+    tempoString.sprintf("%4.3f", tempo);
 
     m_transport->TempoDisplay->setText(tempoString);
 }
@@ -780,9 +642,9 @@ RosegardenTransportDialog::setMidiInLabel(const Rosegarden::MappedEvent *mE)
             }
             break;
 
-        case MappedEvent::MidiSystemMessage:
+        case MappedEvent::MidiSystemExclusive:
             {
-                m_transport->InDisplay->setText(i18n("SYS MESSAGE"));
+                m_transport->InDisplay->setText(i18n("SYS EXCLSVE"));
             }
             break;
 
@@ -808,9 +670,6 @@ void
 RosegardenTransportDialog::slotClearMidiInLabel()
 {
     m_transport->InDisplay->setText(i18n(QString("NO EVENTS")));
-
-    // also, just to be sure:
-    slotResetBackground();
 }
 
 
@@ -857,9 +716,9 @@ RosegardenTransportDialog::setMidiOutLabel(const Rosegarden::MappedEvent *mE)
             }
             break;
 
-        case MappedEvent::MidiSystemMessage:
+        case MappedEvent::MidiSystemExclusive:
             {
-                m_transport->OutDisplay->setText(i18n("SYS MESSAGE"));
+                m_transport->OutDisplay->setText(i18n("SYS EXCLSVE"));
             }
             break;
 
@@ -896,17 +755,6 @@ RosegardenTransportDialog::closeEvent (QCloseEvent * /*e*/)
 void
 RosegardenTransportDialog::slotLoopButtonClicked()
 {
-    // disable if JACK transport has been set #1240039 - DMM
-//    KConfig* config = rgapp->config();
-//    config->setGroup(SequencerOptionsConfigGroup);
-//    if (config->readBoolEntry("jacktransport", false))
-//    {
-//	//!!! - this will fail silently
-//	m_transport->LoopButton->setEnabled(false);
-//	m_transport->LoopButton->setOn(false);
-//        return;
-//    }
-
     if (m_transport->LoopButton->isOn())
     {
         emit setLoop();
@@ -917,22 +765,6 @@ RosegardenTransportDialog::slotLoopButtonClicked()
     }
 }
 
-// Send signal setLoopStartTime() when button is pressed
-//
-void
-RosegardenTransportDialog::slotSetStartLoopingPointAtMarkerPos()
-{
-    emit setLoopStartTime();
-}
-
-// Send signal setLoopStopTime() when button is pressed
-//
-void
-RosegardenTransportDialog::slotSetStopLoopingPointAtMarkerPos()
-{
-    emit setLoopStopTime();
-}
-
 void
 RosegardenTransportDialog::slotPanelOpenButtonClicked()
 {
@@ -983,51 +815,8 @@ RosegardenTransportDialog::slotEditTimeSignature()
     emit editTimeSignature(this);
 }
 
-void
-RosegardenTransportDialog::slotSetBackground(QColor c)
-{
-    if (!m_haveOriginalBackground) {
-	m_originalBackground = m_transport->LCDBoxFrame->paletteBackgroundColor();
-	m_haveOriginalBackground = true;
-    }
-
-    m_transport->LCDBoxFrame->setPaletteBackgroundColor(c);
-    m_transport->NegativePixmap->setPaletteBackgroundColor(c);
-    m_transport->TenHoursPixmap->setPaletteBackgroundColor(c);
-    m_transport->UnitHoursPixmap->setPaletteBackgroundColor(c);
-    m_transport->TimeDisplayLabel->setPaletteBackgroundColor(c);
-
-/* this is a bit more thorough, but too slow and flickery:
-
-    const QObjectList *children = m_transport->LCDBoxFrame->children();
-    QObjectListIt it(*children);
-    QObject *obj;
-
-    while ((obj = it.current()) != 0) {
-
-	QWidget *w = dynamic_cast<QWidget *>(obj);
-	if (w) {
-	    w->setPaletteBackgroundColor(c);
-	}
-        ++it;
-    }
-
-*/
-
-    m_isBackgroundSet = true;
-}
-
-void
-RosegardenTransportDialog::slotResetBackground()
-{
-    if (m_isBackgroundSet) {
-	slotSetBackground(m_originalBackground);
-    }
-    m_isBackgroundSet = false;
-}
-
 const char* const RosegardenTransportDialog::ConfigGroup = "Transport Controls";
 
 }
 
-#include "rosegardentransportdialog.moc"
+
