@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -49,7 +49,7 @@ public:
 
     static const char* const ConfigGroup;
 
-    enum TimeDisplayMode { RealMode, SMPTEMode, BarMode, BarMetronomeMode, FrameMode };
+    enum TimeDisplayMode { RealMode, SMPTEMode, BarMode };
 
     TimeDisplayMode getCurrentMode() { return m_currentMode; }
     bool isShowingTimeToEnd();
@@ -57,10 +57,9 @@ public:
 
     void displayRealTime(const Rosegarden::RealTime &rt);
     void displaySMPTETime(const Rosegarden::RealTime &rt);
-    void displayFrameTime(const Rosegarden::RealTime &rt);
     void displayBarTime(int bar, int beat, int unit);
 
-    void setTempo(const Rosegarden::tempoT &tempo);
+    void setTempo(const double &tempo);
     void setTimeSignature(const Rosegarden::TimeSignature &timeSig);
 
     void setSMPTEResolution(int framesPerSecond, int bitsPerFrame);
@@ -114,12 +113,6 @@ public slots:
     void slotEditTempo();
     void slotEditTimeSignature();
 
-    void slotSetBackground(QColor);
-    void slotResetBackground();
-
-    void slotSetStartLoopingPointAtMarkerPos();
-    void slotSetStopLoopingPointAtMarkerPos();
-
 signals:
     void closed();
 
@@ -127,9 +120,6 @@ signals:
     //
     void setLoop();
     void unsetLoop();
-    void setLoopStartTime();
-    void setLoopStopTime();
-
     void editTempo(QWidget *);
     void scrollTempo(int);
     void editTimeSignature(QWidget *);
@@ -173,7 +163,7 @@ private:
     int m_thousandths;
     int m_tenThousandths;
 
-    Rosegarden::tempoT m_tempo;
+    double m_tempo;
     int m_numerator;
     int m_denominator;
 
@@ -182,7 +172,6 @@ private:
 
     QTimer *m_midiInTimer;
     QTimer *m_midiOutTimer;
-    QTimer *m_clearMetronomeTimer;
 
     QPixmap m_panelOpen;
     QPixmap m_panelClosed;
@@ -191,12 +180,6 @@ private:
 
     QAccel *m_accelerators;
     bool    m_isExpanded;
-
-    bool m_haveOriginalBackground;
-    bool m_isBackgroundSet;
-    QColor m_originalBackground;
-
-    int m_sampleRate;
 };
 
 }
