@@ -1,9 +1,8 @@
-// -*- c-basic-offset: 4 -*-
 /*
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -29,10 +28,5 @@
 extern QString strtoqstr(const std::string &);
 extern QString strtoqstr(const Rosegarden::PropertyName &);
 extern std::string qstrtostr(const QString &);
-extern double strtodouble(const std::string &);
-extern double qstrtodouble(const QString &);
-
-class QTextCodec;
-extern std::string convertFromCodec(std::string, QTextCodec *);
 
 #endif
