@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -247,8 +247,6 @@ RoseXmlHandler::RoseXmlHandler(RosegardenGUIDoc *doc,
       m_lsb(0),
       m_instrument(0),
       m_plugin(0),
-      m_colourMap(0),
-      m_keyMapping(0),
       m_pluginId(0),
       m_totalElements(elementCount),
       m_elementsSoFar(0),
@@ -413,35 +411,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
     } else if (lcName == "rosegarden-data") {
 
-	// FILE FORMAT VERSIONING -- see comments in
-	// rosegardenguidoc.cpp.  We only care about major and minor
-	// here, not point.
-
-	QString version = atts.value("version");
-	QString smajor = atts.value("format-version-major");
-	QString sminor = atts.value("format-version-minor");
-
-	if (smajor) {
-
-	    int major = smajor.toInt();
-	    int minor = sminor.toInt();
-
-	    if (major > RosegardenGUIDoc::FILE_FORMAT_VERSION_MAJOR) {
-		m_errorString = i18n("This file was written by Rosegarden %1, and it uses\na different file format that cannot be read by this version.").arg(version);
-		return false;
-	    }
-
-	    if (major == RosegardenGUIDoc::FILE_FORMAT_VERSION_MAJOR &&
-		minor >  RosegardenGUIDoc::FILE_FORMAT_VERSION_MINOR) {
-
-                CurrentProgressDialog::freeze();
-	        KStartupLogo::hideIfStillThere();
-
-		KMessageBox::information(0, i18n("This file was written by Rosegarden %1, which is more recent than this version.\nThere may be some incompatibilities with the file format.").arg(version));
-
-		CurrentProgressDialog::thaw();
-	    }
-	}
+        // validate top level open
 
     } else if (lcName == "studio") {
 
@@ -526,12 +496,8 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 	QString hiddenStr = atts.value("hidden");
 	if (hiddenStr) hidden = (hiddenStr == "true");
 
-	bool hiddenBars = false;
-	QString hiddenBarsStr = atts.value("hiddenbars");
-	if (hiddenBarsStr) hiddenBars = (hiddenBarsStr == "true");
-
 	getComposition().addTimeSignature
-	    (t, Rosegarden::TimeSignature(num, denom, common, hidden, hiddenBars));
+	    (t, Rosegarden::TimeSignature(num, denom, common, hidden));
 
     } else if (lcName == "tempo") {
 
@@ -539,22 +505,11 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 	QString timeStr = atts.value("time");
 	if (timeStr) t = timeStr.toInt();
 	
-	Rosegarden::tempoT tempo = Rosegarden::Composition::getTempoForQpm(120.0);
-	QString tempoStr = atts.value("tempo");
-	QString targetStr = atts.value("target");
+	int bph = 120 * 60; // arbitrary
 	QString bphStr = atts.value("bph");
-	if (tempoStr) {
-	    tempo = tempoStr.toInt();
-	} else if (bphStr) {
-	    tempo = Rosegarden::Composition::getTempoForQpm
-		(double(bphStr.toInt()) / 60.0);
-	}
+	if (bphStr) bph = bphStr.toInt();
 
-	if (targetStr) {
-	    getComposition().addTempoAtTime(t, tempo, targetStr.toInt());
-	} else {
-	    getComposition().addTempoAtTime(t, tempo);
-	}	    
+	getComposition().addRawTempo(t, bph);
 
     } else if (lcName == "composition") {
 
@@ -569,23 +524,16 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
         // Get and set the record track
         //
+        int recordTrack = -1;
         QString recordStr = atts.value("recordtrack");
+
         if (recordStr) {
-	    getComposition().setTrackRecording(recordStr.toInt(), true);
+            recordTrack = recordStr.toInt();
         }
 
-	QString recordPlStr = atts.value("recordtracks");
-	if (recordPlStr) {
-	    RG_DEBUG << "Record tracks: " << recordPlStr << endl;
-	    QStringList recordList = QStringList::split(',', recordPlStr);
-	    for (QStringList::iterator i = recordList.begin();
-		 i != recordList.end(); ++i) {
-		RG_DEBUG << "Record track: " << (*i).toInt() << endl;
-		getComposition().setTrackRecording((*i).toInt(), true);
-	    }
-	}
+        getComposition().setRecordTrack(recordTrack);
 
-        // Get and set the position pointer
+        // Get and ste the position pointer
         //
         int position = 0;
         QString positionStr = atts.value("pointer");
@@ -596,22 +544,15 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         getComposition().setPosition(position);
 
 
-        // Get and (eventually) set the default tempo.
-	// We prefer the new compositionDefaultTempo over the
-	// older defaultTempo.
+        // Get and (eventually) set the tempo
         //
-        QString tempoStr = atts.value("compositionDefaultTempo");
+        double tempo = 120.0;
+        QString tempoStr = atts.value("defaultTempo");
         if (tempoStr) {
-	    Rosegarden::tempoT tempo = Rosegarden::tempoT(tempoStr.toInt());
-	    getComposition().setCompositionDefaultTempo(tempo);
-	} else {
-	    tempoStr = atts.value("defaultTempo");
-	    if (tempoStr) {
-		double tempo = qstrtodouble(tempoStr);
-		getComposition().setCompositionDefaultTempo
-		    (Composition::getTempoForQpm(tempo));
-	    }
-	}
+            tempo = tempoStr.toDouble();
+        }
+
+        getComposition().setDefaultTempo(tempo);
         
         // set the composition flag
         m_inComposition = true;
@@ -660,7 +601,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                getComposition().setPlayMetronome(false);
         }
 
-        QString recMetStr = atts.value("recordmetronome");
+        QString recMetStr = atts.value("playmetronome");
         if (recMetStr)
         {
             if (recMetStr.toInt())
@@ -669,11 +610,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                getComposition().setRecordMetronome(false);
         }
 
-	QString nextTriggerIdStr = atts.value("nexttriggerid");
-	if (nextTriggerIdStr) {
-	    getComposition().setNextTriggerSegmentId(nextTriggerIdStr.toInt());
-	}
-
 	QString copyrightStr = atts.value("copyright");
 	if (copyrightStr)
 	{
@@ -734,42 +670,12 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         if (instrumentStr) {
             instrument = instrumentStr.toInt();
         }
-
+       
         Rosegarden::Track *track = new Rosegarden::Track(id,
                                                          instrument,
                                                          position,
                                                          label,
                                                          muted);
-
-	// track properties affecting newly created segments are initialized
-	// to default values in the ctor, so they don't need to be initialized
-	// here
-	// 
-	QString clefStr = atts.value("defaultClef");
-	if (clefStr) {
-	    track->setClef(clefStr.toInt());
-	}
-
-	QString transposeStr = atts.value("defaultTranspose");
-	if (transposeStr) {
-	    track->setTranspose(transposeStr.toInt());
-	}
-
-	QString colorStr = atts.value("defaultColour");
-	if (colorStr) {
-	    track->setColor(transposeStr.toInt());
-	}
-
-	QString highplayStr = atts.value("highestPlayable");
-	if (highplayStr) {
-	    track->setHighestPlayable(highplayStr.toInt());
-	}
-      
-	QString lowplayStr = atts.value("lowestPlayable");
-	if (lowplayStr) {
-	    track->setLowestPlayable(lowplayStr.toInt());
-	}
-
         getComposition().addTrack(track);
 
 
@@ -887,33 +793,8 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         }
 
 	m_currentTime = startTime;
-
-	QString triggerIdStr = atts.value("triggerid");
-	QString triggerPitchStr = atts.value("triggerbasepitch");
-	QString triggerVelocityStr = atts.value("triggerbasevelocity");
-	QString triggerRetuneStr = atts.value("triggerretune");
-	QString triggerAdjustTimeStr = atts.value("triggeradjusttimes");
-
-	if (triggerIdStr) {
-	    int pitch = -1;
-	    if (triggerPitchStr) pitch = triggerPitchStr.toInt();
-	    int velocity = -1;
-	    if (triggerVelocityStr) velocity = triggerVelocityStr.toInt();
-	    Rosegarden::TriggerSegmentRec *rec =
-		getComposition().addTriggerSegment(m_currentSegment,
-						   triggerIdStr.toInt(),
-						   pitch, velocity);
-	    if (rec) {
-		if (triggerRetuneStr)
-		    rec->setDefaultRetune(triggerRetuneStr.lower() == "true");
-		if (triggerAdjustTimeStr)
-		    rec->setDefaultTimeAdjust(qstrtostr(triggerAdjustTimeStr));
-	    }
-	    m_currentSegment->setStartTimeDataMember(startTime);
-	} else {
-	    getComposition().addSegment(m_currentSegment);
-	    getComposition().setSegmentStartTime(m_currentSegment, startTime);
-	}
+        getComposition().addSegment(m_currentSegment);
+        getComposition().setSegmentStartTime(m_currentSegment, startTime);
 
 	QString endMarkerStr = atts.value("endmarker");
 	if (endMarkerStr) {
@@ -1095,19 +976,10 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             return false;
         }
 
-	if (!search.startsWith("/") && !search.startsWith("~")) {
-	    QString docPath = m_doc->getAbsFilePath();
-	    QString dirPath = QFileInfo(docPath).dirPath();
-	    if (QFileInfo(dirPath).exists()) {
-		search = dirPath + "/" + search;
-	    }
-	}
-
         getAudioFileManager().setAudioPath(qstrtostr(search));
 
     } else if (lcName == "begin") {
-
-        double marker = qstrtodouble(atts.value("index"));
+        float marker = atts.value("index").toFloat();
 
         if (!m_currentSegment)
         {
@@ -1125,13 +997,12 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
         // convert to RealTime from float
         int sec = (int)marker;
-        int usec = (int)((marker - ((double)sec)) * 1000000.0);
+        int usec = (int)((marker - ((float)sec)) * 1000000.0);
         m_currentSegment->setAudioStartTime(Rosegarden::RealTime(sec, usec * 1000));
 
 
     } else if (lcName == "end") {
-
-        double marker = qstrtodouble(atts.value("index"));
+        float marker = atts.value("index").toFloat();
 
         if (!m_currentSegment)
         {
@@ -1148,7 +1019,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         }
 
         int sec = (int)marker;
-        int usec = (int)((marker - ((double)sec)) * 1000000.0);
+        int usec = (int)((marker - ((float)sec)) * 1000000.0);
         Rosegarden::RealTime markerTime(sec, usec * 1000);
 
         if (markerTime < m_currentSegment->getAudioStartTime())
@@ -1169,55 +1040,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         timeT absEnd = getComposition().getElapsedTimeForRealTime(realEndTime);
 	m_currentSegment->setEndTime(absEnd);
 
-    } else if (lcName == "fadein") {
-
-        if (!m_currentSegment)
-        {
-            // Don't fail - as this segment could be defunct if we
-            // skipped loading the audio file
-            //
-            return true;
-        }
-
-        if (m_currentSegment->getType() != Rosegarden::Segment::Audio)
-        {
-            m_errorString = "found fade in time in non audio segment";
-            return false;
-        }
-
-        double marker = qstrtodouble(atts.value("time"));
-        int sec = (int)marker;
-        int usec = (int)((marker - ((double)sec)) * 1000000.0);
-        Rosegarden::RealTime markerTime(sec, usec * 1000);
-
-        m_currentSegment->setFadeInTime(markerTime);
-        m_currentSegment->setAutoFade(true);
-
-
-    } else if (lcName == "fadeout") {
-
-        if (!m_currentSegment)
-        {
-            // Don't fail - as this segment could be defunct if we
-            // skipped loading the audio file
-            //
-            return true;
-        }
-
-        if (m_currentSegment->getType() != Rosegarden::Segment::Audio)
-        {
-            m_errorString = "found fade out time in non audio segment";
-            return false;
-        }
-
-        double marker = qstrtodouble(atts.value("time"));
-        int sec = (int)marker;
-        int usec = (int)((marker - ((double)sec)) * 1000000.0);
-        Rosegarden::RealTime markerTime(sec, usec * 1000);
-
-        m_currentSegment->setFadeOutTime(markerTime);
-        m_currentSegment->setAutoFade(true);
-
     } else if (lcName == "device") {
 
         if (m_section != InStudio)
@@ -1266,8 +1088,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 		setMIDIDeviceConnection(connection);
 	    }
 
-	    setMIDIDeviceName(nameStr);
-
 	    QString vstr = atts.value("variation").lower();
 	    Rosegarden::MidiDevice::VariationType variation =
 		Rosegarden::MidiDevice::NoVariations;
@@ -1275,7 +1095,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 		if (vstr == "lsb") {
 		    variation = Rosegarden::MidiDevice::VariationFromLSB;
 		} else if (vstr == "msb") {
-		    variation = Rosegarden::MidiDevice::VariationFromMSB;
+		    variation = Rosegarden::MidiDevice::VariationFromLSB;
 		} else if (vstr == "") {
 		    variation = Rosegarden::MidiDevice::NoVariations;
 		}
@@ -1286,13 +1106,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 		md->setVariationType(variation);
 	    }
 	}
-	else if (type == "softsynth")
-        {
-            m_device = getStudio().getDevice(id);
-
-            if (m_device && m_device->getType() == Rosegarden::Device::SoftSynth)
-                m_device->setName(qstrtostr(nameStr));
-        }
 	else if (type == "audio")
         {
             m_device = getStudio().getDevice(id);
@@ -1373,7 +1186,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             {
                 QString nameStr = (atts.value("name"));
                 Rosegarden::MidiByte pc = atts.value("id").toInt();
-		QString keyMappingStr = (atts.value("keymapping"));
 
                 // Create a new program
                 Rosegarden::MidiProgram program
@@ -1381,8 +1193,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 					  m_msb,
 					  m_lsb),
 		     pc,
-		     qstrtostr(nameStr),
-		     keyMappingStr ? qstrtostr(keyMappingStr) : "");
+		     qstrtostr(nameStr));
 
                 if (m_device->getType() == Rosegarden::Device::Midi)
                 {
@@ -1409,34 +1220,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             }
         }
 
-    } else if (lcName == "keymapping") {
-
-	if (m_section == InInstrument) {
-	    RG_DEBUG << "Old-style keymapping in instrument found, ignoring" << endl;
-	} else {
-
-	    if (m_section != InStudio) {
-		m_errorString = "Found Keymapping outside Studio";
-		return false;
-	    }
-	    
-	    if (m_device && (m_device->getType() == Rosegarden::Device::Midi)) {
-		QString name = atts.value("name");
-		m_keyMapping = new Rosegarden::MidiKeyMapping(qstrtostr(name));
-		m_keyNameMap.clear();
-	    }
-	}
-
-    } else if (lcName == "key") {
-	
-	if (m_keyMapping) {
-	    QString numStr = atts.value("number");
-	    QString namStr = atts.value("name");
-	    if (numStr && namStr) {
-		m_keyNameMap[numStr.toInt()] = qstrtostr(namStr);
-	    }
-	}
-
     } else if (lcName == "controls") {
 
         // Only clear down the controllers list if we have found some controllers in the RG file
@@ -1640,8 +1423,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
         if (m_instrument)
         {
-	    if (m_instrument->getType() == Rosegarden::Instrument::Audio ||
-		m_instrument->getType() == Rosegarden::Instrument::SoftSynth) {
+	    if (m_instrument->getType() == Rosegarden::Instrument::Audio) {
 		// Backward compatibility: "volume" was in a 0-127
 		// range and we now store "level" (float dB) instead.
 		// Note that we have no such compatibility for
@@ -1661,13 +1443,12 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         if (m_section != InBuss &&
 	    (m_section != InInstrument ||
 	     (m_instrument &&
-	      m_instrument->getType() != Rosegarden::Instrument::Audio &&
-	      m_instrument->getType() != Rosegarden::Instrument::SoftSynth))) {
+	      m_instrument->getType() != Rosegarden::Instrument::Audio))) {
             m_errorString = "Found Level outside (audio) Instrument or Buss";
             return false;
         }
 
-        double value = qstrtodouble(atts.value("value"));
+	float value = atts.value("value").toFloat();
 
 	if (m_section == InBuss) {
 	    if (m_buss) m_buss->setLevel(value);
@@ -1691,104 +1472,56 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             m_instrument->setControllerValue(type, value);
         }
 
-    } else if (lcName == "plugin" || lcName == "synth") {
+#ifdef HAVE_LADSPA
 
-	Rosegarden::PluginContainer *container = 0;
+    } else if (lcName == "plugin") {
 
-        if (m_section == InInstrument) container = m_instrument;
-        else if (m_section == InBuss) container = m_buss;
-        else {
-            m_errorString = "Found Plugin outside Instrument or Buss";
+        if (m_section != InInstrument)
+        {
+            m_errorString = "Found Plugin outside Instrument";
             return false;
         }
 
-        // Despite being InInstrument or InBuss we might not actually
-        // have a valid one.
+        // Despite being InInstrument we might not actually have a valid
+        // one.
         //
-        if (container)
+        if (m_instrument)
         {
-	    emit setOperationName(i18n("Loading plugins..."));
-	    RosegardenProgressDialog::processEvents();
-
             // Get the details
-	    int position;
-	    if (lcName == "synth") {
-		position = Rosegarden::Instrument::SYNTH_PLUGIN_POSITION;
-	    } else {
-		position = atts.value("position").toInt();
-	    }
+            int position = atts.value("position").toInt();
+            unsigned long id = atts.value("id").toULong();
+            QString bpStr = atts.value("bypassed");
+            bool bypassed = false;
 
-	    bool bypassed = false;
-	    QString bpStr = atts.value("bypassed");
-	    if (bpStr.lower() == "true")
-		bypassed = true;
-
-	    std::string program = "";
-	    QString progStr = atts.value("program");
-	    if (progStr) {
-		program = qstrtostr(progStr);
-	    }
-
-	    // Plugins are identified by a structured identifier
-	    // string, but we will accept a LADSPA UniqueId if there's
-	    // no identifier, for backward compatibility
-
-	    QString identifier = atts.value("identifier");
+            if (bpStr.lower() == "true")
+                bypassed = true;
 
+            // Check that ID exists
+            //
             Rosegarden::AudioPlugin *plugin = 0;
-	    Rosegarden::AudioPluginManager *apm = getAudioPluginManager();
-
-	    if (!identifier) {
-		if (atts.value("id")) {
-		    unsigned long id = atts.value("id").toULong();
-		    if (apm) plugin = apm->getPluginByUniqueId(id);
-		}
-	    } else {
-		if (apm) plugin = apm->getPluginByIdentifier(identifier);
-	    }
+            if (getAudioPluginManager())
+                plugin = getAudioPluginManager()->getPluginByUniqueId(id);
 
             // If we find the plugin all is well and good but if
             // we don't we just skip it.
             //
+	
             if (plugin)
             {
-                m_plugin = container->getPlugin(position);
-		if (!m_plugin) {
-		    RG_DEBUG << "WARNING: RoseXmlHandler: instrument/buss "
-			     << container->getId() << " has no plugin position "
-			     << position << endl;
-		} else {
-		    m_plugin->setAssigned(true);
-		    m_plugin->setBypass(bypassed);
-		    m_plugin->setIdentifier(plugin->getIdentifier().data());
-		    if (program != "") {
-			m_plugin->setProgram(program);
-		    }
-		}
-            } else {
-		// we shouldn't be halting import of the RG file just because
-		// we can't match a plugin
-		//
-		if (identifier) {
-		    RG_DEBUG << "WARNING: RoseXmlHandler: plugin " << identifier << " not found" << endl;
-		    m_pluginsNotFound.insert(identifier);
-		} else if (atts.value("id")) {
-		    RG_DEBUG << "WARNING: RoseXmlHandler: plugin uid " << atts.value("id") << " not found" << endl;
-		} else {
-		    m_errorString = "No plugin identifier or uid specified";
-		    return false;
-		}
-            }
-        } else { // no instrument
+                m_plugin = m_instrument->getPlugin(position);
+                m_plugin->setAssigned(true);
+                m_plugin->setBypass(bypassed);
+                //RG_DEBUG << "SETTING PLUGIN ASSIGNED AT " << position 
+                     //<< " ON INS " << m_instrument->getId() << endl;
 
-	    if (lcName == "synth") {
-		QString identifier = atts.value("identifier");
-		if (identifier) {
-		    RG_DEBUG << "WARNING: RoseXmlHandler: no instrument for plugin " << identifier << endl;
-		    m_pluginsNotFound.insert(identifier);
-		}
-	    }
-	}
+                m_plugin->setId(id);
+            }
+            else
+            {
+                m_errorString = "Can't find Plugin";
+                return false;
+            }
+        }
 
         m_section = InPlugin;
 
@@ -1800,35 +1533,27 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             return false;
         }
         unsigned long portId = atts.value("id").toULong();
-	double value = qstrtodouble(atts.value("value"));
-	
-	QString changed = atts.value("changed");
-	bool changedSinceProgram = (changed == "true");
+        Rosegarden::MappedObjectValue value = atts.value("value").toFloat();
 
         if (m_plugin)
         {
             m_plugin->addPort(portId, value);
-	    if (changedSinceProgram) {
-		Rosegarden::PluginPortInstance *ppi = m_plugin->getPort(portId);
-		if (ppi) ppi->changedSinceProgramChange = true;
-	    }
+            //RG_DEBUG << "ADDING PORT " << portId << " VALUE = " << value << endl;
         }
 
-    } else if (lcName == "configure") {
+#else
 
-        if (m_section != InPlugin)
-        {
-            m_errorString = "Found Configure outside Plugin";
-            return false;
-        }
+        // just ignore them
 
-        QString key = atts.value("key");
-        QString value = atts.value("value");
+    } else if (lcName == "plugin") {
 
-        if (m_plugin)
-        {
-            m_plugin->setConfigurationValue(qstrtostr(key), qstrtostr(value));
-        }
+        ;
+
+    } else if (lcName == "port") {
+
+        ;
+
+#endif // HAVE_LADSPA
 
     } else if (lcName == "metronome") {
 
@@ -1847,12 +1572,8 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
 	    Rosegarden::MidiMetronome metronome(instrument);
 	    
-	    if (atts.value("barpitch"))
-		metronome.setBarPitch(atts.value("barpitch").toInt());
-	    if (atts.value("beatpitch"))
-		metronome.setBeatPitch(atts.value("beatpitch").toInt());
-	    if (atts.value("subbeatpitch"))
-		metronome.setSubBeatPitch(atts.value("subbeatpitch").toInt());
+	    if (atts.value("pitch"))
+		metronome.setPitch(atts.value("pitch").toInt());
 	    if (atts.value("depth"))
 		metronome.setDepth(atts.value("depth").toInt());
 	    if (atts.value("barvelocity"))
@@ -1884,8 +1605,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             type = Rosegarden::Instrument::Midi;
         else if (stringType == "audio")
             type = Rosegarden::Instrument::Audio;
-        else if (stringType == "softsynth")
-            type = Rosegarden::Instrument::SoftSynth;
         else
         {
             m_errorString = "Found unknown Instrument type";
@@ -1967,7 +1686,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
             return false;
         }
 
-	double value = qstrtodouble(atts.value("value"));
+        float value = atts.value("value").toFloat();
 
 	// if the value retrieved is greater than (say) 15 then we
 	// must have an old-style 0-127 value instead of a shiny new
@@ -2114,11 +1833,7 @@ RoseXmlHandler::endElement(const QString& namespaceURI,
 
     QString lcName = qName.lower();
 
-    if (lcName == "rosegarden-data") {
-
-	getComposition().updateTriggerSegmentReferences();
-
-    } else if (lcName == "event") {
+    if (lcName == "event") {
 
         if (m_currentSegment && m_currentEvent) {
             m_currentSegment->insert(m_currentEvent);
@@ -2181,22 +1896,6 @@ RoseXmlHandler::endElement(const QString& namespaceURI,
 
         m_device = 0;
 
-    } else if (lcName == "keymapping") {
-
-	if (m_section == InStudio) {
-	    if (m_keyMapping) {
-		if (!m_keyNameMap.empty()) {
-		    Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>
-			(m_device);
-		    if (md) {
-			m_keyMapping->setMap(m_keyNameMap);
-			md->addKeyMapping(*m_keyMapping);
-		    }
-		}
-		m_keyMapping = 0;
-	    }
-	}
-
     } else if (lcName == "audiofiles") {
 
         m_section = NoSection;
@@ -2252,10 +1951,7 @@ RoseXmlHandler::fatalError(const QXmlParseException& exception)
 bool
 RoseXmlHandler::endDocument()
 {
-    if (m_foundTempo == false) {
-	getComposition().setCompositionDefaultTempo
-	    (Composition::getTempoForQpm(120.0));
-    }
+    if (m_foundTempo == false) getComposition().setDefaultTempo(120.0);
 
     return true;
 }
@@ -2360,40 +2056,23 @@ RoseXmlHandler::skipToNextPlayDevice()
 
 void
 RoseXmlHandler::setMIDIDeviceConnection(QString connection)
-{ 
+{
     SEQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceConnection(" << connection << ")" << endl;
 
     Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>(m_device);
     if (!md) return;
-
+		    
     QByteArray data;
+    QByteArray replyData;
+    QCString replyType;
     QDataStream arg(data, IO_WriteOnly);
-    
+
     arg << (unsigned int)md->getId();
     arg << connection;
-    
-    rgapp->sequencerSend("setPlausibleConnection(unsigned int, QString)",
-			 data);
+
+    rgapp->sequencerCall("setPlausibleConnection(unsigned int, QString)",
+                         replyType, replyData, data);
     // connection should be sync'd later in the natural course of things
 }
 
-void
-RoseXmlHandler::setMIDIDeviceName(QString name)
-{
-    SEQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceName(" << name << ")" << endl;
-
-    Rosegarden::MidiDevice *md = dynamic_cast<Rosegarden::MidiDevice *>(m_device);
-    if (!md) return;
-
-    QByteArray data;
-    QDataStream arg(data, IO_WriteOnly);
-
-    arg << (unsigned int)md->getId();
-    arg << name;
-
-    std::cerr << "Renaming device " << md->getId() << " to " << name << std::endl;
-	
-    rgapp->sequencerSend("renameDevice(unsigned int, QString)",
-			 data);
-}
 
