@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -27,15 +27,13 @@
 #include <kcommand.h>
 
 #include "Segment.h"
+#include "Composition.h"
 #include "NotationTypes.h"
 #include "rosegardenguidoc.h"
 #include "AudioFileManager.h"
 #include "Selection.h"
-#include "TriggerSegment.h"
 #include "basiccommand.h"
 
-namespace Rosegarden { class Composition; }
-
 /**
  * Base class for commands from the SegmentParameterBox
  */
@@ -282,53 +280,6 @@ private:
 };
 
 
-/**
- * SegmentResizeFromStartCommand moves the start time of a segment
- * leaving the events in it at the same absolute times as before, so
- * padding with rests or deleting events as appropriate.  (Distinct
- * from Segment::setStartTime, as used by SegmentReconfigureCommand,
- * which moves all the events in the segment.)
- * Not for use on audio segments (see AudioSegmentResizeFromStartCommand).
- */
-class SegmentResizeFromStartCommand : public BasicCommand
-{
-public:
-    SegmentResizeFromStartCommand(Rosegarden::Segment *segment,
-				  Rosegarden::timeT newStartTime);
-    virtual ~SegmentResizeFromStartCommand();
-
-protected:
-    virtual void modifySegment();
-
-private:
-    Rosegarden::Segment *m_segment;
-    Rosegarden::timeT m_oldStartTime;
-    Rosegarden::timeT m_newStartTime;
-};
-
-
-/**
- * As above, but for audio segments.
- */
-class AudioSegmentResizeFromStartCommand : public KNamedCommand
-{
-public:
-    AudioSegmentResizeFromStartCommand(Rosegarden::Segment *segment,
-				       Rosegarden::timeT newStartTime);
-    virtual ~AudioSegmentResizeFromStartCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Segment *m_segment;
-    Rosegarden::Segment *m_newSegment;
-    bool m_detached;
-    Rosegarden::timeT m_oldStartTime;
-    Rosegarden::timeT m_newStartTime;
-};
-
-
 class AudioSegmentSplitCommand : public KNamedCommand
 {
 public:
@@ -346,7 +297,7 @@ private:
     Rosegarden::timeT *m_previousEndMarkerTime;
     bool m_detached;
     std::string m_segmentLabel;
-//    Rosegarden::RealTime m_previousEndAudioTime;
+    Rosegarden::RealTime m_previousEndAudioTime;
 };
 
 class SegmentSplitCommand : public KNamedCommand
@@ -409,11 +360,11 @@ private:
 };
 
 
-class SegmentJoinCommand : public KNamedCommand
+class SegmentMergeCommand : public KNamedCommand
 {
 public:
-    SegmentJoinCommand(Rosegarden::SegmentSelection &segments);
-    virtual ~SegmentJoinCommand();
+    SegmentMergeCommand(const Rosegarden::SegmentSelection &segments);
+    virtual ~SegmentMergeCommand();
 
     virtual void execute();
     virtual void unexecute();
@@ -542,7 +493,7 @@ class ModifyDefaultTempoCommand : public KNamedCommand
 {
 public:
     ModifyDefaultTempoCommand(Rosegarden::Composition *composition,
-                              Rosegarden::tempoT tempo):
+                              double tempo):
 	KNamedCommand(getGlobalName()),
         m_composition(composition),
         m_tempo(tempo) {}
@@ -556,8 +507,8 @@ public:
 
 private:
     Rosegarden::Composition *m_composition;
-    Rosegarden::tempoT       m_tempo;
-    Rosegarden::tempoT       m_oldTempo;
+    double                   m_tempo;
+    double                   m_oldTempo;
 };
 
 
@@ -583,7 +534,7 @@ private:
     Rosegarden::Composition *m_composition;
     int                      m_tempoChangeIndex;
     Rosegarden::timeT        m_oldTime;
-    Rosegarden::tempoT       m_oldTempo;
+    long                     m_oldTempo; // bph
 };
 
 
@@ -593,19 +544,17 @@ class AddTempoChangeCommand : public KNamedCommand
 public:
     AddTempoChangeCommand(Rosegarden::Composition *composition,
                           Rosegarden::timeT time,
-                          Rosegarden::tempoT tempo,
-			  Rosegarden::tempoT target = -1):
+                          double tempo):
 	KNamedCommand(getGlobalName()),
         m_composition(composition),
         m_time(time),
         m_tempo(tempo),
-	m_target(target),
         m_oldTempo(0),
         m_tempoChangeIndex(0) {}
 
     virtual ~AddTempoChangeCommand();
 
-    static QString getGlobalName() { return i18n("Change Te&mpo..."); }
+    static QString getGlobalName() { return i18n("Add Te&mpo Change..."); }
 
     virtual void execute();
     virtual void unexecute();
@@ -613,9 +562,8 @@ public:
 private:
     Rosegarden::Composition *m_composition;
     Rosegarden::timeT m_time;
-    Rosegarden::tempoT m_tempo;
-    Rosegarden::tempoT m_target;
-    Rosegarden::tempoT m_oldTempo;
+    double m_tempo; // bpm
+    int m_oldTempo; // bph
     int m_tempoChangeIndex;
 };
 
@@ -713,7 +661,7 @@ public:
     virtual ~ChangeCompositionLengthCommand();
 
     static QString getGlobalName()
-        { return i18n("Change &Composition Start and End..."); }
+        { return i18n("Change &Composition Duration..."); }
 
     virtual void execute();
     virtual void unexecute();
@@ -763,33 +711,10 @@ private:
     bool m_executed;
 };
 
-class SegmentSplitByRecordingSrcCommand : public KNamedCommand
-{
-public:
-    SegmentSplitByRecordingSrcCommand(Rosegarden::Segment *segment,
-                                      int channel, int device);
-    virtual ~SegmentSplitByRecordingSrcCommand();
-    
-    static QString getGlobalName()
-        { return i18n("Split by &Recording Source..."); }
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::Segment *m_segment;
-    Rosegarden::Segment *m_newSegmentA;
-    Rosegarden::Segment *m_newSegmentB;
-    int m_channel;
-    int m_device;
-    bool m_executed;
-};
-
 class SegmentLabelCommand : public KNamedCommand
 {
 public:
-    SegmentLabelCommand(Rosegarden::SegmentSelection &segments,
+    SegmentLabelCommand(const Rosegarden::SegmentSelection &segments,
                         const QString &label);
     virtual ~SegmentLabelCommand();
 
@@ -809,7 +734,7 @@ protected:
 class SegmentColourCommand : public KNamedCommand
 {
 public:
-    SegmentColourCommand(Rosegarden::SegmentSelection &segments,
+    SegmentColourCommand(const Rosegarden::SegmentSelection &segments,
                          const unsigned int index);
     virtual ~SegmentColourCommand();
 
@@ -844,316 +769,4 @@ protected:
 };
 
 
-// Trigger Segment commands.  These are the commands that create
-// and manage the triggered segments themselves.  See editcommands.h
-// for SetTriggerCommand and ClearTriggersCommand which manipulate
-// the events that do the triggering.
-
-class AddTriggerSegmentCommand : public KNamedCommand
-{
-public:
-    AddTriggerSegmentCommand(RosegardenGUIDoc *doc,
-			     Rosegarden::timeT duration, // start time always 0
-			     int basePitch = -1,
-			     int baseVelocity = -1);
-    virtual ~AddTriggerSegmentCommand();
-
-    Rosegarden::TriggerSegmentId getId() const; // after invocation
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::timeT m_duration;
-    int m_basePitch;
-    int m_baseVelocity;
-    Rosegarden::TriggerSegmentId m_id;
-    Rosegarden::Segment *m_segment;
-    bool m_detached;
-};
-
-
-class DeleteTriggerSegmentCommand : public KNamedCommand
-{
-public:
-    DeleteTriggerSegmentCommand(RosegardenGUIDoc *doc,
-				Rosegarden::TriggerSegmentId);
-    virtual ~DeleteTriggerSegmentCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::TriggerSegmentId m_id;
-    Rosegarden::Segment *m_segment;
-    int m_basePitch;
-    int m_baseVelocity;
-    bool m_detached;
-};
-
-
-class PasteToTriggerSegmentCommand : public KNamedCommand
-{
-public:
-    /// If basePitch is -1, the first pitch in the selection will be used
-    PasteToTriggerSegmentCommand(Rosegarden::Composition *composition,
-				 Rosegarden::Clipboard *clipboard,
-				 QString label,
-				 int basePitch = -1,
-				 int baseVelocity = -1);
-    virtual ~PasteToTriggerSegmentCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-protected:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::Clipboard *m_clipboard;
-    QString m_label;
-    int m_basePitch;
-    int m_baseVelocity;
-    Rosegarden::Segment *m_segment;
-    Rosegarden::TriggerSegmentId m_id;
-    bool m_detached;
-};
-
-
-class SetTriggerSegmentBasePitchCommand : public KNamedCommand
-{
-public:
-    SetTriggerSegmentBasePitchCommand(Rosegarden::Composition *composition,
-				      Rosegarden::TriggerSegmentId id,
-				      int newPitch);
-    virtual ~SetTriggerSegmentBasePitchCommand();
-    
-    virtual void execute();
-    virtual void unexecute();
-
-protected:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::TriggerSegmentId m_id;
-    int m_newPitch;
-    int m_oldPitch;
-};
-
-
-class SetTriggerSegmentBaseVelocityCommand : public KNamedCommand
-{
-public:
-    SetTriggerSegmentBaseVelocityCommand(Rosegarden::Composition *composition,
-				      Rosegarden::TriggerSegmentId id,
-				      int newVelocity);
-    virtual ~SetTriggerSegmentBaseVelocityCommand();
-    
-    virtual void execute();
-    virtual void unexecute();
-
-protected:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::TriggerSegmentId m_id;
-    int m_newVelocity;
-    int m_oldVelocity;
-};
-
-
-class SetTriggerSegmentDefaultTimeAdjustCommand : public KNamedCommand
-{
-public:
-    SetTriggerSegmentDefaultTimeAdjustCommand(Rosegarden::Composition *composition,
-					      Rosegarden::TriggerSegmentId id,
-					      std::string newDefaultTimeAdjust);
-    virtual ~SetTriggerSegmentDefaultTimeAdjustCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-protected:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::TriggerSegmentId m_id;
-    std::string m_newDefaultTimeAdjust;
-    std::string m_oldDefaultTimeAdjust;
-};
-
-
-class SetTriggerSegmentDefaultRetuneCommand : public KNamedCommand
-{
-public:
-    SetTriggerSegmentDefaultRetuneCommand(Rosegarden::Composition *composition,
-					  Rosegarden::TriggerSegmentId id,
-					  bool newDefaultRetune);
-    virtual ~SetTriggerSegmentDefaultRetuneCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-protected:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::TriggerSegmentId m_id;
-    bool m_newDefaultRetune;
-    bool m_oldDefaultRetune;
-    bool m_haveOldDefaultRetune;
-};
-
-
-/**
- * CreateTempoMapFromSegment applies timings found in a reference
- * segment to the composition as a whole via the tempo map.
- */
-
-class CreateTempoMapFromSegmentCommand : public KNamedCommand
-{
-public:
-    CreateTempoMapFromSegmentCommand(Rosegarden::Segment *grooveSegment);
-    virtual ~CreateTempoMapFromSegmentCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    void initialise(Rosegarden::Segment *s);
-    
-    Rosegarden::Composition *m_composition;
-
-    typedef std::map<Rosegarden::timeT, Rosegarden::tempoT> TempoMap;
-    TempoMap m_oldTempi;
-    TempoMap m_newTempi;
-};
-    
-
-class CutRangeCommand : public KMacroCommand
-{
-public:
-    CutRangeCommand(Rosegarden::Composition *composition,
-		    Rosegarden::timeT begin,
-		    Rosegarden::timeT end,
-		    Rosegarden::Clipboard *clipboard);
-};
-    
-
-class PasteRangeCommand : public KMacroCommand
-{
-public:
-    PasteRangeCommand(Rosegarden::Composition *composition,
-		      Rosegarden::Clipboard *clipboard,
-		      Rosegarden::timeT pasteTime);
-};
-    
-
-class DeleteRangeCommand : public KMacroCommand
-{
-public:
-    DeleteRangeCommand(Rosegarden::Composition *composition,
-		       Rosegarden::timeT begin,
-		       Rosegarden::timeT end);
-    virtual ~DeleteRangeCommand();
-
-private:
-    class RejoinCommand : public KNamedCommand
-    {
-    public:
-	// This command rejoins s on to a subsequent segment on the same
-	// track that ends at endMarkerTime (presumably the original end
-	// marker time of s, with the range duration subtracted).
-
-	RejoinCommand(Rosegarden::Composition *c,
-		      Rosegarden::Segment *s,
-		      Rosegarden::timeT endMarkerTime) :
-	    KNamedCommand(i18n("Rejoin Command")),
-	    m_composition(c), m_segment(s), m_endMarkerTime(endMarkerTime),
-	    m_joinCommand(0) { }
-
-	~RejoinCommand() { delete m_joinCommand; }
-
-	void execute();
-	void unexecute() { if (m_joinCommand) m_joinCommand->unexecute(); }
-
-    private:
-	Rosegarden::Composition *m_composition;
-	Rosegarden::Segment *m_segment;
-	Rosegarden::timeT m_endMarkerTime;
-
-	SegmentJoinCommand *m_joinCommand;
-    };
-};
-
-
-class EraseSegmentsStartingInRangeCommand : public KNamedCommand
-{
-public:
-    EraseSegmentsStartingInRangeCommand(Rosegarden::Composition *composition,
-					Rosegarden::timeT begin,
-					Rosegarden::timeT end);
-    virtual ~EraseSegmentsStartingInRangeCommand();
-    
-    virtual void execute();
-    virtual void unexecute();
-    
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::timeT m_beginTime;
-    Rosegarden::timeT m_endTime;
-    
-    bool m_detached;
-    std::vector<Rosegarden::Segment *> m_detaching;
-};
-
-/**
- * Pull all segments, time sigs, tempos etc starting after the end of
- * a given range back by the duration of that range, so as to fill in
- * the (presumably empty) range itself.
- */
-class OpenOrCloseRangeCommand : public KNamedCommand
-{
-public:
-    OpenOrCloseRangeCommand(Rosegarden::Composition *composition,
-			    Rosegarden::timeT rangeBegin,
-			    Rosegarden::timeT rangeEnd,
-			    bool open);
-    virtual ~OpenOrCloseRangeCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::timeT m_beginTime;
-    Rosegarden::timeT m_endTime;
-
-    bool m_prepared;
-    bool m_opening;
-
-    std::vector<Rosegarden::Segment *> m_moving;
-
-    Rosegarden::TimeSignatureSelection m_timesigsPre;
-    Rosegarden::TimeSignatureSelection m_timesigsPost;
-
-    Rosegarden::TempoSelection m_temposPre;
-    Rosegarden::TempoSelection m_temposPost;
-};
-
-
-/**
- * Paste time signature and tempo data from the given clipboard into
- * the given composition starting at the given time.
- */
-class PasteConductorDataCommand : public KNamedCommand
-{
-public:
-    PasteConductorDataCommand(Rosegarden::Composition *composition,
-			      Rosegarden::Clipboard *clipboard,
-			      Rosegarden::timeT t);
-    virtual ~PasteConductorDataCommand();
-
-    virtual void execute();
-    virtual void unexecute();
-
-private:
-    Rosegarden::Composition *m_composition;
-    Rosegarden::Clipboard *m_clipboard;
-    Rosegarden::timeT m_t0;
-};
-
-
 #endif  // _SEGMENTCOMMANDS_H_
