@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -60,9 +60,7 @@ SegmentParameterBox::SegmentParameterBox(RosegardenGUIDoc* doc,
 
 SegmentParameterBox::~SegmentParameterBox()
 {
-    if (!isCompositionDeleted()) {
-        m_doc->getComposition().removeObserver(this);
-    }
+    m_doc->getComposition().removeObserver(this);
 }
 
 
@@ -75,8 +73,7 @@ SegmentParameterBox::initBox()
     // magic numbers: 13 is the height of the menu pixmaps, 10 is just 10
     int comboHeight = std::max(fontMetrics.height(), 13) + 10;
 
-//    QFrame *frame = new QFrame(this);
-    QGridLayout *gridLayout = new QGridLayout(this, 6, 4, 4, 2);
+    QGridLayout *gridLayout = new QGridLayout(this, 6, 2, 8, 1);
 
     QLabel *label = new QLabel(i18n("Label"), this);
     QLabel *repeatLabel    = new QLabel(i18n("Repeat"), this);
@@ -84,9 +81,6 @@ SegmentParameterBox::initBox()
     QLabel *transposeLabel = new QLabel(i18n("Transpose"), this);
     QLabel *delayLabel     = new QLabel(i18n("Delay"), this);
     QLabel *colourLabel    = new QLabel(i18n("Color"), this);
-    m_autoFadeLabel        = new QLabel(i18n("Audio auto-fade"), this);
-    m_fadeInLabel          = new QLabel(i18n("Fade in"), this);
-    m_fadeOutLabel         = new QLabel(i18n("Fade out"), this);
 
     // HBox for label
     //
@@ -95,13 +89,12 @@ SegmentParameterBox::initBox()
     // Label ..
     m_label = new QLabel(hbox);
     m_label->setFont(font);
-    m_label->setFixedWidth(120);
     m_label->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+    m_label->setFixedWidth(100);
 
     // .. and edit button
     m_labelButton = new QPushButton("...", hbox);
     m_labelButton->setFont(font);
-    m_labelButton->setFixedWidth(25);
 
     connect(m_labelButton, SIGNAL(released()),
             SLOT(slotEditSegmentLabel()));
@@ -144,16 +137,16 @@ SegmentParameterBox::initBox()
     connect(m_delayValue, SIGNAL(activated(int)),
             SLOT(slotDelaySelected(int)));
 
-    // Detect when the document colours are updated
-    connect(m_doc, SIGNAL(docColoursChanged()),
-            this, SLOT(slotDocColoursChanged()));
+//     // Detect when the document colours are updated
+//     connect (m_doc, SIGNAL(docColoursChanged()),
+//              this, SLOT(slotDocColoursChanged()));
 
     // handle text changes for delay
     connect(m_delayValue, SIGNAL(textChanged(const QString&)),
             SLOT(slotDelayTextChanged(const QString &)));
 
     // set up combo box for colours
-    m_colourValue = new KComboBox(false, this);
+    m_colourValue = new KComboBox(this);
     m_colourValue->setFont(font);
     m_colourValue->setFixedHeight(comboHeight);
 
@@ -161,27 +154,7 @@ SegmentParameterBox::initBox()
     connect(m_colourValue, SIGNAL(activated(int)),
             SLOT(slotColourSelected(int)));
 
-    // Audio autofade enabled
-    //
-    m_autoFadeBox = new QCheckBox(this);
-    connect(m_autoFadeBox, SIGNAL(stateChanged(int)),
-            this, SLOT(slotAudioFadeChanged(int)));
 
-    // Fade in and out times
-    //
-    m_fadeInSpin = new QSpinBox(this);
-    m_fadeInSpin->setMinValue(0);
-    m_fadeInSpin->setMaxValue(5000);
-    m_fadeInSpin->setSuffix(i18n(" ms"));
-    connect(m_fadeInSpin, SIGNAL(valueChanged(int)),
-            this, SLOT(slotFadeInChanged(int)));
-
-    m_fadeOutSpin = new QSpinBox(this);
-    m_fadeOutSpin->setMinValue(0);
-    m_fadeOutSpin->setMaxValue(5000);
-    m_fadeOutSpin->setSuffix(i18n(" ms"));
-    connect(m_fadeOutSpin, SIGNAL(valueChanged(int)),
-            this, SLOT(slotFadeOutChanged(int)));
 
     label->setFont(font);
     repeatLabel->setFont(font);
@@ -189,38 +162,26 @@ SegmentParameterBox::initBox()
     transposeLabel->setFont(font);
     delayLabel->setFont(font);
     colourLabel->setFont(font);
-    m_autoFadeLabel->setFont(font);
-    m_fadeInLabel->setFont(font);
-    m_fadeOutLabel->setFont(font);
 
-    gridLayout->addRowSpacing(0, 12);
+    gridLayout->addRowSpacing(0, 8);
 
-    gridLayout->addWidget(label, 1, 0, AlignRight);
-    gridLayout->addMultiCellWidget(hbox, 1, 1, 1, 3, AlignLeft);
+    gridLayout->addWidget(label,         1, 0, AlignLeft);
+    gridLayout->addWidget(hbox,       1, 1, AlignLeft);
 
-    gridLayout->addWidget(repeatLabel, 2, 0, AlignRight);
+    gridLayout->addWidget(repeatLabel,   2, 0, AlignLeft);
     gridLayout->addWidget(m_repeatValue, 2, 1, AlignLeft);
 
-    gridLayout->addWidget(transposeLabel, 2, 2, AlignRight);
-    gridLayout->addWidget(m_transposeValue, 2, 3);
-
-    gridLayout->addWidget(quantizeLabel, 3, 0, AlignRight);
+    gridLayout->addWidget(quantizeLabel,   3, 0, AlignLeft);
     gridLayout->addWidget(m_quantizeValue, 3, 1);
 
-    gridLayout->addWidget(delayLabel, 3, 2, AlignRight);
-    gridLayout->addWidget(m_delayValue, 3, 3);
+    gridLayout->addWidget(transposeLabel,   4, 0, AlignLeft);
+    gridLayout->addWidget(m_transposeValue, 4, 1);
 
-    gridLayout->addWidget(colourLabel, 4, 0, AlignRight);
-    gridLayout->addMultiCellWidget(m_colourValue, 4, 4, 1, 3);
+    gridLayout->addWidget(delayLabel,   5, 0, AlignLeft);
+    gridLayout->addWidget(m_delayValue, 5, 1);
 
-    m_autoFadeLabel->hide();
-    m_autoFadeBox->hide();
-
-    gridLayout->addWidget(m_fadeInLabel,   5, 0, AlignRight);
-    gridLayout->addWidget(m_fadeInSpin,  5, 1);
-
-    gridLayout->addWidget(m_fadeOutLabel,  5, 2, AlignRight);
-    gridLayout->addWidget(m_fadeOutSpin, 5, 3);
+    gridLayout->addWidget(colourLabel,   6, 0, AlignLeft);
+    gridLayout->addWidget(m_colourValue, 6, 1);
 
     // populate the quantize combo
     //
@@ -249,7 +210,7 @@ SegmentParameterBox::initBox()
 
     m_delays.clear();
 
-    for (int i = 0; i < 6; i++)
+    for (int i = 0; i < 9; i++)
     {
 	Rosegarden::timeT time = 0;
 	if (i > 0 && i < 6) {
@@ -282,22 +243,18 @@ SegmentParameterBox::initBox()
 
     // populate m_colourValue
     slotDocColoursChanged();
+
 }
 
 void
 SegmentParameterBox::setDocument(RosegardenGUIDoc* doc)
 {
-    if (m_doc != 0)
-        disconnect(m_doc, SIGNAL(docColoursChanged()),
-                   this, SLOT(slotDocColoursChanged()));
-        
     m_doc = doc;
 
     // Detect when the document colours are updated
     connect (m_doc, SIGNAL(docColoursChanged()),
              this, SLOT(slotDocColoursChanged()));
 
-    slotDocColoursChanged(); // repopulate combo
 }
 
 void
@@ -322,8 +279,6 @@ SegmentParameterBox::useSegments(const Rosegarden::SegmentSelection &segments)
 void
 SegmentParameterBox::slotDocColoursChanged()
 {
-    RG_DEBUG << "SegmentParameterBox::slotDocColoursChanged()" << endl;
-	
     m_colourValue->clear();
     m_colourList.clear();
     // Populate it from composition.m_segmentColourMap
@@ -334,12 +289,12 @@ SegmentParameterBox::slotDocColoursChanged()
     for (Rosegarden::RCMap::const_iterator it=temp.begin(); it != temp.end(); ++it)
     {
         QPixmap colour(15,15);
-        colour.fill(Rosegarden::GUIPalette::convertColour(it->second.first));
+        colour.fill(RosegardenGUIColours::convertColour(it->second.first));
         if (it->second.second == std::string(""))
             m_colourValue->insertItem(colour, i18n("Default Color"), i);
         else
             m_colourValue->insertItem(colour, strtoqstr(it->second.second), i);
-        m_colourList[it->first] = i; // maps colour number to menu index
+        m_colourList[it->first] = i;
         ++i;
     }
 
@@ -351,7 +306,7 @@ SegmentParameterBox::slotDocColoursChanged()
 
 void SegmentParameterBox::update()
 {
-    RG_DEBUG << "SegmentParameterBox::update()" << endl;
+    RG_DEBUG << "SegmentParameterBox::update()\n";
 
     populateBoxFromSegments();
 }
@@ -649,76 +604,6 @@ SegmentParameterBox::populateBoxFromSegments()
 
     m_colourValue->setEnabled(diffcolours != NotApplicable);
 
-    // Enable or disable the fade in/out params
-    if (m_segments.size() == 1 && 
-        (*(m_segments.begin()))->getType() == Rosegarden::Segment::Audio)
-    {
-        m_autoFadeBox->blockSignals(true);
-        m_fadeInSpin->blockSignals(true);
-        m_fadeOutSpin->blockSignals(true);
-
-/*!!! No, not setting up autofade widgets.  The implementation's too
-      incomplete to finish for this release.
-
-      (Or for the next one after the one the previous comment referred to.)
-
-        m_fadeInLabel->show();
-        m_fadeInSpin->show();
-        m_fadeOutLabel->show();
-        m_fadeOutSpin->show();
-
-	instead:
-*/
-        m_fadeInLabel->hide();
-        m_fadeInSpin->hide();
-        m_fadeOutLabel->hide();
-        m_fadeOutSpin->hide();
-
-        m_autoFadeLabel->setEnabled(true);
-        m_autoFadeBox->setEnabled(true);
-        m_fadeInLabel->setEnabled(true);
-        m_fadeInSpin->setEnabled(true);
-        m_fadeOutLabel->setEnabled(true);
-        m_fadeOutSpin->setEnabled(true);
-
-        Rosegarden::Segment *seg = *(m_segments.begin());
-
-        int fadeInTime = seg->getFadeInTime().sec * 1000 +
-            seg->getFadeInTime().msec();
-        m_fadeInSpin->setValue(fadeInTime);
-
-        int fadeOutTime = seg->getFadeOutTime().sec * 1000 +
-            seg->getFadeOutTime().msec();
-        m_fadeOutSpin->setValue(fadeOutTime);
-
-        m_autoFadeBox->setChecked(seg->isAutoFading());
-
-        m_autoFadeBox->blockSignals(false);
-        m_fadeInSpin->blockSignals(false);
-        m_fadeOutSpin->blockSignals(false);
-    }
-    else
-    {
-        m_autoFadeLabel->setEnabled(false);
-        m_autoFadeBox->setEnabled(false);
-        m_fadeInLabel->setEnabled(false);
-        m_fadeInSpin->setEnabled(false);
-        m_fadeOutLabel->setEnabled(false);
-        m_fadeOutSpin->setEnabled(false);
-
-        m_autoFadeLabel->hide();
-        m_autoFadeBox->hide();
-        m_fadeInLabel->hide();
-        m_fadeInSpin->hide();
-        m_fadeOutLabel->hide();
-        m_fadeOutSpin->hide();
-
-        m_autoFadeBox->setChecked(false);
-        m_fadeInSpin->setValue(0);
-        m_fadeOutSpin->setValue(0);
-    }
-
-
 }
 
 void SegmentParameterBox::slotRepeatPressed()
@@ -858,15 +743,14 @@ SegmentParameterBox::slotColourSelected(int value)
 {
     if (value != m_addColourPos)
     {
-        unsigned int temp = 0;
+        unsigned int temp;
 
-	RosegardenColourTable::ColourList::const_iterator pos;
-	for (pos = m_colourList.begin(); pos != m_colourList.end(); ++pos) {
-	    if (pos->second == value) {
-		temp = pos->first;
-		break;
-	    }
-	}
+        RosegardenColourTable::ColourList::const_iterator pos = m_colourList.find(value);
+
+        if (pos != m_colourList.end())
+            temp = pos->first;
+        else // Somehow we are trying to set a colour which doesn't exist
+            temp = 0;
 
         Rosegarden::SegmentSelection segments;
         std::vector<Rosegarden::Segment*>::iterator it;
@@ -895,7 +779,7 @@ SegmentParameterBox::slotColourSelected(int value)
 
             if (result == KColorDialog::Accepted)
             {
-                Rosegarden::Colour newRColour = Rosegarden::GUIPalette::convertColour(newColour);
+                Rosegarden::Colour newRColour = RosegardenGUIColours::convertColour(newColour);
                 newMap.addItem(newRColour, qstrtostr(newName));
                 SegmentColourMapCommand *command = new SegmentColourMapCommand(m_doc, newMap);
                 addCommandToHistory(command);
@@ -957,73 +841,3 @@ SegmentParameterBox::slotEditSegmentLabel()
     }
 }
 
-
-void
-SegmentParameterBox::slotAudioFadeChanged(int value)
-{
-    RG_DEBUG << "SegmentParameterBox::slotAudioFadeChanged - value = "
-             << value << endl;
-
-    if (m_segments.size() == 0)
-        return;
-
-    bool state = false;
-    if (value == QButton::On) state = true;
-
-    std::vector<Rosegarden::Segment*>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
-        (*it)->setAutoFade(state);
-    }
-
-}
-
-
-void
-SegmentParameterBox::slotFadeInChanged(int value)
-{
-    RG_DEBUG << "SegmentParameterBox::slotFadeInChanged - value = "
-             << value << endl;
-
-    if (m_segments.size() == 0)
-        return;
-
-    if (value == 0 && m_fadeOutSpin->value() == 0) slotAudioFadeChanged(QButton::Off);
-    else slotAudioFadeChanged(QButton::On);
-
-    // Convert from ms
-    //
-    Rosegarden::RealTime fadeInTime(value/1000, (value % 1000) * 1000000);
-
-    std::vector<Rosegarden::Segment*>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
-        (*it)->setFadeInTime(fadeInTime);
-    }
-
-    emit documentModified();
-}
-
-void
-SegmentParameterBox::slotFadeOutChanged(int value)
-{
-    RG_DEBUG << "SegmentParameterBox::slotFadeOutChanged - value = "
-             << value << endl;
-
-    if (m_segments.size() == 0)
-        return;
-
-    if (value == 0 && m_fadeInSpin->value() == 0) slotAudioFadeChanged(QButton::Off);
-    else slotAudioFadeChanged(QButton::On);
-
-    // Convert from ms
-    //
-    Rosegarden::RealTime fadeOutTime(value/1000000, (value % 1000) * 10000000);
-
-    std::vector<Rosegarden::Segment*>::iterator it;
-    for (it = m_segments.begin(); it != m_segments.end(); it++) {
-        (*it)->setFadeOutTime(fadeOutTime);
-    }
-
-    emit documentModified();
-}
-
-#include "segmentparameterbox.moc"
