@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -19,11 +19,9 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SEGMENTPARAMETERBOX_H_
-#define _SEGMENTPARAMETERBOX_H_
-
 #include <vector>
 
+
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
@@ -36,7 +34,7 @@
 
 #include "Selection.h"
 #include "colourwidgets.h"
-#include "rosegardenparameterbox.h"
+#include "widgets.h"
 
 
 // Provides a mechanism for viewing and modifying the parameters
@@ -48,8 +46,9 @@ namespace Rosegarden { class Segment; }
 class RosegardenGUIDoc;
 class MultiViewCommandHistory;
 class KCommand;
-class RosegardenTristateCheckBox;
-class QSpinBox;
+
+#ifndef _SEGMENTPARAMETERBOX_H_
+#define _SEGMENTPARAMETERBOX_H_
 
 class SegmentParameterBox : public RosegardenParameterBox,
 			    public Rosegarden::CompositionObserver
@@ -86,10 +85,6 @@ public:
     virtual void segmentRemoved(const Rosegarden::Composition *,
 				Rosegarden::Segment *);
 
-    virtual void showAdditionalControls(bool showThem);
-
-    virtual QString getPreviousBox(RosegardenParameterArea::Arrangement) const;
-
 public slots:
     void slotRepeatPressed();
     void slotQuantizeSelected(int);
@@ -106,13 +101,6 @@ public slots:
     void slotColourSelected(int);
     void slotDocColoursChanged();
 
-    void slotAudioFadeChanged(int);
-    void slotFadeInChanged(int);
-    void slotFadeOutChanged(int);
-
-    void slotHighestPressed();
-    void slotLowestPressed();
-
     virtual void update();
 
 signals:
@@ -122,35 +110,17 @@ signals:
 protected:
     void initBox();
     void populateBoxFromSegments();
-    void updateHighLow();
 
     QLabel                     *m_label;
-    QLabel                     *m_rangeLabel;
     QPushButton                *m_labelButton;
-    QPushButton		       *m_highButton;
-    QPushButton		       *m_lowButton;
     RosegardenTristateCheckBox *m_repeatValue;
     KComboBox                  *m_quantizeValue;
     KComboBox                  *m_transposeValue;
     KComboBox                  *m_delayValue;
     KComboBox                  *m_colourValue;
 
-    // Audio autofade
-    //
-    QLabel                     *m_autoFadeLabel;
-    QCheckBox                  *m_autoFadeBox;
-    QLabel                     *m_fadeInLabel;
-    QSpinBox                   *m_fadeInSpin;
-    QLabel                     *m_fadeOutLabel;
-    QSpinBox                   *m_fadeOutSpin;
-
     int                        m_addColourPos;
 
-    // used to keep track of highest/lowest as there is no associated spinbox
-    // to query for its value
-    int			       m_highestPlayable;
-    int			       m_lowestPlayable;
-
     std::vector<Rosegarden::Segment*> m_segments;
     std::vector<Rosegarden::timeT> m_standardQuantizations;
     std::vector<Rosegarden::timeT> m_delays;
