@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -30,34 +30,30 @@
 #include "Selection.h"
 
 #include "edittool.h"
-#include "compositionitem.h"
 
-namespace Rosegarden { class SegmentSelection; class Segment; }
+class SegmentCanvas;
 class RosegardenGUIDoc;
 class RosegardenGUIApp;
+class SegmentItem;
 class KCommand;
+class QCanvasRectangle;
 class QPopupMenu;  // LDB
-class CompositionView;
 
 namespace Rosegarden { class RulerScale; }
 
-class SegmentToolBox;
-
 //////////////////////////////////////////////////////////////////////
 //                 Segment Tools
 //////////////////////////////////////////////////////////////////////
 
-class SegmentToolBox;
-class SegmentSelector;
-
 // Allow the tools to share the Selector tool's selection
 // through these.
 //
-typedef std::pair<QPoint, CompositionItem> SegmentItemPair;
+typedef std::pair<QPoint, SegmentItem *> SegmentItemPair;
 typedef std::vector<SegmentItemPair> SegmentItemList;
 
 class SegmentTool : public BaseTool
 {
+    Q_OBJECT
 public:
     friend class SegmentToolBox;
 
@@ -77,32 +73,28 @@ public:
 
     void addCommandToHistory(KCommand *command);
 
+signals:
+    void selectedSegments(const Rosegarden::SegmentSelection &);
+
 protected:
-    SegmentTool(CompositionView*, RosegardenGUIDoc *doc);
+    SegmentTool(SegmentCanvas*, RosegardenGUIDoc *doc);
 
     virtual void createMenu();
     virtual bool hasMenu() { return true; }
-    
-    void setCurrentItem(CompositionItem item) { if (item != m_currentItem) { delete m_currentItem; m_currentItem = item; } }
 
     SegmentToolBox* getToolBox();
 
-    bool changeMade() { return m_changeMade; }
-    void setChangeMade(bool c) { m_changeMade = c; }
-
     //--------------- Data members ---------------------------------
 
-    CompositionView*  m_canvas;
-    CompositionItem   m_currentItem;
+    SegmentCanvas*  m_canvas;
+    SegmentItem* m_currentItem;
     RosegardenGUIDoc* m_doc;
-    QPoint            m_origPos;
-    bool              m_changeMade;
 };
 
 class SegmentToolBox : public BaseToolBox
 {
 public:
-    SegmentToolBox(CompositionView* parent, RosegardenGUIDoc*);
+    SegmentToolBox(SegmentCanvas* parent, RosegardenGUIDoc*);
 
     virtual SegmentTool* getTool(const QString& toolName);
     
@@ -111,7 +103,7 @@ protected:
 
     //--------------- Data members ---------------------------------
 
-    CompositionView* m_canvas;
+    SegmentCanvas* m_canvas;
     RosegardenGUIDoc* m_doc;
 };
 
@@ -129,7 +121,6 @@ class SegmentPencil : public SegmentTool
 public:
 
     virtual void ready();
-    virtual void stow();
 
     virtual void handleMouseButtonPress(QMouseEvent*);
     virtual void handleMouseButtonRelease(QMouseEvent*);
@@ -137,11 +128,8 @@ public:
 
     static const QString ToolName;
 
-protected slots:
-    void slotCanvasScrolled(int newX, int newY);
-    
 protected:
-    SegmentPencil(CompositionView*, RosegardenGUIDoc*);
+    SegmentPencil(SegmentCanvas*, RosegardenGUIDoc*);
 
     //--------------- Data members ---------------------------------
 
@@ -168,7 +156,7 @@ public:
     static const QString ToolName;
 
 protected:
-    SegmentEraser(CompositionView*, RosegardenGUIDoc*);
+    SegmentEraser(SegmentCanvas*, RosegardenGUIDoc*);
 };
 
 class SegmentMover : public SegmentTool
@@ -180,7 +168,6 @@ class SegmentMover : public SegmentTool
 public:
 
     virtual void ready();
-    virtual void stow();
 
     virtual void handleMouseButtonPress(QMouseEvent*);
     virtual void handleMouseButtonRelease(QMouseEvent*);
@@ -188,15 +175,18 @@ public:
 
     static const QString ToolName;
 
-protected slots:
-    void slotCanvasScrolled(int newX, int newY);
-
 protected:
-    SegmentMover(CompositionView*, RosegardenGUIDoc*);
+    SegmentMover(SegmentCanvas*, RosegardenGUIDoc*);
 
     //--------------- Data members ---------------------------------
 
     QPoint            m_clickPoint;
+    double            m_currentItemStartX;
+
+    QCanvasRectangle *m_foreGuide;
+    QCanvasRectangle *m_topGuide;
+
+    SegmentItemList  *m_selectedItems;
     bool              m_passedInertiaEdge;
 };
 
@@ -213,29 +203,24 @@ class SegmentResizer : public SegmentTool
 public:
 
     virtual void ready();
-    virtual void stow();
 
     virtual void handleMouseButtonPress(QMouseEvent*);
     virtual void handleMouseButtonRelease(QMouseEvent*);
     virtual int  handleMouseMove(QMouseEvent*);
 
-    static bool cursorIsCloseEnoughToEdge(const CompositionItem&, const QPoint&, int, bool &);
+    static bool cursorIsCloseEnoughToEdge(SegmentItem*, const QPoint&, int);
 
     void setEdgeThreshold(int e) { m_edgeThreshold = e; }
     int getEdgeThreshold() { return m_edgeThreshold; }
 
     static const QString ToolName;
 
-protected slots:
-    void slotCanvasScrolled(int newX, int newY);
-
 protected:
-    SegmentResizer(CompositionView*, RosegardenGUIDoc*, int edgeThreshold = 10);
+    SegmentResizer(SegmentCanvas*, RosegardenGUIDoc*, int edgeThreshold = 10);
 
     //--------------- Data members ---------------------------------
 
     int m_edgeThreshold;
-    bool m_resizeStart;
 };
 
 class SegmentSelector : public SegmentTool
@@ -249,13 +234,24 @@ public:
 
     virtual ~SegmentSelector();
 
-    virtual void ready();
     virtual void stow();
 
     virtual void handleMouseButtonPress(QMouseEvent*);
     virtual void handleMouseButtonRelease(QMouseEvent*);
     virtual int  handleMouseMove(QMouseEvent*);
 
+    // Clear all Segments in our vector and on the view
+    //
+    void clearSelected();
+
+    // Remove the given Segment from the selection, if it's in it
+    // 
+    void removeFromSelection(Rosegarden::Segment *);
+
+    // Add the given Segment to the selection, if we have a SegmentItem for it
+    // 
+    void addToSelection(Rosegarden::Segment *);
+
     // These two alter the behaviour of the selection mode
     //
     // - SegmentAdd (usually when SHIFT is held down) allows
@@ -270,17 +266,30 @@ public:
     bool isSegmentAdding() const { return m_segmentAddMode; }
     bool isSegmentCopying() const { return m_segmentCopyMode; }
 
+    // Return a set of selected Segments
+    //
+    Rosegarden::SegmentSelection getSelectedSegments();
+
     // Return the SegmentItem list for other tools to use
     //
     SegmentItemList* getSegmentItemList() { return &m_selectedItems; }
 
     static const QString ToolName;
 
-protected slots:
-    void slotCanvasScrolled(int newX, int newY);
+public slots:
+    void slotSelectSegmentItem(SegmentItem *selectedItem);
+
+    /**
+     * Connected to the destroyed() signal of the selected segment items
+     *
+     * This is for maintaining the list of selected items
+     */
+    void slotDestroyedSegmentItem(QObject*);
 
 protected:
-    SegmentSelector(CompositionView*, RosegardenGUIDoc*);
+    SegmentSelector(SegmentCanvas*, RosegardenGUIDoc*);
+
+    void addToSelection(SegmentItem*);
 
     //--------------- Data members ---------------------------------
 
@@ -291,10 +300,12 @@ protected:
     QPoint m_clickPoint;
     bool m_segmentQuickCopyDone;
     bool m_passedInertiaEdge;
-    bool m_buttonPressed;
-    bool m_selectionMoveStarted;
 
     SegmentTool *m_dispatchTool;
+
+    QCanvasRectangle *m_foreGuide;
+    QCanvasRectangle *m_topGuide;
+
 };
 
 
@@ -320,15 +331,11 @@ public:
     static const QString ToolName;
 
 protected:
-    SegmentSplitter(CompositionView*, RosegardenGUIDoc*);
+    SegmentSplitter(SegmentCanvas*, RosegardenGUIDoc*);
     
     void drawSplitLine(QMouseEvent*);
     void splitSegment(Rosegarden::Segment *segment,
                       Rosegarden::timeT &splitTime);
-
-    //--------------- Data members ---------------------------------
-    int m_prevX;
-    int m_prevY;
 };
 
 class SegmentJoiner : public SegmentTool
@@ -351,42 +358,33 @@ public:
     static const QString ToolName;
 
 protected:
-    SegmentJoiner(CompositionView*, RosegardenGUIDoc*);
+    SegmentJoiner(SegmentCanvas*, RosegardenGUIDoc*);
 };
 
 
 //////////////////////////////////////////////////////////////////////
 //                SegmentItemPreview
 //////////////////////////////////////////////////////////////////////
-class SegmentItemPreview 
+class SegmentItemPreview
 {
 public:
-    SegmentItemPreview(Rosegarden::Segment& parent,
+    SegmentItemPreview(SegmentItem& parent,
                        Rosegarden::RulerScale* scale);
     virtual ~SegmentItemPreview();
 
-    enum PreviewState {
-	PreviewChanged,
-	PreviewCalculating,
-	PreviewCurrent
-    };
-
     virtual void drawShape(QPainter&) = 0;
 
-    PreviewState getPreviewState() const { return m_previewState; }
+    /**
+     * Returns whether the preview shape shown in the segment needs
+     * to be refreshed
+     */
+    bool isPreviewCurrent()        { return m_previewIsCurrent; }
 
     /**
      * Sets whether the preview shape shown in the segment needs
      * to be refreshed
      */
-    void setPreviewCurrent(bool c)
-    { m_previewState = (c ? PreviewCurrent : PreviewChanged); }
-
-    /**
-     * Clears out the preview entirely so that it will be regenerated
-     * next time
-     */
-    virtual void clearPreview() = 0;
+    void setPreviewCurrent(bool c) { m_previewIsCurrent = c; }
 
     QRect rect();
     
@@ -395,10 +393,11 @@ protected:
 
     //--------------- Data members ---------------------------------
 
+    SegmentItem& m_parent;
     Rosegarden::Segment *m_segment;
     Rosegarden::RulerScale *m_rulerScale;
 
-    PreviewState m_previewState;
+    bool m_previewIsCurrent;
 };
 
 
