@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -37,6 +37,7 @@
 
 #include <ctime>
 
+
 // SequenceManager is a helper class that wraps the sequencing
 // functionality at the GUI level.  The sequencer still communicates
 // with the RosegardenGUIApp but all calls are passed on directly
@@ -88,7 +89,7 @@ public:
     //
 
     /// returns true if the call actually paused playback
-    bool play();
+    bool  play();
 
     // We don't call stop() directly - using stopping() and then
     // call stop().
@@ -102,6 +103,7 @@ public:
     void rewindToBeginning();
     void fastForwardToEnd();
 
+    void setPlayStartTime(const timeT &time);
     void setLoop(const timeT &lhs, const timeT &rhs);
     void notifySequencerStatus(TransportStatus status);
     void sendSequencerJump(const RealTime &time);
@@ -148,6 +150,13 @@ public:
     /// Reset MIDI network
     void resetMidiNetwork();
 
+    /**
+     * Get the plugins that are available at the sequencer and put
+     * them in the local pluginmanager
+     */
+    void getSequencerPlugins(Rosegarden::AudioPluginManager *);
+
+
     /// Reinitialise the studio
     void reinitialiseSequencerStudio();
 
@@ -174,18 +183,16 @@ public:
     virtual void segmentAdded              (const Composition*, Segment*);
     virtual void segmentRemoved            (const Composition*, Segment*);
     virtual void segmentRepeatChanged      (const Composition*, Segment*, bool);
-    virtual void segmentRepeatEndChanged   (const Composition*, Segment*, timeT);
     virtual void segmentEventsTimingChanged(const Composition*, Segment *, timeT delay, RealTime rtDelay);
     virtual void segmentTransposeChanged   (const Composition*, Segment *, int transpose);
     virtual void segmentTrackChanged       (const Composition*, Segment *, TrackId id);
-    virtual void segmentEndMarkerChanged   (const Composition*, Segment *, bool);
     virtual void endMarkerTimeChanged      (const Composition*, bool shorten);
     virtual void trackChanged              (const Composition*, Track*);
-    virtual void trackDeleted              (const Composition*, TrackId);
     virtual void timeSignatureChanged      (const Composition*);
     virtual void metronomeChanged          (const Composition*);
     virtual void soloChanged               (const Composition*, bool solo, TrackId selectedTrack);
     virtual void tempoChanged              (const Composition*);
+    virtual void compositionDeleted        (const Composition*);
 
     void processAddedSegment(Segment*);
     void processRemovedSegment(Segment*);
@@ -205,10 +212,6 @@ public:
 
     /// Ensure that the sequencer file is mapped
     void mapSequencer();
-
-    void setTransport(RosegardenTransportDialog* t) { m_transport = t; }
-    
-    void enableMIDIThruRouting(bool state);
     
 public slots:
 
@@ -220,10 +223,11 @@ signals:
 
     void insertableNoteOnReceived(int pitch, int velocity);
     void insertableNoteOffReceived(int pitch, int velocity);
-    void controllerDeviceEventReceived(Rosegarden::MappedEvent *ev);
     
 protected slots:
+    void slotCountdownCancelled();
     void slotCountdownTimerTimeout();
+    void slotCountdownStop();
 
     // Activated by timer to allow a message to be reported to 
     // the user - we use this mechanism so that the user isn't
@@ -231,13 +235,6 @@ protected slots:
     //
     void slotAllowReport() { m_canReport = true; }
 
-    void slotFoundMountPoint(const QString&,
-                             unsigned long kBSize,
-                             unsigned long kBUsed,
-                             unsigned long kBAvail);
-
-    void slotScheduledCompositionMmapperReset() { resetCompositionMmapper(); }
-    
 protected:
 
     void resetCompositionMmapper();
@@ -245,9 +242,6 @@ protected:
     void resetMetronomeMmapper();
     void resetTempoSegmentMmapper();
     void resetTimeSigSegmentMmapper();
-    void checkRefreshStatus();
-    void sendMIDIRecordingDevice(const QString recordDeviceStr);
-    void restoreRecordSubscriptions();
     
     //--------------- Data members ---------------------------------
 
@@ -270,6 +264,8 @@ protected:
     // pointer to the transport dialog
     RosegardenTransportDialog *m_transport;
 
+    RealTime                   m_playbackAudioLatency;
+
     clock_t                    m_lastRewoundAt;
 
     CountdownDialog           *m_countdownDialog;
@@ -283,14 +279,10 @@ protected:
 
     typedef std::map<Rosegarden::Segment *, int> SegmentRefreshMap;
     SegmentRefreshMap m_segments; // map to refresh status id
-    SegmentRefreshMap m_triggerSegments;
     unsigned int m_compositionRefreshStatusId;
     bool m_updateRequested;
 
-    // used to schedule a composition mmapper reset when the composition end time marker changes
-    // this can be caused by a window resize, and since the reset is potentially expensive we want to collapse
-    // several following requests into one.
-    QTimer                    *m_compositionMmapperResetTimer;
+    void checkRefreshStatus();
 
     // Information that the sequencer is providing to us - for the moment
     // it's only the position pointer.
@@ -302,10 +294,6 @@ protected:
     QTimer                    *m_reportTimer;
     bool                       m_canReport;
 
-    bool                       m_gotDiskSpaceResult;
-    unsigned long              m_diskSpaceKBAvail;
-
-    bool                       m_lastLowLatencySwitchSent;
 };
 
 }
