@@ -3,7 +3,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -48,9 +48,24 @@ ModifyDeviceCommand::ModifyDeviceCommand(
     m_changeBanks(false),
     m_changePrograms(false),
     m_changeControls(false),
-    m_changeKeyMappings(false),
     m_clearBankAndProgramList(false)
 {
+//     if (variationType) {
+// 	m_variationType = *variationType;
+// 	m_changeVariation = true;
+//     }
+//     if (bankList) {
+// 	m_bankList = *bankList;
+// 	m_changeBanks = true;
+//     }
+//     if (programList) {
+// 	m_programList = *programList;
+// 	m_changePrograms = true;
+//     } 
+//     if (controlList) {
+// 	m_controlList = *controlList;
+// 	m_changeControls = true;
+//     }
 }
 
 void ModifyDeviceCommand::setVariation(Rosegarden::MidiDevice::VariationType variationType)
@@ -77,12 +92,6 @@ void ModifyDeviceCommand::setControlList(const Rosegarden::ControlList &controlL
     m_changeControls = true;
 }
 
-void ModifyDeviceCommand::setKeyMappingList(const Rosegarden::KeyMappingList &keyMappingList)
-{
-    m_keyMappingList = keyMappingList;
-    m_changeKeyMappings = true;
-}
-
 void
 ModifyDeviceCommand::execute()
 {
@@ -107,7 +116,6 @@ ModifyDeviceCommand::execute()
     m_oldBankList = midiDevice->getBanks();
     m_oldProgramList = midiDevice->getPrograms();
     m_oldControlList = midiDevice->getControlParameters();
-    m_oldKeyMappingList = midiDevice->getKeyMappings();
     m_oldLibrarianName = midiDevice->getLibrarianName();
     m_oldLibrarianEmail = midiDevice->getLibrarianEmail();
     m_oldVariationType = midiDevice->getVariationType();
@@ -123,10 +131,6 @@ ModifyDeviceCommand::execute()
             if (m_changeBanks) midiDevice->replaceBankList(m_bankList);
             if (m_changePrograms) midiDevice->replaceProgramList(m_programList);
         }
-
-	if (m_changeKeyMappings) {
-	    midiDevice->replaceKeyMappingList(m_keyMappingList);
-	}
         
         if (m_rename) midiDevice->setName(m_name);
         midiDevice->setLibrarian(m_librarianName, m_librarianEmail);
@@ -140,10 +144,6 @@ ModifyDeviceCommand::execute()
             if (m_changeBanks) midiDevice->mergeBankList(m_bankList);
             if (m_changePrograms) midiDevice->mergeProgramList(m_programList);
         }
-
-	if (m_changeKeyMappings) {
-	    midiDevice->mergeKeyMappingList(m_keyMappingList);
-	}
         
 	if (m_rename) {
 	    std::string mergeName = midiDevice->getName() +
@@ -180,7 +180,6 @@ ModifyDeviceCommand::unexecute()
     midiDevice->replaceBankList(m_oldBankList);
     midiDevice->replaceProgramList(m_oldProgramList);
     midiDevice->replaceControlParameters(m_oldControlList);
-    midiDevice->replaceKeyMappingList(m_oldKeyMappingList);
     midiDevice->setLibrarian(m_oldLibrarianName, m_oldLibrarianEmail);
     if (m_changeVariation) midiDevice->setVariationType(m_oldVariationType);
 }
