@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -141,7 +141,8 @@ TempoView::TempoView(RosegardenGUIDoc *doc, QWidget *parent, Rosegarden::timeT o
 
     m_grid->addWidget(m_list, 2, 1);
 
-    updateViewCaption();
+    setCaption(i18n("%1 - Tempo and Time Signature Editor")
+	       .arg(doc->getTitle()));
 
     doc->getComposition().addObserver(this);
 
@@ -173,18 +174,11 @@ TempoView::TempoView(RosegardenGUIDoc *doc, QWidget *parent, Rosegarden::timeT o
 
 TempoView::~TempoView()
 {
-    if (!getDocument()->isBeingDestroyed() && !isCompositionDeleted()) {
+    if (!getDocument()->isBeingDestroyed()) {
 	getDocument()->getComposition().removeObserver(this);
     }
 }
 
-void
-TempoView::closeEvent(QCloseEvent *e)
-{
-    emit closing();
-    EditViewBase::closeEvent(e);
-}
-
 void
 TempoView::tempoChanged(const Rosegarden::Composition *comp)
 {
@@ -264,17 +258,14 @@ TempoView::applyLayout(int /*staffNo*/)
     if (m_filter & Tempo) {
 	for (int i = 0; i < comp->getTempoChangeCount(); ++i) {
 
-	    std::pair<Rosegarden::timeT, Rosegarden::tempoT> tempo =
-		comp->getTempoChange(i);
+	    std::pair<Rosegarden::timeT, long> tempo = comp->getRawTempoChange(i);
 	
 	    QString desc;
 
-	    //!!! imprecise -- better to work from tempoT directly
-
-	    float qpm = comp->getTempoQpm(tempo.second);
-	    int qpmUnits = int(qpm + 0.001);
-	    int qpmTenths = int((qpm - qpmUnits) * 10 + 0.001);
-	    int qpmHundredths = int((qpm - qpmUnits - qpmTenths/10.0) * 100 + 0.001);
+	    float qpm = float(tempo.second) / 60.0;
+	    int qpmUnits = int(qpm);
+	    int qpmTenths = int((qpm - qpmUnits) * 10);
+	    int qpmHundredths = int((qpm - qpmUnits - qpmTenths/10.0) * 100);
 
 	    Rosegarden::TimeSignature sig = comp->getTimeSignatureAt(tempo.first);
 	    if (sig.getBeatDuration() ==
@@ -282,12 +273,12 @@ TempoView::applyLayout(int /*staffNo*/)
 		desc = i18n("%1.%2%3").
 		    arg(qpmUnits).arg(qpmTenths).arg(qpmHundredths);
 	    } else {
-		float bpm = (qpm *
+		float bpm = (float(tempo.second) *
 			     Rosegarden::Note(Rosegarden::Note::Crotchet).getDuration()) /
-		    sig.getBeatDuration();
-		int bpmUnits = int(bpm + 0.001);
-		int bpmTenths = int((bpm - bpmUnits) * 10 + 0.001);
-		int bpmHundredths = int((bpm - bpmUnits - bpmTenths/10.0) * 100 + 0.001);
+		    (sig.getBeatDuration() * 60.0);
+		int bpmUnits = int(bpm);
+		int bpmTenths = int((bpm - bpmUnits) * 10);
+		int bpmHundredths = int((bpm - bpmUnits - bpmTenths/10.0) * 100);
 
 		desc = i18n("%1.%2%3 qpm (%4.%5%6 bpm)   ").
 		    arg(qpmUnits).arg(qpmTenths).arg(qpmHundredths).
@@ -373,13 +364,6 @@ TempoView::makeInitialSelection(Rosegarden::timeT time)
     }
 }
 
-Rosegarden::Segment *
-TempoView::getCurrentSegment()
-{
-    if (m_segments.empty()) return 0;
-    else return *m_segments.begin();
-}
-
 QString
 TempoView::makeTimeString(Rosegarden::timeT time, int timeMode)
 {
@@ -407,8 +391,7 @@ TempoView::makeTimeString(Rosegarden::timeT time, int timeMode)
     {
 	Rosegarden::RealTime rt =
 	    getDocument()->getComposition().getElapsedRealTime(time);
-//	return QString("%1   ").arg(rt.toString().c_str());
-	return QString("%1   ").arg(rt.toText().c_str());
+	return QString("%1   ").arg(rt.toString().c_str());
     }
 
     default:
@@ -465,14 +448,10 @@ TempoView::slotEditDelete()
     int itemIndex = -1;
 
     m_ignoreUpdates = true;
+    KMacroCommand *command = new KMacroCommand
+	(i18n("Delete Tempo or Time Signature"));
     bool haveSomething = false;
 
-    // We want the Remove commands to be in reverse order, because
-    // removing one item by index will affect the indices of
-    // subsequent items.  So we'll stack them onto here and then pull
-    // them off again.
-    std::vector<KCommand *> commands;
-
     while ((listItem = it.current()) != 0)
     {
         item = dynamic_cast<TempoListItem*>((*it));
@@ -482,29 +461,21 @@ TempoView::slotEditDelete()
         if (item)
         {
 	    if (item->getType() == TempoListItem::TimeSignature) {
-		commands.push_back(new RemoveTimeSignatureCommand
-				   (item->getComposition(),
-				    item->getIndex()));
+		command->addCommand(new RemoveTimeSignatureCommand
+				    (item->getComposition(),
+				     item->getIndex()));
 		haveSomething = true;
 	    } else {
-		commands.push_back(new RemoveTempoChangeCommand
-				   (item->getComposition(),
-				    item->getIndex()));
+		command->addCommand(new RemoveTempoChangeCommand
+				    (item->getComposition(),
+				     item->getIndex()));
 		haveSomething = true;
 	    }		
         }
         ++it;
     }
 
-    if (haveSomething) {
-	KMacroCommand *command = new KMacroCommand
-	    (i18n("Delete Tempo or Time Signature"));
-	for (std::vector<KCommand *>::iterator i = commands.end();
-	     i != commands.begin();) {
-	    command->addCommand(*--i);
-	}
-	addCommandToHistory(command);
-    }
+    if (haveSomething) addCommandToHistory(command);
 
     applyLayout();
     m_ignoreUpdates = false;
@@ -527,14 +498,10 @@ TempoView::slotEditInsertTempo()
 
     connect(&dialog, 
 	    SIGNAL(changeTempo(Rosegarden::timeT,
-                               Rosegarden::tempoT,
-                               Rosegarden::tempoT,
-			       TempoDialog::TempoDialogAction)),
+                               double, TempoDialog::TempoDialogAction)),
 	    this,
             SIGNAL(changeTempo(Rosegarden::timeT,
-			       Rosegarden::tempoT,
-			       Rosegarden::tempoT,
-			       TempoDialog::TempoDialogAction)));
+			       double, TempoDialog::TempoDialogAction)));
 
     dialog.exec();
 }
@@ -613,28 +580,25 @@ TempoView::setupActions()
     EditViewBase::setupActions("tempoview.rc", false);
     
     QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-    QIconSet icon(QPixmap(pixmapDir + "/toolbar/event-insert-tempo.png"));
+    QIconSet icon(QPixmap(pixmapDir + "/toolbar/event-insert-tempo.xpm"));
     
     new KAction(AddTempoChangeCommand::getGlobalName(), icon, Key_I, this,
                 SLOT(slotEditInsertTempo()), actionCollection(),
                 "insert_tempo");
 
-    QCanvasPixmap pixmap(pixmapDir + "/toolbar/event-insert-timesig.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-insert-timesig.xpm"));
     
     new KAction(AddTimeSignatureCommand::getGlobalName(), icon, Key_G, this,
                 SLOT(slotEditInsertTimeSignature()), actionCollection(),
                 "insert_timesig");
 
-    pixmap.load(pixmapDir + "/toolbar/event-delete.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-delete.xpm"));
     
     new KAction(i18n("&Delete"), icon, Key_Delete, this,
                 SLOT(slotEditDelete()), actionCollection(),
                 "delete");
     
-    pixmap.load(pixmapDir + "/toolbar/event-edit.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/event-edit.xpm"));
 
     new KAction(i18n("&Edit Item"), icon, Key_E, this,
                 SLOT(slotEdit()), actionCollection(),
@@ -653,8 +617,7 @@ TempoView::setupActions()
 
     KRadioAction *action;
 
-    pixmap.load(pixmapDir + "/toolbar/time-musical.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-musical.xpm"));
 
     action = new KRadioAction(i18n("&Musical Times"), icon, 0, this,
 			      SLOT(slotMusicalTime()),
@@ -662,8 +625,7 @@ TempoView::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 0) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-real.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-real.xpm"));
 
     action = new KRadioAction(i18n("&Real Times"), icon, 0, this,
 			      SLOT(slotRealTime()),
@@ -671,8 +633,7 @@ TempoView::setupActions()
     action->setExclusiveGroup("timeMode");
     if (timeMode == 1) action->setChecked(true);
 
-    pixmap.load(pixmapDir + "/toolbar/time-raw.png");
-    icon = QIconSet(pixmap);
+    icon = QIconSet(QCanvasPixmap(pixmapDir + "/toolbar/time-raw.xpm"));
 
     action = new KRadioAction(i18n("Ra&w Times"), icon, 0, this,
 			      SLOT(slotRawTime()),
@@ -825,14 +786,10 @@ TempoView::slotPopupEditor(QListViewItem *qitem)
 
 	connect(&dialog, 
 		SIGNAL(changeTempo(Rosegarden::timeT,
-				   Rosegarden::tempoT,
-				   Rosegarden::tempoT,
-				   TempoDialog::TempoDialogAction)),
+				   double, TempoDialog::TempoDialogAction)),
 		this,
 		SIGNAL(changeTempo(Rosegarden::timeT,
-				   Rosegarden::tempoT,
-				   Rosegarden::tempoT,
-				   TempoDialog::TempoDialogAction)));
+				   double, TempoDialog::TempoDialogAction)));
 	
 	dialog.exec();
 	break;
@@ -866,17 +823,6 @@ TempoView::slotPopupEditor(QListViewItem *qitem)
     }
 }
 
-
-void
-TempoView::updateViewCaption()
-{
-    setCaption(i18n("%1 - Tempo and Time Signature Editor")
-	       .arg(getDocument()->getTitle()));
-}
-
-
-
 const char* const TempoView::LayoutConfigGroupName = "TempoView Layout";
 const char* const TempoView::ConfigGroup = "TempoView Options";
 
-#include "tempoview.moc"
