@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,7 +23,7 @@
 #define _TEMPOVIEW_H_
 
 #include "editviewbase.h"
-#include "tempodialog.h"
+#include "dialogs.h"
 #include "Composition.h"
 #include <vector>
 
@@ -85,12 +85,9 @@ public:
 signals:
     // forwarded from tempo dialog:
     void changeTempo(Rosegarden::timeT,  // tempo change time
-                     Rosegarden::tempoT,  // tempo value
-                     Rosegarden::tempoT,  // tempo target
+                     double,             // tempo value
                      TempoDialog::TempoDialogAction); // tempo action
 
-    void closing();
-
 public slots:
     // standard slots
     virtual void slotEditCut();
@@ -127,10 +124,6 @@ protected:
     virtual void readOptions();
     void makeInitialSelection(Rosegarden::timeT);
     QString makeTimeString(Rosegarden::timeT time, int timeMode);
-    virtual Rosegarden::Segment *getCurrentSegment();
-    virtual void updateViewCaption();
-
-    virtual void closeEvent(QCloseEvent *);
 
     //--------------- Data members ---------------------------------
     KListView   *m_list;
