@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -29,16 +29,12 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kstddirs.h>
-#include <kmessagebox.h>
 
 #include "trackbuttons.h"
 #include "Track.h"
 #include "Studio.h"
 #include "colours.h"
 #include "tracklabel.h"
-#include "AudioPluginInstance.h"
-#include "PluginIdentifier.h"
-#include "AudioLevel.h"
 
 #include "segmentcommands.h"
 #include "rosestrings.h"
@@ -84,16 +80,10 @@ TrackVUMeter::TrackVUMeter(QWidget *parent,
                            int height,
                            int position,
                            const char *name):
-    VUMeter(parent, type, false, false, width, height, VUMeter::Horizontal, name),
+    VUMeter(parent, type, false, width, height, VUMeter::Horizontal, name),
     m_position(position), m_textHeight(12)
 {
     setAlignment(AlignCenter);
-
-    QFont font;
-    font.setPointSize(font.pointSize() * 95 / 100);
-    if (font.pointSize() > 14) font.setPointSize(14);
-    font.setBold(false);
-    setFont(font);
 }
 
 
@@ -103,7 +93,6 @@ TrackVUMeter::meterStart()
     clear();
     setMinimumHeight(m_originalHeight);
     setMaximumHeight(m_originalHeight);
-    m_active = true;
 }
 
 
@@ -113,10 +102,6 @@ TrackVUMeter::meterStop()
     setMinimumHeight(m_textHeight);
     setMaximumHeight(m_textHeight);
     setText(QString("%1").arg(m_position + 1));
-    if (m_active) {
-	m_active = false;
-	update();
-    }
 }
 
 TrackButtons::TrackButtons(RosegardenGUIDoc* doc,
@@ -138,6 +123,7 @@ TrackButtons::TrackButtons(RosegardenGUIDoc* doc,
       m_offset(4),
       m_cellSize(trackCellHeight),
       m_borderGap(1),
+      m_lastID(-1),
       m_trackLabelWidth(trackLabelWidth),
       m_popupItem(0),
       m_lastSelected(-1)
@@ -161,7 +147,7 @@ TrackButtons::TrackButtons(RosegardenGUIDoc* doc,
     m_layout->addStretch(20);
 
     connect(m_recordSigMapper, SIGNAL(mapped(int)),
-            this, SLOT(slotToggleRecordTrack(int)));
+            this, SLOT(slotSetRecordTrack(int)));
 
     connect(m_muteSigMapper, SIGNAL(mapped(int)),
             this, SLOT(slotToggleMutedTrack(int)));
@@ -277,14 +263,10 @@ QFrame* TrackButtons::makeButton(Rosegarden::TrackId trackId)
     //
     // 'mute' and 'record' leds
     //
-
-    mute = new KLedButton(Rosegarden::GUIPalette::getColour
-			  (Rosegarden::GUIPalette::MuteTrackLED), trackHBox);
+    mute = new KLedButton(RosegardenGUIColours::MuteTrackLED, trackHBox);
     QToolTip::add(mute, i18n("Mute track"));
     hblayout->addWidget(mute);
-
-    record = new KLedButton(Rosegarden::GUIPalette::getColour
-			    (Rosegarden::GUIPalette::RecordMIDITrackLED), trackHBox);
+    record = new KLedButton(RosegardenGUIColours::RecordTrackLED, trackHBox);
     QToolTip::add(record, i18n("Record on this track"));
     hblayout->addWidget(record);
 
@@ -297,14 +279,15 @@ QFrame* TrackButtons::makeButton(Rosegarden::TrackId trackId)
             m_recordSigMapper, SLOT(map()));
     connect(mute, SIGNAL(stateChanged(bool)),
             m_muteSigMapper, SLOT(map()));
-    m_recordSigMapper->setMapping(record, track->getPosition());
-    m_muteSigMapper->setMapping(mute, track->getPosition());
+    m_recordSigMapper->setMapping(record, trackId);
+    m_muteSigMapper->setMapping(mute, trackId);
 
     // Store the KLedButton
     //
     m_muteLeds.push_back(mute);
     m_recordLeds.push_back(record);
 
+
     //
     // Track label
     //
@@ -377,6 +360,15 @@ void TrackButtons::setButtonMapping(QObject* obj, Rosegarden::TrackId trackId)
 }
 
 
+
+// Return the track that's currently set for recording
+//
+//
+int TrackButtons::selectedRecordTrack()
+{
+    return m_lastID;
+}
+
 // Fill out the buttons with Instrument information
 //
 void
@@ -402,9 +394,8 @@ TrackButtons::populateButtons()
 
             // Set record button from track
             //
-	    bool recording = 
-		m_doc->getComposition().isTrackRecording(track->getId());
-	    setRecordTrack(track->getPosition(), recording);
+            if (m_doc->getComposition().getRecordTrack() == track->getId())
+                setRecordTrack(track->getPosition());
 
             // reset track tokens
             m_trackLabels[i]->setId(track->getId());
@@ -457,15 +448,18 @@ TrackButtons::mutedTracks()
 //
 //
 void
-TrackButtons::slotToggleMutedTrack(int mutedTrackPos)
+TrackButtons::slotToggleMutedTrack(int mutedTrack)
 {
-    RG_DEBUG << "TrackButtons::slotToggleMutedTrack(" << mutedTrackPos << ")\n";
+    RG_DEBUG << "TrackButtons::slotToggleMutedTrack(" << mutedTrack << ")\n";
 
-    if (mutedTrackPos < 0 || mutedTrackPos > (int)m_tracks )
+    if (mutedTrack < 0 || mutedTrack > (int)m_tracks )
         return;
 
     Rosegarden::Track *track = 
-        m_doc->getComposition().getTrackByPosition(mutedTrackPos);
+        m_doc->getComposition().getTrackByPosition(mutedTrack);
+
+    RG_DEBUG << "TrackButtons::slotToggleMutedTrack - track = " << mutedTrack
+             << " is " << !track->isMuted() << endl;
 
     emit muteButton(track->getId(), !track->isMuted()); // will set the value
 }
@@ -516,6 +510,10 @@ TrackButtons::slotUpdateTracks()
     unsigned int newNbTracks = comp.getNbTracks();
     Rosegarden::Track *track = 0;
 
+    track = comp.getTrackById(comp.getRecordTrack());
+    if (track)
+        setRecordTrack(track->getPosition());
+
     if (newNbTracks < m_tracks)
     {
         for (unsigned int i = m_tracks; i > newNbTracks; --i)
@@ -538,7 +536,8 @@ TrackButtons::slotUpdateTracks()
                 }
             }
             else
-                RG_DEBUG << "TrackButtons::slotUpdateTracks - can't find TrackId for position " << i << endl;
+                RG_DEBUG << "TrackButtons::slotUpdateTracks - "
+                         << "can't find TrackId for position " << i << endl;
         }
     }
 
@@ -562,43 +561,14 @@ TrackButtons::slotUpdateTracks()
 		    trackLabel->setText(i18n("<untitled>"));
 		}
 	    }
-	    else {
+	    else
 		trackLabel->setText(strtoqstr(track->getLabel()));
-            }
-            
-//             RG_DEBUG << "TrackButtons::slotUpdateTracks - set button mapping at pos "
-//                      << i << " to track id " << track->getId() << endl;
+	    
 	    setButtonMapping(m_trackLabels[i], track->getId());
 	}
     }
     m_tracks = newNbTracks;
 
-    // Set record status and colour
-
-    for (unsigned int i = 0; i < m_trackLabels.size(); ++i) {
-
-	track = comp.getTrackByPosition(i);
-
-	if (track) {
-
-	    setRecordTrack(i, comp.isTrackRecording(track->getId()));
-
-	    Rosegarden::Instrument *ins =
-		m_doc->getStudio().getInstrumentById(track->getInstrument());
-
-	    if (ins &&
-		ins->getType() == Rosegarden::Instrument::Audio) {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordAudioTrackLED));
-	    } else {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordMIDITrackLED));
-	    }
-	}
-    }
-
     // repopulate the buttons
     populateButtons();
 }
@@ -608,125 +578,52 @@ TrackButtons::slotUpdateTracks()
 //
 //
 void
-TrackButtons::slotToggleRecordTrack(int position)
+TrackButtons::slotSetRecordTrack(int position)
 {
     Rosegarden::Composition &comp = m_doc->getComposition();
     Rosegarden::Track *track = comp.getTrackByPosition(position);
 
-    bool state = !comp.isTrackRecording(track->getId());
+    setRecordTrack(position);
+    selectLabel(position);
 
-    Rosegarden::Instrument *instrument = m_doc->getStudio().getInstrumentById
-	(track->getInstrument());
-
-    bool audio = (instrument &&
-		  instrument->getType() == Rosegarden::Instrument::Audio);
-
-    if (audio && state) {
-	try {
-	    m_doc->getAudioFileManager().testAudioPath();
-	} catch(Rosegarden::AudioFileManager::BadAudioPathException e) {
-	    if (KMessageBox::warningContinueCancel
-		(this,
-		 i18n("The audio file path does not exist or is not writable.\nPlease set the audio file path to a valid directory in Document Properties before recording audio.\nWould you like to set it now?"),
-		 i18n("Warning"),
-		 i18n("Set audio file path")) == KMessageBox::Continue) {
-		RosegardenGUIApp::self()->slotOpenAudioPathSettings();
-	    }
-	}
-    }
-
-    // can have any number of audio instruments armed, but only one
-    // track armed per instrument.
-
-    // Need to copy this container, as we're implicitly modifying it
-    // through calls to comp.setTrackRecording
-
-    Rosegarden::Composition::recordtrackcontainer oldRecordTracks =
-	comp.getRecordTracks();
-
-    for (Rosegarden::Composition::recordtrackcontainer::const_iterator i =
-	     oldRecordTracks.begin();
-	 i != oldRecordTracks.end(); ++i) {
-
-	if (!comp.isTrackRecording(*i)) {
-	    // We've already reset this one
-	    continue;
-	}
-
-	Rosegarden::Track *otherTrack = comp.getTrackById(*i);
-
-	if (otherTrack &&
-	    otherTrack != track) {
-	    
-	    /* Obsolete code: audio, MIDI and plugin tracks behave the same now.
-               plcl, 06/2006 - Multitrack MIDI recording
-               
-            bool unselect;
-
-	    if (audio) {
-		unselect = (otherTrack->getInstrument() == track->getInstrument());
-	    } else {
-		// our track is not an audio track, check that the
-		// other isn't either
-		Rosegarden::Instrument *otherInstrument =
-		    m_doc->getStudio().getInstrumentById(otherTrack->getInstrument());
-		bool otherAudio = (otherInstrument &&
-				   otherInstrument->getType() == 
-				   Rosegarden::Instrument::Audio);
-
-		unselect = !otherAudio;
-	    }
-
-	    if (unselect) { */
-            
-            if (otherTrack->getInstrument() == track->getInstrument()) {
-		// found another record track of the same type (and
-		// with the same instrument, if audio): unselect that
-
-		//!!! should we tell the user, particularly for the
-		//audio case? might seem odd otherwise
-
-		int otherPos = otherTrack->getPosition();
-		setRecordTrack(otherPos, false);
-	    }
-	}
-    }
-
-    setRecordTrack(position, state);
-
-    emit recordButton(track->getId(), state);
+    comp.setSelectedTrack(track->getId());
+    emit newRecordButton();
 }
 
 void
-TrackButtons::setRecordTrack(int position, bool state)
+TrackButtons::setRecordTrack(int position)
 {
-    setRecordButton(position, state);
-    m_doc->getComposition().setTrackRecording
-	(m_trackLabels[position]->getId(), state);
+    setRecordButtonDown(position);
+
+    // set and update
+    m_doc->getComposition().setRecordTrack(m_trackLabels[position]->getId());
 }
 
 void
-TrackButtons::setRecordButton(int position, bool state)
+TrackButtons::setRecordButtonDown(int position)
 {
     if (position < 0 || position >= (int)m_tracks)
         return;
 
     KLedButton* led = m_recordLeds[position];
     
-    led->setState(state ? KLed::On : KLed::Off);
+    led->on();
+
+    if (m_lastID != position && m_lastID != -1) {
+        m_recordLeds[m_lastID]->off();
+    }
+
+    m_lastID = position;
 }
 
 void
 TrackButtons::selectLabel(int position)
 {
-    if (m_lastSelected >= 0 && m_lastSelected < (int)m_trackLabels.size()) {
+    if (m_lastSelected >= 0)
         m_trackLabels[m_lastSelected]->setSelected(false);
-    }
+    m_trackLabels[position]->setSelected(true);
 
-    if (position >= 0 && position < (int)m_trackLabels.size()) {
-	m_trackLabels[position]->setSelected(true);
-	m_lastSelected = position;
-    }
+    m_lastSelected = position;
 }
 
 
@@ -761,17 +658,13 @@ TrackButtons::slotRenameTrack(QString newName, Rosegarden::TrackId trackId)
 
 
 void
-TrackButtons::slotSetTrackMeter(float value, int position)
+TrackButtons::slotSetTrackMeter(double value, int position)
 {
-    //Rosegarden::Composition &comp = m_doc->getComposition();
-    //Rosegarden::Studio &studio = m_doc->getStudio();
-    //Rosegarden::Track *track;
-
     for (unsigned int i = 0; i < m_trackMeters.size(); ++i)
     {
         if (i == ((unsigned int)position))
         {
-	    m_trackMeters[i]->setLevel(value);
+            m_trackMeters[i]->setLevel(value);
             return;
         }
     }
@@ -782,20 +675,25 @@ TrackButtons::slotSetTrackMeter(float value, int position)
 // equate that to the Instrument we're setting.
 //
 void
-TrackButtons::slotSetMetersByInstrument(float value,
+TrackButtons::slotSetMetersByInstrument(double value,
                                         Rosegarden::InstrumentId id)
 {
     Rosegarden::Composition &comp = m_doc->getComposition();
-    //Rosegarden::Studio &studio = m_doc->getStudio();
     Rosegarden::Track *track;
 
     for (unsigned int i = 0; i < m_trackMeters.size(); ++i)
     {
         track = comp.getTrackByPosition(i);
 
-        if (track != 0 && track->getInstrument() == id)
+        if (track !=0 && track->getInstrument() == id)
         {
-	    m_trackMeters[i]->setLevel(value);
+            m_trackMeters[i]->setLevel(value);
+
+            /*
+            RG_DEBUG << "TrackButtons::slotSetMetersByInstrument - "
+                     << "setting level = " << value 
+                     << " on instrument " << id << endl;
+                     */
         }
     }
 }
@@ -900,37 +798,6 @@ TrackButtons::populateInstrumentPopup(Rosegarden::Instrument *thisTrackInstr, QP
 	QString pname(strtoqstr((*it)->getProgramName()));
 	Rosegarden::Device *device = (*it)->getDevice();
         Rosegarden::DeviceId devId = device->getId();
-	bool connected = false;
-
-	if ((*it)->getType() == Rosegarden::Instrument::SoftSynth) {
-	    pname = "";
-	    Rosegarden::AudioPluginInstance *plugin = (*it)->getPlugin
-		(Rosegarden::Instrument::SYNTH_PLUGIN_POSITION);
-	    if (plugin) {
-		pname = strtoqstr(plugin->getProgram());
-		QString identifier = strtoqstr(plugin->getIdentifier());
-		if (identifier != "") {
-		    connected = true;
-		    QString type, soName, label;
-		    Rosegarden::PluginIdentifier::parseIdentifier
-			(identifier, type, soName, label);
-		    if (pname == "") {
-			pname = strtoqstr(plugin->getDistinctiveConfigurationText());
-		    }
-		    if (pname != "") {
-			pname = QString("%1: %2").arg(label).arg(pname);
-		    } else {
-			pname = label;
-		    }
-		} else {
-		    connected = false;
-		}
-	    }
-	} else if ((*it)->getType() == Rosegarden::Instrument::Audio) {
-	    connected = true;
-	} else {
-	    connected = (device->getConnection() != "");
-	}
 
 	bool instrUsedByMe = false;
 	bool instrUsedByAnyone = false;
@@ -965,11 +832,11 @@ TrackButtons::populateInstrumentPopup(Rosegarden::Instrument *thisTrackInstr, QP
 	    }
 
 	    QIconSet iconSet
-		(connected ?
+		(device->getConnection() == "" ?
 		 (deviceUsedByAnyone ? 
-		  connectedUsedPixmap : connectedPixmap) :
+		  unconnectedUsedPixmap : unconnectedPixmap) :
 		 (deviceUsedByAnyone ? 
-		  unconnectedUsedPixmap : unconnectedPixmap));
+		  connectedUsedPixmap : connectedPixmap));
 
             currentDevId = int(devId);
 
@@ -997,15 +864,15 @@ TrackButtons::populateInstrumentPopup(Rosegarden::Instrument *thisTrackInstr, QP
 	}
 
 	QIconSet iconSet
-	    (connected ?
-	     (instrUsedByAnyone ? 
-	      instrUsedByMe ?
-	      connectedSelectedPixmap :
-	      connectedUsedPixmap : connectedPixmap) :
+	    (device->getConnection() == "" ?
 	     (instrUsedByAnyone ? 
 	      instrUsedByMe ?
 	      unconnectedSelectedPixmap :
-	      unconnectedUsedPixmap : unconnectedPixmap));
+	      unconnectedUsedPixmap : unconnectedPixmap) :
+	     (instrUsedByAnyone ? 
+	      instrUsedByMe ?
+	      connectedSelectedPixmap :
+	      connectedUsedPixmap : connectedPixmap));
 
 	if (pname != "") iname += " (" + pname + ")";
 
@@ -1052,15 +919,11 @@ TrackButtons::slotInstrumentPopupActivated(int item)
             if (inst->sendsProgramChange())
                 m_trackLabels[m_popupItem]->setAlternativeLabel(strtoqstr(inst->getProgramName()));
 
-	    if (inst->getType() == Rosegarden::Instrument::Audio) {
-		m_recordLeds[m_popupItem]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordAudioTrackLED));
-	    } else {
-		m_recordLeds[m_popupItem]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordMIDITrackLED));
-	    }
+            // Ensure that we set a record track properly
+            //
+            if (track->getId() == comp.getRecordTrack())
+                slotSetRecordTrack(track->getId());
+
         }
         else
             RG_DEBUG << "slotInstrumentPopupActivated() - can't find item!\n";
@@ -1098,23 +961,8 @@ TrackButtons::changeInstrumentLabel(Rosegarden::InstrumentId id, QString label)
     {
         track = comp.getTrackByPosition(i);
 
-        if (track && track->getInstrument() == id) {
-
+        if(track && track->getInstrument() == id)
             m_trackLabels[i]->setAlternativeLabel(label);
-
-	    Rosegarden::Instrument *ins = m_doc->getStudio().
-                getInstrumentById(track->getInstrument());
-
-	    if (ins && ins->getType() == Rosegarden::Instrument::Audio) {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordAudioTrackLED));
-	    } else {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordMIDITrackLED));
-	    }
-	}
     }
 }
 
@@ -1153,9 +1001,9 @@ TrackButtons::slotSynchroniseWithComposition()
         if (track)
         {
             if (track->isMuted())
-                m_muteLeds[i]->off();
-            else
                 m_muteLeds[i]->on();
+            else
+                m_muteLeds[i]->off();
 
             Rosegarden::Instrument *ins = studio.
                 getInstrumentById(track->getInstrument());
@@ -1164,20 +1012,10 @@ TrackButtons::slotSynchroniseWithComposition()
 	    if (ins) instrumentName = strtoqstr(ins->getPresentationName());
 
             m_trackLabels[i]->getInstrumentLabel()->setText(instrumentName);
-
-	    setRecordButton(i, comp.isTrackRecording(track->getId()));
-
-	    if (ins && ins->getType() == Rosegarden::Instrument::Audio) {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordAudioTrackLED));
-	    } else {
-		m_recordLeds[i]->setColor
-		    (Rosegarden::GUIPalette::getColour
-		     (Rosegarden::GUIPalette::RecordMIDITrackLED));
-	    }
         }
     }
+
+    setRecordButtonDown(comp.getRecordTrack());
 }
 
 void
@@ -1200,24 +1038,9 @@ TrackButtons::setMuteButton(TrackId track, bool value)
     Rosegarden::Track *trackObj = m_doc->getComposition().getTrackById(track);
     if (trackObj == 0) return;
 
-    int pos = trackObj->getPosition();
-
-    RG_DEBUG << "TrackButtons::setMuteButton() trackId = "
-             << track << ", pos = " << pos << endl;
-    
-    m_muteLeds[pos]->setState(value ? KLed::Off : KLed::On);
-}
-
-void 
-TrackButtons::slotTrackInstrumentSelection(Rosegarden::TrackId trackId, int item) 
-{
-    RG_DEBUG << "TrackButtons::slotTrackInstrumentSelection(" << trackId << ")\n";
-
-    Rosegarden::Composition &comp = m_doc->getComposition();
-    int position = comp.getTrackById(trackId)->getPosition();
-    m_popupItem = position;
-    slotInstrumentPopupActivated( item );
+    m_muteLeds[trackObj->getPosition()]->setState(value ? KLed::Off : KLed::On);
 }
 
 
-#include "trackbuttons.moc"
+
+
