@@ -5,7 +5,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -111,6 +111,9 @@ public:
 
     ~TrackButtons();
 
+    /// Return the track selected for recording
+    int selectedRecordTrack();
+
     /// Return a vector of muted tracks
     std::vector<int> mutedTracks();
 
@@ -140,7 +143,7 @@ public:
     /*
      * Make this available so that others can set record buttons down
      */
-    void setRecordTrack(int position, bool value);
+    void setRecordTrack(int position);
 
     /**
      * Precalculate the Instrument popup so we don't have to every
@@ -167,11 +170,10 @@ signals:
     //
     void modified();
 
-    // A record button has been pressed - if we're setting to an audio
-    // track we need to tell the sequencer for live monitoring
-    // purposes.
+    // New record button set - if we're setting to an audio track
+    // we need to tell the sequencer for live monitoring purposes.
     //
-    void recordButton(Rosegarden::TrackId track, bool state);
+    void newRecordButton();
 
     // A mute button has been pressed
     //
@@ -179,17 +181,16 @@ signals:
 
 public slots:
 
-    void slotToggleRecordTrack(int position);
+    void slotSetRecordTrack(int position);
     void slotToggleMutedTrack(int mutedTrack);
     void slotUpdateTracks();
     void slotRenameTrack(QString newName, Rosegarden::TrackId trackId);
-    void slotSetTrackMeter(float value, int position);
-    void slotSetMetersByInstrument(float value, Rosegarden::InstrumentId id);
+    void slotSetTrackMeter(double value, int position);
+    void slotSetMetersByInstrument(double value, Rosegarden::InstrumentId id);
 
     void slotInstrumentSelection(int);
     void slotInstrumentPopupActivated(int);
-    void slotTrackInstrumentSelection(Rosegarden::TrackId, int);
-    
+
     // ensure track buttons match the Composition
     //
     void slotSynchroniseWithComposition();
@@ -211,9 +212,9 @@ protected:
     void removeButtons(unsigned int position);
 
     /**
-     * Set record button - graphically only
+     * Set record button down - graphically only
      */
-    void setRecordButton(int position, bool down);
+    void setRecordButtonDown(int position);
 
     /**
      *  buttons, starting at the specified index
@@ -258,6 +259,7 @@ protected:
     //
     int                               m_borderGap;
 
+    int                               m_lastID;
     int                               m_trackLabelWidth;
     int                               m_popupItem;
 
