@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -39,10 +39,9 @@
 #include "Track.h"
 #include "NotationTypes.h"
 
-#include "compositionview.h"
-#include "compositionitemhelper.h"
 #include "constants.h"
 #include "trackeditor.h"
+#include "segmentcanvas.h"
 #include "temporuler.h"
 #include "chordnameruler.h"
 #include "rosestrings.h"
@@ -53,11 +52,9 @@
 #include "barbuttons.h"
 #include "trackbuttons.h"
 #include "loopruler.h"
-#include "widgets.h"
 #include "segmenttool.h"
 #include "qdeferscrollview.h"
 #include "rosegardenguiview.h"
-#include "sequencemanager.h"
 
 #include "rosedebug.h"
 
@@ -67,6 +64,8 @@ using Rosegarden::timeT;
 using Rosegarden::Segment;
 using Rosegarden::TrackId;
 
+static double _pointerWidth = 3.0;
+
 TrackEditor::TrackEditor(RosegardenGUIDoc* doc,
                          QWidget* rosegardenguiview,
 			 RulerScale *rulerScale,
@@ -99,7 +98,11 @@ TrackEditor::TrackEditor(RosegardenGUIDoc* doc,
 TrackEditor::~TrackEditor()
 {
     delete m_chordNameRuler;
-    delete m_compositionModel;
+
+    // flush gc (i.e. forget what's in there).
+    // All remaining items will be deleted by the canvas anyway.
+    //
+    CanvasItemGC::flush();
 }
 
 void
@@ -107,6 +110,21 @@ TrackEditor::init(QWidget* rosegardenguiview)
 {
     QGridLayout *grid = new QGridLayout(this, 4, 2);
 
+    QCanvas *canvas = new QCanvas(this);
+    canvas->resize(100, 100); // call slotReadjustCanvasSize later
+    canvas->setBackgroundColor(RosegardenGUIColours::SegmentCanvas);
+    //canvas->retune(128);
+
+    kapp->config()->setGroup(Rosegarden::GeneralOptionsConfigGroup);
+    if (kapp->config()->readBoolEntry("backgroundtextures", false)) {
+	QPixmap background;
+	QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+	if (background.load(QString("%1/misc/bg-paper-grey.xpm").
+			    arg(pixmapDir))) {
+	    canvas->setBackgroundPixmap(background);
+	}
+    }
+
     int trackLabelWidth = 230;
     int barButtonsHeight = 25;
 
@@ -119,16 +137,13 @@ TrackEditor::init(QWidget* rosegardenguiview)
 
     m_tempoRuler = new TempoRuler(m_rulerScale,
 				  m_doc,
-				  RosegardenGUIApp::self()->factory(),
 				  0.0,
-				  24,
+				  18,
 				  true,
 				  this);
 
     grid->addWidget(m_tempoRuler, 1, 1);
 
-    m_tempoRuler->connectSignals();
-
     //
     // Top Bar Buttons
     //
@@ -145,27 +160,11 @@ TrackEditor::init(QWidget* rosegardenguiview)
     //
     // Segment Canvas
     //
-    m_compositionModel = new CompositionModelImpl(m_doc->getComposition(),
-                                                  m_doc->getStudio(),
-                                                  m_rulerScale, getTrackCellHeight());
-    
-    connect(rosegardenguiview, SIGNAL(instrumentParametersChanged(Rosegarden::InstrumentId)),
-            m_compositionModel, SLOT(slotInstrumentParametersChanged(Rosegarden::InstrumentId)));
-    connect(rosegardenguiview->parent(), SIGNAL(instrumentParametersChanged(Rosegarden::InstrumentId)),
-            m_compositionModel, SLOT(slotInstrumentParametersChanged(Rosegarden::InstrumentId)));
-
-    m_segmentCanvas = new CompositionView(m_doc, m_compositionModel, this);
-
-    kapp->config()->setGroup(Rosegarden::GeneralOptionsConfigGroup);
-    if (kapp->config()->readBoolEntry("backgroundtextures", true)) {
-	QPixmap background;
-	QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
-	if (background.load(QString("%1/misc/bg-segmentcanvas.xpm").
-			    arg(pixmapDir))) {
-	    m_segmentCanvas->setBackgroundPixmap(background);
-	    m_segmentCanvas->viewport()->setBackgroundPixmap(background);
-	}
-    }
+    m_segmentCanvas = new SegmentCanvas(m_doc,
+                                        new Rosegarden::SimpleRulerScale(*(
+                                            dynamic_cast<Rosegarden::SimpleRulerScale*>(m_rulerScale))),
+                                        getTrackCellHeight(),
+                                        canvas, this);
 
     //
     // Bottom Bar Buttons
@@ -182,8 +181,6 @@ TrackEditor::init(QWidget* rosegardenguiview)
 
     grid->addWidget(m_segmentCanvas, 3, 1);
 
-    grid->setColStretch(1, 10); // to make sure the seg canvas doesn't leave a "blank" grey space when
-    // loading a file which has a low zoom factor
   
     // Track Buttons
     //
@@ -204,7 +201,7 @@ TrackEditor::init(QWidget* rosegardenguiview)
     m_trackButtonScroll->addChild(m_trackButtons);
     m_trackButtonScroll->setHScrollBarMode(QScrollView::AlwaysOff);
     m_trackButtonScroll->setVScrollBarMode(QScrollView::AlwaysOff);
-    m_trackButtonScroll->setResizePolicy(QScrollView::AutoOneFit);
+    m_trackButtonScroll->setMinimumWidth(m_trackButtonScroll->contentsWidth());
     m_trackButtonScroll->setBottomMargin(m_bottomBarButtons->height() +
                                          m_segmentCanvas->horizontalScrollBar()->height());
 
@@ -226,18 +223,8 @@ TrackEditor::init(QWidget* rosegardenguiview)
     connect(m_trackButtons, SIGNAL(muteButton(Rosegarden::TrackId, bool)),
             rosegardenguiview, SLOT(slotSetMuteButton(Rosegarden::TrackId, bool)));
 
-    // connect loop rulers' follow-scroll signals
-    connect(m_topBarButtons->getLoopRuler(), SIGNAL(startMouseMove(int)),
-            m_segmentCanvas, SLOT(startAutoScroll(int)));
-    connect(m_topBarButtons->getLoopRuler(), SIGNAL(stopMouseMove()),
-            m_segmentCanvas, SLOT(stopAutoScroll()));
-    connect(m_bottomBarButtons->getLoopRuler(), SIGNAL(startMouseMove(int)),
-            m_segmentCanvas, SLOT(startAutoScroll(int)));
-    connect(m_bottomBarButtons->getLoopRuler(), SIGNAL(stopMouseMove()),
-            m_segmentCanvas, SLOT(stopAutoScroll()));
-
-    connect(m_segmentCanvas, SIGNAL(contentsMoving(int, int)),
-            this, SLOT(slotCanvasScrolled(int, int)));
+    connect(m_trackButtons, SIGNAL(newRecordButton()),
+            m_doc, SLOT(slotNewRecordButton()));
 
     // Synchronize bar buttons' scrollview with segment canvas' scrollbar
     //
@@ -273,38 +260,67 @@ TrackEditor::init(QWidget* rosegardenguiview)
     connect(m_segmentCanvas->horizontalScrollBar(), SIGNAL(sliderMoved(int)),
             m_chordNameRuler, SLOT(slotScrollHoriz(int)));
 
-    connect(this, SIGNAL(needUpdate()), m_segmentCanvas, SLOT(slotUpdateSegmentsDrawBuffer()));
+    connect(this, SIGNAL(needUpdate()), m_segmentCanvas, SLOT(slotUpdate()));
 
     connect(m_segmentCanvas, 
             SIGNAL(selectedSegments(const Rosegarden::SegmentSelection &)),
             rosegardenguiview,
             SLOT(slotSelectedSegments(const Rosegarden::SegmentSelection &)));
 
-    connect(m_segmentCanvas, SIGNAL(zoomIn()),
-	    RosegardenGUIApp::self(), SLOT(slotZoomIn()));
-    connect(m_segmentCanvas, SIGNAL(zoomOut()),
-	    RosegardenGUIApp::self(), SLOT(slotZoomOut()));
-
     connect(getCommandHistory(), SIGNAL(commandExecuted()),
 	    this, SLOT(update()));
 
     connect(m_doc, SIGNAL(pointerPositionChanged(Rosegarden::timeT)),
 	    this, SLOT(slotSetPointerPosition(Rosegarden::timeT)));
-
-    connect(m_doc, SIGNAL(pointerDraggedToPosition(Rosegarden::timeT)),
-	    this, SLOT(slotPointerDraggedToPosition(Rosegarden::timeT)));
- 
-    connect(m_doc, SIGNAL(loopDraggedToPosition(Rosegarden::timeT)),
-            this, SLOT(slotLoopDraggedToPosition(Rosegarden::timeT)));
  
     connect(m_doc, SIGNAL(loopChanged(Rosegarden::timeT,
-                                      Rosegarden::timeT)),
+					   Rosegarden::timeT)),
 	    this, SLOT(slotSetLoop(Rosegarden::timeT, Rosegarden::timeT)));
+
+    // create the position pointer
+    m_pointer = new QCanvasRectangle(canvas);
+    m_pointer->setPen(RosegardenGUIColours::Pointer);
+    m_pointer->setBrush(RosegardenGUIColours::Pointer);
+    m_pointer->setSize(3, canvas->height());
+    m_pointer->setX(-2);
+    m_pointer->setY(0);
+    m_pointer->setZ(10);
+    m_pointer->show();
 }
 
 void TrackEditor::slotReadjustCanvasSize()
 {
-    m_segmentCanvas->slotUpdateSize();
+    Composition &comp = m_doc->getComposition();
+    int lastBar = comp.getBarNumber(comp.getEndMarker());
+    
+    RulerScale *ruler = m_segmentCanvas->grid().getRulerScale();
+    m_canvasWidth = (int)(ruler->getBarPosition(lastBar) +
+                          ruler->getBarWidth(lastBar));
+
+    // Not very satisfactory
+    //
+//     int canvasHeight = std::max(getTrackCellHeight() * comp.getNbTracks(),
+//                                 m_segmentCanvas->viewport()->height()
+//                                 //QApplication::desktop()->height()
+//                                 );
+
+    RG_DEBUG << "TrackEditor::slotReadjustCanvasSize() : nbTracks = "
+             << comp.getNbTracks() << endl;
+
+    int canvasHeight = getTrackCellHeight() * std::max(40u, comp.getNbTracks());
+
+    m_segmentCanvas->canvas()->resize(m_canvasWidth, canvasHeight);
+
+
+    Rosegarden::SimpleRulerScale *sRuler = 
+        dynamic_cast<Rosegarden::SimpleRulerScale*>(m_rulerScale);
+
+    int width = int(rint((_pointerWidth * sRuler->getUnitsPerPixel())/ m_initialUnitsPerPixel));
+    width = int(_pointerWidth);
+
+    m_pointer->setSize(width, m_segmentCanvas->canvas()->height());
+
+    RG_DEBUG << "TrackEditor::slotReadjustCanvasSize - done" << endl;
 }
 
 void TrackEditor::slotTrackButtonsWidthChanged()
@@ -338,6 +354,29 @@ int TrackEditor::getTrackCellHeight() const
     return size + 12;
 }
 
+void
+TrackEditor::setupSegments()
+{
+    RG_DEBUG << "TrackEditor::setupSegments() begin" << endl;
+
+    if (!m_doc) return; // sanity check
+    
+    Composition &comp = m_doc->getComposition();
+
+    for (Composition::iterator i = comp.begin(); i != comp.end(); ++i) {
+
+        if (!(*i)) continue;
+
+	RG_DEBUG << "TrackEditor::setupSegments() add segment"
+			     << " - start idx : " << (*i)->getStartTime()
+			     << " - nb time steps : " << ((*i)->getEndTime() - (*i)->getStartTime())
+			     << " - track : " << (*i)->getTrack()
+			     << endl;
+
+	m_segmentCanvas->addSegmentItem((*i));
+    }
+}
+
 bool TrackEditor::isCompositionModified()
 {
     return m_doc->getComposition().getRefreshStatus
@@ -350,17 +389,6 @@ void TrackEditor::setCompositionModified(bool c)
 	(m_compositionRefreshStatusId).setNeedsRefresh(c);
 }
 
-void TrackEditor::updateRulers()
-{
-    if (getTempoRuler() != 0)
-        getTempoRuler()->update();
-
-    if (getChordNameRuler() != 0)
-        getChordNameRuler()->update();
-
-    getTopBarButtons()->update();
-    getBottomBarButtons()->update();
-}
 
 void TrackEditor::paintEvent(QPaintEvent* e)
 {
@@ -369,9 +397,8 @@ void TrackEditor::paintEvent(QPaintEvent* e)
         RG_DEBUG << "TrackEditor::paintEvent: composition is modified, update everything\n";
 
 	slotReadjustCanvasSize();
+        m_segmentCanvas->updateAllSegmentItems();
         m_trackButtons->slotUpdateTracks();
-        m_segmentCanvas->clearSegmentRectsCache(true);
-        m_segmentCanvas->updateContents();
 
 	Composition &composition = m_doc->getComposition();
 
@@ -388,6 +415,36 @@ void TrackEditor::paintEvent(QPaintEvent* e)
         }
 
         setCompositionModified(false);
+
+    } else if (m_segmentCanvas->isShowingPreviews()) { 
+
+	for (Composition::iterator i = m_doc->getComposition().begin();
+	     i != m_doc->getComposition().end(); ++i) {
+
+	    SegmentRefreshStatusIdMap::iterator ri =
+		m_segmentsRefreshStatusIds.find(*i);
+
+	    bool refresh = false;
+
+	    if (ri == m_segmentsRefreshStatusIds.end()) {
+		
+		//RG_DEBUG << "TrackEditor::paintEvent: adding segment " << *i << " to map" << endl;
+		m_segmentsRefreshStatusIds[*i] = (*i)->getNewRefreshStatusId();
+
+	    } else {
+	    
+		unsigned int refreshStatusId = m_segmentsRefreshStatusIds[*i];
+		Rosegarden::SegmentRefreshStatus &refreshStatus =
+		    (*i)->getRefreshStatus(refreshStatusId);
+
+		refresh = refreshStatus.needsRefresh();
+		refreshStatus.setNeedsRefresh(false);
+	    }
+
+	    if (refresh) {
+		m_segmentCanvas->updateSegmentItem(*i);
+	    }
+	}
     }
 
     QWidget::paintEvent(e);
@@ -432,117 +489,42 @@ void TrackEditor::slotSegmentOrderChanged(int section, int fromIdx, int toIdx)
     emit needUpdate();
 }
 
-void
-TrackEditor::slotCanvasScrolled(int x, int y)
-{
-    // update the pointer position if the user is dragging it from the loop ruler
-    if ((m_topBarButtons && m_topBarButtons->getLoopRuler() &&
-	 m_topBarButtons->getLoopRuler()->hasActiveMousePress() &&
-         !m_topBarButtons->getLoopRuler()->getLoopingMode()) ||
-	(m_bottomBarButtons && m_bottomBarButtons->getLoopRuler() &&
-	 m_bottomBarButtons->getLoopRuler()->hasActiveMousePress() &&
-         !m_bottomBarButtons->getLoopRuler()->getLoopingMode()
-         )) {
-
-	int mx = m_segmentCanvas->viewport()->mapFromGlobal(QCursor::pos()).x();
-        m_segmentCanvas->setPointerPos(x + mx);
-
-        // bad idea, creates a feedback loop
-// 	timeT t = m_segmentCanvas->grid().getRulerScale()->getTimeForX(x + mx);
-// 	slotSetPointerPosition(t);
-    }
-}
-
-
 // Move the position pointer
 void
 TrackEditor::slotSetPointerPosition(Rosegarden::timeT position)
 {
+
+    //RG_DEBUG << "TrackEditor::setPointerPosition: time is " << position << endl;
+    if (!m_pointer) return;
+
     Rosegarden::SimpleRulerScale *ruler = 
         dynamic_cast<Rosegarden::SimpleRulerScale*>(m_rulerScale);
 
     if (!ruler) return;
 
+    // scale by the x scale factor
+    /*
+    RG_DEBUG << "TrackEditor::setPointerPosition - scale = " << ruler->getUnitsPerPixel() << endl;
+    */
+    int width = int(rint((_pointerWidth * ruler->getUnitsPerPixel())/ m_initialUnitsPerPixel));
+    width = int(_pointerWidth);
+
+    m_pointer->setSize(width, m_segmentCanvas->canvas()->height());
+
     double pos = m_segmentCanvas->grid().getRulerScale()->getXForTime(position);
+    double distance = pos - m_pointer->x();
 
-    int currentPointerPos = m_segmentCanvas->getPointerPos();
-
-    double distance = pos - currentPointerPos;
     if (distance < 0.0) distance = -distance;
-
     if (distance >= 1.0) {
 
-        if (m_doc && m_doc->getSequenceManager() &&
-            (m_doc->getSequenceManager()->getTransportStatus() != STOPPED)) {
+	m_pointer->setX(pos);
 
-            if (m_playTracking) {
-                getSegmentCanvas()->slotScrollHoriz(int(double(position) / ruler->getUnitsPerPixel()));
-            }
-        } else if (!getSegmentCanvas()->isAutoScrolling()) {
-            int newpos = int(double(position) / ruler->getUnitsPerPixel());
-//             RG_DEBUG << "TrackEditor::slotSetPointerPosition("
-//                      << position
-//                      << ") : calling canvas->slotScrollHoriz() "
-//                      << newpos << endl;
-            getSegmentCanvas()->slotScrollHoriz(newpos);
-        }
+	if (m_playTracking) {
+	    getSegmentCanvas()->slotScrollHoriz(int(double(position) / ruler->getUnitsPerPixel()));
+	}
 
-        m_segmentCanvas->setPointerPos(pos);
+	emit needUpdate();
     }
-    
-}
-
-void
-TrackEditor::slotPointerDraggedToPosition(Rosegarden::timeT position)
-{
-    int currentPointerPos = m_segmentCanvas->getPointerPos();
-
-    double newPosition;
-    
-    if (handleAutoScroll(currentPointerPos, position, newPosition))
-        m_segmentCanvas->setPointerPos(int(newPosition));    
-}
-
-void
-TrackEditor::slotLoopDraggedToPosition(Rosegarden::timeT position)
-{
-    if (m_doc) {
-        int currentEndLoopPos = m_doc->getComposition().getLoopEnd();
-        double dummy;
-        handleAutoScroll(currentEndLoopPos, position, dummy);
-    }
-}
-
-bool TrackEditor::handleAutoScroll(int currentPosition, Rosegarden::timeT newTimePosition, double &newPosition)
-{
-    Rosegarden::SimpleRulerScale *ruler = 
-        dynamic_cast<Rosegarden::SimpleRulerScale*>(m_rulerScale);
-
-    if (!ruler) return false;
-
-    newPosition = m_segmentCanvas->grid().getRulerScale()->getXForTime(newTimePosition);
-    
-    double distance = fabs(newPosition - currentPosition);
-
-    bool moveDetected = distance >= 1.0;
-    
-    if (moveDetected) {
-
-        if (m_doc && m_doc->getSequenceManager() &&
-            (m_doc->getSequenceManager()->getTransportStatus() != STOPPED)) {
-
-            if (m_playTracking) {
-                getSegmentCanvas()->slotScrollHoriz(int(double(newTimePosition) / ruler->getUnitsPerPixel()));
-            }
-        } else {
-            int newpos = int(double(newTimePosition) / ruler->getUnitsPerPixel());
-            getSegmentCanvas()->slotScrollHorizSmallSteps(newpos);
-            getSegmentCanvas()->doAutoScroll();
-        }
-        
-    }
-
-    return moveDetected;
 }
 
 void
@@ -558,6 +540,50 @@ TrackEditor::slotSetLoop(Rosegarden::timeT start, Rosegarden::timeT end)
     getBottomBarButtons()->getLoopRuler()->slotSetLoopMarker(start, end);
 }
 
+void
+TrackEditor::slotSetSelectAdd(bool value)
+{
+    m_segmentCanvas->slotSetSelectAdd(value);
+}
+
+void
+TrackEditor::slotSetSelectCopy(bool value)
+{
+     m_segmentCanvas->slotSetSelectCopy(value);
+}
+
+void
+TrackEditor::slotSetFineGrain(bool value)
+{
+     m_segmentCanvas->slotSetFineGrain(value);
+}
+
+// Show a Segment as its being recorded
+//
+void
+TrackEditor::slotUpdateRecordingSegmentItem(Rosegarden::Segment *segment)
+{
+    Composition &comp = m_doc->getComposition();
+    //int y = segment->getTrack() * getTrackCellHeight();
+
+    // Show recording SegmentItem from recording start point to
+    // current point position
+    //
+    timeT endTime = comp.getPosition();
+
+    m_segmentCanvas->showRecordingSegmentItem(segment, endTime);
+
+    emit needUpdate();
+}
+
+void
+TrackEditor::slotDeleteRecordingSegmentItem()
+{
+    m_segmentCanvas->deleteRecordingSegmentItem();
+    emit needUpdate();
+}
+
+
 MultiViewCommandHistory*
 TrackEditor::getCommandHistory()
 {
@@ -601,7 +627,7 @@ TrackEditor::slotDeleteSelectedSegments()
     // Clear the selection before erasing the Segments
     // the selection points to
     //
-    m_segmentCanvas->getModel()->clearSelected();
+    m_segmentCanvas->clearSelected();
 
     // Create the compound command
     //
@@ -682,9 +708,9 @@ void TrackEditor::dropEvent(QDropEvent* event)
         heightAdjust += m_chordNameRuler->height();
 
     QPoint posInSegmentCanvas = 
-	m_segmentCanvas->viewportToContents
-	(m_segmentCanvas->
-	 viewport()->mapFrom(this, event->pos()));
+        m_segmentCanvas->inverseWorldMatrix().map(
+            (m_segmentCanvas->viewportToContents(m_segmentCanvas->
+                viewport()->mapFrom(this, event->pos()))));
 
     int trackPos = m_segmentCanvas->grid().getYBin(posInSegmentCanvas.y());
 
@@ -719,14 +745,13 @@ void TrackEditor::dropEvent(QDropEvent* event)
                      << posInSegmentCanvas.x()
                      << endl;
 
-            Rosegarden::Track* track = m_doc->getComposition().getTrackByPosition(trackPos);
-            if (track)
+            if (m_doc->getComposition().getTrackById(trackPos))
             {
                 QString audioText;
                 QTextOStream t(&audioText);
 
                 t << filePath << "\n";
-                t << track->getId() << "\n";
+                t << trackPos << "\n";
                 t << time << "\n";
 
                 emit droppedNewAudio(audioText);
@@ -769,31 +794,31 @@ void TrackEditor::dropEvent(QDropEvent* event)
                 // Drop this audio segment if we have a valid track number
                 // (could also check for time limits too)
                 //
-                Rosegarden::Track* track = m_doc->getComposition().getTrackByPosition(trackPos);
-                if (track) {
+                if (m_doc->getComposition().getTrackById(trackPos))
+                    {
 
-                    RG_DEBUG << "TrackEditor::dropEvent() : dropping at track pos = " 
-                             << trackPos
-                             << ", time = "
-                             << time 
-                             << ", x = "
-                             << event->pos().x()
-                             << ", map = "
-                             << posInSegmentCanvas.x()
-                             << endl;
+                        RG_DEBUG << "TrackEditor::dropEvent() : dropping at track pos = " 
+                                 << trackPos
+                                 << ", time = "
+                                 << time 
+                                 << ", x = "
+                                 << event->pos().x()
+                                 << ", map = "
+                                 << posInSegmentCanvas.x()
+                                 << endl;
 
-                    QString audioText;
-                    QTextOStream t(&audioText);
-                    t << audioFileId << "\n";
-                    t << track->getId() << "\n";
-                    t << time << "\n"; // time on canvas
-                    t << startTime.sec << "\n";
-                    t << startTime.nsec << "\n";
-                    t << endTime.sec << "\n";
-                    t << endTime.nsec << "\n";
+                        QString audioText;
+                        QTextOStream t(&audioText);
+                        t << audioFileId << "\n";
+                        t << trackPos << "\n"; // track id
+                        t << time << "\n"; // time on canvas
+                        t << startTime.sec << "\n";
+                        t << startTime.nsec << "\n";
+                        t << endTime.sec << "\n";
+                        t << endTime.nsec << "\n";
 
-                    emit droppedAudio(audioText);
-                }
+                        emit droppedAudio(audioText);
+                    }
 
             } else {
 
@@ -809,4 +834,8 @@ void TrackEditor::dropEvent(QDropEvent* event)
     }
 }
 
-#include "trackeditor.moc"
+void TrackEditor::updateSegmentItemSelection()
+{
+    if (m_segmentCanvas) m_segmentCanvas->updateSegmentItemSelection();
+}
+
