@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -41,8 +41,7 @@ namespace Rosegarden {
 }
 
 class SegmentItem;
-class CompositionView;
-class CompositionModel;
+class SegmentCanvas;
 class RosegardenGUIDoc;
 class BarButtons;
 class TempoRuler;
@@ -50,6 +49,7 @@ class ChordNameRuler;
 class TrackButtons;
 class MultiViewCommandHistory;
 class KCommand;
+class QCanvasRectangle;
 class QDeferScrollView;
 class QScrollBar;
 
@@ -78,7 +78,7 @@ public:
 
     ~TrackEditor();
 
-    CompositionView* getSegmentCanvas()       { return m_segmentCanvas; }
+    SegmentCanvas* getSegmentCanvas()       { return m_segmentCanvas; }
     TempoRuler*    getTempoRuler()          { return m_tempoRuler; }
     ChordNameRuler*getChordNameRuler()      { return m_chordNameRuler; }
     BarButtons*    getTopBarButtons()       { return m_topBarButtons; }
@@ -88,6 +88,13 @@ public:
 
     int getTrackCellHeight() const;
 
+    /**
+     * Must be called after construction and signal connection
+     * if a document was passed to ctor, otherwise segments will
+     * be created but not registered in the main doc
+     */
+    void setupSegments();
+
     /**
      * Add a new segment - DCOP interface
      */
@@ -99,12 +106,16 @@ public:
     MultiViewCommandHistory *getCommandHistory();
     void addCommandToHistory(KCommand *command);
 
-    void updateRulers();
+    /*
+     * Update the selection tools selection - used on zoom
+     */
+    void updateSegmentItemSelection();
 
-    bool isTracking() const { return m_playTracking; }
 
 public slots:
 
+//!!! I suspect most of these of never actually being used as slots, only as plain methods
+
     /**
      * Scroll the view such that the numbered track is on-screen
      */
@@ -115,23 +126,6 @@ public slots:
      */
     void slotSetPointerPosition(Rosegarden::timeT position);
 
-    /**
-     * Update the pointer position as it is being dragged along
-     * This changes how the segment canvas will scroll to follow the pointer
-     */
-    void slotPointerDraggedToPosition(Rosegarden::timeT position);
-
-    /**
-     * Update the loop end position as it is being dragged along
-     * This changes how the segment canvas will scroll to follow the pointer
-     */
-    void slotLoopDraggedToPosition(Rosegarden::timeT position);
-
-    /**
-     * Act on a canvas scroll event
-     */
-    void slotCanvasScrolled(int, int);
-
     /**
      * Adjust the canvas size to that required for the composition
      */
@@ -142,6 +136,27 @@ public slots:
      */
     void slotSetLoop(Rosegarden::timeT start, Rosegarden::timeT end);
 
+    /**
+     * Show a Segment as it records
+     */
+    void slotUpdateRecordingSegmentItem(Rosegarden::Segment *segment);
+
+    /*
+     * Destroys same
+     */
+    void slotDeleteRecordingSegmentItem();
+
+    /**
+     * c.f. what we have in rosegardenguiview.h
+     * These are instrumental in passing through
+     * key presses from GUI front panel down to
+     * the SegmentCanvas.
+     *
+     */
+    void slotSetSelectAdd(bool value);
+    void slotSetSelectCopy(bool value);
+    void slotSetFineGrain(bool value);
+
     /**
      * Add given number of tracks
      */
@@ -210,9 +225,6 @@ protected:
     bool isCompositionModified();
     void setCompositionModified(bool);
     
-    /// return true if an actual move occurred between current and new position, newPosition contains the horiz. pos corresponding to newTimePosition
-    bool handleAutoScroll(int currentPosition, Rosegarden::timeT newTimePosition, double& newPosition);
-    
     //--------------- Data members ---------------------------------
 
     RosegardenGUIDoc        *m_doc;
@@ -222,8 +234,8 @@ protected:
     BarButtons              *m_topBarButtons;
     BarButtons              *m_bottomBarButtons;
     TrackButtons            *m_trackButtons;
-    CompositionView         *m_segmentCanvas;
-    CompositionModel        *m_compositionModel;
+    SegmentCanvas           *m_segmentCanvas;
+    QCanvasRectangle        *m_pointer;
     QDeferScrollView        *m_trackButtonScroll;
 
     bool                     m_showTrackLabels;
