@@ -1,10 +1,8 @@
-// -*- c-basic-offset: 4 -*-
-
 /*
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -20,16 +18,14 @@
 */
 
 
+#include "tracklabel.h"
+
 #include <qlabel.h>
 #include <qtimer.h>
-#include <qvalidator.h>
-#include <qtooltip.h>
-
 #include <klineeditdlg.h>
-#include <klocale.h>
+#include <qvalidator.h>
 
 #include "rosedebug.h"
-#include "tracklabel.h"
 
 TrackLabel::TrackLabel(Rosegarden::TrackId id,
                        int position,
@@ -41,13 +37,6 @@ TrackLabel::TrackLabel(Rosegarden::TrackId id,
     m_id(id),
     m_position(position)
 {
-    QFont font;
-    font.setPointSize(font.pointSize() * 95 / 100);
-    if (font.pixelSize() > 14) font.setPixelSize(14);
-    font.setBold(false);
-    m_instrumentLabel->setFont(font);
-    m_trackLabel->setFont(font);
-
     addWidget(m_instrumentLabel, ShowInstrument);
     addWidget(m_trackLabel, ShowTrack);
     raiseWidget(ShowTrack);
@@ -59,9 +48,6 @@ TrackLabel::TrackLabel(Rosegarden::TrackId id,
 
     connect(m_pressTimer, SIGNAL(timeout()),
             this, SIGNAL(changeToInstrumentList()));
-
-    QToolTip::add(this, i18n("Click and hold with left mouse button to assign this Track to an Instrument."));
-
 }
 
 TrackLabel::~TrackLabel()
@@ -187,8 +173,8 @@ TrackLabel::mouseDoubleClickEvent(QMouseEvent *e)
 
     QRegExpValidator validator(QRegExp(".*"), this); // empty is OK
 
-    QString newText = KLineEditDlg::getText(i18n("Change track name"),
-                                            i18n("Enter new track name"),
+    QString newText = KLineEditDlg::getText(QString("Change track name"),
+                                            QString("Enter new track name"),
                                             m_trackLabel->text(),
                                             &ok,
                                             this,
@@ -202,4 +188,3 @@ QLabel* TrackLabel::getVisibleLabel()
 {
     return dynamic_cast<QLabel*>(visibleWidget());
 }
-#include "tracklabel.moc"
