@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -34,7 +34,6 @@
 #include <qlineedit.h>
 #include <qbitmap.h>
 #include <qeventloop.h>
-#include <qimage.h>
 
 #include <klocale.h>
 #include <kconfig.h>
@@ -48,7 +47,6 @@
 #include "notepixmapfactory.h"
 #include "colours.h"
 #include "midipitchlabel.h"
-#include "commondialogs.h"
 
 #include "Quantizer.h"
 #include "Composition.h" // currently for time widget only
@@ -88,7 +86,7 @@ RosegardenSpinBox::mapValueToText(int value)
 int
 RosegardenSpinBox::mapTextToValue(bool * /*ok*/)
 {
-    double number = qstrtodouble(text());
+    double number = text().toDouble();
 
     if (number)
     {
@@ -99,6 +97,40 @@ RosegardenSpinBox::mapTextToValue(bool * /*ok*/)
     return 120; // default
 }
 
+
+RosegardenParameterBox::RosegardenParameterBox(int strips,
+                                               Orientation orientation,
+                                               QString label,
+					       QWidget *parent,
+					       const char *name) :
+    QGroupBox(strips, orientation, label, parent, name)
+{
+    init();
+}
+
+RosegardenParameterBox::RosegardenParameterBox(QString label,
+					       QWidget *parent,
+					       const char *name) :
+    QGroupBox(label, parent, name)
+{
+    init();
+}
+
+void RosegardenParameterBox::init()
+{
+    QFont plainFont;
+    plainFont.setPointSize(plainFont.pointSize() * 9 / 10);
+    plainFont.setBold(false);
+    m_font = plainFont;
+
+    QFont boldFont;
+    boldFont.setPointSize(int(boldFont.pointSize() * 9.5 / 10.0 + 0.5));
+    boldFont.setBold(true);
+
+    setFont(boldFont);
+}
+
+
 bool RosegardenProgressDialog::m_modalVisible = false;
 
 RosegardenProgressDialog::RosegardenProgressDialog(QWidget *creator,
@@ -225,11 +257,6 @@ void RosegardenProgressDialog::slotFreeze()
 	hide();
     }
 
-    // This is also a convenient place to ensure the wait cursor (if
-    // currently shown) returns to the original cursor to ensure that
-    // the user can respond to whatever's freezing the progress dialog
-    QApplication::restoreOverrideCursor();
-
     mShowTimer->stop();
     m_frozen = true;
 }
@@ -333,7 +360,6 @@ RosegardenProgressDialog* CurrentProgressDialog::m_currentProgressDialog = 0;
 
 static RosegardenTextFloat* _float = 0;
 static QTimer *_floatTimer = 0;
-RosegardenRotary::PixmapCache RosegardenRotary::m_pixmaps;
 
 RosegardenRotary::RosegardenRotary(QWidget *parent,
                                    float minValue,
@@ -343,8 +369,7 @@ RosegardenRotary::RosegardenRotary(QWidget *parent,
                                    float initialPosition,
                                    int size,
 				   TickMode ticks,
-				   bool snapToTicks,
-				   bool centred) :
+				   bool snapToTicks) :
     QWidget(parent),
     m_minValue(minValue),
     m_maxValue(maxValue),
@@ -353,17 +378,14 @@ RosegardenRotary::RosegardenRotary(QWidget *parent,
     m_size(size),
     m_tickMode(ticks),
     m_snapToTicks(snapToTicks),
-    m_centred(centred),
+    m_lastPosition(initialPosition),
     m_position(initialPosition),
     m_snapPosition(m_position),
-    m_initialPosition(initialPosition),
     m_buttonPressed(false),
     m_lastY(0),
     m_lastX(0),
     m_knobColour(0, 0, 0)
 {
-    setBackgroundMode(Qt::NoBackground);
-
     if (!_float) _float = new RosegardenTextFloat(this);
 
     if (!_floatTimer)
@@ -377,9 +399,12 @@ RosegardenRotary::RosegardenRotary(QWidget *parent,
     _float->hide();
 
     QToolTip::add(this,
-                  i18n("Click and drag up and down or left and right to modify.\nDouble click to edit value directly."));
+                 "Click and drag up and down or left and right to modify");
     setFixedSize(size, size);
 
+    // set the initial position
+    drawPosition();
+
     emit valueChanged(m_snapPosition);
 }
 
@@ -412,189 +437,94 @@ RosegardenRotary::setKnobColour(const QColor &colour)
 }
 
 void
-RosegardenRotary::paintEvent(QPaintEvent *)
+RosegardenRotary::paintEvent(QPaintEvent *e)
 {
-    QPainter paint;
+    QPainter paint(this);
 
-    double angle = ROTARY_MIN // offset 
-                   + (ROTARY_RANGE *
-		      (double(m_snapPosition - m_minValue) /
-		       (double(m_maxValue) - double(m_minValue))));
-    int degrees = int(angle * 180.0 / M_PI);
+    paint.setClipRegion(e->region());
+    paint.setClipRect(e->rect().normalize());
 
-//    RG_DEBUG << "degrees: " << degrees << ", size " << m_size << ", pixel " << m_knobColour.pixel() << endl;
+    paint.setPen(kapp->palette().color(QPalette::Active, QColorGroup::Dark));
 
-    int numTicks = 0;
-    switch (m_tickMode) {
-    case LimitTicks:
-	numTicks = 2;
-	break;
-    case IntervalTicks:
-	numTicks = 5;
-	break;
-    case PageStepTicks:
-	numTicks = 1 + (m_maxValue + 0.0001 - m_minValue) / m_pageStep;
-	break;
-    case StepTicks:
-	numTicks = 1 + (m_maxValue + 0.0001 - m_minValue) / m_step;
-	break;
-    default: break;
-    }
-
-    CacheIndex index(m_size, m_knobColour.pixel(), degrees, numTicks, m_centred);
-
-    if (m_pixmaps.find(index) != m_pixmaps.end()) {
-	paint.begin(this);
-	paint.drawPixmap(0, 0, m_pixmaps[index]);
-	paint.end();
-	return;
-    }
-
-    int scale = 4;
-    int width = m_size * scale;
-    QPixmap map(width, width);
-    map.fill(paletteBackgroundColor());
-    paint.begin(&map);
-
-    QPen pen;
-    pen.setColor(kapp->palette().color(QPalette::Active, QColorGroup::Dark));
-    pen.setWidth(scale);
-    paint.setPen(pen);
-
-    if (m_knobColour != Qt::black) {
+    if (m_knobColour != Qt::black)
         paint.setBrush(m_knobColour);
-    } else {
+    else
         paint.setBrush(
                 kapp->palette().color(QPalette::Active, QColorGroup::Base));
-    }
 
-    QColor c(m_knobColour);
-    pen.setColor(c);
-    paint.setPen(pen);
-    
-    int indent = width * 0.15 + 1;
-    
-    paint.drawEllipse(indent, indent, width-2*indent, width-2*indent);
-    
-    pen.setWidth(2 * scale);
-    int pos = indent + (width-2*indent)/8;
-    int darkWidth = (width-2*indent) * 2 / 3;
-    int darkQuote = (130 * 2 / (darkWidth ? darkWidth : 1)) + 100;
-    while (darkWidth) {
-	c = c.light(101);
-	pen.setColor(c);
-	paint.setPen(pen);
-	paint.drawEllipse(pos, pos, darkWidth, darkWidth);
-	if (!--darkWidth) break;
-	paint.drawEllipse(pos, pos, darkWidth, darkWidth);
-	if (!--darkWidth) break;
-	paint.drawEllipse(pos, pos, darkWidth, darkWidth);
-	++pos; --darkWidth;
-    }
-    
-    paint.setBrush(QBrush::NoBrush);
-    
-    pen.setColor(colorGroup().dark());
-    pen.setWidth(scale);
-    paint.setPen(pen);
+    if (m_tickMode == NoTicks) {
 
-    for (int i = 0; i < numTicks; ++i) {
-	int div = numTicks;
-	if (div > 1) --div;
-	drawTick(paint, ROTARY_MIN + (ROTARY_MAX - ROTARY_MIN) * i / div,
-		 width, i != 0 && i != numTicks-1);
-    }
+	paint.drawEllipse(0, 0, m_size, m_size);
+	drawPosition();
 
-    // now the bright metering bit
-
-    pen.setColor(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::RotaryMeter));
-    pen.setWidth(indent);
-    paint.setPen(pen);
-
-    if (m_centred) {
-	paint.drawArc(indent/2, indent/2, width-indent, width-indent,
-		      90 * 16, -(degrees - 180) * 16);
     } else {
-	paint.drawArc(indent/2, indent/2, width-indent, width-indent,
-		      (180 + 45) * 16, -(degrees - 45) * 16);
+
+	paint.drawEllipse(int(m_size * 0.1), int(m_size * 0.1),
+			  int(m_size * 0.8), int(m_size * 0.8));
+	drawPosition();
+
+	// if we have ticks at all, we always have start and end ticks
+	
+	drawTick(paint, ROTARY_MIN);
+	drawTick(paint, ROTARY_MAX);
+
+	switch (m_tickMode) {
+
+	case NoTicks:
+	case LimitTicks:
+	    break; // done that already
+
+	case IntervalTicks:
+	    drawTick(paint, ROTARY_MIN * 0.75 + ROTARY_MAX * 0.25);
+	    drawTick(paint, ROTARY_MIN * 0.50 + ROTARY_MAX * 0.50);
+	    drawTick(paint, ROTARY_MIN * 0.25 + ROTARY_MAX * 0.75);
+	    break;
+
+	case PageStepTicks:
+	    for (double value = m_minValue; value < m_maxValue; value += m_pageStep) {
+
+		float angle = ROTARY_MIN
+                   + (ROTARY_RANGE *
+		      (double(value - m_minValue) /
+		       (double(m_maxValue) - double(m_minValue))));
+
+		drawTick(paint, angle);
+	    }
+	    break;
+
+	case StepTicks:
+	    for (double value = m_minValue; value < m_maxValue; value += m_step) {
+
+		float angle = ROTARY_MIN
+                   + (ROTARY_RANGE *
+		      (double(value - m_minValue) /
+		       (double(m_maxValue) - double(m_minValue))));
+
+		drawTick(paint, angle);
+	    }
+	    break;
+	}
     }
-    
-    pen.setWidth(scale);
-    paint.setPen(pen);
-    
-    int shadowAngle = -720;
-    c = colorGroup().dark();
-    for (int arc = 120; arc < 2880; arc += 240) {
-	pen.setColor(c);
-	paint.setPen(pen);
-	paint.drawArc(indent, indent, width-2*indent, width-2*indent, shadowAngle + arc, 240);
-	paint.drawArc(indent, indent, width-2*indent, width-2*indent, shadowAngle - arc, 240);
-	c = c.light( 110 );
-    }
-    
-    shadowAngle = 2160;
-    c = colorGroup().dark();
-    for (int arc = 120; arc < 2880; arc += 240) {
-	pen.setColor(c);
-	paint.setPen(pen);
-	paint.drawArc(scale/2, scale/2, width-scale, width-scale, shadowAngle + arc, 240);
-	paint.drawArc(scale/2, scale/2, width-scale, width-scale, shadowAngle - arc, 240);
-	c = c.light( 109 );
-    }
-    
-    // and un-draw the bottom part
-    pen.setColor(paletteBackgroundColor());
-    paint.setPen(pen);
-    paint.drawArc(scale/2, scale/2, width-scale, width-scale,
-		  -45 * 16, -90 * 16);
-
-    double hyp = double(width) / 2.0;
-    double len = hyp - indent;
-    --len;
-
-    double x0 = hyp;
-    double y0 = hyp;
-
-    double x = hyp - len * sin(angle);
-    double y = hyp + len * cos(angle);
-
-    pen.setWidth(scale * 2);
-    pen.setColor(colorGroup().dark());
-    paint.setPen(pen);
-
-    paint.drawLine(int(x0), int(y0), int(x), int(y));
-
-    paint.end();
-
-    QImage i = map.convertToImage().smoothScale(m_size, m_size);
-    m_pixmaps[index] = QPixmap(i);
-    paint.begin(this);
-    paint.drawPixmap(0, 0, m_pixmaps[index]);
-    paint.end();
 }
 
 void
-RosegardenRotary::drawTick(QPainter &paint, double angle, int size, bool internal)
+RosegardenRotary::drawTick(QPainter &paint, double angle)
 {
-    double hyp = double(size) / 2.0;
-    double x0 = hyp - (hyp - 1) * sin(angle);
-    double y0 = hyp + (hyp - 1) * cos(angle);
+    double hyp = double(m_size) / 2.0;
+    double x0 = hyp - hyp * sin(angle);
+    double y0 = hyp + hyp * cos(angle);
     
-    if (internal) {
+    if (angle < ROTARY_MIN + 0.001 || angle > ROTARY_MAX - 0.001) {
 
-	double len = hyp / 4;
-	double x1 = hyp - (hyp - len) * sin(angle);
-	double y1 = hyp + (hyp - len) * cos(angle);
-    
-	paint.drawLine(int(x0), int(y0), int(x1), int(y1));
-
-    } else {
-
-	double len = hyp / 4;
+	double len = hyp / 5;
 	double x1 = hyp - (hyp + len) * sin(angle);
 	double y1 = hyp + (hyp + len) * cos(angle);
     
 	paint.drawLine(int(x0), int(y0), int(x1), int(y1));
+
+    } else {
+
+	paint.drawPoint(int(x0), int(y0));
     }
 }
     
@@ -641,6 +571,72 @@ RosegardenRotary::snapPosition()
     }
 }
     
+// Draw the position line - note that we adjust for the minimum value
+// so that the knobs always work "vertically".
+//
+void
+RosegardenRotary::drawPosition()
+{
+    QPainter paint(this);
+
+    double hyp = double(m_size) / 2.0;
+    double len = hyp;
+    if (m_tickMode != NoTicks) len = 0.8 * len;
+    --len;
+
+    // Undraw the previous line
+    //
+    double angle = ROTARY_MIN // offset 
+                   + (ROTARY_RANGE *
+		      (double(m_lastPosition - m_minValue) /
+		       (double(m_maxValue) - double(m_minValue))));
+
+    double x0 = hyp - len/4 * sin(angle);
+    double y0 = hyp + len/4 * cos(angle);
+
+    double x = hyp - len * sin(angle);
+    double y = hyp + len * cos(angle);
+
+    QPen pen;
+    pen.setColor(m_knobColour);
+    pen.setWidth(2);
+    if (m_knobColour == Qt::black) {
+	pen.setColor(kapp->palette().color(QPalette::Active, QColorGroup::Base));
+    }
+
+    paint.setPen(pen);
+    paint.drawLine(int(x0), int(y0), int(x), int(y));
+
+    // Draw the new position
+    //
+    angle = ROTARY_MIN // offset 
+                   + (ROTARY_RANGE * (double(m_snapPosition - m_minValue) /
+                     (double(m_maxValue) - double(m_minValue))));
+
+    x0 = hyp - len/4 * sin(angle);
+    y0 = hyp + len/4 * cos(angle);
+
+    x = hyp - len * sin(angle);
+    y = hyp + len * cos(angle);
+
+    pen.setColor(Qt::black);
+    paint.setPen(pen);
+
+    paint.drawLine(int(x0), int(y0), int(x), int(y));
+
+    m_lastPosition = m_snapPosition;
+
+    pen.setWidth(0);
+    paint.setPen(pen);
+    paint.setBrush(Qt::NoBrush);
+    if (m_tickMode == NoTicks) {
+	paint.drawEllipse(0, 0, m_size, m_size);
+    } else {
+	paint.drawEllipse(int(m_size * 0.1), int(m_size * 0.1),
+			  int(m_size * 0.8), int(m_size * 0.8));
+    }
+} 
+
 
 void
 RosegardenRotary::mousePressEvent(QMouseEvent *e)
@@ -650,61 +646,34 @@ RosegardenRotary::mousePressEvent(QMouseEvent *e)
         m_buttonPressed = true;
         m_lastY = e->y();
         m_lastX = e->x();
-        //_float->setText(QString("%1").arg(m_snapPosition));
-    }
-    else if (e->button() == MidButton) // reset to default
-    {
-        m_position = m_initialPosition;
-	snapPosition();
-	update();
-        emit valueChanged(m_snapPosition);
+
+        if (!_float) _float = new RosegardenTextFloat(this);
+
+        // Reposition - we need to sum the relative positions up to the
+        // topLevel or dialog to please move(). Move just top/right of the 
+        // rotary
+        //
+        QPoint totalPos = mapTo(topLevelWidget(), QPoint(0, 0));
+        //_float->reparent(this, totalPos + QPoint(width() + 2, -height()/2));
+        _float->reparent(this);
+        _float->move(totalPos + QPoint(width() + 2, -height()/2));
+
+        // draw on the float text
+        _float->setText(QString("%1").arg(m_snapPosition));
+
+        // Show
+        _float->show();
     }
     else if (e->button() == RightButton) // reset to centre position
     {
         m_position = (m_maxValue + m_minValue) / 2.0;
 	snapPosition();
-	update();
+        drawPosition();
         emit valueChanged(m_snapPosition);
     }
 
-    QPoint totalPos = mapTo(topLevelWidget(), QPoint(0, 0));
-
-    if (!_float) _float = new RosegardenTextFloat(this);
-    _float->reparent(this);
-    _float->move(totalPos + QPoint(width() + 2, -height()/2));
-    _float->setText(QString("%1").arg(m_position));
-    _float->show();
-
-    if (e->button() == RightButton || e->button() == MidButton)
-    {
-        // one shot, 500ms
-        _floatTimer->start(500, true);
-    }
 }
 
-
-void
-RosegardenRotary::mouseDoubleClickEvent(QMouseEvent * /*e*/)
-{
-    RosegardenFloatEdit dialog(this,
-            i18n("Select a new value"),
-            i18n("Enter a new value"),
-            m_minValue,
-            m_maxValue,
-            m_position,
-            m_step);
-
-    if (dialog.exec() == QDialog::Accepted)
-    {
-        m_position = dialog.getValue();
-        snapPosition();
-        update();
-
-        emit valueChanged(m_snapPosition);
-    }
-}
-
-
 void
 RosegardenRotary::mouseReleaseEvent(QMouseEvent *e)
 {
@@ -744,9 +713,9 @@ RosegardenRotary::mouseMoveEvent(QMouseEvent *e)
 	snapPosition();
 
         // don't update if there's nothing to update
-//        if (m_lastPosition == m_snapPosition) return;
+        if (m_lastPosition == m_snapPosition) return;
 
-	update();
+        drawPosition();
 
         emit valueChanged(m_snapPosition);
 
@@ -770,7 +739,7 @@ RosegardenRotary::wheelEvent(QWheelEvent *e)
         m_position = m_minValue;
 
     snapPosition();
-    update();
+    drawPosition();
 
     if (!_float) _float = new RosegardenTextFloat(this);
 
@@ -799,7 +768,7 @@ RosegardenRotary::setPosition(float position)
     m_position = position;
     
     snapPosition();
-    update();
+    drawPosition();
 }
 
 
@@ -1289,18 +1258,10 @@ RosegardenTextFloat::paintEvent(QPaintEvent *e)
 
     paint.setPen(kapp->palette().color(QPalette::Active, QColorGroup::Dark));
 
-    paint.setPen(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::RotaryFloatForeground));
-    paint.setBrush(Rosegarden::GUIPalette::getColour(Rosegarden::GUIPalette::RotaryFloatBackground));
+    paint.setPen(RosegardenGUIColours::RotaryFloatForeground);
+    paint.setBrush(RosegardenGUIColours::RotaryFloatBackground);
 
     QFontMetrics metrics(paint.fontMetrics());
-
-    QRect r = metrics.boundingRect(0, 0, 400, 400, Qt::AlignAuto, m_text);
-    resize(r.width() + 7, r.height() + 7);
-    paint.drawRect(0, 0, r.width() + 6, r.height() + 6);
-    paint.setPen(Qt::black);
-    paint.drawText(QRect(3, 3, r.width(), r.height()), Qt::AlignAuto, m_text);
-
-/*
     QRect textBound = metrics.boundingRect(m_text);
 
     resize(textBound.width() + 7, textBound.height() + 7);
@@ -1308,7 +1269,6 @@ RosegardenTextFloat::paintEvent(QPaintEvent *e)
 
     paint.setPen(Qt::black);
     paint.drawText(3, textBound.height() + 3, m_text);
-*/
 }
 
 
@@ -1375,7 +1335,7 @@ RosegardenPitchDragLabel::mouseMoveEvent(QMouseEvent *e)
 	    bool up = (newPitch > m_pitch);
 	    m_pitch = newPitch;
 	    calculatePixmap(up);
-	    emit pitchDragged(m_pitch);
+	    emit pitchChanged(m_pitch);
 	    emit preview(m_pitch);
 	    paintEvent(0);
 	}
@@ -1386,7 +1346,6 @@ void
 RosegardenPitchDragLabel::mouseReleaseEvent(QMouseEvent *e)
 {
     mouseMoveEvent(e);
-    emit pitchChanged(m_pitch);
     m_clicked = false;
 }
 
@@ -1495,9 +1454,6 @@ RosegardenPitchChooser::RosegardenPitchChooser(QString title,
     connect(m_pitch, SIGNAL(valueChanged(int)),
             this, SIGNAL(preview(int)));
 
-    connect(m_pitchDragLabel, SIGNAL(pitchDragged(int)),
-	    this, SLOT(slotSetPitch(int)));
-
     connect(m_pitchDragLabel, SIGNAL(pitchChanged(int)),
 	    this, SLOT(slotSetPitch(int)));
 
@@ -1531,4 +1487,597 @@ RosegardenPitchChooser::slotResetToDefault()
 {
     slotSetPitch(m_defaultPitch);
 }
-#include "widgets.moc"
+
+RosegardenTimeWidget::RosegardenTimeWidget(QString title,
+					   QWidget *parent,
+					   Rosegarden::Composition *composition,
+					   Rosegarden::timeT absTime,
+					   bool editable) :
+    QGroupBox(1, Horizontal, title, parent),
+    m_composition(composition),
+    m_isDuration(false),
+    m_time(absTime),
+    m_startTime(0),
+    m_defaultTime(absTime)
+{
+    init(editable);
+}
+
+RosegardenTimeWidget::RosegardenTimeWidget(QString title,
+					   QWidget *parent,
+					   Rosegarden::Composition *composition,
+					   Rosegarden::timeT startTime,
+					   Rosegarden::timeT duration,
+					   bool editable) :
+    QGroupBox(1, Horizontal, title, parent),
+    m_composition(composition),
+    m_isDuration(true),
+    m_time(duration),
+    m_startTime(startTime),
+    m_defaultTime(duration)
+{
+    init(editable);
+}
+
+void
+RosegardenTimeWidget::init(bool editable)
+{
+    int denoms[] = {
+	1, 2, 3, 4, 6, 8, 12, 16, 24, 32, 48, 64, 96, 128
+    };
+
+    bool savedEditable = editable;
+    editable = true; //!!!
+
+    QFrame *frame = new QFrame(this);
+    QGridLayout *layout = new QGridLayout(frame, 7, 3, 5, 5);
+    QLabel *label = 0;
+
+    if (m_isDuration) {
+
+	label = new QLabel(i18n("Note:"), frame);
+	label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+	layout->addWidget(label, 0, 0);
+
+	if (editable) {
+	    m_note = new QComboBox(frame);
+	    m_noteDurations.push_back(0);
+	    m_note->insertItem(i18n("<inexact>"));
+	    for (size_t i = 0; i < sizeof(denoms)/sizeof(denoms[0]); ++i) {
+
+		Rosegarden::timeT duration =
+		    Rosegarden::Note(Rosegarden::Note::Breve).getDuration() / denoms[i];
+		
+		if (denoms[i] > 1 && denoms[i] < 128 && (denoms[i] % 3) != 0) {
+		    // not breve or hemidemi, not a triplet
+		    Rosegarden::timeT dottedDuration = duration * 3 / 2;
+		    m_noteDurations.push_back(dottedDuration);
+		    Rosegarden::timeT error = 0;
+		    QString label = NotationStrings::makeNoteMenuLabel
+			(dottedDuration, false, error);
+		    QPixmap pmap = NotePixmapFactory::toQPixmap
+			(NotePixmapFactory::makeNoteMenuPixmap(dottedDuration, error));
+		    m_note->insertItem(pmap, label); // ignore error
+		}		
+		
+		m_noteDurations.push_back(duration);
+		Rosegarden::timeT error = 0;
+		QString label = NotationStrings::makeNoteMenuLabel
+		    (duration, false, error);
+		QPixmap pmap = NotePixmapFactory::toQPixmap
+		    (NotePixmapFactory::makeNoteMenuPixmap(duration, error));
+		m_note->insertItem(pmap, label); // ignore error
+	    }
+	    connect(m_note, SIGNAL(activated(int)),
+		    this, SLOT(slotNoteChanged(int)));
+	    layout->addMultiCellWidget(m_note, 0, 0, 1, 3);
+
+	} else {
+
+	    m_note = 0;
+	    Rosegarden::timeT error = 0;
+	    QString label = NotationStrings::makeNoteMenuLabel
+		(m_time, false, error);
+	    if (error != 0) label = i18n("<inexact>");
+	    QLineEdit *le = new QLineEdit(label, frame);
+	    le->setReadOnly(true);
+	    layout->addMultiCellWidget(le, 0, 0, 1, 3);
+	}
+
+	label = new QLabel(i18n("Units:"), frame);
+	label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+	layout->addWidget(label, 0, 4);
+
+	if (editable) {
+	    m_timeT = new QSpinBox(frame);
+	    m_timeT->setLineStep
+		(Rosegarden::Note(Rosegarden::Note::Shortest).getDuration());
+	    connect(m_timeT, SIGNAL(valueChanged(int)),
+		    this, SLOT(slotTimeTChanged(int)));
+	    layout->addWidget(m_timeT, 0, 5);
+	} else {
+	    m_timeT = 0;
+	    QLineEdit *le = new QLineEdit(QString("%1").arg(m_time), frame);
+	    le->setReadOnly(true);
+	    layout->addWidget(le, 0, 5);
+	}
+
+    } else {
+
+	m_note = 0;
+
+	label = new QLabel(i18n("Time:"), frame);
+	label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+	layout->addWidget(label, 0, 0);
+
+	if (editable) {
+	    m_timeT = new QSpinBox(frame);
+	    m_timeT->setLineStep
+		(Rosegarden::Note(Rosegarden::Note::Shortest).getDuration());
+	    connect(m_timeT, SIGNAL(valueChanged(int)),
+		    this, SLOT(slotTimeTChanged(int)));
+	    layout->addWidget(m_timeT, 0,1);
+	    layout->addWidget(new QLabel(i18n("units"), frame), 0, 2);
+	} else {
+	    m_timeT = 0;
+	    QLineEdit *le = new QLineEdit(QString("%1").arg(m_time), frame);
+	    le->setReadOnly(true);
+	    layout->addWidget(le, 0, 2);
+	}
+    }
+
+    label = new QLabel(m_isDuration ? i18n("Measures:") : i18n("Measure:"), frame);
+    label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    layout->addWidget(label, 1, 0);
+
+    if (editable) {
+	m_barLabel = 0;
+	m_bar = new QSpinBox(frame);
+	if (m_isDuration) m_bar->setMinValue(0);
+	connect(m_bar, SIGNAL(valueChanged(int)),
+		this, SLOT(slotBarBeatOrFractionChanged(int)));
+	layout->addWidget(m_bar, 1, 1);
+    } else {
+	m_bar = 0;
+	m_barLabel = new QLineEdit(frame);
+	m_barLabel->setReadOnly(true);
+	layout->addWidget(m_barLabel, 1, 1);
+    }
+
+    label = new QLabel(m_isDuration ? i18n("beats:") : i18n("beat:"), frame);
+    label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    layout->addWidget(label, 1, 2);
+
+    if (editable) {
+	m_beatLabel = 0;
+	m_beat = new QSpinBox(frame);
+	m_beat->setMinValue(1);
+	connect(m_beat, SIGNAL(valueChanged(int)),
+		this, SLOT(slotBarBeatOrFractionChanged(int)));
+	layout->addWidget(m_beat, 1, 3);
+    } else {
+	m_beat = 0;
+	m_beatLabel = new QLineEdit(frame);
+	m_beatLabel->setReadOnly(true);
+	layout->addWidget(m_beatLabel, 1, 3);
+    }
+
+    label = new QLabel(i18n("%1:").arg(NotationStrings::getShortNoteName
+				       (Rosegarden::Note
+					(Rosegarden::Note::Shortest), true)),
+				       frame);
+    label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    layout->addWidget(label, 1, 4);
+
+    if (editable) {
+	m_fractionLabel = 0;
+	m_fraction = new QSpinBox(frame);
+	m_fraction->setMinValue(1);
+	connect(m_fraction, SIGNAL(valueChanged(int)),
+		this, SLOT(slotBarBeatOrFractionChanged(int)));
+	layout->addWidget(m_fraction, 1, 5);
+    } else {
+	m_fraction = 0;
+	m_fractionLabel = new QLineEdit(frame);
+	m_fractionLabel->setReadOnly(true);
+	layout->addWidget(m_fractionLabel, 1, 5);
+    }
+
+    m_timeSig = new QLabel(frame);
+    layout->addWidget(m_timeSig, 1, 6);
+    
+    label = new QLabel(i18n("Seconds:"), frame);
+    label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    layout->addWidget(label, 2, 0);
+
+    if (editable) {
+	m_secLabel = 0;
+	m_sec = new QSpinBox(frame);
+	if (m_isDuration) m_sec->setMinValue(0);
+	connect(m_sec, SIGNAL(valueChanged(int)),
+		this, SLOT(slotSecOrMSecChanged(int)));
+	layout->addWidget(m_sec, 2, 1);
+    } else { 
+	m_sec = 0;
+	m_secLabel = new QLineEdit(frame);
+	m_secLabel->setReadOnly(true);
+	layout->addWidget(m_secLabel, 2, 1);
+    }
+
+    label = new QLabel(i18n("msec:"), frame);
+    label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    layout->addWidget(label, 2, 2);
+
+    if (editable) {
+	m_msecLabel = 0;
+	m_msec = new QSpinBox(frame);
+	m_msec->setMinValue(0);
+	m_msec->setLineStep(10);
+	connect(m_msec, SIGNAL(valueChanged(int)),
+		this, SLOT(slotSecOrMSecChanged(int)));
+	layout->addWidget(m_msec, 2, 3);
+    } else { 
+	m_msec = 0;
+	m_msecLabel = new QLineEdit(frame);
+	m_msecLabel->setReadOnly(true);
+	layout->addWidget(m_msecLabel, 2, 3);
+    }
+
+    if (m_isDuration) {
+	m_tempo = new QLabel(frame);
+	layout->addWidget(m_tempo, 2, 6);
+    } else {
+	m_tempo = 0;
+    }
+
+    if (!savedEditable) {
+	if (m_note)     m_note     ->setEnabled(false);
+	if (m_timeT)    m_timeT    ->setEnabled(false);
+	if (m_bar)      m_bar      ->setEnabled(false);
+	if (m_beat)     m_beat     ->setEnabled(false);
+	if (m_fraction) m_fraction ->setEnabled(false);
+	if (m_sec)      m_sec      ->setEnabled(false);
+	if (m_msec)     m_msec     ->setEnabled(false);
+    }
+
+    populate();
+}
+
+void
+RosegardenTimeWidget::populate()
+{
+    // populate everything from m_time and m_startTime
+
+    if (m_note)     m_note     ->blockSignals(true);
+    if (m_timeT)    m_timeT    ->blockSignals(true);
+    if (m_bar)      m_bar      ->blockSignals(true);
+    if (m_beat)     m_beat     ->blockSignals(true);
+    if (m_fraction) m_fraction ->blockSignals(true);
+    if (m_sec)      m_sec      ->blockSignals(true);
+    if (m_msec)     m_msec     ->blockSignals(true);
+
+    if (m_isDuration) {
+
+	if (m_time + m_startTime > m_composition->getEndMarker()) {
+	    m_time = m_composition->getEndMarker() - m_startTime;
+	}
+
+	if (m_timeT) {
+	    m_timeT->setMinValue(0);
+	    m_timeT->setMaxValue(m_composition->getEndMarker() - m_startTime);
+	    m_timeT->setValue(m_time);
+	}
+    
+	if (m_note) {
+	    m_note->setCurrentItem(0);
+	    for (size_t i = 0; i < m_noteDurations.size(); ++i) {
+		if (m_time == m_noteDurations[i]) {
+		    m_note->setCurrentItem(i);
+		    break;
+		}
+	    }
+	}
+	
+	// the bar/beat etc timings are considered to be times of a note
+	// starting at the start of a bar, in the time signature in effect
+	// at m_startTime
+
+	int bars = 0, beats = 0, hemidemis = 0, remainder = 0;
+	m_composition->getMusicalTimeForDuration(m_startTime, m_time,
+						 bars, beats, hemidemis, remainder);
+	Rosegarden::TimeSignature timeSig =
+	    m_composition->getTimeSignatureAt(m_startTime);
+/*!!!
+	Rosegarden::timeT barDuration = timeSig.getBarDuration();
+	Rosegarden::timeT beatDuration = timeSig.getBeatDuration();
+	int bars = m_time / barDuration;
+	int beats = (m_time % barDuration) / beatDuration;
+	Rosegarden::timeT remainder = (m_time % barDuration) % beatDuration;
+	int hemidemis = remainder /
+	    Rosegarden::Note(Rosegarden::Note::Shortest).getDuration();
+*/
+	if (m_bar) {
+	    m_bar->setMinValue(0);
+	    m_bar->setMaxValue
+		(m_composition->getBarNumber(m_composition->getEndMarker()) -
+		 m_composition->getBarNumber(m_startTime));
+	    m_bar->setValue(bars);
+	} else {
+	    m_barLabel->setText(QString("%1").arg(bars));
+	}
+
+	if (m_beat) {
+	    m_beat->setMinValue(0);
+	    m_beat->setMaxValue(timeSig.getBeatsPerBar() - 1);
+	    m_beat->setValue(beats);
+	} else {
+	    m_beatLabel->setText(QString("%1").arg(beats));
+	}
+
+	if (m_fraction) {
+	    m_fraction->setMinValue(0);
+	    m_fraction->setMaxValue(timeSig.getBeatDuration() /
+				    Rosegarden::Note(Rosegarden::Note::Shortest).
+				    getDuration() - 1);
+	    m_fraction->setValue(hemidemis);
+	} else {
+	    m_fractionLabel->setText(QString("%1").arg(hemidemis));
+	}
+
+	m_timeSig->setText(i18n("(%1/%2 time)").arg(timeSig.getNumerator()).
+			   arg(timeSig.getDenominator()));
+	
+	Rosegarden::timeT endTime = m_startTime + m_time;
+
+	Rosegarden::RealTime rt = m_composition->getRealTimeDifference
+	    (m_startTime, endTime);
+
+	if (m_sec) {
+	    m_sec->setMinValue(0);
+	    m_sec->setMaxValue(m_composition->getRealTimeDifference
+			       (m_startTime, m_composition->getEndMarker()).sec);
+	    m_sec->setValue(rt.sec);
+	} else {
+	    m_secLabel->setText(QString("%1").arg(rt.sec));
+	}
+
+	if (m_msec) {
+	    m_msec->setMinValue(0);
+	    m_msec->setMaxValue(999);
+	    m_msec->setValue(rt.msec());
+	} else {
+	    m_msecLabel->setText(QString("%1").arg(rt.msec()));
+	}
+
+	bool change = (m_composition->getTempoChangeNumberAt(endTime) !=
+		       m_composition->getTempoChangeNumberAt(m_startTime));
+	double tempo = m_composition->getTempoAt(m_startTime);
+	int qpmc = int(tempo * 100.0);
+	int bpmc = qpmc;
+	if (timeSig.getBeatDuration()
+	    != Rosegarden::Note(Rosegarden::Note::Crotchet).getDuration()) {
+	    bpmc = int(tempo * 100.0 *
+		       Rosegarden::Note(Rosegarden::Note::Crotchet).getDuration() /
+		       timeSig.getBeatDuration());
+	}
+	if (change) {
+	    if (bpmc != qpmc) {
+		m_tempo->setText(i18n("(starting %1.%2 qpm, %2.%3 bpm)").
+				 arg(qpmc / 100).
+				 arg(qpmc % 100).
+				 arg(bpmc / 100).
+				 arg(bpmc % 100));
+	    } else {
+		m_tempo->setText(i18n("(starting %1.%2 bpm)").
+				 arg(bpmc / 100).
+				 arg(bpmc % 100));
+	    }
+	} else {
+	    if (bpmc != qpmc) {
+		m_tempo->setText(i18n("(%1.%2 qpm, %2.%3 bpm)").
+				 arg(qpmc / 100).
+				 arg(qpmc % 100).
+				 arg(bpmc / 100).
+				 arg(bpmc % 100));
+	    } else {
+		m_tempo->setText(i18n("(%1.%2 bpm)").
+				 arg(bpmc / 100).
+				 arg(bpmc % 100));
+	    }
+	}	    
+
+    } else {
+
+	if (m_time > m_composition->getEndMarker()) {
+	    m_time = m_composition->getEndMarker();
+	}
+
+	if (m_timeT) {
+	    m_timeT->setMinValue(INT_MIN);
+	    m_timeT->setMaxValue(m_composition->getEndMarker());
+	    m_timeT->setValue(m_time);
+	}
+
+	int bar = 1, beat = 1, hemidemis = 0, remainder = 0;
+	m_composition->getMusicalTimeForAbsoluteTime
+	    (m_time, bar, beat, hemidemis, remainder);
+	
+	Rosegarden::TimeSignature timeSig =
+	    m_composition->getTimeSignatureAt(m_time);
+/*!!!
+	int bar = m_composition->getBarNumber(m_time);
+	Rosegarden::timeT barStart = m_composition->getBarStart(bar);
+	Rosegarden::timeT beatDuration = timeSig.getBeatDuration();
+	int beat = (m_time - barStart) / beatDuration + 1;
+	Rosegarden::timeT remainder = (m_time - barStart) % beatDuration;
+	int hemidemis = remainder /
+	    Rosegarden::Note(Rosegarden::Note::Shortest).getDuration();
+*/
+
+	if (m_bar) {
+	    m_bar->setMinValue(INT_MIN);
+	    m_bar->setMaxValue(m_composition->getBarNumber
+			       (m_composition->getEndMarker()));
+	    m_bar->setValue(bar + 1);
+	} else {
+	    m_barLabel->setText(QString("%1").arg(bar + 1));
+	}
+
+	if (m_beat) {
+	    m_beat->setMinValue(1);
+	    m_beat->setMaxValue(timeSig.getBeatsPerBar());
+	    m_beat->setValue(beat);
+	} else {
+	    m_beatLabel->setText(QString("%1").arg(beat));
+	}
+
+	if (m_fraction) {
+	    m_fraction->setMinValue(0);
+	    m_fraction->setMaxValue(timeSig.getBeatDuration() /
+				    Rosegarden::Note(Rosegarden::Note::Shortest).
+				    getDuration() - 1);
+	    m_fraction->setValue(hemidemis);
+	} else {
+	    m_fractionLabel->setText(QString("%1").arg(hemidemis));
+	}
+
+	m_timeSig->setText(i18n("(%1/%2 time)").arg(timeSig.getNumerator()).
+			   arg(timeSig.getDenominator()));
+	
+	Rosegarden::RealTime rt = m_composition->getElapsedRealTime(m_time);
+
+	if (m_sec) {
+	    m_sec->setMinValue(INT_MIN);
+	    m_sec->setMaxValue(m_composition->getElapsedRealTime
+			       (m_composition->getEndMarker()).sec);
+	    m_sec->setValue(rt.sec);
+	} else {
+	    m_secLabel->setText(QString("%1").arg(rt.sec));
+	}
+
+	if (m_msec) {
+	    m_msec->setMinValue(0);
+	    m_msec->setMaxValue(999);
+	    m_msec->setValue(rt.msec());
+	} else {
+	    m_msecLabel->setText(QString("%1").arg(rt.msec()));
+	}
+    }
+
+    if (m_note)     m_note     ->blockSignals(false);
+    if (m_timeT)    m_timeT    ->blockSignals(false);
+    if (m_bar)      m_bar      ->blockSignals(false);
+    if (m_beat)     m_beat     ->blockSignals(false);
+    if (m_fraction) m_fraction ->blockSignals(false);
+    if (m_sec)      m_sec      ->blockSignals(false);
+    if (m_msec)     m_msec     ->blockSignals(false);
+}
+
+Rosegarden::timeT
+RosegardenTimeWidget::getTime()
+{
+    return m_time;
+}
+
+Rosegarden::RealTime
+RosegardenTimeWidget::getRealTime()
+{
+    if (m_isDuration) {
+	return m_composition->getRealTimeDifference(m_startTime,
+						    m_startTime + m_time);
+    } else {
+	return m_composition->getElapsedRealTime(m_time);
+    }
+}
+
+void
+RosegardenTimeWidget::slotSetTime(Rosegarden::timeT t)
+{
+    bool change = (m_time != t);
+    if (!change) return;
+    m_time = t;
+    populate();
+    emit timeChanged(getTime());
+    emit realTimeChanged(getRealTime());
+}
+
+void
+RosegardenTimeWidget::slotSetRealTime(Rosegarden::RealTime rt)
+{
+    if (m_isDuration) {
+	Rosegarden::RealTime startRT = m_composition->getElapsedRealTime(m_startTime);
+	if (rt >= Rosegarden::RealTime::zeroTime) {
+	    slotSetTime(m_composition->getElapsedTimeForRealTime(startRT + rt) -
+			m_startTime);
+	} else {
+	    RG_DEBUG << "WARNING: RosegardenTimeWidget::slotSetRealTime: rt must be >0 for duration widget (was " << rt << ")" << endl;
+	}
+    } else {
+	slotSetTime(m_composition->getElapsedTimeForRealTime(rt));
+    }
+}
+
+void
+RosegardenTimeWidget::slotResetToDefault()
+{
+    slotSetTime(m_defaultTime);
+}
+	
+void
+RosegardenTimeWidget::slotNoteChanged(int n)
+{
+    if (n > 0) {
+	slotSetTime(m_noteDurations[n]);
+    }
+}
+
+void
+RosegardenTimeWidget::slotTimeTChanged(int t)
+{
+    RG_DEBUG << "slotTimeTChanged: t is " << t << ", value is " << m_timeT->value() << endl;
+
+    slotSetTime(t);
+}
+
+void
+RosegardenTimeWidget::slotBarBeatOrFractionChanged(int)
+{
+    int bar = m_bar->value();
+    int beat = m_beat->value();
+    int fraction = m_fraction->value();
+
+    if (m_isDuration) {
+	slotSetTime(m_composition->getDurationForMusicalTime
+		    (m_startTime, bar, beat, fraction, 0));
+/*!!!
+	Rosegarden::TimeSignature timeSig =
+	    m_composition->getTimeSignatureAt(m_startTime);
+	Rosegarden::timeT barDuration = timeSig.getBarDuration();
+	Rosegarden::timeT beatDuration = timeSig.getBeatDuration();
+	Rosegarden::timeT t = bar * barDuration + beat * beatDuration + fraction *
+	    Rosegarden::Note(Rosegarden::Note::Shortest).getDuration();
+	slotSetTime(t);
+*/
+    } else {
+	slotSetTime(m_composition->getAbsoluteTimeForMusicalTime
+		    (bar, beat, fraction, 0));
+	/*!!!
+	Rosegarden::timeT t = m_composition->getBarStart(bar - 1);
+	Rosegarden::TimeSignature timesig = m_composition->getTimeSignatureAt(t);
+	t += (beat-1) * timesig.getBeatDuration();
+	t += Rosegarden::Note(Rosegarden::Note::Shortest).getDuration() *
+	    fraction;
+	slotSetTime(t);
+	*/
+    }
+}
+
+void
+RosegardenTimeWidget::slotSecOrMSecChanged(int)
+{
+    int sec = m_sec->value();
+    int msec = m_msec->value();
+
+    slotSetRealTime(Rosegarden::RealTime(sec, msec * 1000000));
+}
+
