@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -51,15 +51,12 @@ public:
     virtual ~ZoomSlider();
     
     void reinitialise(const std::vector<T> &sizes, T defaultValue);
+    void setToDefault(); // restore the initial value
+
+    void setSize(T size);
 
     const T &getCurrentSize() const;
     const T &getDefault() const;
-
-public slots:
-    void setToDefault(); // restore the initial value
-    void setSize(T size);
-    void increment();
-    void decrement();
         
 protected:
     static int getIndex(const std::vector<T> &, T size);
@@ -130,22 +127,6 @@ ZoomSlider<T>::setSize(T size)
     setValue(getIndex(m_sizes, size));
 }
 
-template <class T>
-void
-ZoomSlider<T>::increment()
-{
-    if (value() + 1 >= m_sizes.size()) return;
-    setValue(value() + 1);
-}
-
-template <class T>
-void
-ZoomSlider<T>::decrement()
-{
-    if (value() <= 0) return;
-    setValue(value() - 1);
-}
-
 template <class T>
 const T &
 ZoomSlider<T>::getDefault() const
