@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -46,16 +46,9 @@ public:
     // delegate ControlBlock's interface
     InstrumentId getInstrumentForTrack(unsigned int trackId) 
         { return m_controlBlock->getInstrumentForTrack(trackId); }
-        
-    InstrumentId getInstrumentForEvent(unsigned int dev, 
-                                       unsigned int chan)
-        { return m_controlBlock->getInstrumentForEvent(dev, chan); }
 
     bool isTrackMuted(unsigned int trackId)
         { return m_controlBlock->isTrackMuted(trackId); }
-        
-    bool isTrackArmed(unsigned int trackId)
-        { return m_controlBlock->isTrackArmed(trackId); }
 
     InstrumentId getInstrumentForMetronome() 
         { return m_controlBlock->getInstrumentForMetronome(); }
@@ -64,9 +57,6 @@ public:
 
     bool isSolo()  { return m_controlBlock->isSolo(); }
 
-    bool isMidiRoutingEnabled() 
-        { return m_controlBlock->isMidiRoutingEnabled(); }
-        
     Rosegarden::TrackId getSelectedTrack()
         { return m_controlBlock->getSelectedTrack(); }
 
