@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -21,17 +21,12 @@
 #include "mmappedsegment.h"
 #include "rosedebug.h"
 
-#include "MappedComposition.h"
-#include "Midi.h"
-
 using std::cerr;
 using std::endl;
 using std::cout;
 using Rosegarden::MappedEvent;
 
 //#define DEBUG_META_ITERATOR 1
-//#define DEBUG_PLAYING_AUDIO_FILES 1
-
 
 MmappedSegment::MmappedSegment(const QString filename)
     : m_fd(-1),
@@ -129,10 +124,10 @@ bool MmappedSegment::remap(size_t newSize)
     }
 
 #ifdef linux
-    void *oldRegion = m_mmappedRegion;
-    m_mmappedRegion = (MappedEvent*)::mremap(m_mmappedRegion, m_mmappedSize, newSize, MREMAP_MAYMOVE);
-    if (m_mmappedRegion != oldRegion) {
-	SEQUENCER_DEBUG << "NOTE: buffer moved from " << oldRegion <<
+    void *oldBuffer = m_mmappedRegion;
+    m_mmappedRegion = (MappedEvent*)::mremap(m_mmappedBuffer, m_mmappedSize, newSize, MREMAP_MAYMOVE);
+    if (m_mmappedRegion != oldBuffer) {
+	SEQUENCER_DEBUG << "NOTE: buffer moved from " << oldBuffer <<
 	    " to " << (void *)m_mmappedRegion << endl;
     }
 #else
@@ -364,44 +359,26 @@ bool MmappedSegmentsMetaIterator::acceptEvent(MappedEvent *evt, bool evtIsFromMe
     if (evt->getType() == 0) return false; // discard those right away
 
     if (evtIsFromMetronome)
-    {
-        if (evt->getType() == MappedEvent::MidiSystemMessage && 
-                evt->getData1() == Rosegarden::MIDI_TIMING_CLOCK)
-        {
-            /*
-            std::cout << "MmappedSegmentsMetaIterator::acceptEvent - " 
-                      << "found clock" << std::endl;
-                      */
-            return true;
-        }
-
         return !m_controlBlockMmapper->isMetronomeMuted();
-    }
         
     // else, evt is not from metronome : first check if we're soloing (i.e. playing only the selected track)
     if (m_controlBlockMmapper->isSolo())
         return (evt->getTrackId() == m_controlBlockMmapper->getSelectedTrack());
 
     // finally we're not soloing, so check if track is muted
-    Rosegarden::TrackId track = evt->getTrackId();
-    bool muted = m_controlBlockMmapper->isTrackMuted(evt->getTrackId());
-
-#ifdef DEBUG_META_ITERATOR
-    SEQUENCER_DEBUG << "MSMI::acceptEvent: track " << track << " muted status: " << muted << endl;
-#endif
-    
-    return !muted;
+    return !m_controlBlockMmapper->isTrackMuted(evt->getTrackId());
+                     
 }
 
 
 bool
-MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
+MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool firstFetch,
                                                             Rosegarden::MappedComposition* c,
                                                             const Rosegarden::RealTime& startTime,
                                                             const Rosegarden::RealTime& endTime)
 {
 #ifdef DEBUG_META_ITERATOR
-    SEQUENCER_DEBUG << "MSMI::fillCompositionWithEventsUntil " << startTime << " -> " << endTime << endl;
+    SEQUENCER_DEBUG << "fillCompositionWithEventsUntil " << startTime << " -> " << endTime << endl;
 #endif
 
     m_currentTime = endTime;
@@ -424,14 +401,14 @@ MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
             //std::cerr << "Iterating on Segment #" << i << std::endl;
 
 #ifdef DEBUG_META_ITERATOR
-            SEQUENCER_DEBUG << "MSMI::fillCompositionWithEventsUntil : "
+            SEQUENCER_DEBUG << "fillCompositionWithEventsUntil : "
                             << "checking segment #" << i << " " 
                             << iter->getSegment()->getFileName() << endl;
 #endif
 
             if (!validSegments[i]) {
 #ifdef DEBUG_META_ITERATOR
-                SEQUENCER_DEBUG << "MSMI::fillCompositionWithEventsUntil : "
+                SEQUENCER_DEBUG << "fillCompositionWithEventsUntil : "
                                 << "no more events to get for this slice "
                                 << "in segment #" << i << endl;
 #endif
@@ -442,7 +419,7 @@ MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
 
             if (iter->atEnd()) {
 #ifdef DEBUG_META_ITERATOR
-                SEQUENCER_DEBUG << "MSMI::fillCompositionWithEventsUntil : " 
+                SEQUENCER_DEBUG << "fillCompositionWithEventsUntil : " 
                                 << endTime
                                 << " reached end of segment #"
                                 << i << endl;
@@ -471,7 +448,7 @@ MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
                 }
                 
 #ifdef DEBUG_META_ITERATOR
-                SEQUENCER_DEBUG << "MSMI::fillCompositionWithEventsUntil : " << endTime
+                SEQUENCER_DEBUG << "fillCompositionWithEventsUntil : " << endTime
                                 << " inserting evt from segment #"
                                 << i
                                 << " : trackId: " << evt->getTrackId()
@@ -482,6 +459,7 @@ MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
                                 << " - data1: " << (unsigned int)evt->getData1()
                                 << " - data2: " << (unsigned int)evt->getData2()
                                 << " - metronome event: " << evtIsFromMetronome
+                                << " - firstFetch : " << firstFetch
                                 << endl;
 #endif
 
@@ -497,40 +475,17 @@ MmappedSegmentsMetaIterator::fillCompositionWithEventsUntil(bool /*firstFetch*/,
 
 		    c->insert(evt);
 
-                } else if (evt->getType() == MappedEvent::MidiSystemMessage &&
-
-			   // #1048388:
-			   // Ensure sysex heeds mute status, but ensure
-			   // clocks etc still get through
-			   evt->getData1() != Rosegarden::MIDI_SYSTEM_EXCLUSIVE) {
-
-                    c->insert(evt);
-
                 } else if (acceptEvent(evt, evtIsFromMetronome) &&
 
-			   ((evt->getEventTime() + evt->getDuration() > startTime) ||
-			    (evt->getDuration() == Rosegarden::RealTime::zeroTime &&
-			     evt->getEventTime() == startTime))) {
-
-//                    std::cout << "inserting event" << std::endl;
-
-                    /*
-                    std::cout << "Inserting event (type = "
-                        << evt->getType() << ")" << std::endl;
-                        */
+			   (evt->getEventTime() + evt->getDuration() > startTime)) {
+                    //SEQUENCER_DEBUG << "inserting event\n";
 
 
                     c->insert(evt);
 
                 } else {
                     
-#ifdef DEBUG_META_ITERATOR
-                    std::cout << "MSMI: skipping event"
-                        << " - event time = " << evt->getEventTime()
-                        << ", duration = " << evt->getDuration()
-                        << ", startTime = " << startTime << std::endl;
-#endif
-
+                    //SEQUENCER_DEBUG << "skipping event\n";
 		    delete evt;
                 }
             
@@ -562,7 +517,7 @@ void MmappedSegmentsMetaIterator::resetIteratorForSegment(const QString& filenam
         MmappedSegment::iterator* iter = *i;
 
         if (iter->getSegment()->getFileName() == filename) {
-             SEQUENCER_DEBUG << "MSMI::resetIteratorForSegment(" << filename << ") : found iterator\n";
+             SEQUENCER_DEBUG << "resetIteratorForSegment(" << filename << ") : found iterator\n";
             // delete iterator and create another one
             MmappedSegment* ms = (*i)->getSegment();
             delete iter;
@@ -576,49 +531,6 @@ void MmappedSegmentsMetaIterator::resetIteratorForSegment(const QString& filenam
     }
 }
 
-void
-MmappedSegmentsMetaIterator::getAudioEvents(std::vector<MappedEvent> &v)
-{
-    v.clear();
-    
-    for (mmappedsegments::iterator i = m_segments.begin();
-	 i != m_segments.end(); ++i) {
-
-        MmappedSegment::iterator itr(i->second);
-
-        while (!itr.atEnd()) {
-	    
-	    if ((*itr).getType() != MappedEvent::Audio) {
-		++itr;
-		continue;
-	    }
-	    
-            MappedEvent evt(*itr);
-	    ++itr;
-
-            if (m_controlBlockMmapper->isTrackMuted(evt.getTrackId())) {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                std::cout << "MSMI::getAudioEvents - "
-                          << "track " << evt.getTrackId() << " is muted" << std::endl;
-#endif
-		continue;
-            }
-
-            if (m_controlBlockMmapper->isSolo() == true && 
-                evt.getTrackId() != m_controlBlockMmapper->getSelectedTrack()) {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                std::cout << "MSMI::getAudioEvents - "
-                          << "track " << evt.getTrackId() << " is not solo track" << std::endl;
-#endif
-                continue;
-            }
-
-	    v.push_back(evt);
-        }
-    }
-}
-
-
 std::vector<MappedEvent>& 
 MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
 						  songPosition)
@@ -627,9 +539,8 @@ MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
     //
     m_playingAudioSegments.clear();
 
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-    std::cout << "MSMI::getPlayingAudioFiles" << std::endl;
-#endif
+    std::cout << "MmappedSegmentsMetaIterator::getPlayingAudioFiles" << std::endl;
+    //int count = 0;
 
     for (mmappedsegments::iterator i = m_segments.begin();
 	 i != m_segments.end(); ++i) {
@@ -638,7 +549,6 @@ MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
 
         bool found = false;
 
-	//!!! any point to this loop at all? can found ever fail?
         for (segmentiterators::iterator sI = m_iterators.begin();
 	     sI != m_iterators.end(); ++sI) {
             if ((*sI)->getSegment() == iter.getSegment())
@@ -661,10 +571,6 @@ MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
             //
             if (m_controlBlockMmapper->isTrackMuted(evt.getTrackId()) == true)
             {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                std::cout << "MSMI::getPlayingAudioFiles - "
-                          << "track " << evt.getTrackId() << " is muted" << std::endl;
-#endif
                 ++iter;
                 continue;
             }
@@ -672,10 +578,6 @@ MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
             if (m_controlBlockMmapper->isSolo() == true && 
                 evt.getTrackId() != m_controlBlockMmapper->getSelectedTrack())
             {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                std::cout << "MSMI::getPlayingAudioFiles - "
-                          << "track " << evt.getTrackId() << " is not solo track" << std::endl;
-#endif
                 ++iter;
                 continue;
             }
@@ -687,18 +589,19 @@ MmappedSegmentsMetaIterator::getPlayingAudioFiles(const Rosegarden::RealTime &
                 songPosition < evt.getEventTime() + evt.getDuration())
             {
 
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                std::cout << "MSMI::getPlayingAudioFiles - "
+#define PLAYING_AUDIO_FILES_DEBUG 1
+#ifdef PLAYING_AUDIO_FILES_DEBUG
+                std::cout << "MmappedSegmentsMetaIterator::getPlayingAudioFiles - "
                           << "instrument id = " << evt.getInstrument() << std::endl;
 
 
-                std::cout << "MSMI::getPlayingAudioFiles - "
+                std::cout << "MmappedSegmentsMetaIterator::getPlayingAudioFiles - "
                           << " id " << evt.getRuntimeSegmentId() << ", audio event time     = " << evt.getEventTime() << std::endl;
-                std::cout << "MSMI::getPlayingAudioFiles - "
+                std::cout << "MmappedSegmentsMetaIterator::getPlayingAudioFiles - "
                           << "audio event duration = " << evt.getDuration() << std::endl;
 
 
-#endif // DEBUG_PLAYING_AUDIO_FILES
+#endif // PLAYING_AUDIO_FILES_DEBUG
 
                 m_playingAudioSegments.push_back(evt);
             }
