@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -23,13 +23,17 @@
 #define _ROSEGARDEN_SEQUENCER_APP_H_
  
 // RosegardenSequencerApp is the sequencer application for Rosegarden.
-// It owns a Rosegarden::Sequencer object which wraps the ALSA 
-// and JACK funtionality.  At this level we deal with comms with
+// It owns a Rosegarden::Sequencer object which wraps the ALSA, JACK,
+// aRTS etc. level funtionality.  At this level we deal with comms with
 // the Rosegarden GUI application, the high level marshalling of data 
 // and main event loop of the sequencer.  [rwb]
 //
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // include files for Qt
 #include <qstrlist.h>
 
@@ -44,6 +48,7 @@
 #include "rosegardendcop.h"
 #include "rosegardensequenceriface.h"
 #include "MappedComposition.h"
+#include "Sequencer.h"
 #include "Event.h"
 #include "MappedStudio.h"
 #include "ExternalTransport.h"
@@ -60,7 +65,7 @@ class RosegardenGUIDoc;
 class RosegardenGUIView;
 class ControlBlockMmapper;
 
-namespace Rosegarden { class MappedInstrument; class SoundDriver; }
+namespace Rosegarden { class MappedInstrument; }
 
 /**
  * The sequencer application
@@ -72,7 +77,7 @@ class RosegardenSequencerApp : public KMainWindow,
     Q_OBJECT
 
 public:
-    RosegardenSequencerApp();
+    RosegardenSequencerApp(const std::vector<std::string> &jackArgs);
     ~RosegardenSequencerApp();
 
     //      -------- START OF DCOP INTERFACE METHODS --------
@@ -99,9 +104,7 @@ public:
 	       const Rosegarden::RealTime &audioRead,
 	       const Rosegarden::RealTime &audioWrite,
 	       long smallFileSize,
-               long recordMode);
-
-    virtual int punchOut();
+               int recordMode);
 
     // looping
     void setLoop(const Rosegarden::RealTime &loopStart,
@@ -135,7 +138,7 @@ public:
 		       long audioWriteSec,
 		       long audioWriteNsec,
 		       long smallFileSize,
-                       long recordMode);
+                       int recordMode);
 
     
     // Jump to a pointer in the playback (uses longs instead
@@ -151,7 +154,7 @@ public:
  
     // Return the Sound system status (audio/MIDI)
     //
-    virtual unsigned int getSoundDriverStatus(const QString &guiVersion);
+    virtual unsigned int getSoundDriverStatus();
 
     // Add and remove Audio files on the sequencer
     //
@@ -199,7 +202,6 @@ public:
     virtual int canReconnect(int deviceType);
     virtual unsigned int addDevice(int type, unsigned int direction);
     virtual void removeDevice(unsigned int id);
-    virtual void renameDevice(unsigned int id, QString name);
     virtual unsigned int getConnections(int type, unsigned int direction);
     virtual QString getConnection(int type, unsigned int direction,
 				  unsigned int connectionNo);
@@ -212,7 +214,10 @@ public:
     virtual QString getCurrentTimer();
     virtual void setCurrentTimer(QString timer);
 
-    virtual void setLowLatencyMode(bool);
+    // Audio monitoring
+    //
+    virtual void setAudioMonitoring(long value);
+    virtual void setAudioMonitoringInstrument(unsigned int id);
 
     // Audio latencies
     //
@@ -225,23 +230,11 @@ public:
                                    const QString &property,
                                    float value);
 
-    // Set many properties on many MappedObjects
-    //
-    virtual void setMappedProperties(const Rosegarden::MappedObjectIdList &ids,
-				     const Rosegarden::MappedObjectPropertyList &properties,
-				     const Rosegarden::MappedObjectValueList &values);
-
-    // Set a MappedObject to a string
+    // Set a MappedObject to a property list
     //
     virtual void setMappedProperty(int id,
                                    const QString &property,
-                                   const QString &value);
-
-    // Set a MappedObject to a property list
-    //
-    virtual void setMappedPropertyList(int id,
-				       const QString &property,
-				       const Rosegarden::MappedObjectPropertyList &values);
+                                   std::vector<float> value);
 
     // Get a MappedObject for a type
     //
@@ -252,21 +245,12 @@ public:
     virtual std::vector<QString> getPropertyList(int id,
                                                  const QString &property);
 
-    virtual std::vector<QString> getPluginInformation();
-
-    virtual QString getPluginProgram(int id, int bank, int program);
-
-    virtual unsigned long getPluginProgram(int id, const QString &name);
-
     // Set a plugin port
     //
     virtual void setMappedPort(int pluginId,
                                unsigned long portId,
                                float value);
 
-    virtual float getMappedPort(int pluginId,
-				unsigned long portId);
-
     // Create a MappedObject
     virtual int createMappedObject(int type);
 
@@ -360,18 +344,8 @@ public:
     //
     void sleep(const Rosegarden::RealTime &rt);
 
-    // Removes from a MappedComposition the events not matching
-    // the supplied filer.
-    //
     void applyFiltering(Rosegarden::MappedComposition *mC,
-			Rosegarden::MidiFilter filter,
-			bool filterControlDevice);
-
-    // This method assigns an Instrument to each MappedEvent 
-    // belongin to the MappedComposition, and sends the 
-    // transformed events to the driver to be played.
-    //
-    void routeEvents(Rosegarden::MappedComposition *mC, bool useSelectedTrack);
+			Rosegarden::MidiFilter filter);
 
     // Are we looping?
     //
@@ -409,7 +383,6 @@ public:
     TransportToken transportChange(TransportRequest);
     TransportToken transportJump(TransportRequest, Rosegarden::RealTime);
     bool isTransportSyncComplete(TransportToken token);
-    TransportToken getInvalidTransportToken() const { return 0; }
 
 public slots:
 
@@ -433,10 +406,6 @@ protected:
 		  const Rosegarden::RealTime &end,
 		  bool firstFetch);
 
-    // adjust event times according to relative instrument latencies
-    //
-    void applyLatencyCompensation(Rosegarden::MappedComposition &);
-
     // mmap-related stuff
     MmappedSegment* mmapSegment(const QString&);
     void cleanupMmapData();
@@ -449,7 +418,7 @@ protected:
 
     //--------------- Data members ---------------------------------
 
-    Rosegarden::SoundDriver *m_driver;
+    Rosegarden::Sequencer *m_sequencer;
     TransportStatus m_transportStatus;
 
     // Position pointer
