@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -18,6 +18,8 @@
   COPYING included with this distribution for more information.
 */
 
+#include "config.h"
+
 #ifndef HAVE_ALSA
 
 // aRts
@@ -129,25 +131,18 @@ ArtsDriver::generateInstruments()
 
 
 
-bool
+void
 ArtsDriver::initialise()
 {
-    bool result = true;
-
-    result = initialiseMidi();
-    if( result ) 
-    {
-	result = initialiseAudio();
-    }
-
-    return result;
+    initialiseMidi();
+    initialiseAudio();
 }
 
-bool
+void
 ArtsDriver::initialiseMidi()
 {
     // Don't come in here if there's no SoundServer
-    if (m_soundServer.isNull()) return false;
+    if (m_soundServer.isNull()) return;
 
     m_midiManager = Arts::Reference("global:Arts_MidiManager");
     if (m_midiManager.isNull())
@@ -155,7 +150,7 @@ ArtsDriver::initialiseMidi()
 #ifdef DEBUG_ARTS
         cerr << "ArtsDriver - can't get aRts MidiManager" << endl;
 #endif
-        return false;
+        return;
     }
 
     m_midiRecordPort =
@@ -182,7 +177,7 @@ ArtsDriver::initialiseMidi()
 #ifdef DEBUG_ARTS
         cerr << "ArtsDriver - can't create aRts MidiClient" << endl;
 #endif
-        return false;
+        return;
     }
 
     m_midiPlayPort = m_midiPlayClient.addOutputPort();
@@ -192,7 +187,7 @@ ArtsDriver::initialiseMidi()
         cerr << "ArtsDriver - can't create aRts Midi Output Port"
              << endl;
 #endif
-        return false;
+        return;
     }
 
     m_midiRecordClient = m_midiManager.addClient(Arts::mcdRecord,
@@ -205,7 +200,7 @@ ArtsDriver::initialiseMidi()
         cerr << "ArtsDriver - can't create aRts MidiRecordClient"
              << endl;
 #endif
-        return false;
+        return;
     }
 
     // Create our recording midi port
@@ -228,15 +223,14 @@ ArtsDriver::initialiseMidi()
     m_driverStatus |= MIDI_OK;
 
     generateInstruments();
-    
-    return true;
+
 }
 
-bool
+void
 ArtsDriver::initialiseAudio()
 {
     // don't come in here if there's no SoundServer
-    if (m_soundServer.isNull()) return false;
+    if (m_soundServer.isNull()) return;
 
     m_amanPlay =
         Arts::DynamicCast(m_soundServer.createObject("Arts::Synth_AMAN_PLAY"));
@@ -249,7 +243,7 @@ ArtsDriver::initialiseAudio()
 #ifdef DEBUG_ARTS
         cerr << "ArtsDriver - can't create audio play object" << endl;
 #endif
-        return false;
+        return;
     }
 
     m_amanRecord =
@@ -264,7 +258,7 @@ ArtsDriver::initialiseAudio()
         cerr << "ArtsDriver - can't create audio record object" <<
              endl;
 #endif
-        return false;
+        return;
     }
 
     // Start the play and record audio ports
@@ -282,7 +276,7 @@ ArtsDriver::initialiseAudio()
 #ifdef DEBUG_ARTS
         cerr << "ArtsDriver - can't create .wav record object" << endl;
 #endif
-        return false;
+        return;
     }
 
     Arts::Synth_PLAY_WAV playWav = Arts::DynamicCast(m_soundServer.
@@ -293,7 +287,7 @@ ArtsDriver::initialiseAudio()
 #ifdef DEBUG_ARTS
         cerr << "ArtsDriver - can't create .wav play object "<< endl;
 #endif
-        return false;
+        return;
     }
 
     // Now test connections - aRts will moan if these fail
@@ -331,7 +325,6 @@ ArtsDriver::initialiseAudio()
 #endif
 
     m_driverStatus |= AUDIO_OK;
-    return true;
 }
 
 void
@@ -364,7 +357,7 @@ ArtsDriver::stopPlayback()
 
 
 void
-ArtsDriver::resetPlayback(const RealTime &oldPosition, const RealTime &position)
+ArtsDriver::resetPlayback(const RealTime &position)
 {
     //allNotesOff();
     RealTime artsPlayStartTime = RealTime(m_artsPlayStartTime.sec,
@@ -463,10 +456,6 @@ ArtsDriver::processNotesOff(const RealTime &time)
 void
 ArtsDriver::processAudioQueue(bool /*now*/)
 {
-#ifdef NOT_DEFINED
-/*** Removed following change to SoundDriver structure for audio files.
-     This would need to be heavily revised */
-
     // Now check queue for events that need playing
     std::list<PlayableAudioFile*>::iterator it;
     RealTime currentTime = getSequencerTime();
@@ -529,7 +518,7 @@ ArtsDriver::processAudioQueue(bool /*now*/)
                defunctEvents++;
     }
     while(defunctEvents);
-#endif
+
 }
 
 RealTime
@@ -556,7 +545,10 @@ ArtsDriver::getMappedComposition()
 
     // Return empty set if we're currently not recording or monitoring
     
-    if (m_recordStatus != RECORD_ON)
+    if (m_recordStatus != RECORD_MIDI &&
+        m_recordStatus != RECORD_AUDIO &&
+        m_recordStatus != ASYNCHRONOUS_MIDI &&
+        m_recordStatus != ASYNCHRONOUS_AUDIO)
            return &m_recordComposition;
 
 
@@ -583,12 +575,8 @@ ArtsDriver::getMappedComposition()
     
 void
 ArtsDriver::processMidiOut(const MappedComposition &mC,
-                           const RealTime &sliceStart,
-                           const RealTime &sliceEnd)
+                           bool now)
 {
-    // special case for unqueued events
-    bool now = (sliceStart == RealTime::zeroTime && sliceEnd == RealTime::zeroTime);
-
     Arts::MidiEvent event;
 
     // MidiCommandStatus
@@ -958,20 +946,10 @@ ArtsDriver::processMidiIn(const Arts::MidiCommand &midiCommand,
 }
 
 
-void
-ArtsDriver::processEventsOut(const MappedComposition &mC)
-{
-    processEventsOut(mC, RealTime::zeroTime, RealTime::zeroTime);
-}
-
 void
 ArtsDriver::processEventsOut(const MappedComposition &mC,
-                             const RealTime &sliceStart,
-                             const RealTime &sliceEnd)
+                             bool now)
 {
-    // special case for unqueued events
-    bool now = (sliceStart == RealTime::zeroTime && sliceEnd == RealTime::zeroTime);
-
     // Start playback if it isn't already
     //
     if (m_startPlayback)
@@ -988,10 +966,6 @@ ArtsDriver::processEventsOut(const MappedComposition &mC,
     {
         if ((*i)->getType() == MappedEvent::Audio)
         {
-#ifdef NOT_DEFINED
-/*** Removed following change to SoundDriver structure for audio files.
-     This would need to be heavily revised */
-
             PlayableAudioFile *audioFile =
                     new PlayableAudioFile((*i)->getInstrument(),
                                           getAudioFile((*i)->getAudioID()),
@@ -1000,32 +974,27 @@ ArtsDriver::processEventsOut(const MappedComposition &mC,
                                           (*i)->getDuration());
 
             queueAudio(audioFile);
-#endif
         }
     }
 
     // do MIDI events
-    processMidiOut(mC, sliceStart, sliceEnd);
+    processMidiOut(mC, now);
 
     // do any audio events
     processAudioQueue(now);
 }
 
-
 bool
-ArtsDriver::record(RecordStatus recordStatus,
-                   const std::vector<InstrumentId> */*armedInstruments*/,
-                   const std::vector<QString> */*audioFileNames*/)
-
+ArtsDriver::record(RecordStatus recordStatus)
 {
-    if (recordStatus == RECORD_ON)
+    if (recordStatus == RECORD_MIDI)
     {
         // Set status and the record start position
         //
-        m_recordStatus = RECORD_ON;
+        m_recordStatus = RECORD_MIDI;
         m_artsRecordStartTime = m_midiRecordPort.time();
     }
-/*    else if (recordStatus == RECORD_AUDIO)
+    else if (recordStatus == RECORD_AUDIO)
     {
 #ifdef DEBUG_ARTS
         std::cerr << "ArtsDriver - record() - AUDIO RECORDING not yet supported"
@@ -1048,7 +1017,7 @@ ArtsDriver::record(RecordStatus recordStatus,
                   << std::endl;
     }
 #endif
-*/
+
     return true;
 }
 
