@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -24,7 +24,6 @@
 #include <string>
 #include <dirent.h> // for new recording file
 #include <cstdio>   // sprintf
-#include <pthread.h>
 
 #if (__GNUC__ < 3)
 #include <strstream>
@@ -38,48 +37,20 @@
 
 #include <qpixmap.h>
 #include <qpainter.h>
-#include <qdatetime.h>
-#include <qfile.h>
 
 #include "AudioFile.h"
 #include "AudioFileManager.h"
 #include "WAVAudioFile.h"
 #include "BWFAudioFile.h"
 #include "MP3AudioFile.h"
+#include "config.h"
 #include "rosestrings.h"
 
 namespace Rosegarden
 {
 
-static pthread_mutex_t _audioFileManagerLock;
-
-class MutexLock {
-public:
-    MutexLock(pthread_mutex_t *mutex) : m_mutex(mutex) {
-	pthread_mutex_lock(m_mutex);
-    }
-    ~MutexLock() {
-	pthread_mutex_unlock(m_mutex);
-    }
-private:
-    pthread_mutex_t *m_mutex;
-};
-
 AudioFileManager::AudioFileManager()
 {
-    pthread_mutexattr_t attr;
-    pthread_mutexattr_init(&attr);
-#ifdef HAVE_PTHREAD_MUTEX_RECURSIVE
-    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
-#else
-#ifdef PTHREAD_MUTEX_RECURSIVE
-    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
-#else
-    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE_NP);
-#endif
-#endif
-    pthread_mutex_init(&_audioFileManagerLock, &attr);
-
     // Set this through the set method so that the tilde gets
     // shaken out.
     //
@@ -101,17 +72,13 @@ AudioFileManager::~AudioFileManager()
 AudioFileId
 AudioFileManager::addFile(const std::string &filePath)
 {
-    MutexLock lock(&_audioFileManagerLock);
-    
     QString ext =
         QString(filePath.substr(filePath.length() - 3, 3).c_str()).lower();
 
     // Check for file existing already in manager by path
     //
     int check = fileExists(filePath);
-    if (check != -1) {
-	return AudioFileId(check);
-    }
+    if (check != -1) return AudioFileId(check);
 
     // prepare for audio file
     AudioFile *aF = 0;
@@ -127,65 +94,59 @@ AudioFileManager::addFile(const std::string &filePath)
 #ifdef DEBUG_AUDIOFILEMANAGER
             std::cout << "FOUND BWF" << std::endl;
 #endif
-	    try {
-		aF = new BWFAudioFile(id, getShortFilename(filePath), filePath);
-	    } catch (SoundFile::BadSoundFileException e) {
-		delete aF;
-		throw BadAudioPathException(e);
-	    }
+            aF = new BWFAudioFile(id, getShortFilename(filePath), filePath);
         }
         else if (subType == WAV)
         {
-	    try {
-		aF = new WAVAudioFile(id, getShortFilename(filePath), filePath);
-	    } catch (SoundFile::BadSoundFileException e) {
-		delete aF;
-		throw BadAudioPathException(e);
-	    }
+            aF = new WAVAudioFile(id, getShortFilename(filePath), filePath);
         }
 
         // Ensure we have a valid file handle
         //
-        if (aF == 0) {
-	    std::cerr << "AudioFileManager: Unknown WAV audio file subtype in " << filePath << std::endl;
-	    throw BadAudioPathException(filePath, __FILE__, __LINE__);
-	}
+        if (aF == 0) throw i18n("Unsupported audio file type."); 
 
         // Add file type on extension
-	try {
-	    if (aF->open() == false)
-	    {
-		delete aF;
-		std::cerr << "AudioFileManager: Malformed audio file in " << filePath << std::endl;
-		throw BadAudioPathException(filePath, __FILE__, __LINE__);
-	    }
-	} catch (SoundFile::BadSoundFileException e) {
-	    delete aF;
-	    throw BadAudioPathException(e);
-	}
+        try
+        { 
+            if (aF->open() == false)
+            {
+                delete aF;
+                throw(i18n("Can't open audiofile"));
+            }
+        }
+        catch(std::string e)
+        {
+            // catch and rethrow
+            //
+            delete aF;
+            throw(e);
+        }
     }
 #ifdef HAVE_LIBMAD
     else if (ext == "mp3")
     {
-	try {
-	    aF = new MP3AudioFile(id, getShortFilename(filePath), filePath);
+        aF = new MP3AudioFile(id, getShortFilename(filePath), filePath);
 
-	    if (aF->open() == false)
-	    {
-		delete aF;
-		std::cerr << "AudioFileManager: Malformed mp3 audio file in " << filePath << std::endl;
-		throw BadAudioPathException(filePath, __FILE__, __LINE__);
-	    }
-	} catch (SoundFile::BadSoundFileException e) {
-	    delete aF;
-	    throw BadAudioPathException(e);
-	}
+        try
+        { 
+            if (aF->open() == false)
+            {
+                delete aF;
+                throw(i18n("Problem opening MP3 file"));
+            }
+        }
+        catch(std::string e)
+        {
+            // catch and rethrow
+            //
+            delete aF;
+            throw(e);
+        }
     }
 #endif // HAVE_LIBMAD
     else
     {
-	std::cerr << "AudioFileManager: Unsupported audio file extension in " << filePath << std::endl;
-        throw BadAudioPathException(filePath, __FILE__, __LINE__);
+        throw(i18n("Unsupported audio file format"));
     }
 
     if (aF)
@@ -232,8 +193,6 @@ AudioFileId
 AudioFileManager::insertFile(const std::string &name,
                              const std::string &fileName)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     // first try to expand any beginning tilde
     //
     std::string foundFileName = substituteTildeForHome(fileName);
@@ -256,26 +215,17 @@ AudioFileManager::insertFile(const std::string &name,
 
     AudioFileId id = getFirstUnusedID();
 
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = new WAVAudioFile(id, name, foundFileName);
 
-    try {
-
-	aF = new WAVAudioFile(id, name, foundFileName);
-
-	// if we don't recognise the file then don't insert it
-	//
-	if (aF->open() == false)
-	{
-	    delete aF;
-	    std::cerr << "AudioFileManager::insertFile - don't recognise file type in " << foundFileName << std::endl;
-	    throw BadAudioPathException(foundFileName, __FILE__, __LINE__);
-	}
-	m_audioFiles.push_back(aF);
-
-    } catch (SoundFile::BadSoundFileException e) {
-	delete aF;
-	throw BadAudioPathException(e);
+    // if we don't recognise the file then don't insert it
+    //
+    if (aF->open() == false)
+    {
+        delete aF;
+        throw(std::string(
+                "AudioFileManager::insertFile - don't recognise file type"));
     }
+    m_audioFiles.push_back(aF);
 
     return id;
 }
@@ -284,8 +234,6 @@ AudioFileManager::insertFile(const std::string &name,
 bool
 AudioFileManager::removeFile(AudioFileId id)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it;
 
     for (it = m_audioFiles.begin();
@@ -295,7 +243,6 @@ AudioFileManager::removeFile(AudioFileId id)
         if ((*it)->getId() == id)
         {
 	    m_peakManager.removeAudioFile(*it);
-	    m_recordedAudioFiles.erase(*it);
             delete(*it);
             m_audioFiles.erase(it);
             return true;
@@ -332,8 +279,6 @@ AudioFileManager::insertFile(const std::string &name,
                              const std::string &fileName,
                              AudioFileId id)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     // first try to expany any beginning tilde
     std::string foundFileName = substituteTildeForHome(fileName);
 
@@ -357,26 +302,16 @@ AudioFileManager::insertFile(const std::string &name,
     removeFile(id);
 
     // and insert
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = new WAVAudioFile(id, name, foundFileName);
 
-    try {
-
-	aF = new WAVAudioFile(id, name, foundFileName);
-
-	// Test the file
-	if (aF->open() == false)
-	{
-	    delete aF;
-	    return false;
-	}
-
-	m_audioFiles.push_back(aF);
-
-    } catch (SoundFile::BadSoundFileException e) {
-	delete aF;
-	throw BadAudioPathException(e);
+    // Test the file
+    if (aF->open() == false)
+    {
+        delete aF;
+        return false;
     }
 
+    m_audioFiles.push_back(aF);
     return true;
 }
 
@@ -385,8 +320,6 @@ AudioFileManager::insertFile(const std::string &name,
 void
 AudioFileManager::setAudioPath(const std::string &path)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::string hPath = path;
 
     // add a trailing / if we don't have one
@@ -405,15 +338,6 @@ AudioFileManager::setAudioPath(const std::string &path)
 
 }
 
-void
-AudioFileManager::testAudioPath() throw (BadAudioPathException)
-{
-    QFileInfo info(m_audioPath.c_str());
-    if (!(info.exists() && info.isDir() && !info.isRelative() &&
-	  info.isWritable() && info.isReadable()))
-	throw BadAudioPathException(m_audioPath.data());
-}
-
 
 // See if we can find a given file in our search path
 // return the first occurence of a match or the empty
@@ -422,8 +346,6 @@ AudioFileManager::testAudioPath() throw (BadAudioPathException)
 std::string
 AudioFileManager::getFileInPath(const std::string &file)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     QFileInfo info(file.c_str());
 
     if (info.exists())
@@ -450,8 +372,6 @@ AudioFileManager::getFileInPath(const std::string &file)
 int
 AudioFileManager::fileExists(const std::string &path)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it;
 
     for (it = m_audioFiles.begin();
@@ -471,8 +391,6 @@ AudioFileManager::fileExists(const std::string &path)
 bool
 AudioFileManager::fileExists(AudioFileId id)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it;
 
     for (it = m_audioFiles.begin();
@@ -490,16 +408,12 @@ AudioFileManager::fileExists(AudioFileId id)
 void
 AudioFileManager::clear()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it;
 
     for (it = m_audioFiles.begin();
          it != m_audioFiles.end();
-         ++it) {
-	m_recordedAudioFiles.erase(*it);
+         ++it)
         delete(*it);
-    }
 
     m_audioFiles.erase(m_audioFiles.begin(), m_audioFiles.end());
 
@@ -508,73 +422,80 @@ AudioFileManager::clear()
     m_peakManager.clear();
 }
 
-AudioFile *
+std::string
 AudioFileManager::createRecordingAudioFile()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFileId newId = getFirstUnusedID();
-    QString fileName = "";
+    int audioFileNumber = 0;
 
-    while (fileName == "") {
+    // search for used RG-AUDIO files in the record directory
+    DIR *dir = opendir(m_audioPath.c_str());
+    std::string prefix = "RG-AUDIO-";
+    std::string file;
 
-	fileName = QString("rg-%1-%2.wav")
-	    .arg(QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss"))
-	    .arg(newId + 1);
+    if (dir)
+    {
+        dirent *entry;
+
+        while ((entry = readdir(dir)) != NULL)
+        {
+            file = entry->d_name;
+
+            // hmm, why aren't file types working?
+            // we should be able to filter by d_type but
+            // it's currently returning NULL
+
+#if (__GNUC__ < 3)
+            if (file.compare(prefix, 0, 9) == 0)
+#else
+            if (file.compare(0, 9, prefix) == 0)
+#endif
+            {
+                // get the number
+                file.erase(0, 9);
+
+                // match and remove post dot
+                int pos = file.find(".");
+                file.erase(pos, file.length());
+
+                // store
+                if (atoi(file.c_str()) > audioFileNumber)
+                    audioFileNumber = atoi(file.c_str());
+            }
+        }
 
-	if (QFile(m_audioPath.c_str() + fileName).exists()) {
-	    fileName = "";
-	    ++newId;
-	}
     }
+#ifdef DEBUG_AUDIOFILEMANAGER
+    else
+    {
+        std::cerr << "AudioFileManager::createRecordingAudioFile - "
+                  << "can't access recording directory \'"
+                  << m_audioPath << "\'" << std::endl;
+    }
+#endif
+
+    // start from 1, not 0 if we've not found anything
+    if (audioFileNumber == 0)
+        audioFileNumber = 1;
+    else
+        audioFileNumber++;
+
+    // composite with number and return
+    char number[100];
+    sprintf(number, "%.4d", audioFileNumber);
+    file = prefix + number + ".wav";
 
     // insert file into vector
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = new WAVAudioFile(newId, file, m_audioPath + file);
+    m_audioFiles.push_back(aF);
 
-    try {
-	aF = new WAVAudioFile(newId, fileName.data(), m_audioPath + fileName.data());
-	m_audioFiles.push_back(aF);
-	m_recordedAudioFiles.insert(aF);
-    } catch (SoundFile::BadSoundFileException e) {
-	delete aF;
-	throw BadAudioPathException(e);
-    }
-
-    return aF;
+    // what we return is the full path to the file
+    return m_audioPath + file;
 } 
 
-std::vector<std::string>
-AudioFileManager::createRecordingAudioFiles(unsigned int n)
-{
-    std::vector<std::string> v;
-    for (unsigned int i = 0; i < n; ++i) {
-	AudioFile *af = createRecordingAudioFile();
-	if (af) v.push_back(m_audioPath + af->getFilename().data());
-	// !af should not happen, and we have no good recovery if it does
-    }
-    return v;
-}
-
-bool
-AudioFileManager::wasAudioFileRecentlyRecorded(AudioFileId id)
-{
-    AudioFile *file = getAudioFile(id);
-    if (file) return (m_recordedAudioFiles.find(file) !=
-		      m_recordedAudioFiles.end());
-    return false;
-}
-
-void
-AudioFileManager::resetRecentlyRecordedFiles()
-{
-    m_recordedAudioFiles.clear();
-}
-
 AudioFile*
 AudioFileManager::getLastAudioFile()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it = m_audioFiles.begin();
     AudioFile* audioFile = 0;
 
@@ -632,8 +553,6 @@ AudioFileManager::substituteTildeForHome(const std::string &path)
 std::string
 AudioFileManager::toXmlString()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::stringstream audioFiles;
     std::string audioPath = substituteHomeForTilde(m_audioPath);
 
@@ -690,8 +609,6 @@ AudioFileManager::toXmlString()
 void
 AudioFileManager::generatePreviews()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
 #ifdef DEBUG_AUDIOFILEMANAGER
     std::cout << "AudioFileManager::generatePreviews - "
               << "for " << m_audioFiles.size() << " files"
@@ -714,8 +631,6 @@ AudioFileManager::generatePreviews()
 void
 AudioFileManager::stopPreview()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     m_peakManager.stopPreview();
 }
 
@@ -729,8 +644,6 @@ AudioFileManager::stopPreview()
 bool
 AudioFileManager::generatePreview(AudioFileId id)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFile *audioFile = getAudioFile(id);
     
     if (audioFile == 0)
@@ -745,8 +658,6 @@ AudioFileManager::generatePreview(AudioFileId id)
 AudioFile*
 AudioFileManager::getAudioFile(AudioFileId id)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     std::vector<AudioFile*>::iterator it;
 
     for (it = m_audioFiles.begin();
@@ -766,19 +677,14 @@ AudioFileManager::getPreview(AudioFileId id,
                              int width,
                              bool withMinima)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFile *audioFile = getAudioFile(id);
     
     if (audioFile == 0) {
         return std::vector<float>();
     }
 
-    if (!m_peakManager.hasValidPeaks(audioFile)) {
-	std::cerr << "AudioFileManager::getPreview: No peaks for audio file " << audioFile->getFilename() << std::endl;
-        throw PeakFileManager::BadPeakFileException
-	    (audioFile->getFilename(), __FILE__, __LINE__);
-    }
+    if (!m_peakManager.hasValidPeaks(audioFile))
+        throw std::string("<no peakfile>");
 
     return m_peakManager.getPreview(audioFile,
                                     startTime,
@@ -793,15 +699,10 @@ AudioFileManager::drawPreview(AudioFileId id,
                               const RealTime &endTime,
                               QPixmap *pixmap)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFile *audioFile = getAudioFile(id);
-    if (!audioFile) return;
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-	std::cerr << "AudioFileManager::getPreview: No peaks for audio file " << audioFile->getFilename() << std::endl;
-        throw PeakFileManager::BadPeakFileException
-	    (audioFile->getFilename(), __FILE__, __LINE__);
+        throw std::string("<no peakfile>");
     }
 
     std::vector<float> values = m_peakManager.getPreview
@@ -858,8 +759,8 @@ AudioFileManager::drawPreview(AudioFileId id,
             ch2Value = values[i * channels + 1];
         }
 
-        painter.drawLine(i, static_cast<int>(yStep - ch1Value * yStep),
-                         i, static_cast<int>(yStep + ch2Value * yStep));
+        painter.drawLine(i, static_cast<int>(yStep + ch1Value * yStep),
+                         i, static_cast<int>(yStep - ch2Value * yStep));
     }
 }
 
@@ -871,16 +772,10 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
                                          const RealTime &highlightEnd,
                                          QPixmap *pixmap)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFile *audioFile = getAudioFile(id);
-    if (!audioFile) return;
 
-    if (!m_peakManager.hasValidPeaks(audioFile)) {
-	std::cerr << "AudioFileManager::getPreview: No peaks for audio file " << audioFile->getFilename() << std::endl;
-        throw PeakFileManager::BadPeakFileException
-	    (audioFile->getFilename(), __FILE__, __LINE__);
-    }
+    if (!m_peakManager.hasValidPeaks(audioFile))
+        throw std::string("<no peakfile>");
 
     std::vector<float> values = m_peakManager.getPreview
                                         (audioFile,
@@ -929,8 +824,8 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
             painter.setPen(kapp->palette().color(QPalette::Active,
                                                  QColorGroup::Dark));
 
-        painter.drawLine(i, static_cast<int>(yStep - ch1Value * yStep),
-                         i, static_cast<int>(yStep + ch2Value * yStep));
+        painter.drawLine(i, static_cast<int>(yStep + ch1Value * yStep),
+                         i, static_cast<int>(yStep - ch2Value * yStep));
     }
 }
 
@@ -938,8 +833,6 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
 void
 AudioFileManager::print()
 {
-    MutexLock lock(&_audioFileManagerLock);
-
 #ifdef DEBUG_AUDIOFILEMANAGER
     std::cout << "AudioFileManager - " << m_audioFiles.size() << " entr";
 
@@ -966,8 +859,6 @@ AudioFileManager::getSplitPoints(AudioFileId id,
                                  int threshold,
                                  const RealTime &minTime)
 {
-    MutexLock lock(&_audioFileManagerLock);
-
     AudioFile *audioFile = getAudioFile(id);
 
     if (audioFile == 0) return std::vector<SplitPointPair>();
@@ -982,4 +873,3 @@ AudioFileManager::getSplitPoints(AudioFileId id,
 }
 
 
-#include "AudioFileManager.moc"
