@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -23,7 +23,6 @@
 
 #include <string>
 #include <vector>
-#include <set>
 #include <map>
 
 #include <qpixmap.h>
@@ -33,7 +32,6 @@
 #include "XmlExportable.h"
 #include "PeakFileManager.h"
 #include "PeakFile.h"
-#include "Exception.h"
 
 // AudioFileManager loads and maps audio files to their
 // internal references (ids).  A point of contact for
@@ -41,13 +39,9 @@
 // use this class to pick up the AudioFile references,
 // editing the AudioFiles in a Composition will be
 // made through this manager.
-
-// This is in the sound library because it's so closely
-// connected to other sound classes like the AudioFile
-// ones.  However, the audio file manager itself within
-// Rosegarden is stored in the GUI process.  This class
-// is not (and should not be) used elsewhere within the
-// sound or sequencer libraries.
+//
+//
+//
 
 namespace Rosegarden
 {
@@ -61,24 +55,6 @@ public:
     AudioFileManager();
     virtual ~AudioFileManager();
     
-    class BadAudioPathException : public Exception
-    {
-    public:
-	BadAudioPathException(std::string path) :
-	    Exception("Bad audio file path " + path), m_path(path) { }
-	BadAudioPathException(std::string path, std::string file, int line) :
-	    Exception("Bad audio file path " + path, file, line), m_path(path) { }
-	BadAudioPathException(const SoundFile::BadSoundFileException &e) :
-	    Exception("Bad audio file path (malformed file?) " + e.getPath()), m_path(e.getPath()) { }
-
-	~BadAudioPathException() throw() { }
-
-	std::string getPath() const { return m_path; }
-
-    private:
-	std::string m_path;
-    };
-
 private:
     AudioFileManager(const AudioFileManager &aFM);
     AudioFileManager& operator=(const AudioFileManager &);
@@ -89,7 +65,6 @@ public:
     // to add an actual file.
     //
     AudioFileId addFile(const std::string &filePath);
-    // throw BadAudioPathException
 
     // Insert an audio file into the AudioFileManager and get the
     // first allocated id for it.  Used from the RG file as we already
@@ -97,13 +72,11 @@ public:
     //
     AudioFileId insertFile(const std::string &name,
                            const std::string &fileName);
-    // throw BadAudioPathException
 
     // And insert an AudioFile and specify an id
     //
     bool insertFile(const std::string &name, const std::string &fileName,
                     AudioFileId id);
-    // throw BadAudioPathException
 
     // Remove a file from the AudioManager by id
     //
@@ -138,28 +111,9 @@ public:
     std::string getAudioPath() const { return m_audioPath; }
     void setAudioPath(const std::string &path);
 
-    // Throw if the current audio path does not exist or is not writable
-    //
-    void testAudioPath() throw(BadAudioPathException);
-
     // Get a new audio filename at the audio record path
     //
-    AudioFile *createRecordingAudioFile();
-    // throw BadAudioPathException
-
-    // Get a set of new audio filenames at the audio record path
-    //
-    std::vector<std::string> createRecordingAudioFiles(unsigned int number);
-    // throw BadAudioPathException
-
-    // Return whether a file was created by recording within this "session"
-    //
-    bool wasAudioFileRecentlyRecorded(AudioFileId id);
-
-    // Indicate that a new "session" has started from the point of view of
-    // recorded audio files (e.g. that the document has been saved)
-    //
-    void resetRecentlyRecordedFiles();
+    std::string createRecordingAudioFile();
 
     // return the last file in the vector - the last created
     //
@@ -170,14 +124,13 @@ public:
     virtual std::string toXmlString();
 
     // Convenience function generate all previews on the audio file.
+    // 
     //
     void generatePreviews();
-    // throw BadSoundFileException, BadPeakFileException
 
     // Generate for a single audio file
     //
     bool generatePreview(AudioFileId id);
-    // throw BadSoundFileException, BadPeakFileException
 
     // Get a preview for an AudioFile adjusted to Segment start and
     // end parameters (assuming they fall within boundaries).
@@ -190,7 +143,6 @@ public:
                                   const RealTime &endTime,
                                   int width,
                                   bool withMinima);
-    // throw BadPeakFileException, BadAudioPathException
 
     // Draw a fixed size (fixed by QPixmap) preview of an audio file
     //
@@ -198,7 +150,6 @@ public:
                      const RealTime &startTime, 
                      const RealTime &endTime,
                      QPixmap *pixmap);
-    // throw BadPeakFileException, BadAudioPathException
 
     // Usually used to show how an audio Segment makes up part of
     // an audio file.
@@ -209,7 +160,6 @@ public:
                                 const RealTime &highlightStart,
                                 const RealTime &highlightEnd,
                                 QPixmap *pixmap);
-    // throw BadPeakFileException, BadAudioPathException
 
     // Get a short file name from a long one (with '/'s)
     //
@@ -238,16 +188,11 @@ public:
                        const RealTime &endTime,
                        int threshold,
                        const RealTime &minTime = RealTime(0, 100000000));
-    // throw BadPeakFileException, BadAudioPathException
 
     // Get the peak file manager
     //
     const PeakFileManager& getPeakFileManager() const { return m_peakManager; }
 
-    // Get the peak file manager
-    //
-    PeakFileManager& getPeakFileManager() { return m_peakManager; }
-
     // Cancel a running preview
     //
     void stopPreview();
@@ -265,13 +210,6 @@ private:
 
     PeakFileManager                               m_peakManager;
 
-    // All audio files are stored in m_audioFiles.  This additional
-    // set of pointers just refers to those that have been created by
-    // recording within the current session, and thus that the user
-    // may wish to remove at the end of the session if the document is
-    // not saved.
-    std::set<AudioFile*>                          m_recordedAudioFiles;
-
 };
 
 }
