@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -92,7 +92,7 @@ BWFAudioFile::open()
     {
         parseHeader();
     }
-    catch (BadSoundFileException s)
+    catch(std::string s)
     {
         //throw(s);
         return false;
