@@ -3,7 +3,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -54,11 +54,6 @@ public:
     virtual TransportToken transportJump(TransportRequest, RealTime) = 0;
 
     virtual bool isTransportSyncComplete(TransportToken token) = 0;
-
-    // The value returned here is a constant (within the context of a
-    // particular ExternalTransport object) that is guaranteed never
-    // to be returned by any of the transport request methods.
-    virtual TransportToken getInvalidTransportToken() const = 0;
 };
 
 }
