@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -90,6 +90,8 @@ protected:
     //--------------- Data members ---------------------------------
 
     static DataBlockRepository* m_instance;
+
+    blockid m_lastId;
 };
 
 
@@ -111,7 +113,7 @@ public:
         MidiChannelPressure      = 1 << 4,
         MidiPitchBend            = 1 << 5,
         MidiController           = 1 << 6,
-        MidiSystemMessage        = 1 << 7,
+        MidiSystemExclusive      = 1 << 7,
 
         // Sent from the gui to play an audio file
         Audio                    = 1 << 8,
@@ -146,17 +148,7 @@ public:
         // Time sig. event (from time sig. composition reference segment)
         TimeSignature            = 1 << 22,
         // Tempo event (from tempo composition reference segment)
-        Tempo                    = 1 << 23,
-        
-        // Panic function
-        Panic			 = 1 << 24,
-
-        // Set RG as MTC master/slave
-        SystemMTCTransport       = 1 << 25,
-        // Auto-connect sync outputs
-        SystemMIDISyncAuto       = 1 << 26,
-	// File format used for audio recording (data1 is 0=PCM,1=float)
-	SystemAudioFileFormat    = 1 << 27
+        Tempo                    = 1 << 23
 
     } MappedEventType;
 
@@ -173,7 +165,7 @@ public:
     {
         // JACK is having some xruns - warn the user maybe
 	FailureXRuns             = 0,
-        // JACK has died or kicked us out
+        // JACK has died
         FailureJackDied          = 1,
         // Audio subsystem failed to read from disc fast enough
         FailureDiscUnderrun      = 2,
@@ -182,17 +174,8 @@ public:
         // Audio subsystem failed to mix busses fast enough
         FailureBussMixUnderrun   = 4,
         // Audio subsystem failed to mix instruments fast enough
-        FailureMixUnderrun       = 5,
-	// Using a timer that has too low a resolution (e.g. 100Hz system timer)
-	WarningImpreciseTimer    = 6,
-	// Too much CPU time spent in audio processing -- risk of xruns and lockup
-	FailureCPUOverload       = 7,
-        // JACK kicked us out, but we've reconnected
-        FailureJackRestart       = 8,
-        // JACK kicked us out, and now the reconnection has failed
-        FailureJackRestartFailed = 9,
-	// A necessary ALSA call has returned an error code
-	FailureALSACallFailed    = 10,
+        FailureMixUnderrun       = 5
+
     } FailureCode;	
 
     MappedEvent(): m_trackId(0),
@@ -208,9 +191,7 @@ public:
                    m_runtimeSegmentId(-1),
                    m_autoFade(false),
                    m_fadeInTime(Rosegarden::RealTime::zeroTime),
-                   m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-                   m_recordedChannel(0),
-                   m_recordedDevice(0) {}
+                   m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
     // Construct from Events to Internal (MIDI) type MappedEvent
     //
@@ -222,6 +203,29 @@ public:
                 const RealTime &eventTime,
                 const RealTime &duration);
 
+    // A shortcut for creating MIDI/Internal MappedEvents
+    // from base properties
+    //
+    MappedEvent(InstrumentId id,
+                MidiByte pitch,
+                MidiByte velocity,
+                const RealTime &absTime,
+                const RealTime &duration):
+        m_trackId(0),
+        m_instrument(id),
+        m_type(MidiNote),
+        m_data1(pitch),
+        m_data2(velocity),
+        m_eventTime(absTime),
+        m_duration(duration),
+        m_audioStartMarker(RealTime(0,0)),
+        m_dataBlockId(0),
+        m_isPersistent(false),
+        m_runtimeSegmentId(-1),
+        m_autoFade(false),
+        m_fadeInTime(Rosegarden::RealTime::zeroTime),
+        m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
+
     // A general MappedEvent constructor for any MappedEvent type
     //
     MappedEvent(InstrumentId id,
@@ -244,22 +248,20 @@ public:
         m_runtimeSegmentId(-1),
         m_autoFade(false),
         m_fadeInTime(Rosegarden::RealTime::zeroTime),
-        m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-        m_recordedChannel(0),
-        m_recordedDevice(0) {}
+        m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
     // Audio MappedEvent shortcut constructor
     //
     MappedEvent(InstrumentId id,
-                unsigned short audioID,
+                MidiByte audioID,
                 const RealTime &eventTime,
                 const RealTime &duration,
                 const RealTime &audioStartMarker):
          m_trackId(0),
          m_instrument(id),
          m_type(Audio),
-         m_data1(audioID % 256),
-         m_data2(audioID / 256),
+         m_data1(audioID),
+         m_data2(0),
          m_eventTime(eventTime),
          m_duration(duration),
          m_audioStartMarker(audioStartMarker),
@@ -268,9 +270,7 @@ public:
          m_runtimeSegmentId(-1),
          m_autoFade(false),
          m_fadeInTime(Rosegarden::RealTime::zeroTime),
-         m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-         m_recordedChannel(0),
-         m_recordedDevice(0) {}
+         m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
     // More generalised MIDI event containers for
     // large and small events (one param, two param)
@@ -292,9 +292,7 @@ public:
          m_runtimeSegmentId(-1),
          m_autoFade(false),
          m_fadeInTime(Rosegarden::RealTime::zeroTime),
-         m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-         m_recordedChannel(0),
-         m_recordedDevice(0) {}
+         m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
     MappedEvent(InstrumentId id,
                 MappedEventType type,
@@ -312,9 +310,7 @@ public:
         m_runtimeSegmentId(-1),
         m_autoFade(false),
         m_fadeInTime(Rosegarden::RealTime::zeroTime),
-        m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-        m_recordedChannel(0),
-        m_recordedDevice(0) {}
+        m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
 
     // Construct SysExs say
@@ -334,9 +330,7 @@ public:
         m_runtimeSegmentId(-1),
         m_autoFade(false),
         m_fadeInTime(Rosegarden::RealTime::zeroTime),
-        m_fadeOutTime(Rosegarden::RealTime::zeroTime),
-        m_recordedChannel(0),
-        m_recordedDevice(0) {}
+        m_fadeOutTime(Rosegarden::RealTime::zeroTime) {}
 
     // Copy constructor
     //
@@ -355,9 +349,7 @@ public:
         m_runtimeSegmentId(mE.getRuntimeSegmentId()),
         m_autoFade(mE.isAutoFading()),
         m_fadeInTime(mE.getFadeInTime()),
-        m_fadeOutTime(mE.getFadeOutTime()),
-        m_recordedChannel(mE.getRecordedChannel()),
-        m_recordedDevice(mE.getRecordedDevice()) {}
+        m_fadeOutTime(mE.getFadeOutTime()) {}
 
     // Copy from pointer
     // Fix for 674731 by Pedro Lopez-Cabanillas (20030531)
@@ -375,9 +367,7 @@ public:
         m_runtimeSegmentId(mE->getRuntimeSegmentId()),
         m_autoFade(mE->isAutoFading()),
         m_fadeInTime(mE->getFadeInTime()),
-        m_fadeOutTime(mE->getFadeOutTime()),
-        m_recordedChannel(mE->getRecordedChannel()),
-        m_recordedDevice(mE->getRecordedDevice()) {}
+        m_fadeOutTime(mE->getFadeOutTime()) {}
 
     // Construct perhaps without initialising, for placement new or equivalent
     MappedEvent(bool initialise) {
@@ -422,14 +412,17 @@ public:
     void setData1(MidiByte d1) { m_data1 = d1; }
     void setData2(MidiByte d2) { m_data2 = d2; }
 
-    void setAudioID(unsigned short id) { m_data1 = id % 256; m_data2 = id / 256; }
-    int getAudioID() const { return m_data1 + 256 * m_data2; }
+    // Also use the pitch as the Audio file ID
+    //
+    void setAudioID(MidiByte id) { m_data1 = id; }
+    int getAudioID() const { return m_data1; }
 
     // A sample doesn't have to be played from the beginning.  When
     // passing an Audio event this value may be set to indicate from
     // where in the sample it should be played.  Duration is measured
     // against total sounding length (not absolute position).
     //
+    //
     void setAudioStartMarker(const RealTime &aS)
         { m_audioStartMarker = aS; }
     RealTime getAudioStartMarker() const
@@ -488,17 +481,6 @@ public:
     RealTime getFadeOutTime() const { return m_fadeOutTime; }
     void setFadeOutTime(const Rosegarden::RealTime &time)
             { m_fadeOutTime = time; }
-    
-    // Original event input channel as it was recorded
-    //
-    unsigned int getRecordedChannel() const { return m_recordedChannel; }
-    void setRecordedChannel(const unsigned int channel) 
-	    { m_recordedChannel = channel; }
-	    
-    // Original event record device as it was recorded
-    //
-    unsigned int getRecordedDevice() const { return m_recordedDevice; }
-    void setRecordedDevice(const unsigned int device) { m_recordedDevice = device; }
 
 private:
     TrackId          m_trackId;
@@ -531,11 +513,6 @@ private:
     Rosegarden::RealTime  m_fadeInTime;
     Rosegarden::RealTime  m_fadeOutTime;
 
-    // input event original data,
-    // stored as it was recorded
-    //
-    unsigned int	  m_recordedChannel;
-    unsigned int	  m_recordedDevice;
 };
 
 
