@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -23,13 +23,13 @@
 #include <string>
 #include <vector>
 #include <qdatastream.h>
-#include <qstring.h>
 
 #include "MappedCommon.h"
 #include "Instrument.h"
 #include "Device.h"
+#include "Plugins.h"
 
-#include "AudioPluginInstance.h" // for PluginPort::PortDisplayHint //!!!???
+#include "AudioPluginInstance.h" // for PluginPort::PortDisplayHint
 
 #ifndef _MAPPEDSTUDIO_H_
 #define _MAPPEDSTUDIO_H_
@@ -39,15 +39,22 @@
 // gui that enables us to control outgoing or incoming audio
 // and MIDI with run-time only persistence.  Placeholders for
 // our Studio elements on the sequencer.
+//
+//
 
 namespace Rosegarden
 {
 
-class SoundDriver;
+class Sequencer;
 
 
 // Types are in MappedCommon.h
 //
+
+// Every MappedStudio object derives from this class - if an
+// object is static then you're only allowed one per Studio
+// (as in the case of a PluginManager).
+//
 class MappedObject
 {
 public:
@@ -66,19 +73,36 @@ public:
         AudioFader,          // connectable fader - interfaces with devices
         AudioBuss,           // connectable buss - inferfaces with faders
 	AudioInput,          // connectable record input
-	PluginSlot,
-	PluginPort
-
+        AudioPluginManager,
+        LADSPAPlugin,
+        LADSPAPort
+   
     } MappedObjectType;
 
     MappedObject(MappedObject *parent,
                  const std::string &name,
                  MappedObjectType type,
-                 MappedObjectId id):
+                 MappedObjectId id,
+                 bool readOnly):
         m_type(type),
         m_id(id), 
         m_name(name),
-        m_parent(parent) {;}
+        m_parent(parent),
+        m_static(false), 
+        m_readOnly(readOnly) {;}
+
+    MappedObject(MappedObject *parent, 
+                 const std::string &name,
+                 MappedObjectType type,
+                 MappedObjectId id,
+                 bool readOnly,
+                 bool s):
+        m_type(type),
+        m_id(id),
+        m_name(name),
+        m_parent(parent),
+        m_static(s),
+        m_readOnly(readOnly) {;}
 
     virtual ~MappedObject() {;}
 
@@ -96,23 +120,24 @@ public:
     virtual bool getProperty(const MappedObjectProperty &property,
 			     MappedObjectValue &value) = 0;
 
-    // Only relevant to objects that have string properties
-    // 
-    virtual bool getProperty(const MappedObjectProperty &/* property */,
-			     QString &/* value */) { return false; }
-
     virtual void setProperty(const MappedObjectProperty &property,
                              MappedObjectValue value) = 0;
 
-    // Only relevant to objects that have string properties
-    // 
-    virtual void setProperty(const MappedObjectProperty &/* property */,
-                             QString /* value */) { }
-
-    // Only relevant to objects that have list properties
+    // Not a requirement - but an occasionally useful method
     //
-    virtual void setPropertyList(const MappedObjectProperty &/* property */,
-				 const MappedObjectPropertyList &/* values */) { }
+    virtual void setProperty(const MappedObjectProperty & /*property*/,
+                             MappedObjectValueList /*value*/) {;}
+
+    // Accepts a MappedObject* which to clone the current object into.
+    // All children of the passed MappedObject are free'd and new children
+    // created as part of the clone process.  This operation turns readonly
+    // objects into real objects.
+    //
+    // For the moment we allow this method to be overwritten so that
+    // in the case of child (end of line) classes we can implement
+    // attribute copying easily.
+    //
+    virtual void clone(MappedObject *object);
 
     // Ownership
     //
@@ -130,6 +155,7 @@ public:
     void addChild(MappedObject *mO);
     void removeChild(MappedObject *mO);
 
+
     // Destruction
     //
     void destroy();
@@ -137,6 +163,8 @@ public:
 
     std::vector<MappedObject*> getChildObjects() { return m_children; }
 
+    bool isReadOnly() const { return m_readOnly; }
+
 protected:
 
     MappedObjectType m_type;
@@ -145,6 +173,12 @@ protected:
 
     MappedObject                *m_parent;
     std::vector<MappedObject*>   m_children;
+
+private:
+
+    bool             m_static;
+    bool             m_readOnly;
+
 };
 
 
@@ -166,12 +200,14 @@ public:
     // Create a new slider of a certain type for a certain
     // type of device.
     //
-    MappedObject* createObject(MappedObjectType type);
+    MappedObject* createObject(MappedObjectType type,
+                               bool readOnly);
 
     // And create an object with a specified id
     //
     MappedObject* createObject(MappedObjectType type, 
-                               MappedObjectId id);
+                               MappedObjectId id,
+                               bool readOnly);
 
     bool connectObjects(MappedObjectId mId1, MappedObjectId mId2);
     bool disconnectObjects(MappedObjectId mId1, MappedObjectId mId2);
@@ -209,6 +245,11 @@ public:
     //
     void clear();
 
+    // Clear the temporary elements leaving all read-only (system)
+    // elements in place.
+    //
+    void clearTemporaries();
+
     // Clear a MappedObject reference from the Studio
     //
     bool clearObject(MappedObjectId id);
@@ -230,6 +271,8 @@ public:
     MappedAudioBuss *getAudioBuss(int bussNumber); // not buss no., not object id
     MappedAudioInput *getAudioInput(int inputNumber); // likewise
 
+    MappedObject* getPluginInstance(InstrumentId id, int position);
+
     // Return the object vector
     //
     //std::vector<MappedObject*>* getObjects() const { return &m_objects; }
@@ -244,12 +287,36 @@ public:
     */
 
 
-    // Set the driver object so that we can do things like
+    // Set the sequencer object so that we can do things like
     // initialise plugins etc.
     //
-    SoundDriver* getSoundDriver() { return m_soundDriver; }
-    const SoundDriver* getSoundDriver() const { return m_soundDriver; }
-    void setSoundDriver(SoundDriver *driver) { m_soundDriver = driver; }
+    Sequencer* getSequencer() { return m_sequencer; }
+    const Sequencer* getSequencer() const { return m_sequencer; }
+    void setSequencer(Sequencer *sequencer)
+        { m_sequencer = sequencer; }
+
+#ifdef HAVE_LADSPA
+
+    // Create a plugin instance
+    //
+    const LADSPA_Descriptor* createPluginDescriptor(unsigned long uniqueId);
+
+    // Remove a plugin instance - and potentially unload the library
+    //
+    void unloadPlugin(unsigned long uniqueId);
+
+    // Unload all the plugin libraries
+    //
+    void unloadAllPluginLibraries();
+
+    // Modify a port
+    //
+    void setPluginInstancePort(InstrumentId id,
+                               int position,
+                               unsigned long portNumber,
+                               LADSPA_Data value);
+
+#endif // HAVE_LADSPA
 
 protected:
 
@@ -272,9 +339,9 @@ private:
     typedef std::map<MappedObjectType, MappedObjectCategory> MappedObjectMap;
     MappedObjectMap m_objects;
     
-    // Driver object
+    // Sequencer object
     //
-    SoundDriver *m_soundDriver;
+    Sequencer     *m_sequencer;
 };
 
 
@@ -301,7 +368,8 @@ public:
     MappedConnectableObject(MappedObject *parent,
 			    const std::string &name,
 			    MappedObjectType type,
-			    MappedObjectId id);
+			    MappedObjectId id,
+			    bool readOnly);
 
     ~MappedConnectableObject();
 
@@ -337,7 +405,8 @@ public:
 
     MappedAudioFader(MappedObject *parent,
                      MappedObjectId id,
-                     MappedObjectValue channels = 2); // stereo default
+                     MappedObjectValue channels = 2, // stereo default
+                     bool readOnly = false);
     ~MappedAudioFader();
 
     virtual MappedObjectPropertyList getPropertyList(
@@ -386,7 +455,8 @@ public:
     static const MappedObjectProperty Level;
 
     MappedAudioBuss(MappedObject *parent,
-                    MappedObjectId id);
+                    MappedObjectId id,
+                    bool readOnly = false);
     ~MappedAudioBuss();
 
     virtual MappedObjectPropertyList getPropertyList(
@@ -405,7 +475,7 @@ public:
     std::vector<InstrumentId> getInstruments();
 
 protected:
-    int m_bussId;
+    MappedObjectValue m_bussId;
     MappedObjectValue m_level;
     MappedObjectValue m_pan;
 };
@@ -419,7 +489,8 @@ public:
     static const MappedObjectProperty InputNumber;
 
     MappedAudioInput(MappedObject *parent,
-		     MappedObjectId id);
+		     MappedObjectId id,
+		     bool readOnly = false);
     ~MappedAudioInput();
 
     virtual MappedObjectPropertyList getPropertyList(
@@ -437,10 +508,12 @@ protected:
     MappedObjectValue m_inputNumber;
 };
 
-class MappedPluginSlot : public MappedObject
+#ifdef HAVE_LADSPA
+class MappedLADSPAPlugin : public MappedObject, public LADSPAPlugin
 {
 public:
-    static const MappedObjectProperty Identifier;
+    // properties
+    static const MappedObjectProperty UniqueId;
     static const MappedObjectProperty PluginName;
     static const MappedObjectProperty Label;
     static const MappedObjectProperty Author;
@@ -448,15 +521,32 @@ public:
     static const MappedObjectProperty Category;
     static const MappedObjectProperty PortCount;
     static const MappedObjectProperty Ports;
-    static const MappedObjectProperty Program;
-    static const MappedObjectProperty Programs; // list property
-    static const MappedObjectProperty Instrument;
-    static const MappedObjectProperty Position;
     static const MappedObjectProperty Bypassed;
-    static const MappedObjectProperty Configuration; // list property
 
-    MappedPluginSlot(MappedObject *parent, MappedObjectId id);
-    ~MappedPluginSlot();
+    MappedLADSPAPlugin(MappedObject *parent,
+                       MappedObjectId id,
+                       bool readOnly):
+        MappedObject(parent,
+                     "MappedLADSPAPlugin",
+                     MappedObject::LADSPAPlugin,
+                     id,
+                     readOnly),
+                     m_instrument(0),
+                     m_position(0),
+                     m_bypassed(false) {;}
+
+    MappedLADSPAPlugin(MappedObject *parent,
+                       MappedObjectId id):
+        MappedObject(parent,
+                     "MappedLADSPAPlugin",
+                     MappedObject::LADSPAPlugin,
+                     id,
+                     false),
+                     m_instrument(0),
+                     m_position(0),
+                     m_bypassed(false) {;}
+
+    ~MappedLADSPAPlugin();
 
     virtual MappedObjectPropertyList getPropertyList(
                         const MappedObjectProperty &property);
@@ -464,57 +554,65 @@ public:
     virtual bool getProperty(const MappedObjectProperty &property,
 			     MappedObjectValue &value);
 
-    virtual bool getProperty(const MappedObjectProperty &property,
-			     QString &value);
-
     virtual void setProperty(const MappedObjectProperty &property,
                              MappedObjectValue value);
 
-    virtual void setProperty(const MappedObjectProperty &property,
-                             QString value);
-
-    virtual void setPropertyList(const MappedObjectProperty &,
-				 const MappedObjectPropertyList &);
-
-    void  setPort(unsigned long portNumber, float value);
-    float getPort(unsigned long portNumber);
+    unsigned long getUniqueId() const { return m_uniqueId;}
+    std::string getLabel() const { return m_label; }
+    std::string getAuthor() const { return m_author; }
+    std::string getCopyright() const { return m_copyright; }
+    std::string getCategory() const { return m_category; }
+    unsigned long getPortCount() const { return m_portCount; }
 
     InstrumentId getInstrument() const { return m_instrument; }
     int getPosition() const { return m_position; }
 
-    QString getProgram(int bank, int program);
-    unsigned long getProgram(QString name); // rv is bank << 16 + program
+    // populate this object with descriptor information
+    void populate(const LADSPA_Descriptor *descriptor, std::string category);
+
+    // redefine
+    virtual void clone(MappedObject *object);
+
+    // Cheat - we want to use a thin interface to ports from
+    // the gui - this sets port values on port number.
+    //
+    void setPort(unsigned long portNumber, float value);
+
+    bool isBypassed() const { return m_bypassed; }
 
 protected:
-    QString                   m_identifier;
 
-    QString                   m_name;
-    QString                   m_label;
-    QString                   m_author;
-    QString                   m_copyright;
-    QString                   m_category;
+    unsigned long             m_uniqueId;
+    std::string               m_label;
+    std::string               m_author;
+    std::string               m_copyright;
+    std::string               m_category;
     unsigned long             m_portCount;
 
     InstrumentId              m_instrument;
     int                       m_position;
     bool                      m_bypassed;
 
-    std::map<QString, QString> m_configuration;
 };
 
-class MappedPluginPort : public MappedObject
+class MappedLADSPAPort : public MappedObject
 {
 public:
-    static const MappedObjectProperty PortNumber;
-    static const MappedObjectProperty Name;
-    static const MappedObjectProperty Minimum;
-    static const MappedObjectProperty Maximum;
-    static const MappedObjectProperty Default;
-    static const MappedObjectProperty DisplayHint;
-    static const MappedObjectProperty Value;
 
-    MappedPluginPort(MappedObject *parent, MappedObjectId id);
-    ~MappedPluginPort();
+    // properties
+    //
+    static const MappedObjectProperty Descriptor;
+    static const MappedObjectProperty RangeHint;
+    static const MappedObjectProperty RangeLower;
+    static const MappedObjectProperty RangeUpper;
+    static const MappedObjectProperty Value;
+    static const MappedObjectProperty Default;
+
+    static const MappedObjectProperty PortNumber;
+
+    MappedLADSPAPort(MappedObject *parent,
+                     MappedObjectId id,
+                     bool readOnly);
 
     virtual MappedObjectPropertyList getPropertyList(
                         const MappedObjectProperty &property);
@@ -522,31 +620,176 @@ public:
     virtual bool getProperty(const MappedObjectProperty &property,
 			     MappedObjectValue &value);
 
+    virtual void setProperty(const MappedObjectProperty &property,
+                             MappedObjectValue value);
+
+    void setPortName(const std::string &name) { m_portName = name; }
+    std::string getPortName() const { return m_portName; }
+
+    void setRangeHint(LADSPA_PortRangeHintDescriptor hd,
+                      LADSPA_Data lowerBound,
+                      LADSPA_Data upperBound)
+        { m_portRangeHint.HintDescriptor = hd;
+          m_portRangeHint.LowerBound = lowerBound;
+          m_portRangeHint.UpperBound= upperBound; }
+    LADSPA_PortRangeHint getRangeHint() const { return m_portRangeHint; }
+
+    void setDescriptor(const LADSPA_PortDescriptor &pD)
+        { m_portDescriptor = pD; }
+    LADSPA_PortDescriptor getDescriptor() const { return m_portDescriptor; }
+ 
+    // Convenience functions that interpret the range hint.  LADPSA
+    // plugins are not required to provide bounds, but all our
+    // controls for them are bounded, so a plugin that doesn't provide
+    // any will just get some unsuitable ones invented for it.
+    MappedObjectValue getMinimum() const;
+    MappedObjectValue getMaximum() const;
+
+    // Another convenience function.
+    // PortDisplayHint (base/AudioPluginInstance.h) encapsulates the
+    // parts of the LADSPA hint descriptor that are relevant to us and
+    // are not about range.
+    PluginPort::PortDisplayHint getDisplayHint() const;
+
+    void setPortNumber(unsigned long portNumber) { m_portNumber = portNumber; }
+    unsigned long getPortNumber() const { return m_portNumber; }
+
+    void setValue(MappedObjectValue value) { m_value = value; }
+    MappedObjectValue getValue() const { return m_value; }
+
+    void setDefault(MappedObjectValue value) {
+	m_default = value; 
+	m_haveDefault = true;
+    }
+    MappedObjectValue getDefault() const; // return set value or calculate
+
+    // redefine clone() here to copy across value only
+    //
+    virtual void clone(MappedObject *object);
+
+protected:
+    unsigned int getSampleRate() const;
+
+    std::string           m_portName;
+    LADSPA_PortRangeHint  m_portRangeHint;
+    LADSPA_PortDescriptor m_portDescriptor;
+
+    MappedObjectValue     m_value;
+    MappedObjectValue     m_default;  // default value
+    bool                  m_haveDefault;
+    unsigned long         m_portNumber;
+
+};
+
+#endif // HAVE_LADSPA
+
+
+// MappedPluginManager locates and lists plugins and
+// provides an interface for plugging them into the
+// faders/Instruments.
+//
+// Rather confusingly this manager holds both the class of 
+// the plugin (in a read-only manner) as well as the actual
+// live instances of the plugin.  While this isn't very
+// clever or very efficient it works for the moment until
+// we have the energy or patience to change it.
+//
+//
+
+#ifdef HAVE_LADSPA
+typedef std::vector<std::pair<std::string, void*> > LADSPAPluginHandles;
+typedef std::vector<std::pair<std::string, void*> >::iterator LADSPAIterator;
+#endif // HAVE_LADSPA
+
+class MappedAudioPluginManager : public MappedObject
+{
+public:
+
+    // public properties for the query interface
+    //
+    static const MappedObjectProperty Plugins;
+    static const MappedObjectProperty PluginIds;
+
+    MappedAudioPluginManager(MappedObject *parent,
+                             MappedObjectId id,
+                             bool readOnly);
+    ~MappedAudioPluginManager();
+
+    // Property list
+    //
+    virtual MappedObjectPropertyList getPropertyList(
+            const MappedObjectProperty &property);
+
     virtual bool getProperty(const MappedObjectProperty &property,
-			     QString &value);
+			     MappedObjectValue &value);
 
     virtual void setProperty(const MappedObjectProperty &property,
                              MappedObjectValue value);
 
-    virtual void setProperty(const MappedObjectProperty &property,
-                             QString value);
+    // Get a list of plugins and create MappedObjects out of them
+    //
+    void discoverPlugins(MappedStudio *studio);
+    void clearPlugins(MappedStudio *studio);
 
-    void setValue(MappedObjectValue value);
-    MappedObjectValue getValue() const;
+#ifdef HAVE_LADSPA
+    // Locate and load a plugin from its uniqueId.  The caller
+    // can then use the descriptor to create and control a plugin 
+    // instance.
+    //
+    const LADSPA_Descriptor* getPluginDescriptor(unsigned long uniqueId);
 
-    int getPortNumber() const { return m_portNumber; }
+    // Using this method we unload a plugin from the list of pluginHandles
+    // and we check to see if we can unload the file completely.
+    //
+    void unloadPlugin(unsigned long uniqueId);
+
+    // Close down all plugins
+    //
+    void unloadAllPluginLibraries();
+
+    // Get all the plugin IDs from a library
+    //
+    std::vector<unsigned long> getPluginsInLibrary(void *pluginHandle);
+
+#endif
+
+    // Get the class of this plugin so we can clone() it
+    //
+    MappedObject* getReadOnlyPlugin(unsigned long uniqueId);
+
+    // Get a plugin according to read-onlyness
+    //
+    MappedObject* getPluginInstance(unsigned long uniqueId, bool readOnly);
+
+    // Get a plugin instance according to instrument and position
+    //
+    MappedObject* getPluginInstance(InstrumentId instrument, int position);
 
 protected:
-    int                     m_portNumber;
-    QString                 m_name;
-    MappedObjectValue       m_minimum;
-    MappedObjectValue       m_maximum;
-    MappedObjectValue       m_default;
-    PluginPort::PortDisplayHint m_displayHint;
+    // Help discover plugins
+    //
+    void enumeratePlugin(MappedStudio *studio, const std::string& path);
+
+#ifdef HAVE_LADSPA
+
+    // Look up and remember the LADSPA path
+    //
+    void getenvLADSPAPath();
+
+    const LADSPA_Descriptor* getDescriptorFromHandle(unsigned long uniqueId,
+                                                     void *pluginHandle);
+
+
+    // Keep a track of plugin handles
+    //
+    LADSPAPluginHandles m_pluginHandles;
+
+#endif // HAVE_LADSPA
+
+    std::vector<std::string> m_path;
 
 };
 
-    
 }
 
 #endif // _MAPPEDSTUDIO_H_
