@@ -4,7 +4,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -24,7 +24,6 @@
 #include <fstream>
 #include <string>
 #include <cstdio>
-#include <algorithm>
 
 #include "Midi.h"
 #include "MidiFile.h"
@@ -117,8 +116,6 @@ MidiFile::midiBytesToLong(const string& bytes)
                    ((long)(((MidiByte)bytes[2]) << 8)) |
                    ((long)((MidiByte)(bytes[3])));
 
-    std::cerr << "midiBytesToLong(" << int((MidiByte)bytes[0]) << "," << int((MidiByte)bytes[1]) << "," << int((MidiByte)bytes[2]) << "," << int((MidiByte)bytes[3]) << ") -> " << longRet << std::endl;
-
     return longRet;
 }
 
@@ -140,50 +137,11 @@ MidiFile::midiBytesToInt(const string& bytes)
 
 
 
-// Gets a single byte from the MIDI byte stream.  For each track
-// section we can read only a specified number of bytes held in
-// m_trackByteCount.
+// Our MIDI file accessor function and best regarded as single point of entry
+// despite the ifstream pointer flying around the place.  Gets a specified
+// number of bytes from the MIDI byte stream.  For each track section we
+// can read only a specified number of bytes held in m_trackByteCount.
 //
-MidiByte
-MidiFile::getMidiByte(ifstream* midiFile)
-{
-    static int bytesGot = 0; // purely for progress reporting purposes
-
-    if (midiFile->eof())
-    {
-        throw(Exception("End of MIDI file encountered while reading"));
-    }
-
-    if (m_decrementCount && m_trackByteCount <= 0)
-    {
-        throw(Exception("Attempt to get more bytes than expected on Track"));
-    }
-
-    char byte;
-    if (midiFile->read(&byte, 1)) {
-
-	--m_trackByteCount;
-	
-	// update a progress dialog if we have one
-	//
-	++bytesGot;
-	if (bytesGot % 2000 == 0) {
-
-	    emit setProgress((int)(double(midiFile->tellg())/
-				   double(m_fileSize) * 20.0));
-	    kapp->processEvents(50);
-	}
-
-	return (MidiByte)byte;
-    }
-
-    throw(Exception("Attempt to read past MIDI file end"));
-}
-
-
-// Gets a specified number of bytes from the MIDI byte stream.  For
-// each track section we can read only a specified number of bytes
-// held in m_trackByteCount.
 //
 string
 MidiFile::getMidiBytes(ifstream* midiFile, unsigned long numberOfBytes)
@@ -192,6 +150,23 @@ MidiFile::getMidiBytes(ifstream* midiFile, unsigned long numberOfBytes)
     char fileMidiByte;
     static int bytesGot = 0; // purely for progress reporting purposes
 
+    if (m_decrementCount && (numberOfBytes > (unsigned long)m_trackByteCount))
+    {
+#ifdef MIDI_DEBUG
+        std::cerr << "Attempt to get more bytes than allowed on Track - ( "
+             << numberOfBytes
+             << " > "
+             << m_trackByteCount
+             << " )" << endl;
+#endif
+
+	//!!! Investigate -- I'm seeing this on new-notation-quantization
+	// branch: load glazunov.rg, run Interpret on first segment, export
+	// and attempt to import again
+	
+        throw(Exception("Attempt to get more bytes than allowed on Track"));
+    }
+
     if (midiFile->eof())
     {
 #ifdef MIDI_DEBUG
@@ -200,26 +175,10 @@ MidiFile::getMidiBytes(ifstream* midiFile, unsigned long numberOfBytes)
              << numberOfBytes << endl;
 #endif
 
-        throw(Exception("End of MIDI file encountered while reading"));
+        throw(Exception("MIDI EOF encountered while reading"));
 
     }
 
-    if (m_decrementCount && (numberOfBytes > (unsigned long)m_trackByteCount))
-    {
-#ifdef MIDI_DEBUG
-        std::cerr << "Attempt to get more bytes than allowed on Track ("
-             << numberOfBytes
-             << " > "
-             << m_trackByteCount << endl;
-#endif
-
-	//!!! Investigate -- I'm seeing this on new-notation-quantization
-	// branch: load glazunov.rg, run Interpret on first segment, export
-	// and attempt to import again
-	
-        throw(Exception("Attempt to get more bytes than expected on Track"));
-    }
-
     while(stringRet.length() < numberOfBytes &&
            midiFile->read(&fileMidiByte, 1))
     {
@@ -249,10 +208,13 @@ MidiFile::getMidiBytes(ifstream* midiFile, unsigned long numberOfBytes)
     // update a progress dialog if we have one
     //
     bytesGot += numberOfBytes;
-    if (bytesGot % 2000 == 0) {
+    if (bytesGot > 1000) {
+
         emit setProgress((int)(double(midiFile->tellg())/
 			       double(m_fileSize) * 20.0));
         kapp->processEvents(50);
+
+        bytesGot = 0;
     }
 
     return stringRet;
@@ -263,31 +225,28 @@ MidiFile::getMidiBytes(ifstream* midiFile, unsigned long numberOfBytes)
 //
 //
 long
-MidiFile::getNumberFromMidiBytes(ifstream* midiFile, int firstByte)
+MidiFile::getNumberFromMidiBytes(ifstream* midiFile)
 {
     long longRet = 0;
     MidiByte midiByte;
 
-    if (firstByte >= 0) {
-	midiByte = (MidiByte)firstByte;
-    } else if (midiFile->eof()) {
-	return longRet;
-    } else {
-	midiByte = getMidiByte(midiFile);
-    }
-
-    longRet = midiByte;
-    if (midiByte & 0x80 )
+    if(!midiFile->eof())
     {
-	longRet &= 0x7F;
-	do
-	{
-	    midiByte = getMidiByte(midiFile);
-	    longRet = (longRet << 7) + (midiByte & 0x7F);
-	}
-	while (!midiFile->eof() && (midiByte & 0x80));
-    }
+        midiByte = getMidiBytes(midiFile, 1)[0];
 
+        longRet = midiByte;
+        if(midiByte & 0x80 )
+        {
+            longRet &= 0x7F;
+            do
+            {
+                midiByte = getMidiBytes(midiFile, 1)[0];
+
+                longRet = (longRet << 7) + (midiByte & 0x7F);
+            }
+            while (!midiFile->eof() && (midiByte & 0x80));
+        }
+    }
     return longRet;
 }
 
@@ -300,7 +259,7 @@ bool
 MidiFile::skipToNextTrack(ifstream *midiFile)
 {
     string buffer, buffer2;
-    m_trackByteCount = -1;
+    m_trackByteCount = 0;
     m_decrementCount = false;
 
     while(!midiFile->eof() && (m_decrementCount == false ))
@@ -320,7 +279,7 @@ MidiFile::skipToNextTrack(ifstream *midiFile)
 
     }
 
-    if ( m_trackByteCount == -1 ) // we haven't found a track
+    if ( m_trackByteCount == 0 ) // we haven't found a track
         return(false);
     else
         return(true);
@@ -373,7 +332,7 @@ MidiFile::open()
             {
 
 #ifdef MIDI_DEBUG
-		std::cerr << "Parsing Track " << j << endl;
+                std::std::cerr << "Parsing Track " << j << endl;
 #endif
 
                 if(!skipToNextTrack(midiFile))
@@ -387,7 +346,7 @@ MidiFile::open()
                 }
 
 #ifdef MIDI_DEBUG
-		std::cerr << "Track has " << m_trackByteCount << " bytes" << std::endl;
+		std::std::cerr << "Track has " << m_trackByteCount << " bytes" << std::endl;
 #endif
 
                 // Run through the events taking them into our internal
@@ -533,9 +492,6 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
     // track number instead
     TrackId metaTrack = lastTrackNum;
 
-    // Remember the last non-meta status byte (-1 if we haven't seen one)
-    int runningStatus = -1;
-
     bool firstTrack = true;
 
     while (!midiFile->eof() && ( m_trackByteCount > 0 ) )
@@ -550,42 +506,21 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
 
         deltaTime = getNumberFromMidiBytes(midiFile);
 
-#ifdef MIDI_DEBUG
-	cerr << "read delta time " << deltaTime << endl;
-#endif
-
         // Get a single byte
-        midiByte = getMidiByte(midiFile);
+        midiByte = (MidiByte) getMidiBytes(midiFile, 1)[0];
 
         if (!(midiByte & MIDI_STATUS_BYTE_MASK))
         {
-	    if (runningStatus < 0) {
-		throw (Exception("Running status used for first event in track"));
-	    }
-
-	    eventCode = (MidiByte)runningStatus;
-	    data1 = midiByte;
-
-#ifdef MIDI_DEBUG
-	    std::cerr << "using running status (byte " << int(midiByte) << " found)" << std::endl;
-#endif
-        } else {
-#ifdef MIDI_DEBUG
-	    std::cerr << "have new event code " << int(midiByte) << std::endl;
-#endif
+            midiFile->seekg(-1, ios::cur);
+            m_trackByteCount++;
+        }
+        else
             eventCode = midiByte;
-	    data1 = getMidiByte(midiFile);
-	}
 
         if (eventCode == MIDI_FILE_META_EVENT) // meta events
         { 
-//            metaEventCode = getMidiByte(midiFile);
-	    metaEventCode = data1;
+            metaEventCode = getMidiBytes(midiFile,1)[0];
             messageLength = getNumberFromMidiBytes(midiFile);
-
-#ifdef MIDI_DEBUG
-	    std::cerr << "Meta event of type " << int(metaEventCode) << " and " << messageLength << " bytes found" << std::endl;
-#endif
             metaMessage = getMidiBytes(midiFile, messageLength);
 
 	    if (metaEventCode == MIDI_TIME_SIGNATURE ||
@@ -607,8 +542,6 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
         }
         else // the rest
         {
-	    runningStatus = eventCode;
-
             MidiEvent *midiEvent;
 
 	    int channel = (eventCode & MIDI_CHANNEL_NUM_MASK);
@@ -634,13 +567,15 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
             case MIDI_NOTE_OFF:
             case MIDI_POLY_AFTERTOUCH:
             case MIDI_CTRL_CHANGE:
-                data2 = getMidiByte(midiFile);
+
+                data1 = (MidiByte) getMidiBytes(midiFile, 1)[0];
+                data2 = (MidiByte) getMidiBytes(midiFile, 1)[0];
 
                 // create and store our event
                 midiEvent = new MidiEvent(deltaTime, eventCode, data1, data2);
 
                 /*
-		std::cerr << "MIDI event for channel " << channel << " (track "
+		std::std::cerr << "MIDI event for channel " << channel << " (track "
 			  << trackNum << ")" << std::endl;
 		midiEvent->print();
                           */
@@ -650,7 +585,9 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
                 break;
 
             case MIDI_PITCH_BEND:
-                data2 = getMidiByte(midiFile);
+
+                data1 = (MidiByte) getMidiBytes(midiFile, 1)[0];
+                data2 = (MidiByte) getMidiBytes(midiFile, 1)[0];
 
                 // create and store our event
                 midiEvent = new MidiEvent(deltaTime, eventCode, data1, data2);
@@ -659,18 +596,15 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
 
             case MIDI_PROG_CHANGE:
             case MIDI_CHNL_AFTERTOUCH:
+                data1 = (MidiByte) getMidiBytes(midiFile, 1)[0];
+
                 // create and store our event
                 midiEvent = new MidiEvent(deltaTime, eventCode, data1);
                 m_midiComposition[trackNum].push_back(midiEvent);
                 break;
 
             case MIDI_SYSTEM_EXCLUSIVE:
-                messageLength = getNumberFromMidiBytes(midiFile, data1);
-
-#ifdef MIDI_DEBUG
-		std::cerr << "SysEx of " << messageLength << " bytes found" << std::endl;
-#endif
-
+                messageLength = getNumberFromMidiBytes(midiFile);
                 metaMessage= getMidiBytes(midiFile, messageLength);
 
                 if (MidiByte(metaMessage[metaMessage.length() - 1]) !=
@@ -716,22 +650,6 @@ MidiFile::parseTrack(ifstream* midiFile, TrackId &lastTrackNum)
     return(true);
 }
 
-// borrowed from ALSA pcm_timer.c
-//
-static unsigned long gcd(unsigned long a, unsigned long b)
-{
-	unsigned long r;
-	if (a < b) {
-		r = a;
-		a = b;
-		b = r;
-	}
-	while ((r = a % b) != 0) {
-		a = b;
-		b = r;
-	}
-	return b;
-}
 
 // If we wanted to abstract the MidiFile class to make it more useful to
 // other applications (and formats) we'd make this method and its twin
@@ -760,8 +678,8 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
 
     // Event specific vars
     //
-    int numerator = 4;
-    int denominator = 4;
+    int numerator;
+    int denominator;
     timeT segmentTime;
 
     // keys
@@ -789,16 +707,8 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
     // [cc] -- attempt to avoid floating-point rounding errors
     timeT crotchetTime = Note(Note::Crotchet).getDuration();
     int divisor = m_timingDivision ? m_timingDivision : 96;
-
-    unsigned long multiplier = crotchetTime;
-    int g = (int)gcd(crotchetTime, divisor);
-    multiplier /= g;
-    divisor /= g;
-    
-    timeT maxRawTime = LONG_MAX;
-    if (multiplier > divisor) maxRawTime = (maxRawTime / multiplier) * divisor;
-
     bool haveTimeSignatures = false;
+
     InstrumentId compInstrument = MidiInstrumentBase;
 
     // Clear down the assigned Instruments we already have
@@ -867,20 +777,12 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
         {
 	    rosegardenEvent = 0;
 
-            // [cc] -- avoid floating-point where possible
-
-	    timeT rawTime = (*midiEvent)->getTime();
-
-	    if (rawTime < maxRawTime) {
-		rosegardenTime = origin +
-		    timeT((rawTime * multiplier) / divisor);
-	    } else {
-		rosegardenTime = origin +
-		    timeT((double(rawTime) * multiplier) / double(divisor) + 0.01);
-	    }
-
-	    rosegardenDuration =
-		timeT(((*midiEvent)->getDuration() * multiplier) / divisor);
+            // [cc] -- avoid floating-point
+            rosegardenTime = origin +
+                timeT(((*midiEvent)->getTime() * crotchetTime) / divisor);
+            rosegardenDuration =
+                timeT(((*midiEvent)->getDuration() * crotchetTime) / divisor);
+	    if (rosegardenTime + rosegardenDuration > maxTime) {
 
 #ifdef MIDI_DEBUG
 		std::cerr << "MIDI file import: origin " << origin
@@ -888,15 +790,9 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
 			  << ", duration " << rosegardenDuration
 			  << ", event type " << (int)(*midiEvent)->getMessageType()
 			  << ", previous max time " << maxTime
-			  << ", potential max time " << (rosegardenTime + rosegardenDuration)
-			  << ", ev raw time " << (*midiEvent)->getTime()
-			  << ", crotchet " << crotchetTime
-			  << ", multiplier " << multiplier
-			  << ", divisor " << divisor
-			  << std::endl;
+			  << ", new max time " << (rosegardenTime + rosegardenDuration) << std::endl;
 #endif
 
-	    if (rosegardenTime + rosegardenDuration > maxTime) {
 		maxTime = rosegardenTime + rosegardenDuration;
 	    }
 
@@ -947,18 +843,13 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
                     break;
 
                 case MIDI_END_OF_TRACK:
-                    {
-			timeT trackEndTime = rosegardenTime;
-			if (trackEndTime <= 0) {
-			    trackEndTime = crotchetTime*4*numerator/denominator;	
-			}
-			if (endOfLastNote < trackEndTime) {
-			    //If there's nothing in the segment yet, then we
-			    //shouldn't fill with rests because we don't want
-			    //to cause the otherwise empty segment to be created
-			    if (rosegardenSegment->size() > 0) {
-				rosegardenSegment->fillWithRests(trackEndTime);
-			    }
+		    if (endOfLastNote < rosegardenTime) {
+
+			// If there's nothing in the segment yet, then we
+			// shouldn't fill with rests because we don't want
+			// to cause the otherwise empty segment to be created
+			if (rosegardenSegment->size() > 0) {
+			    rosegardenSegment->fillWithRests(rosegardenTime);
 			}
                     }
                     break;
@@ -973,10 +864,8 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
 
                         if (tempo != 0)
                         {
-			    double qpm = 60000000.0 / double(tempo);
-			    Rosegarden::tempoT rgt(Composition::getTempoForQpm(qpm));
-			    std::cout << "MidiFile: converted MIDI tempo " << tempo << " to Rosegarden tempo " << rgt << std::endl;
-                            composition.addTempoAtTime(rosegardenTime, rgt);
+                            tempo = 60000000 / tempo;
+                            composition.addTempo(rosegardenTime, tempo);
                         }
                     }
                     break;
@@ -1283,10 +1172,6 @@ MidiFile::convertToRosegarden(Composition &composition, ConversionType type)
 		}
 	    }
 
-#ifdef MIDI_DEBUG
-	    std::cerr << "MIDI import: adding segment with start time " << rosegardenSegment->getStartTime() << " and end time " << rosegardenSegment->getEndTime() << std::endl;
-#endif
-
 	    // add the Segment to the Composition and increment the
 	    // Rosegarden segment number
 	    //
@@ -1348,32 +1233,27 @@ MidiFile::convertToMidi(Composition &comp)
     // file META information - this will get written out just like
     // any other MIDI track.
     //
-    midiEvent = new MidiEvent(0, MIDI_FILE_META_EVENT, MIDI_COPYRIGHT_NOTICE,
-                              comp.getCopyrightNote());
-
-    m_midiComposition[trackNumber].push_back(midiEvent);
-
-    midiEvent = new MidiEvent(0, MIDI_FILE_META_EVENT, MIDI_CUE_POINT,
+    midiEvent = new MidiEvent(0, MIDI_FILE_META_EVENT, MIDI_TEXT_MARKER,
                               "Created by Rosegarden");
 
     m_midiComposition[trackNumber].push_back(midiEvent);
 
-    midiEvent = new MidiEvent(0, MIDI_FILE_META_EVENT, MIDI_CUE_POINT,
+    midiEvent = new MidiEvent(0, MIDI_FILE_META_EVENT, MIDI_TEXT_MARKER,
                               "http://www.rosegardenmusic.com/");
 
     m_midiComposition[trackNumber].push_back(midiEvent);
 
     // Insert tempo events
     //
-    for (int i = 0; i < comp.getTempoChangeCount(); i++) // i=0 should be comp.getStart-something
+    for (int i = 0; i < comp.getTempoChangeCount(); i++)
     {
-        std::pair<timeT, Rosegarden::tempoT> tempo = comp.getTempoChange(i);
+        std::pair<timeT, long> tempo = comp.getRawTempoChange(i);
 
         midiEventAbsoluteTime = tempo.first * m_timingDivision
                                  / crotchetDuration;
 
-	double qpm = Composition::getTempoQpm(tempo.second);
-        long tempoValue = long(60000000.0 / qpm + 0.01);
+        long tempoValue = (long) ( tempo.second / 60.0 );
+        tempoValue = 60000000 / tempoValue;
 
         string tempoString;
         tempoString += (MidiByte) ( tempoValue >> 16 & 0xFF );
@@ -1433,23 +1313,6 @@ MidiFile::convertToMidi(Composition &comp)
         m_midiComposition[trackNumber].push_back(midiEvent);
     }
 
-    // Insert markers
-    // fix for bug#
-    Composition::markercontainer marks = comp.getMarkers();
-    
-    for (unsigned int i = 0; i < marks.size(); i++)
-    {
-        midiEventAbsoluteTime = marks[i]->getTime() * m_timingDivision
-                                 / crotchetDuration;
-
-        midiEvent = new MidiEvent( midiEventAbsoluteTime, 
-                                   MIDI_FILE_META_EVENT, 
-                                   MIDI_TEXT_MARKER,
-                                   marks[i]->getName() );
-
-        m_midiComposition[trackNumber].push_back(midiEvent);
-    }
-
     // first track proper
     //
     trackNumber++;
@@ -1634,8 +1497,7 @@ MidiFile::convertToMidi(Composition &comp)
 				soundingDuration * m_timingDivision /
 				crotchetDuration;
 
-			    long pitch = 60;
-			    (*el)->get<Int>(BaseProperties::PITCH, pitch);
+			    int pitch = (*el)->get<Int>(BaseProperties::PITCH);
 			    pitch += (*segment)->getTranspose();
                               
 			    // insert the NOTE_ON at the appropriate channel
@@ -2232,4 +2094,3 @@ MidiFile::close()
 
 }
 
-#include "MidiFile.moc"
