@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -29,20 +29,11 @@
 #include "AudioFile.h"
 #include "Audio.h"
 #include "Sound.h"
-#include "Profiler.h"
 
 using std::cout;
 using std::cerr;
 using std::endl;
 
-//#define DEBUG_PEAKFILE 1
-//#define DEBUG_PEAKFILE_BRIEF 1
-//#define DEBUG_PEAKFILE_CACHE 1
-
-#ifdef DEBUG_PEAKFILE
-#define DEBUG_PEAKFILE_BRIEF 1
-#endif
-
 namespace Rosegarden
 {
 
@@ -96,11 +87,11 @@ PeakFile::open()
     {
         parseHeader();
     }
-    catch (BadSoundFileException s)
+    catch(std::string s)
     {
 
 #ifdef DEBUG_PEAKFILE
-        cerr << "PeakFile::open - EXCEPTION \"" << s.getMessage() << "\""
+        cerr << "PeakFile::open - EXCEPTION \"" << s << "\""
              << endl;
 #endif
         return false;
@@ -126,7 +117,7 @@ PeakFile::parseHeader()
     if (header.compare(0, 4, Rosegarden::AUDIO_BWF_PEAK_ID) != 0)
 #endif
     {
-        throw(BadSoundFileException(m_fileName, "PeakFile::parseHeader - can't find LEVL identifier"));
+        throw(std::string("PeakFile::parseHeader - can't find LEVL identifier"));
     }
 
     int length = getIntegerFromLittleEndian(header.substr(4, 4));
@@ -134,7 +125,7 @@ PeakFile::parseHeader()
     // Get the length of the header minus the first 8 bytes
     //
     if (length == 0)
-        throw(BadSoundFileException(m_fileName, "PeakFile::parseHeader - can't get header length"));
+        throw(std::string("PeakFile::parseHeader - can't get header length"));
 
     // Get the file information
     //
@@ -218,10 +209,10 @@ PeakFile::write(unsigned short updatePercentage)
         if (!m_audioFile->open())
             return false;
     }
-    catch(BadSoundFileException e)
+    catch(std::string e)
     {
 #ifdef DEBUG_PEAKFILE
-        std::cerr << "PeakFile::write - \"" << e.getMessage() << "\"" << std::endl;
+        std::cerr << "PeakFile::write - \"" << e << "\"" << std::endl;
 #endif
         return false;
     }
@@ -426,19 +417,9 @@ PeakFile::scanToPeak(int peak)
 
     // Scan to start of chunk and then seek to peak number
     //
-    ssize_t pos = (ssize_t)m_chunkStartPosition + 128 +
-	peak * m_format * m_channels * m_pointsPerValue;
-
-    ssize_t off = pos - m_inFile->tellg();
-
-    if (off == 0) {
-	return true;
-    } else if (off < 0) {
-//	std::cerr << "PeakFile::scanToPeak: warning: seeking backwards for peak " << peak << " (" << m_inFile->tellg() << " -> " << pos << ")" << std::endl;
-	m_inFile->seekg(pos);
-    } else {
-	m_inFile->seekg(off, std::ios::cur);
-    }
+    m_inFile->seekg(m_chunkStartPosition + std::streampos(128), std::ios::beg); 
+    m_inFile->seekg(peak * m_format * m_channels * m_pointsPerValue,
+                    std::ios::cur);
 
     // Ensure we re-read the input buffer if we're 
     // doing buffered reads as it's now meaningless
@@ -499,7 +480,7 @@ PeakFile::writePeaks(unsigned short /*updatePercentage*/,
     //
     std::vector<std::pair<int, int> > channelPeaks;
     std::string samples;
-    unsigned char *samplePtr;
+    char *samplePtr;
 
     int sampleValue;
     int sampleMax = 0 ;
@@ -508,10 +489,6 @@ PeakFile::writePeaks(unsigned short /*updatePercentage*/,
     int channels = m_audioFile->getChannels();
     int bytes = m_audioFile->getBitsPerSample() / 8;
 
-    m_format = bytes;
-    if (bytes == 3 || bytes == 4) // 24-bit PCM or 32-bit float
-	m_format = 2; // write 16-bit PCM instead
-
     // for the progress dialog
     unsigned int apprxTotalBytes = m_audioFile->getSize();
     unsigned int byteCount = 0;
@@ -526,14 +503,15 @@ PeakFile::writePeaks(unsigned short /*updatePercentage*/,
 
     while(m_keepProcessing)
     {
-	try {
-	    samples = m_audioFile->
-		getBytes(m_blockSize * channels * bytes);
-	} catch (BadSoundFileException e) {
-	    std::cerr << "PeakFile::writePeaks: " << e.getMessage()
-		      << std::endl;
-	    break;
-	}
+        try
+        {
+            samples = m_audioFile->
+                getBytes(m_blockSize * channels * bytes);
+        }
+        catch (std::string e)
+        {
+            // do nothing
+        }
 
         // If no bytes or less than the total number of bytes are returned
         // then break out
@@ -549,70 +527,51 @@ PeakFile::writePeaks(unsigned short /*updatePercentage*/,
                                double(apprxTotalBytes) * 100.0));
         kapp->processEvents();
 
-        samplePtr = (unsigned char *)samples.c_str();
+        samplePtr = (char *)samples.c_str();
 
         for (int i = 0; i < m_blockSize; i++)
         {
-            for (unsigned int ch = 0; ch < m_audioFile->getChannels(); ch++)
+            for (unsigned int j = 0; j < m_audioFile->getChannels(); j++)
             {
+
                 // Single byte format values range from 0-255 and then
                 // shifted down about the x-axis.  Double byte and above
                 // are already centred about x-axis.
                 //
-                if (bytes == 1)
+                if(bytes == 1)
                 {
                     // get value
-		    sampleValue = int(*samplePtr) - 128;
+                    sampleValue = (unsigned char)(*samplePtr)
+                                      - (int(SAMPLE_MAX_8BIT) / 2);
                     samplePtr++;
+
                 }
                 else if (bytes == 2)
                 {
-		    unsigned char b2 = samplePtr[0];
-		    unsigned char b1 = samplePtr[1];
-		    unsigned int bits = (b1 << 8) + b2;
-		    sampleValue = (short)bits;
+                    sampleValue = (int)(*((short *)samplePtr));
                     samplePtr += 2;
                 }
-		else if (bytes == 3) 
-		{
-		    unsigned char b3 = samplePtr[0];
-		    unsigned char b2 = samplePtr[1];
-		    unsigned char b1 = samplePtr[2];
-		    unsigned int bits = (b1 << 24) + (b2 << 16) + (b3 << 8);
-
-		    // write out as 16-bit (m_format == 2)
-		    sampleValue = int(bits) / 65536;
-
-		    samplePtr += 3;
-		}
-		else if (bytes == 4)  // IEEE float (enforced by RIFFAudioFile)
-		{
-		    // write out as 16-bit (m_format == 2)
-		    float val = *(float *)samplePtr;
-		    sampleValue = (int)(32767.0 * val);
-		    samplePtr += 4;
-		}
                 else
                 {
-                    throw(BadSoundFileException(m_fileName, "PeakFile::writePeaks - unsupported bit depth"));
+                    throw(std::string("PeakFile::writePeaks - unsupported bit depth"));
                 }
 
                 // First time for each channel
                 //
                 if (i == 0)
                 {
-                    channelPeaks[ch].first = sampleValue;
-                    channelPeaks[ch].second = sampleValue;
+                    channelPeaks[j].first = sampleValue;
+                    channelPeaks[j].second = sampleValue;
                 }
                 else
                 {
                     // Compare and store
                     //
-                    if (sampleValue > channelPeaks[ch].first)
-                        channelPeaks[ch].first = sampleValue;
+                    if (sampleValue > channelPeaks[j].first)
+                        channelPeaks[j].first = sampleValue;
 
-                    if (sampleValue < channelPeaks[ch].second)
-                        channelPeaks[ch].second = sampleValue;
+                    if (sampleValue < channelPeaks[j].second)
+                        channelPeaks[j].second = sampleValue;
                 }
 
                 // Store peak of peaks if it fits
@@ -633,16 +592,19 @@ PeakFile::writePeaks(unsigned short /*updatePercentage*/,
         for (unsigned int i = 0; i < m_audioFile->getChannels(); i++)
         {
             putBytes(file, getLittleEndianFromInteger(channelPeaks[i].first,
-                                                      m_format));
+                                                      bytes));
             putBytes(file, getLittleEndianFromInteger(channelPeaks[i].second,
-                                                      m_format));
-            m_bodyBytes += m_format * 2;
+                                                      bytes));
+            m_bodyBytes += bytes * 2;
         }
 
         // increment number of peak frames
         m_numberOfPeaks++;
     }
 
+    // set format number
+    m_format = bytes;
+
 #ifdef DEBUG_PEAKFILE
     cout << "PeakFile::writePeaks - "
               << "completed peaks" << endl;
@@ -661,7 +623,8 @@ PeakFile::getPreview(const RealTime &startTime,
                      int width,
                      bool showMinima)
 {
-#ifdef DEBUG_PEAKFILE_BRIEF
+#define DEBUG_PREVIEW_SIZE
+#ifdef DEBUG_PREVIEW_SIZE
     std::cout << "PeakFile::getPreview - "
               << "startTime = " << startTime
               << ", endTime = " << endTime
@@ -679,31 +642,28 @@ PeakFile::getPreview(const RealTime &startTime,
     //
     if (!m_peakCache.length())
     {
-#ifdef DEBUG_PEAKFILE_CACHE
-                std::cerr << "PeakFile::getPreview - no peak cache" << std::endl;
-#endif
-
         if (getSize() < (256 *1024)) // if less than 256K PeakFile
         {
             // Scan to start of peak data
             scanToPeak(0);
-	    try {
-		m_peakCache = getBytes(m_inFile, getSize() - 128);
-	    } catch (BadSoundFileException e) {
-		std::cerr << "PeakFile::getPreview: " << e.getMessage()
-			  << std::endl;
-	    }
+            try
+            {
+                m_peakCache = getBytes(m_inFile, getSize() - 128);
+            }
+            catch(std::string e)
+            {
+//#define DEBUG_PEAKFILE_CACHE
+#ifdef DEBUG_PEAKFILE_CACHE
+                std::cerr << "PeakFile::getPreview - generating peak cache - "
+                          << e << std::endl;
+#endif
+            }
 
 #ifdef DEBUG_PEAKFILE_CACHE
-	    std::cout << "PeakFile::getPreview - generated peak cache - " 
-		      << "size = " << m_peakCache.length() << std::endl;
+        std::cout << "PeakFile::getPreview - generating peak cache - " 
+                  << "size = " << m_peakCache.length() << std::endl;
 #endif
-        } else {
-#ifdef DEBUG_PEAKFILE_CACHE
-	    std::cout << "PeakFile::getPreview - file size = " << getSize()
-		      << ", not generating cache" << std::endl;
-#endif
-	}
+        }
     }
 
     // Check to see if we hit the "lastPreview" cache by comparing the last 
@@ -713,14 +673,9 @@ PeakFile::getPreview(const RealTime &startTime,
         && width == m_lastPreviewWidth && showMinima == m_lastPreviewShowMinima)
     {
 #ifdef DEBUG_PEAKFILE_CACHE
-        std::cout << "PeakFile::getPreview - hit last preview cache" << std::endl;
+        std::cout << "PeakFile::getPreview - hit preview cache" << std::endl;
 #endif
         return m_lastPreviewCache;
-    } else {
-#ifdef DEBUG_PEAKFILE_CACHE
-	std::cout << "PeakFile::getPreview - last preview " << m_lastPreviewStartTime
-		  << " -> " << m_lastPreviewEndTime << ", w " << m_lastPreviewWidth << "; this " << startTime << " -> " << endTime << ", w " << width << std::endl;
-#endif
     }
 
     // Clear the cache - we need to regenerate it
@@ -739,8 +694,10 @@ PeakFile::getPreview(const RealTime &startTime,
     double step = double(endPeak - startPeak) / double(width);
     std::string peakData;
     int peakNumber;
+    float hiValue = 0.0f;
+    float loValue = 0.0f;
 
-#ifdef DEBUG_PEAKFILE_BRIEF
+#ifdef DEBUG_PEAKFILE
     std::cout << "PeakFile::getPreview - getting preview for \""
               << m_audioFile->getFilename() << "\"" << endl;
 #endif
@@ -759,7 +716,7 @@ PeakFile::getPreview(const RealTime &startTime,
             break;
 
         default:
-#ifdef DEBUG_PEAKFILE_BRIEF
+#ifdef DEBUG_PEAKFILE
             std::cout << "PeakFile::getPreview - "
                       << "unsupported peak length format (" << m_format << ")"
                       << endl;
@@ -767,151 +724,123 @@ PeakFile::getPreview(const RealTime &startTime,
             return m_lastPreviewCache;
     }
 
-    float *hiValues = new float[m_channels];
-    float *loValues = new float[m_channels];
-
-    for (int i = 0; i < width; i++) {
-
+    for (int i = 0; i < width; i++)
+    {
         peakNumber = startPeak + int(double(i) * step);
-	int nextPeakNumber = startPeak + int(double(i+1) * step);
 
         // Seek to value
         //
-        if (!m_peakCache.length()) {
-
-	    if (scanToPeak(peakNumber) == false) {
-#ifdef DEBUG_PEAKFILE
-		std::cout << "PeakFile::getPreview: scanToPeak(" << peakNumber << ") failed" << std::endl;
-#endif
+        if (!m_peakCache.length())
+        {
+            if (scanToPeak(peakNumber) == false)
                 m_lastPreviewCache.push_back(0.0f);
-	    }
-	}
-#ifdef DEBUG_PEAKFILE
-	std::cout << "PeakFile::getPreview: step is " << step << ", format * pointsPerValue * chans is " << (m_format * m_pointsPerValue * m_channels) << std::endl;
-	std::cout << "i = " << i << ", peakNumber = " << peakNumber << ", nextPeakNumber = " << nextPeakNumber << std::endl;
-#endif
-
-	for (int ch = 0; ch < m_channels; ch++) {
-            hiValues[ch] = 0.0f;
-            loValues[ch] = 0.0f;
-	}
+        }
 
         // Get peak value over channels
         //
-	for (int k = 0; peakNumber < nextPeakNumber; ++k) {
+        for (int j = 0; j < m_channels; j++)
+        {
 
-	    for (int ch = 0; ch < m_channels; ch++) {
+            hiValue = 0.0f;
+            loValue = 0.0f;
 
-		if (!m_peakCache.length()) {
-
-		    try {
-			peakData = getBytes(m_inFile, m_format * m_pointsPerValue);
-		    } catch (BadSoundFileException e) {
-			// Problem with the get - probably an EOF
-			// return the results so far.
-			//
+            if (!m_peakCache.length())
+            {
+                try
+                {
+                    peakData = getBytes(m_inFile, m_format * m_pointsPerValue);
+                }
+                catch (std::string e)
+                {
+                    // Problem with the get - probably an EOF
+                    // return the results so far.
+                    //
 #ifdef DEBUG_PEAKFILE
-			std::cout << "PeakFile::getPreview - \"" << e.getMessage() << "\"\n"
-				  << endl;
+                    std::cout << "PeakFile::getPreview - \"" << e << "\"\n"
+                              << endl;
 #endif
-			goto done;
-		    }
-#ifdef DEBUG_PEAKFILE
-		    std::cout << "PeakFile::getPreview - "
-			      << "read from file" << std::endl;
+                    resetStream();
+
+                    return m_lastPreviewCache;
+                }
+#ifdef DEBUG_PEAKFILE_CACHE
+                std::cout << "PeakFile::getPreview - "
+                          << "read from file" << std::endl;
 #endif
-		} else {
+            }
+            else
+            {
+                int charNum = peakNumber * m_format * 
+                              m_channels * m_pointsPerValue;
+                int charLength = m_format * m_pointsPerValue;
 
-		    int valueNum = peakNumber * m_channels + ch;
-		    int charNum = valueNum * m_format * m_pointsPerValue;
-		    int charLength = m_format * m_pointsPerValue;
-
-		    // Get peak value from the cached string if 
-		    // the value is valid.
-		    //
-		    if (charNum + charLength <= m_peakCache.length()) {
-			peakData = m_peakCache.substr(charNum, charLength);
-#ifdef DEBUG_PEAKFILE
-			std::cout << "PeakFile::getPreview - "
-				  << "hit peakCache" << std::endl;
+                // Get peak value from the cached string if 
+                // the value is valid.
+                //
+                if (charNum + charLength <= m_peakCache.length())
+                {
+                    peakData = m_peakCache.substr(charNum, charLength);
+#ifdef DEBUG_PEAKFILE_CACHE
+                    std::cout << "PeakFile::getPreview - "
+                              << "hit peakCache" << std::endl;
 #endif
-		    }
-		}
+                }
+            }
 
 
-		if (peakData.length() != (unsigned int)(m_format *
-							m_pointsPerValue)) {
-		    // We didn't get the whole peak block - return what
-		    // we've got so far
-		    //
-#ifdef DEBUG_PEAKFILE
-		    std::cout << "PeakFile::getPreview - "
-			      << "failed to get complete peak block"
-			      << endl;
-#endif
-		    goto done;
-		}
+            if (peakData.length() == (unsigned int)(m_format *
+                                                    m_pointsPerValue))
+            {
+                int intDivisor = int(divisor);
+                int inValue =
+                    getIntegerFromLittleEndian(peakData.substr(0, m_format));
 
-		int intDivisor = int(divisor);
-		int inValue =
-		    getIntegerFromLittleEndian(peakData.substr(0, m_format));
-		
 		while (inValue > intDivisor) {
 		    inValue -= (1 << (m_format * 8));
 		}
-		
-#ifdef DEBUG_PEAKFILE
-		std::cout << "found potential hivalue " << inValue << std::endl;
-#endif
-		
-		if (k == 0 || inValue > hiValues[ch]) {
-		    hiValues[ch] = float(inValue);
-		}
-		
-		if (m_pointsPerValue == 2) {
-		    
-		    inValue = 
-			getIntegerFromLittleEndian(
-			    peakData.substr(m_format, m_format));
-		    
+
+                hiValue += float(inValue);
+
+                if (m_pointsPerValue == 2)
+                {
+                    inValue = 
+                        getIntegerFromLittleEndian(
+                                peakData.substr(m_format, m_format));
+
 		    while (inValue > intDivisor) {
 			inValue -= (1 << (m_format * 8));
 		    }
-		    
-		    if (k == 0 || inValue < loValues[ch]) {
-			loValues[ch] = inValue;
-		    }
-		}
-	    }
 
-	    ++peakNumber;
-	}
-
-	for (int ch = 0; ch < m_channels; ++ch) {
-
-	    float value = hiValues[ch] / divisor;
-
-#ifdef DEBUG_PEAKFILE_BRIEF
-	    std::cout << "VALUE = " << hiValues[ch] / divisor << std::endl;
+                    loValue += float(inValue);
+                }
+            }
+            else
+            {
+                // We didn't get the whole peak block - return what
+                // we've got so far
+                //
+#ifdef DEBUG_PEAKFILE
+                std::cout << "PeakFile::getPreview - "
+                          << "failed to get complete peak block"
+                          << endl;
 #endif
 
-	    if (showMinima) {
-                m_lastPreviewCache.push_back(loValues[ch] / divisor);
-	    } else {
-		value = fabs(value);
-		if (m_pointsPerValue == 2) {
-		    value = std::max(value, fabsf(loValues[ch] / divisor));
-		}
-		m_lastPreviewCache.push_back(value);
-	    }
-	}
+                resetStream();
+                return m_lastPreviewCache;
+            }
+
+            //cout << "VALUE = " << hiValue / divisor << endl;
+
+            // Always push back high value
+            m_lastPreviewCache.push_back(hiValue / divisor);
+
+            if (showMinima)
+                m_lastPreviewCache.push_back(loValue / divisor);
+        }
     }
 
-done:
     resetStream();
-    delete[] hiValues;
-    delete[] loValues;
-    
+
     // We have a good preview in the cache so store our parameters
     //
     m_lastPreviewStartTime = startTime;
@@ -919,10 +848,6 @@ done:
     m_lastPreviewWidth = width;
     m_lastPreviewShowMinima = showMinima;
 
-#ifdef DEBUG_PEAKFILE_BRIEF
-    std::cout << "Returning " << m_lastPreviewCache.size() << " items" << std::endl;
-#endif
-
     return m_lastPreviewCache;
 }
 
@@ -979,23 +904,20 @@ PeakFile::getSplitPoints(const RealTime &startTime,
     float value;
     float fThreshold = float(threshold)/100.0;
     bool belowThreshold = true;
-    RealTime startSplit = RealTime::zeroTime;
-    bool inSplit = false;
+    RealTime startSplit;
 
     for (int i = startPeak; i < endPeak; i++)
     {
         value = 0.0;
 
-        for (int ch = 0; ch < m_channels; ch++)
+        for (int j = 0; j < m_channels; j++)
         {
             try
             {
                 peakData = getBytes(m_inFile, m_format * m_pointsPerValue);
             }
-            catch (BadSoundFileException e)
+            catch (std::string e)
             {
-		std::cerr << "PeakFile::getSplitPoints: "
-			  << e.getMessage() << std::endl;
                 break;
             }
 
@@ -1016,7 +938,6 @@ PeakFile::getSplitPoints(const RealTime &startTime,
             if (value > fThreshold)
             {
                 startSplit = getTime(i);
-		inSplit = true;
                 belowThreshold = false;
             }
         }
@@ -1025,17 +946,14 @@ PeakFile::getSplitPoints(const RealTime &startTime,
             if (value < fThreshold && getTime(i) - startSplit > minLength)
             {
                 // insert values
-		if (inSplit) {
-		    points.push_back(SplitPointPair(startSplit, getTime(i)));
-		}
-		inSplit = false;
+                points.push_back(SplitPointPair(startSplit, getTime(i)));
                 belowThreshold = true;
             }
         }
     }
 
     // if we've got a split point open the close it
-    if (inSplit)
+    if (belowThreshold == false)
     {
         points.push_back(SplitPointPair(startSplit,
                                         getTime(endPeak)));
@@ -1048,4 +966,3 @@ PeakFile::getSplitPoints(const RealTime &startTime,
 }
 
 
-#include "PeakFile.moc"
