@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -196,19 +196,16 @@ PeakFileManager::generatePeaks(AudioFile *audioFile,
         //
         if(m_currentPeakFile->write(updatePercentage) == false)
         {
-	    std::cerr << "Can't write peak file for " << audioFile->getFilename() << " - no preview generated" << std::endl;
-	    throw BadPeakFileException
-		(audioFile->getFilename(), __FILE__, __LINE__);
+            std::string rS = std::string("Can't write peak file for \"") +
+                             audioFile->getFilename() +
+                             std::string("\" - no preview generated");
+            throw(rS);
         }
 
-        // The m_currentPeakFile might have been cancelled (see stopPreview())
-        //
-        if (m_currentPeakFile)
-        {
-            // close writes out important things
-            m_currentPeakFile->close();
-            m_currentPeakFile->disconnect();
-        }
+        // close writes out important things
+        m_currentPeakFile->close();
+        m_currentPeakFile->disconnect();
+
     }
     else if (audioFile->getType() == BWF)
     {
@@ -255,7 +252,7 @@ PeakFileManager::getPreview(AudioFile *audioFile,
                                       width,
                                       showMinima);
         }
-        catch (SoundFile::BadSoundFileException e)
+        catch(std::string e)
         {
 #ifdef DEBUG_PEAKFILEMANAGER
             std::cout << "PeakFileManager::getPreview "
@@ -263,7 +260,6 @@ PeakFileManager::getPreview(AudioFile *audioFile,
 #else
             ;
 #endif
-	    throw BadPeakFileException(e);
         }
     }
     else if (audioFile->getType() == BWF)
@@ -345,4 +341,3 @@ PeakFileManager::stopPreview()
 }
 
 
-#include "PeakFileManager.moc"
