@@ -4,7 +4,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -55,11 +55,6 @@ RIFFAudioFile::RIFFAudioFile(const std::string &fileName,
     m_bytesPerSecond = bytesPerSecond;
     m_bytesPerFrame = bytesPerFrame;
     m_channels = channels;
-
-    if (bitsPerSample == 16) m_subFormat = PCM;
-    else if (bitsPerSample == 32) m_subFormat = FLOAT;
-    else throw(BadSoundFileException(m_fileName, "Rosegarden currently only supports 16-bit PCM or IEEE floating-point RIFF files for writing"));
-
 }
 
 RIFFAudioFile::~RIFFAudioFile()
@@ -96,13 +91,6 @@ RIFFAudioFile::appendSamples(const std::string &buffer)
     return true;
 }
 
-bool
-RIFFAudioFile::appendSamples(const char *buf, unsigned int frames)
-{
-    putBytes(m_outFile, buf, frames * m_bytesPerFrame);
-    return true;
-}
-
 // scan on from a descriptor position
 bool
 RIFFAudioFile::scanForward(std::ifstream *file, const RealTime &time)
@@ -119,7 +107,7 @@ RIFFAudioFile::scanForward(std::ifstream *file, const RealTime &time)
     // do the seek
     file->seekg(totalBytes, std::ios::cur);
 
-    if (file->eof())
+    if (file->get() == EOF)
         return false;
 
     return true;
@@ -147,6 +135,8 @@ RIFFAudioFile::scanTo(const RealTime &time)
 bool
 RIFFAudioFile::scanTo(std::ifstream *file, const RealTime &time)
 {
+    Rosegarden::Profiler("RIFFAudioFile::scanTo", true); //!!!
+
     // sanity
     if (file == 0) return false;
 
@@ -154,19 +144,15 @@ RIFFAudioFile::scanTo(std::ifstream *file, const RealTime &time)
     //
     m_loseBuffer = true;
 
-    file->clear();
-
     // seek past header - don't hardcode this - use the file format
     // spec to get header length and then scoot to that.
     //
     file->seekg(16, std::ios::beg);
+    unsigned int lengthOfFormat = getIntegerFromLittleEndian(getBytes(file, 4));
+    file->seekg(lengthOfFormat, std::ios::cur);
 
-    unsigned int lengthOfFormat = 0;
-
-    try {
-	lengthOfFormat = getIntegerFromLittleEndian(getBytes(file, 4));
-	file->seekg(lengthOfFormat, std::ios::cur);
-
+    try
+    {
         // check we've got data chunk start
         if (getBytes(file, 4) != "data")
         {
@@ -185,11 +171,11 @@ RIFFAudioFile::scanTo(std::ifstream *file, const RealTime &time)
 #endif
 
     }
-    catch (BadSoundFileException s)
+    catch(std::string s)
     {
 #ifdef DEBUG_RIFF
         std::cerr << "RIFFAudioFile::scanTo - EXCEPTION - \""
-                  << s.getMessage() << "\"" << std::endl;
+                  << s << "\"" << std::endl;
 #endif
         return false;
     }
@@ -240,24 +226,7 @@ RIFFAudioFile::getSampleFrames(std::ifstream *file, unsigned int frames)
     // of channels we're using
     //
     long totalBytes = frames * m_bytesPerFrame;
-
-    try {
-	return getBytes(file, totalBytes);
-    } catch (BadSoundFileException s) {
-	return "";
-    }
-}
-
-unsigned int
-RIFFAudioFile::getSampleFrames(std::ifstream *file, char *buf,
-			       unsigned int frames)
-{
-    if (file == 0) return 0;
-    try {
-	return getBytes(file, buf, frames * m_bytesPerFrame) / m_bytesPerFrame;
-    } catch (BadSoundFileException s) {
-	return 0;
-    }
+    return getBytes(file, totalBytes);
 }
 
 std::string
@@ -278,14 +247,11 @@ RIFFAudioFile::getSampleFrameSlice(std::ifstream *file, const RealTime &time)
     // sanity
     if (file == 0) return std::string("");
 
-    long totalFrames = RealTime::realTime2Frame(time, m_sampleRate);
-    long totalBytes = totalFrames * m_bytesPerFrame;
-    
-    try {
-	return getBytes(file, totalBytes);
-    } catch (BadSoundFileException s) {
-	return "";
-    }
+    long totalSamples = m_sampleRate * time.sec +
+                        ( ( m_sampleRate * time.usec() ) / 1000000 );
+
+    long totalBytes = totalSamples * m_channels * m_bytesPerFrame;
+    return getBytes(file, totalBytes);
 }
 
 std::string
@@ -361,7 +327,7 @@ RIFFAudioFile::readFormatChunk()
         std::cerr << "RIFFAudioFile::readFormatChunk - "
                   << "can't find RIFF identifier\n";
 #endif
-        throw(BadSoundFileException(m_fileName, "RIFFAudioFile::readFormatChunk - can't find RIFF identifier"));
+        throw((std::string("RIFFAudioFile::readFormatChunk - can't find RIFF identifier")));
     }
 
     // Look for the WAV identifier
@@ -375,7 +341,7 @@ RIFFAudioFile::readFormatChunk()
 #ifdef DEBUG_RIFF
         std::cerr << "Can't find WAV identifier\n";
 #endif
-        throw(BadSoundFileException(m_fileName, "Can't find WAV identifier"));
+        throw((std::string("Can't find WAV identifier")));
     }
 
     // Look for the FORMAT identifier - note that this doesn't actually
@@ -392,7 +358,7 @@ RIFFAudioFile::readFormatChunk()
 #ifdef DEBUG_RIFF
         std::cerr << "Can't find FORMAT identifier\n";
 #endif
-        throw(BadSoundFileException(m_fileName, "Can't find FORMAT identifier"));
+        throw((std::string("Can't find FORMAT identifier")));
     }
 
     // Little endian conversion of length bytes into file length
@@ -403,6 +369,13 @@ RIFFAudioFile::readFormatChunk()
 
     if (length != m_fileSize)
     {
+	/*!!!
+        char value[80];
+        sprintf(value, "(read %u when size is %u)", length, m_fileSize);
+        throw(std::string("\"" + m_fileName +
+              "\" corrupted (wrong length) - " +
+              std::string(value)));
+	*/
 	std::cerr << "WARNING: RIFFAudioFile: incorrect length ("
 		  << length << ", file size is " << m_fileSize << "), ignoring"
 		  << std::endl;
@@ -436,21 +409,18 @@ RIFFAudioFile::readFormatChunk()
 #endif
 
         m_inFile->seekg(lengthOfFormat - 0x10, std::ios::cur);
-        //throw(BadSoundFileException(m_fileName, "Format chunk too short"));
+        //throw(std::string("Format chunk too short"));
     }
 
 
-    // Check sub format - we support PCM or IEEE floating point.
+    // Check our sub format is PCM encoded - currently the only encoding
+    // we support.
     //
-    unsigned int subFormat = getIntegerFromLittleEndian(hS.substr(20, 2));
+    unsigned int alwaysOne = getIntegerFromLittleEndian(hS.substr(20, 2));
+
+    if (alwaysOne != 0x01)
+        throw(std::string("Rosegarden currently only supports PCM encoded RIFF files"));
 
-    if (subFormat == 0x01) {
-	m_subFormat = PCM;
-    } else if (subFormat == 0x03) {
-	m_subFormat = FLOAT;
-    } else {
-        throw(BadSoundFileException(m_fileName, "Rosegarden currently only supports PCM or IEEE floating-point RIFF files"));
-    }
 
     // We seem to have a good looking .WAV file - extract the
     // sample information and populate this locally
@@ -466,7 +436,7 @@ RIFFAudioFile::readFormatChunk()
 
         default:
             {
-                throw(BadSoundFileException(m_fileName, "Unsupported number of channels"));
+                throw(std::string("Unsupported number of channels"));
             }
             break;
     }
@@ -478,16 +448,6 @@ RIFFAudioFile::readFormatChunk()
     m_bytesPerFrame = getIntegerFromLittleEndian(hS.substr(32,2));
     m_bitsPerSample = getIntegerFromLittleEndian(hS.substr(34,2));
 
-    if (m_subFormat == PCM) {
-	if (m_bitsPerSample != 8 && m_bitsPerSample != 16 && m_bitsPerSample != 24) {
-	    throw BadSoundFileException("Rosegarden currently only supports 8-, 16- or 24-bit PCM in RIFF files");
-	}
-    } else if (m_subFormat == FLOAT) {
-	if (m_bitsPerSample != 32) {
-	    throw BadSoundFileException("Rosegarden currently only supports 32-bit floating-point in RIFF files");
-	}
-    }
-
     //printStats();
 
 }
@@ -521,12 +481,8 @@ RIFFAudioFile::writeFormatChunk()
     //cout << "LENGTH = " << getLittleEndianFromInteger(0x10, 4) << endl;
     outString += getLittleEndianFromInteger(0x10, 4);
 
-    // 1 for PCM, 3 for float
-    if (m_subFormat == PCM) {
-	outString += getLittleEndianFromInteger(0x01, 2);
-    } else {
-	outString += getLittleEndianFromInteger(0x03, 2);
-    }
+    // "always one"
+    outString += getLittleEndianFromInteger(0x01, 2);
 
     // channel
     outString += getLittleEndianFromInteger(m_channels, 2);
@@ -611,51 +567,7 @@ RIFFAudioFile::identifySubType(const std::string &filename)
     return type;
 }
 
-float
-RIFFAudioFile::convertBytesToSample(const unsigned char *ubuf)
-{
-    switch (getBitsPerSample()) {
-	
-    case 8:
-    {
-	// WAV stores 8-bit samples unsigned, other sizes signed.
-	return (float)(ubuf[0] - 128.0) / 128.0;
-    }
-    
-    case 16:
-    {
-	// Two's complement little-endian 16-bit integer.
-	// We convert endianness (if necessary) but assume 16-bit short.
-	unsigned char b2 = ubuf[0];
-	unsigned char b1 = ubuf[1];
-	unsigned int bits = (b1 << 8) + b2;
-	return (float)(short(bits)) / 32767.0;
-    }
 
-    case 24:
-    {
-	// Two's complement little-endian 24-bit integer.
-	// Again, convert endianness but assume 32-bit int.
-	unsigned char b3 = ubuf[0];
-	unsigned char b2 = ubuf[1];
-	unsigned char b1 = ubuf[2];
-	// Rotate 8 bits too far in order to get the sign bit
-	// in the right place; this gives us a 32-bit value,
-	// hence the larger float divisor
-	unsigned int bits = (b1 << 24) + (b2 << 16) + (b3 << 8);
-	return (float)(int(bits)) / 2147483647.0;
-    }
-
-    case 32:
-    {
-	// IEEE floating point
-	return *(float *)ubuf;
-    }
-    
-    default:
-	return 0.0f;
-    }
-}
 
 }
 
