@@ -3,7 +3,7 @@
     Rosegarden-4
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2006
+    This program is Copyright 2000-2004
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -21,7 +21,6 @@
 #include <string>
 #include <vector>
 #include <list>
-#include <qstringlist.h>
 
 #include "Device.h"
 #include "MappedComposition.h"
@@ -29,10 +28,8 @@
 #include "MappedDevice.h"
 #include "SequencerDataBlock.h"
 #include "PlayableAudioFile.h"
-#include "Scavenger.h"
-#include "RIFFAudioFile.h" // for SubFormat enum
 
-// Abstract base to support SoundDrivers, such as ALSA.
+// Abstract base to support SoundDrivers such as aRts and ALSA.
 //
 // This base class provides the generic driver support for
 // these drivers with the Sequencer class owning an instance
@@ -52,8 +49,10 @@ namespace Rosegarden
 //
 typedef enum
 {
-    RECORD_OFF,
-    RECORD_ON,
+    ASYNCHRONOUS_MIDI,
+    ASYNCHRONOUS_AUDIO,
+    RECORD_MIDI,
+    RECORD_AUDIO
 } RecordStatus;
 
 
@@ -63,23 +62,12 @@ typedef enum
 //
 typedef enum
 {
-    NO_DRIVER  = 0x00,          // Nothing's OK
-    AUDIO_OK   = 0x01,          // AUDIO's OK
-    MIDI_OK    = 0x02,          // MIDI's OK
-    VERSION_OK = 0x04           // GUI and sequencer versions match
+    NO_DRIVER = 0x00,          // Nothing's OK
+    AUDIO_OK  = 0x01,          // AUDIO's OK
+    MIDI_OK   = 0x02           // MIDI's OK
 } SoundDriverStatus;
 
 
-// Used for MMC and MTC, not for JACK transport
-//
-typedef enum
-{
-    TRANSPORT_OFF,
-    TRANSPORT_MASTER,
-    TRANSPORT_SLAVE
-} TransportSyncStatus;
-
-
 // The NoteOffQueue holds a time ordered set of
 // pending MIDI NOTE OFF events.
 //
@@ -135,7 +123,6 @@ private:
 
 class MappedStudio;
 class ExternalTransport;
-class AudioPlayQueue;
 
 typedef std::vector<PlayableAudioFile *> PlayableAudioFileList;
 
@@ -148,14 +135,14 @@ public:
     SoundDriver(MappedStudio *studio, const std::string &name);
     virtual ~SoundDriver();
 
-    virtual bool initialise() = 0;
+    virtual void initialise() = 0;
     virtual void shutdown() { }
 
     virtual void initialisePlayback(const RealTime &position) = 0;
     virtual void stopPlayback() = 0;
-    virtual void punchOut() = 0; // stop recording, continue playing
-    virtual void resetPlayback(const RealTime &oldPosition, const RealTime &position) = 0;
+    virtual void resetPlayback(const RealTime &position) = 0;
     virtual void allNotesOff() = 0;
+    virtual void processNotesOff(const RealTime &time) = 0;
     
     virtual RealTime getSequencerTime() = 0;
 
@@ -164,24 +151,12 @@ public:
     virtual void startClocks() { }
     virtual void stopClocks() { }
 
-    // Process some asynchronous events
-    //
-    virtual void processEventsOut(const MappedComposition &mC) = 0;
-
-    // Process some scheduled events on the output queue.  The
-    // slice times are here so that the driver can interleave
-    // note-off events as appropriate.
-    //
     virtual void processEventsOut(const MappedComposition &mC,
-				  const RealTime &sliceStart,
-				  const RealTime &sliceEnd) = 0;
+                                  bool now) = 0;
 
-    // Activate a recording state.  armedInstruments and audioFileNames
-    // can be NULL if no audio tracks recording.
+    // Activate a recording state
     //
-    virtual bool record(RecordStatus recordStatus,
-			const std::vector<InstrumentId> *armedInstruments = 0,
-			const std::vector<QString> *audioFileNames = 0) = 0;
+    virtual bool record(RecordStatus recordStatus) = 0;
 
     // Process anything that's pending
     //
@@ -194,7 +169,7 @@ public:
     // Plugin instance management
     //
     virtual void setPluginInstance(InstrumentId id,
-                                   QString identifier,
+                                   unsigned long pluginId,
                                    int position) = 0;
 
     virtual void removePluginInstance(InstrumentId id,
@@ -209,46 +184,10 @@ public:
                                             unsigned long portNumber,
                                             float value) = 0;
 
-    virtual float getPluginInstancePortValue(InstrumentId id,
-					     int position,
-					     unsigned long portNumber) = 0;
-
     virtual void setPluginInstanceBypass(InstrumentId id,
                                          int position,
                                          bool value) = 0;
 
-    virtual QStringList getPluginInstancePrograms(InstrumentId id,
-						  int position) = 0;
-
-    virtual QString getPluginInstanceProgram(InstrumentId id,
-					     int position) = 0;
-
-    virtual QString getPluginInstanceProgram(InstrumentId id,
-					     int position,
-					     int bank,
-					     int program) = 0;
-
-    virtual unsigned long getPluginInstanceProgram(InstrumentId id,
-						   int position,
-						   QString name) = 0;
-    
-    virtual void setPluginInstanceProgram(InstrumentId id,
-					  int position,
-					  QString program) = 0;
-
-    virtual QString configurePlugin(InstrumentId id,
-				    int position,
-				    QString key,
-				    QString value) = 0;
-
-    virtual void setAudioBussLevels(int bussId,
-				    float dB,
-				    float pan) = 0;
-
-    virtual void setAudioInstrumentLevels(InstrumentId id,
-					  float dB,
-					  float pan) = 0;
-
     // Poll for new clients (for new Devices/Instruments)
     //
     virtual bool checkForNewClients() = 0;
@@ -260,6 +199,10 @@ public:
 
     virtual void sleep(const RealTime &rt);
 
+    // Send the MIDI clock
+    //
+    virtual void sendMidiClock() = 0;
+
     virtual QString getStatusLog() { return ""; }
 
     // Mapped Instruments
@@ -271,14 +214,19 @@ public:
     //
     unsigned int getStatus() const { return m_driverStatus; }
 
+    // Queue an audio file for playback
+    //
+    void queueAudio(PlayableAudioFile *audioFile);
+
     // Are we playing?
     //
     bool isPlaying() const { return m_playing; }
 
-    // Are we counting?  By default a subclass probably wants to
-    // return true, if it doesn't know better.
+    // Are we counting?  (Default implementation is always counting,
+    // but if a subclass implements stopClocks/startClocks then that
+    // won't always be the case.)
     //
-    virtual bool areClocksRunning() const = 0;
+    virtual bool areClocksRunning() const { return true; }
 
     RealTime getStartPosition() const { return m_playStartPosition; }
     RecordStatus getRecordStatus() const { return m_recordStatus; }
@@ -301,7 +249,6 @@ public:
 	return Device::NO_DEVICE;
     }
     virtual void removeDevice(DeviceId) { }
-    virtual void renameDevice(DeviceId, QString) { }
 
     virtual unsigned int getConnections(Device::DeviceType,
 					MidiDevice::DeviceDirection) { return 0; }
@@ -312,46 +259,59 @@ public:
     virtual void setPlausibleConnection(DeviceId id, QString c) { setConnection(id, c); }
 
     virtual unsigned int getTimers() { return 0; }
-    virtual QString getTimer(unsigned int) { return ""; }
+    virtual QString getTimer(unsigned int n) { return ""; }
     virtual QString getCurrentTimer() { return ""; }
     virtual void setCurrentTimer(QString) { }
 
     virtual void getAudioInstrumentNumbers(InstrumentId &, int &) = 0;
-    virtual void getSoftSynthInstrumentNumbers(InstrumentId &, int &) = 0;
 
-    // Plugin management -- SoundDrivers should maintain a plugin
-    // scavenger which the audio process code can use for defunct
-    // plugins.  Ownership of plugin is passed to the SoundDriver.
+    // Return the whole audio play queue
     //
-    virtual void claimUnwantedPlugin(void *plugin) = 0;
+    PlayableAudioFileList getAudioPlayQueue();
 
-    // This causes all scavenged plugins to be destroyed.  It
-    // should only be called in non-RT contexts.
+    // Just non-defunct queue members
     //
-    virtual void scavengePlugins() = 0;
+    PlayableAudioFileList getAudioPlayQueueNotDefunct();
+
+    // Just non-defunct queue members on a particular audio instrument
+    //
+    PlayableAudioFileList getAudioPlayQueuePerInstrument(InstrumentId);
+
+    // Clear the queue
+    //
+    void clearAudioPlayQueue();
+
+    // Does what it says it does
+    //
+    void clearDefunctFromAudioPlayQueue();
 
     // Handle audio file references
     //
     void clearAudioFiles();
     bool addAudioFile(const std::string &fileName, unsigned int id);
     bool removeAudioFile(unsigned int id);
+    void rationalisePlayingAudio(const std::vector<MappedEvent> &list,
+				 const RealTime &playtime);
                     
-    void initialiseAudioQueue(const std::vector<MappedEvent> &audioEvents);
-    void clearAudioQueue();
-    const AudioPlayQueue *getAudioQueue() const;
+    // Recording filename
+    //
+    void setRecordingFilename(const std::string &file)
+        {  m_recordingFilename = file; }
 
-    RIFFAudioFile::SubFormat getAudioRecFileFormat() const { return m_audioRecFileFormat; }
 
+    // Audio monitoring InstrumentId
+    //
+    InstrumentId getAudioMonitoringInstrument()
+        { return m_audioMonitoringInstrument; }
+
+    void setAudioMonitoringInstrument(InstrumentId id)
+        { m_audioMonitoringInstrument = id; }
 
     // Latencies
     //
-    virtual RealTime getAudioPlayLatency() { return RealTime::zeroTime; }
-    virtual RealTime getAudioRecordLatency() { return RealTime::zeroTime; }
-    virtual RealTime getInstrumentPlayLatency(InstrumentId) { return RealTime::zeroTime; }
-    virtual RealTime getMaximumPlayLatency() { return RealTime::zeroTime; }
+    virtual RealTime getAudioPlayLatency() { return RealTime(0, 0); }
+    virtual RealTime getAudioRecordLatency() { return RealTime(0, 0); }
 
-    // Buffer sizes
-    //
     void setAudioBufferSizes(RealTime mix, RealTime read, RealTime write,
 			     int smallFileSize) {
 	m_audioMixBufferLength = mix;
@@ -365,9 +325,6 @@ public:
     RealTime getAudioWriteBufferLength() { return m_audioWriteBufferLength; }
     int getSmallFileSize() { return m_smallFileSize; }
 
-    void setLowLatencyMode(bool ll) { m_lowLatencyMode = ll; }
-    bool getLowLatencyMode() const { return m_lowLatencyMode; }
-
     // Cancel the playback of an audio file - either by instrument and audio file id
     // or by audio segment id.
     //
@@ -378,25 +335,24 @@ public:
     MappedStudio* getMappedStudio() { return m_studio; }
     void setMappedStudio(MappedStudio *studio) { m_studio = studio; }
 
+    // Arguments
+    //
+    void setArgs(const std::vector<std::string> &args) { m_args = args; }
+
     // Modify MIDI record device
     //
     void setMidiRecordDevice(DeviceId id) { m_midiRecordDevice = id; }
     DeviceId getMIDIRecordDevice() const { return m_midiRecordDevice; }
 
-    // MIDI Realtime Sync setting
+    // Set MMC state
     //
-    TransportSyncStatus getMIDISyncStatus() const { return m_midiSyncStatus; }
-    void setMIDISyncStatus(TransportSyncStatus status) { m_midiSyncStatus = status; }
+    bool isMMCEnabled() const { return m_mmcEnabled; }
+    void enableMMC(bool mmc) { m_mmcEnabled = mmc; }
 
-    // MMC master/slave setting
+    // Set MMC master/slave
     //
-    TransportSyncStatus getMMCStatus() const { return m_mmcStatus; }
-    void setMMCStatus(TransportSyncStatus status) { m_mmcStatus = status; }
-
-    // MTC master/slave setting
-    //
-    TransportSyncStatus getMTCStatus() const { return m_mtcStatus; }
-    void setMTCStatus(TransportSyncStatus status) { m_mtcStatus = status; }
+    bool isMMCMaster() const { return (m_mmcMaster && m_mmcEnabled); }
+    void setMasterMMC(bool mmc) { m_mmcMaster = mmc; }
 
     // MMC Id
     //
@@ -424,11 +380,6 @@ public:
 	m_externalTransport = transport;
     }
 
-    // Do any bits and bobs of work that need to be done continuously
-    // (this is called repeatedly whether playing or not).
-    //
-    virtual void runTasks() { }
-
     // Report a failure back to the GUI - ideally.  Default does nothing.
     //
     virtual void reportFailure(Rosegarden::MappedEvent::FailureCode) { }
@@ -437,8 +388,8 @@ protected:
     // Helper functions to be implemented by subclasses
     //
     virtual void processMidiOut(const MappedComposition &mC,
-                                const RealTime &sliceStart,
-				const RealTime &sliceEnd) = 0;
+                                bool now) = 0;
+    virtual void processAudioQueue(bool now) = 0;
     virtual void generateInstruments() = 0;
 
     // Audio
@@ -453,6 +404,7 @@ protected:
 
     // MIDI Note-off handling
     //
+    std::map<unsigned int, MappedEvent*>        m_noteOnMap;
     NoteOffQueue                                m_noteOffQueue;
 
     // This is our driver's own list of MappedInstruments and MappedDevices.  
@@ -476,22 +428,26 @@ protected:
     InstrumentId                                m_midiRunningId;
     InstrumentId                                m_audioRunningId;
 
-    // Subclass _MUST_ scavenge this regularly:
-    Scavenger<AudioPlayQueue>                   m_audioQueueScavenger;
-    AudioPlayQueue                             *m_audioQueue;
+    // Audio files playing at the driver are held here - if we're
+    // using threads then make sure you mutex access to this
+    // vector.
+    //
+    std::list<PlayableAudioFile *>              m_audioPlayQueue;
 
     // A list of AudioFiles that we can play.
     //
     std::vector<AudioFile*>                     m_audioFiles;
 
+    // Filename we should record to
+    std::string                                 m_recordingFilename;
+
+    InstrumentId                                m_audioMonitoringInstrument;
+
     RealTime m_audioMixBufferLength;
     RealTime m_audioReadBufferLength;
     RealTime m_audioWriteBufferLength;
     int m_smallFileSize;
-    bool m_lowLatencyMode;
 
-    RIFFAudioFile::SubFormat m_audioRecFileFormat;
-    
     // Virtual studio hook
     //
     MappedStudio                *m_studio;
@@ -504,11 +460,12 @@ protected:
     //
     ExternalTransport           *m_externalTransport;
 
-    // MMC and MTC status and ID
+    std::vector<std::string>     m_args;
+
+    // MMC status and ID
     //
-    TransportSyncStatus          m_midiSyncStatus;
-    TransportSyncStatus          m_mmcStatus;
-    TransportSyncStatus          m_mtcStatus;
+    bool                         m_mmcEnabled;
+    bool                         m_mmcMaster;
     MidiByte                     m_mmcId;      // device id
 
     // MIDI clock interval
