@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -20,7 +20,6 @@
 
 
 #include "SoundFile.h"
-#include "Profiler.h"
 
 
 //#define DEBUG_SOUNDFILE 1
@@ -70,7 +69,7 @@ SoundFile::getBytes(std::ifstream *file, unsigned int numberOfBytes)
         //
         file->clear();
 
-        throw(BadSoundFileException(m_fileName, "SoundFile::getBytes() - EOF encountered"));
+        throw(std::string("SoundFile::getBytes() - EOF encountered"));
     }
 
     if (!(*file)) {
@@ -101,32 +100,13 @@ SoundFile::getBytes(std::ifstream *file, unsigned int numberOfBytes)
     return rS;
 }
 
-// Read a specified number of bytes into a buffer.
-//
-size_t
-SoundFile::getBytes(std::ifstream *file, char *buf, size_t n)
-{
-    if (!(*file)) {
-        std::cerr << "SoundFile::getBytes() -  stream is not well";
-	return 0;
-    }
-
-    if (file->eof()) {
-        file->clear();
-	return 0;
-    }
-    
-    file->read(buf, n);
-    return file->gcount();
-}
-
 // A buffered read based on the current file handle.
 //
 std::string
 SoundFile::getBytes(unsigned int numberOfBytes)
 {
     if (m_inFile == 0)
-        throw(BadSoundFileException(m_fileName, "SoundFile::getBytes - no open file handle"));
+        throw(std::string("SoundFile::getBytes - no open file handle"));
 
     if (m_inFile->eof())
     {
@@ -134,7 +114,7 @@ SoundFile::getBytes(unsigned int numberOfBytes)
         //
         m_inFile->clear();
 
-        throw(BadSoundFileException(m_fileName, "SoundFile::getBytes() - EOF encountered"));
+        throw(std::string("SoundFile::getBytes() - EOF encountered"));
     }
 
 
@@ -238,12 +218,6 @@ SoundFile::putBytes(std::ofstream *file,
         *file << (FileByte) oS[i];
 }
 
-void
-SoundFile::putBytes(std::ofstream *file, const char *buffer, size_t n)
-{
-    file->write(buffer, n);
-}
-
 
 // Clip off any path from the filename
 std::string
