@@ -3,7 +3,7 @@
   Rosegarden-4
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2006
+  This program is Copyright 2000-2004
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -32,8 +32,6 @@
 #include <fstream>
 #include <string>
 
-#include "Exception.h"
-
 namespace Rosegarden
 {
 
@@ -46,24 +44,6 @@ public:
     SoundFile(const std::string &fileName);
     virtual ~SoundFile();
 
-    class BadSoundFileException : public Exception
-    {
-    public:
-	BadSoundFileException(std::string path) :
-	    Exception("Bad sound file " + path), m_path(path) { }
-	BadSoundFileException(std::string path, std::string message) :
-	    Exception("Bad sound file " + path + ": " + message), m_path(path) { }
-	BadSoundFileException(std::string path, std::string file, int line) :
-	    Exception("Bad sound file " + path, file, line), m_path(path) { }
-
-	~BadSoundFileException() throw() { }
-
-	std::string getPath() const { return m_path; }
-
-    private:
-	std::string m_path;
-    };
-
     // All files should be able open, write and close
     virtual bool open() = 0;
     virtual bool write() = 0;
@@ -105,16 +85,9 @@ protected:
     // modify the file stream
     std::string getBytes(std::ifstream *file, unsigned int numberOfBytes);
 
-    // Get n bytes from an input stream and write them into buffer.
-    // Return the actual number of bytes read.
-    size_t getBytes(std::ifstream *file, char *buffer, size_t n);
-
     // write some bytes to an output stream
     void putBytes(std::ofstream *file, const std::string outputString);
 
-    // write some bytes to an output stream
-    void putBytes(std::ofstream *file, const char *buffer, size_t n);
-
     // Read buffering - define chunk size and buffer file reading
     //
     int            m_readChunkPtr;
@@ -131,7 +104,7 @@ protected:
 
 };
 
-}
+};
 
 
 #endif // _SOUNDFILE_H_
